@@ -10,20 +10,18 @@
 #include "utils.h"
 #include "canvas.h"
 #include "canvas_private.h"
-
-#include <kdebug.h>
-
-#include "qapplication.h"
-#include "qbitmap.h"
-//#include "q3ptrdict.h"
-#include "qpainter.h"
 #include "ktlq3polygonscanner.h"
-#include "qtimer.h"
+
+#include <ktlqt3support/ktlq3scrollview.h>
+
+#include <QDebug>
+#include <QApplication>
+#include <QDesktopWidget>
+//#include "q3ptrdict.h"
+#include <QPainter>
+#include <QTimer>
 // #include "q3tl.h"
 // #include <q3pointarray.h>   // needed for q3polygonscanner
-#include <ktlqt3support/ktlq3scrollview.h>
-#include <qdesktopwidget.h>
-
 
 #include <stdlib.h>
 
@@ -265,9 +263,9 @@ void KtlQCanvas::init( const QRect & r, int chunksze, int mxclusters )
 	maxclusters=mxclusters;
 	initChunkSize( r );
 	chunks=new KtlQCanvasChunk[m_chunkSize.width()*m_chunkSize.height()];
-	update_timer = 0;
+	update_timer = nullptr;
 	bgcolor = Qt::white;
-	grid = 0;
+	grid = nullptr;
 	htiles = 0;
 	vtiles = 0;
 	debug_redraw_areas = false;
@@ -295,7 +293,7 @@ void qt_unview( KtlQCanvas * c )
 {
 	for (QList<KtlQCanvasView*>::iterator itView =c->m_viewList.begin(); itView != c->m_viewList.end(); ++itView) {
         KtlQCanvasView* view = *itView;
-		view->viewing = 0;
+		view->viewing = nullptr;
     }
 }
 
@@ -763,7 +761,7 @@ void KtlQCanvas::drawChanges(const QRect& inarea)
 		elarea.width()*chunksize,
 		elarea.height()*chunksize
 					  );
-		drawCanvasArea(elarea, NULL, /*true*/ false);
+		drawCanvasArea(elarea, nullptr, /*true*/ false);
 	}
 }
 
@@ -1196,7 +1194,7 @@ void KtlQCanvas::setTiles( QPixmap p, int h, int v, int tilewidth, int tileheigh
 		tilew = tilewidth;
 		tileh = tileheight;
 	} else {
-		grid = 0;
+		grid = nullptr;
 	}
 	if ( h + v > 10 ) {
 		int s = scm(tilewidth,tileheight);
@@ -1288,8 +1286,8 @@ KtlQCanvasView::KtlQCanvasView(QWidget* parent, const char* name, Qt::WindowFlag
 {
     setAttribute( Qt::WA_StaticContents );
 	d = new KtlQCanvasViewData;
-	viewing = 0;
-	setCanvas(0);
+	viewing = nullptr;
+	setCanvas(nullptr);
 	connect(this,SIGNAL(contentsMoving(int,int)),this,SLOT(cMoving(int,int)));
 }
 
@@ -1298,7 +1296,7 @@ KtlQCanvasView::KtlQCanvasView(KtlQCanvas* canvas, QWidget* parent, const char*
 {
     setAttribute( Qt::WA_StaticContents );
 	d = new KtlQCanvasViewData;
-	viewing = 0;
+	viewing = nullptr;
 	setCanvas(canvas);
 
 	connect(this,SIGNAL(contentsMoving(int,int)),this,SLOT(cMoving(int,int)));
@@ -1308,8 +1306,8 @@ KtlQCanvasView::KtlQCanvasView(KtlQCanvas* canvas, QWidget* parent, const char*
 KtlQCanvasView::~KtlQCanvasView()
 {
 	delete d;
-    d = NULL;
-	setCanvas(0);
+    d = nullptr;
+	setCanvas(nullptr);
 }
 
 
@@ -1440,6 +1438,3 @@ QSize KtlQCanvasView::sizeHint() const
 	return ( canvas()->size() + 2 * QSize(frameWidth(), frameWidth()) )
 			.boundedTo( 3 * QApplication::desktop()->size() / 4 );
 }
-
-
-#include "canvas.moc"
