@@ -13,11 +13,11 @@
 #include <map>
 
 #include "ktlqt3support/ktlq3scrollview.h"
-#include "qpixmap.h"
+#include <QPixmap>
 // #include "q3ptrlist.h"
-#include "qbrush.h"
-#include "qpen.h"
-#include "qlist.h"
+#include <QBrush>
+#include <QPen>
+#include <QList>
 // #include "q3pointarray.h" // 2018.08.14
 
 #include "canvasitemlist.h"
@@ -29,11 +29,11 @@ class KtlQCanvas : public QObject
 {
 	Q_OBJECT
 	public:
-		KtlQCanvas( QObject* parent = 0, const char* name = 0 );
+		KtlQCanvas( QObject* parent = nullptr, const char* name = nullptr );
 		KtlQCanvas( const int w, const int h);
 		KtlQCanvas( QPixmap p, int h, int v, int tilewidth, int tileheight );
 
-		virtual ~KtlQCanvas();
+		~KtlQCanvas() override;
 
 		virtual void setTiles( QPixmap tiles, int h, int v,
 							   int tilewidth, int tileheight );
@@ -156,9 +156,9 @@ class KtlQCanvasView : public KtlQ3ScrollView
 	Q_OBJECT
 	public:
 
-		KtlQCanvasView(QWidget* parent=0, const char* name=0, Qt::WFlags f=0); // 2018.08.15 - unused?
-		KtlQCanvasView(KtlQCanvas* viewing, QWidget* parent=0, const char* name=0, Qt::WFlags f=0);
-		~KtlQCanvasView();
+		KtlQCanvasView(QWidget* parent = nullptr, const char* name = nullptr, Qt::WindowFlags f = {}); // 2018.08.15 - unused?
+		KtlQCanvasView(KtlQCanvas* viewing, QWidget* parent = nullptr, const char* name = nullptr, Qt::WindowFlags f = {});
+		~KtlQCanvasView() override;
 
 		KtlQCanvas* canvas() const
 		{ return viewing; }
@@ -170,11 +170,11 @@ class KtlQCanvasView : public KtlQ3ScrollView
 
 	protected:
         /** overrides KtlQ3ScrollView::drawContents() */   // override paintEvent?
-		virtual void drawContents( QPainter*, int cx, int cy, int cw, int ch );
-		QSize sizeHint() const;
+		void drawContents( QPainter*, int cx, int cy, int cw, int ch ) override;
+		QSize sizeHint() const override;
 
 	private:
-		void drawContents( QPainter* );
+		void drawContents( QPainter* ) override;
 		KtlQCanvas* viewing;
 		KtlQCanvasViewData* d;
 		friend void qt_unview(KtlQCanvas* c);
