@@ -12,11 +12,12 @@
 #include "canvasitemparts.h"
 #include "eventinfo.h"
 
-#include <qevent.h>
+#include <QWheelEvent>
+#include <QMouseEvent>
 
 // #include <q3button.h>
 
-#include <kdebug.h>
+#include <QDebug>
 
 CIWidgetMgr::CIWidgetMgr( KtlQCanvas *canvas, CNItem *item )
 {
@@ -59,7 +60,7 @@ Widget *CIWidgetMgr::widgetWithID( const QString &id ) const
 {
 	WidgetMap::const_iterator it = m_widgetMap.find(id);
 	if ( it == m_widgetMap.end() )
-		return 0l;
+		return nullptr;
 	else return it.value();
 }
 
@@ -126,7 +127,7 @@ Button* CIWidgetMgr::addButton( const QString &id, const QRect & pos, const QStr
 	}
 	else
 	{
-		kWarning() << "CIWidgetMgr::addButton: Attempting to re-add button with same id as previous"<<endl;
+		qWarning() << "CIWidgetMgr::addButton: Attempting to re-add button with same id as previous"<<endl;
 		delete it.value();
 		it.value() = button;
 	}
@@ -150,7 +151,7 @@ Button* CIWidgetMgr::addButton( const QString &id, const QRect & pos, const QIco
 	}
 	else
 	{
-		kWarning() << "CIWidgetMgr::addButton: Attempting to re-add button with same id as previous"<<endl;
+		qWarning() << "CIWidgetMgr::addButton: Attempting to re-add button with same id as previous"<<endl;
 		delete it.value();
 		it.value() = button;
 	}
@@ -178,9 +179,9 @@ Slider* CIWidgetMgr::addSlider( const QString &id, int minValue, int maxValue, i
 	}
 	else
 	{
-		kWarning() << "CIWidgetMgr::addSlider: Attempting to re-add slider with same id as previous"<<endl;
+		qWarning() << "CIWidgetMgr::addSlider: Attempting to re-add slider with same id as previous"<<endl;
 		delete slider;
-		return 0l;
+		return nullptr;
 	}
 	
 	p_cnItem->updateAttachedPositioning();
@@ -297,7 +298,7 @@ void CIWidgetMgr::enterEvent(QEvent *)
 	const WidgetMap::iterator widgetMapEnd = m_widgetMap.end();
 	for ( WidgetMap::iterator it = m_widgetMap.begin(); it != widgetMapEnd; ++it )
 	{
-		it.value()->enterEvent(0);
+		it.value()->enterEvent(nullptr);
 	}
 }
 
@@ -307,7 +308,7 @@ void CIWidgetMgr::leaveEvent(QEvent *)
 	const WidgetMap::iterator widgetMapEnd = m_widgetMap.end();
 	for ( WidgetMap::iterator it = m_widgetMap.begin(); it != widgetMapEnd; ++it )
 	{
-		it.value()->leaveEvent(0);
+		it.value()->leaveEvent(nullptr);
 	}
 }
 
