@@ -13,7 +13,7 @@
 
 //#include <canvas.h> // 2018.10.16 - not needed
 #include "canvasitems.h"
-#include <qpointer.h>
+#include <QPointer>
 // #include <q3valuevector.h>
 
 class Cell;
@@ -41,8 +41,8 @@ class Connector : /* public QObject, */ public KtlQCanvasPolygon {
 	Q_OBJECT
 
 public:
-	Connector(Node *startNode, Node *endNode, ICNDocument *_ICNDocument, QString *id = 0L);
-	~Connector();
+	Connector(Node *startNode, Node *endNode, ICNDocument *_ICNDocument, QString *id = nullptr);
+	~Connector() override;
 
 	/**
 	 * Node at start of connector (which refers to this as the output connector)
@@ -67,7 +67,7 @@ public:
 	/**
 	 * If selected, will be drawn in a different colour
 	 */
-	virtual void setSelected(bool yes);
+	void setSelected(bool yes) override;
 
 	/**
 	 * Connected id
@@ -166,16 +166,14 @@ public:
 	 * the translation is useful, etc.
 	 */
 	void translateRoute(int dx, int dy);
-	virtual void setVisible(bool yes);
+	void setVisible(bool yes) override;
 
 	/**
 	Methods relating to wire lists
 	*/
 	WireVector wires() const { return m_wires; }
 	unsigned numWires() const { return m_wires.size(); }
-	Wire *wire(unsigned num = 0) const ; /* {
-		return (num < m_wires.size()) ? m_wires[num] : 0;
-	} */
+	Wire* wire(unsigned num=0) const;
 
 	void updateConnectorLines(bool forceRedraw = false);
 
@@ -197,14 +195,14 @@ signals:
 	void numWiresChanged(unsigned newNum);
 
 public slots:
-	void removeConnector(Node* = 0);
+	void removeConnector(Node* = nullptr);
 
 //protected:
 //	bool m_bIsSyncingWires;
 
 protected:
 	WireVector        m_wires;
-		
+
 private:
 
 	bool b_semiHidden;
@@ -243,7 +241,7 @@ public:
 	void setAnimateCurrent(bool animateCurrent) { m_bAnimateCurrent = animateCurrent; }
 
 protected:
-	virtual void drawShape(QPainter &p);
+	void drawShape(QPainter &p) override;
 
 	Connector *m_pConnector;
 	int  m_pixelOffset;
