@@ -10,20 +10,21 @@
 #ifndef KTECHLAB_CORE_MAIN_H__
 #define KTECHLAB_CORE_MAIN_H__
 
-#include <QMotifStyle>
+// #include <QMotifStyle>
+#include <QProxyStyle>
 
 /**
  * see approach from here:
  * http://stackoverflow.com/questions/5909907/drawing-an-overlay-on-top-of-an-applications-window
  */
-class DiagnosticStyle : public QMotifStyle
+class DiagnosticStyle : public QProxyStyle
 {
 Q_OBJECT
 
 public:
-    typedef QMotifStyle BaseStyle;
-    void drawControl(ControlElement element, const QStyleOption* option, QPainter* painter, const QWidget* widget) const;
-    virtual ~DiagnosticStyle() { }
+    typedef QProxyStyle BaseStyle;
+    void drawControl(ControlElement element, const QStyleOption* option, QPainter* painter, const QWidget* widget) const override;
+    ~DiagnosticStyle() override { }
 };
 
 #endif // KTECHLAB_CORE_MAIN_H__
