@@ -16,16 +16,16 @@
 #include "gpsimprocessor.h"
 #include "textdocument.h"
 
-#include <kdebug.h>
+#include <QDebug>
 // #include <k3staticdeleter.h>
-#include <kglobal.h>
+#include <QGlobalStatic>
 
 
 //BEGIN class DebugManager
-// DebugManager * DebugManager::m_pSelf = 0l; // 2017.10.10 - use K_GLOBAL_STATIC
+// DebugManager * DebugManager::m_pSelf = nullptr; // 2017.10.10 - use K_GLOBAL_STATIC
 // static K3StaticDeleter<DebugManager> staticDebugManagerDeleter;
 
-K_GLOBAL_STATIC( DebugManager, globalDebugManager);
+Q_GLOBAL_STATIC( DebugManager, globalDebugManager);
 
 DebugManager * DebugManager::self()
 {
@@ -55,8 +55,8 @@ void DebugManager::registerGpsim( GpsimProcessor * gpsim )
 	QStringList::const_iterator end = files.end();
 	for ( QStringList::const_iterator it = files.begin(); it != end; ++it )
 	{
-		if ( TextDocument * doc = dynamic_cast<TextDocument*>(DocManager::self()->findDocument(*it)) )
-		{
+		const QUrl url = QUrl::fromLocalFile(*it);
+		if (TextDocument * doc = dynamic_cast<TextDocument*>(DocManager::self()->findDocument(url))) {
 			if ( !doc->debuggerIsRunning() )
 				doc->setDebugger( gpsim->currentDebugger(), false );
 		}
@@ -69,7 +69,7 @@ void DebugManager::urlOpened( TextDocument * td )
 	if ( td->debuggerIsRunning() )
 		return;
 	
-	m_processors.removeAll( (GpsimProcessor*)0l );
+	m_processors.removeAll( (GpsimProcessor*)nullptr );
 	GpsimProcessorList::iterator end = m_processors.end();
 	for ( GpsimProcessorList::iterator it = m_processors.begin(); it != end; ++it )
 	{
@@ -84,7 +84,4 @@ void DebugManager::urlOpened( TextDocument * td )
 }
 //END class DebugManager
 
-
-#include "debugmanager.moc"
-
 #endif
