@@ -20,18 +20,19 @@
 #include "textview.h"
 #include "viewcontainer.h"
 
-#include <klocalizedstring.h>
-#include <kmessagebox.h>
-#include <ktabwidget.h>
-#include <kxmlguifactory.h>
+#include <KLocalizedString>
+#include <KMessageBox>
+#include <KXMLGUIFactory>
 
-#include <qfile.h>
+#include <QTabWidget>
+#include <QAction>
+#include <QFile>
 
 #include <cassert>
 
 #include <ktlconfig.h>
 
-DocManager * DocManager::m_pSelf = 0l;
+DocManager * DocManager::m_pSelf = nullptr;
 
 DocManager * DocManager::self()
 {
@@ -45,12 +46,12 @@ DocManager * DocManager::self()
 DocManager::DocManager()
 	: QObject( KTechlab::self() )
 {
-	p_focusedView = 0l;
+	p_focusedView = nullptr;
 	m_countCircuit = 0;
 	m_countFlowCode = 0;
 	m_countMechanics = 0;
 	m_countOther = 0;
-	p_connectedDocument = 0;
+	p_connectedDocument = nullptr;
 	m_nextDocumentID = 1;
 	m_pIface = new DocManagerIface(this);
 }
@@ -77,10 +78,10 @@ bool DocManager::closeAll()
 }
 
 
-void DocManager::gotoTextLine( const KUrl &url, int line )
+void DocManager::gotoTextLine( const QUrl &url, int line )
 {
 	TextDocument * doc = dynamic_cast<TextDocument*>( openURL(url) );
-	TextView * tv = doc ? doc->textView() : 0l;
+	TextView * tv = doc ? doc->textView() : nullptr;
 	
 	if ( !tv ) return;
 	
@@ -89,17 +90,17 @@ void DocManager::gotoTextLine( const KUrl &url, int line )
 }
 
 
-Document* DocManager::openURL( const KUrl &url, ViewArea *viewArea )
+Document* DocManager::openURL( const QUrl &url, ViewArea *viewArea )
 {
-	if ( url.isEmpty() ) return 0;
+	if ( url.isEmpty() ) return nullptr;
 	
 	if ( url.isLocalFile() )
 	{
-		QFile file(url.path());
+		QFile file(url.toLocalFile());
 		if ( file.open(QIODevice::ReadOnly) == false )
 		{
-			KMessageBox::sorry( 0l, i18n( "Could not open '%1'", url.prettyUrl() ) );
-			return 0l;
+			KMessageBox::sorry(nullptr, i18n( "Could not open '%1'", file.fileName()));
+			return nullptr;
 		}
 		file.close();
 	}
@@ -143,8 +144,8 @@ Document* DocManager::openURL( const KUrl &url, ViewArea *viewArea )
 
 Document *DocManager::getFocusedDocument() const
 {
-	Document * doc = p_focusedView ? p_focusedView->document() : 0l;
-	return (doc && !doc->isDeleted()) ? doc : 0l;
+	Document * doc = p_focusedView ? p_focusedView->document() : nullptr;
+	return (doc && !doc->isDeleted()) ? doc : nullptr;
 }
 
 
@@ -209,7 +210,7 @@ QString DocManager::untitledName( int type )
 }
 
 
-Document *DocManager::findDocument( const KUrl &url ) const
+Document *DocManager::findDocument( const QUrl &url ) const
 {
 	// First, look in the associated documents
 	if ( m_associatedDocuments.contains(url) )
@@ -223,11 +224,11 @@ Document *DocManager::findDocument( const KUrl &url ) const
 			return *it;
 	}
 	
-	return 0l;
+	return nullptr;
 }
 
 
-void DocManager::associateDocument( const KUrl &url, Document *document )
+void DocManager::associateDocument( const QUrl &url, Document *document )
 {
 	if (!document)
 		return;
@@ -266,8 +267,10 @@ void DocManager::handleNewDocument( Document *document, ViewArea *viewArea )
 	document->setDCOPID(m_nextDocumentID++);
 	
 	connect( document, SIGNAL(modifiedStateChanged()), KTechlab::self(), SLOT(slotDocModifiedChanged()) );
-	connect( document, SIGNAL(fileNameChanged(const KUrl&)), KTechlab::self(), SLOT(slotDocModifiedChanged()) );
-	connect( document, SIGNAL(fileNameChanged(const KUrl&)), KTechlab::self(), SLOT(addRecentFile(const KUrl&)) );
+	connect( document, &Document::fileNameChanged,
+	         KTechlab::self(), &KTechlab::slotDocModifiedChanged);
+	connect( document, &Document::fileNameChanged,
+	         KTechlab::self(), &KTechlab::addRecentFile);
 	connect( document, SIGNAL(destroyed(QObject* )), this, SLOT(documentDestroyed(QObject* )) );
 	connect( document, SIGNAL(viewFocused(View* )), this, SLOT(slotViewFocused(View* )) );
 	connect( document, SIGNAL(viewUnfocused()), this, SLOT(slotViewUnfocused()) );
@@ -279,9 +282,9 @@ void DocManager::handleNewDocument( Document *document, ViewArea *viewArea )
 View *DocManager::createNewView( Document *document, ViewArea *viewArea )
 {
 	if (!document)
-		return 0l;
+		return nullptr;
 	
-	View *view = 0l;
+	View *view = nullptr;
 	
 	if (viewArea)
 		view = document->createView( viewArea->viewContainer(), viewArea->id() );
@@ -310,7 +313,7 @@ void DocManager::slotViewFocused( View *view )
 {
 	ViewContainer * vc = static_cast<ViewContainer*>(KTechlab::self()->tabWidget()->currentWidget());
 	if (!vc)
-		view = 0l;
+		view = nullptr;
 	
 	if (!view)
 		return;
@@ -367,11 +370,11 @@ void DocManager::slotViewUnfocused()
 	if (p_connectedDocument)
 	{
 		disconnect( p_connectedDocument, SIGNAL(undoRedoStateChanged()), KTechlab::self(), SLOT(slotDocUndoRedoChanged()) );
-		p_connectedDocument = 0l;
+		p_connectedDocument = nullptr;
 	}
 	
-	ItemInterface::self()->slotItemDocumentChanged(0l);
-	p_focusedView = 0l;
+	ItemInterface::self()->slotItemDocumentChanged(nullptr);
+	p_focusedView = nullptr;
 	
 // 	KTechlab::self()->setCaption( 0 );
 	KTechlab::self()->requestUpdateCaptions();
@@ -435,15 +438,15 @@ MechanicsDocument *DocManager::createMechanicsDocument()
 }
 
 
-CircuitDocument *DocManager::openCircuitFile( const KUrl &url, ViewArea *viewArea )
+CircuitDocument *DocManager::openCircuitFile( const QUrl &url, ViewArea *viewArea )
 {
-	CircuitDocument *document = new CircuitDocument( url.fileName().remove(url.directory()) );
+	CircuitDocument *document = new CircuitDocument( url.fileName() );
 	
 	if ( !document->openURL(url) )
 	{
-		KMessageBox::sorry( 0l, i18n("Could not open Circuit file \"%1\"", url.prettyUrl()) );
+		KMessageBox::sorry(nullptr, i18n("Could not open Circuit file \"%1\"", url.toDisplayString(QUrl::PreferLocalFile)));
 		document->deleteLater();
-		return 0l;
+		return nullptr;
 	}
 	
 	handleNewDocument( document, viewArea );
@@ -452,15 +455,15 @@ CircuitDocument *DocManager::openCircuitFile( const KUrl &url, ViewArea *viewAre
 }
 
 
-FlowCodeDocument *DocManager::openFlowCodeFile( const KUrl &url, ViewArea *viewArea )
+FlowCodeDocument *DocManager::openFlowCodeFile( const QUrl &url, ViewArea *viewArea )
 {
-	FlowCodeDocument *document = new FlowCodeDocument( url.fileName().remove(url.directory()) );
+	FlowCodeDocument *document = new FlowCodeDocument( url.fileName() );
 	
 	if ( !document->openURL(url) )
 	{
-		KMessageBox::sorry( 0l, i18n("Could not open FlowCode file \"%1\"", url.prettyUrl()) );
+		KMessageBox::sorry(nullptr, i18n("Could not open FlowCode file \"%1\"", url.toDisplayString(QUrl::PreferLocalFile)));
 		document->deleteLater();
-		return 0l;
+		return nullptr;
 	}
 	
 	handleNewDocument( document, viewArea );
@@ -469,15 +472,15 @@ FlowCodeDocument *DocManager::openFlowCodeFile( const KUrl &url, ViewArea *viewA
 }
 
 
-MechanicsDocument *DocManager::openMechanicsFile( const KUrl &url, ViewArea *viewArea )
+MechanicsDocument *DocManager::openMechanicsFile( const QUrl &url, ViewArea *viewArea )
 {
-	MechanicsDocument *document = new MechanicsDocument( url.fileName().remove(url.directory()) );
+	MechanicsDocument *document = new MechanicsDocument( url.fileName() );
 	
 	if ( !document->openURL(url) )
 	{
-		KMessageBox::sorry( 0l, i18n("Could not open Mechanics file \"%1\"", url.prettyUrl()) );
+		KMessageBox::sorry(nullptr, i18n("Could not open Mechanics file \"%1\"", url.toDisplayString(QUrl::PreferLocalFile)));
 		document->deleteLater();
-		return 0l;
+		return nullptr;
 	}
 	
 	handleNewDocument( document, viewArea );
@@ -487,24 +490,21 @@ MechanicsDocument *DocManager::openMechanicsFile( const KUrl &url, ViewArea *vie
 }
 
 
-TextDocument *DocManager::openTextFile( const KUrl &url, ViewArea *viewArea )
+TextDocument *DocManager::openTextFile( const QUrl &url, ViewArea *viewArea )
 {
-	TextDocument *document = TextDocument::constructTextDocument( url.fileName().remove(url.directory()) );
+	TextDocument *document = TextDocument::constructTextDocument( url.fileName() );
 	
 	if (!document)
-		return 0l;
+		return nullptr;
 	
 	if ( !document->openURL(url) )
 	{
-		KMessageBox::sorry( 0l, i18n("Could not open text file \"%1\"", url.prettyUrl()) );
+		KMessageBox::sorry(nullptr, i18n("Could not open text file \"%1\"", url.toDisplayString(QUrl::PreferLocalFile)));
 		document->deleteLater();
-		return 0l;
+		return nullptr;
 	}
 	
 	handleNewDocument( document, viewArea );
 	emit fileOpened(url);
 	return document;
 }
-
-
-#include "docmanager.moc"
