@@ -13,9 +13,8 @@
 
 #include "view.h"
 
-#include <kurl.h>
-
-#include <qpointer.h>
+#include <QUrl>
+#include <QPointer>
 
 class CircuitDocument;
 class DocManager;
@@ -28,11 +27,8 @@ class TextDocument;
 class View;
 class ViewArea;
 
-class KAction;
-
 typedef QList<Document*> DocumentList;
-typedef QMap< KUrl, Document* > URLDocumentMap;
-typedef QList<KAction*> KActionList;
+typedef QMap<QUrl, Document*> URLDocumentMap;
 
 /**
 @author David Saxton
@@ -45,7 +41,7 @@ Q_OBJECT
 
 public:
 	static DocManager * self();
-	~DocManager();
+	~DocManager() override;
 	
 	/**
 	 * Attempts to close all open documents, returning true if successful
@@ -54,12 +50,12 @@ public:
 	/**
 	 * Goes to the given line in the given text file (if the file exists)
 	 */
-	void gotoTextLine( const KUrl &url, int line );
+	void gotoTextLine( const QUrl &url, int line );
 	/**
 	 * Attempts to open the document at the given url.
 	 * @param viewArea if non-null, will open the new view into the ViewArea
 	 */
-	Document* openURL( const KUrl &url, ViewArea *viewArea = 0l );
+	Document* openURL( const QUrl &url, ViewArea *viewArea = nullptr );
 	/**
 	 * Returns the focused View
 	 */
@@ -79,19 +75,19 @@ public:
 	 * returns a pointer to that Document if so - otherwises returns null
 	 * @see associateDocument
 	 */
-	Document *findDocument( const KUrl &url ) const;
+	Document *findDocument( const QUrl &url ) const;
 	/**
 	 * Associates a url with a pointer to a document. When findFile is called
 	 * with the given url, it will return a pointer to this document if it still
 	 * exists.
 	 * @see findDocument
 	 */
-	void associateDocument( const KUrl &url, Document *document );
+	void associateDocument( const QUrl &url, Document *document );
 	/**
 	 * Gives the given document focus. If it has no open views, one will be
 	 * created for it if viewAreaForNew is non-null
 	 */
-	void giveDocumentFocus( Document * toFocus, ViewArea * viewAreaForNew = 0l );
+	void giveDocumentFocus( Document * toFocus, ViewArea * viewAreaForNew = nullptr );
 	void removeDocumentAssociations( Document *document );
 	void disableContextActions();
 	
@@ -120,7 +116,7 @@ signals:
 	/**
 	 * Emitted when a file is successfully opened
 	 */
-	void fileOpened( const KUrl &url );
+	void fileOpened( const QUrl &url );
 	
 protected slots:
 	/**
@@ -138,16 +134,16 @@ protected:
 	 * This function should be called after creating a new document to add it
 	 * to the appropriate lists and connect it up as appropriate
 	 */
-	void handleNewDocument( Document *document, ViewArea *viewArea = 0l );
+	void handleNewDocument( Document *document, ViewArea *viewArea = nullptr );
 	/**
 	 * Takes the document, creates a new view and shoves it in a new
 	 * ViewContainer
 	 */
-	View *createNewView( Document *document, ViewArea *viewArea = 0l );
-	CircuitDocument *openCircuitFile( const KUrl &url, ViewArea *viewArea = 0l );
-	FlowCodeDocument *openFlowCodeFile( const KUrl &url, ViewArea *viewArea = 0l );
-	MechanicsDocument *openMechanicsFile( const KUrl &url, ViewArea *viewArea = 0l );
-	TextDocument *openTextFile( const KUrl &url, ViewArea *viewArea = 0l );
+	View *createNewView( Document *document, ViewArea *viewArea = nullptr );
+	CircuitDocument *openCircuitFile( const QUrl &url, ViewArea *viewArea = nullptr );
+	FlowCodeDocument *openFlowCodeFile( const QUrl &url, ViewArea *viewArea = nullptr );
+	MechanicsDocument *openMechanicsFile( const QUrl &url, ViewArea *viewArea = nullptr );
+	TextDocument *openTextFile( const QUrl &url, ViewArea *viewArea = nullptr );
 	
 	DocumentList m_documentList;
 	URLDocumentMap m_associatedDocuments;
