@@ -16,17 +16,18 @@
 #include "view.h"
 #include "viewcontainer.h"
 
-#include <kfiledialog.h>
-#include <klocalizedstring.h>
-#include <kmessagebox.h>
-#include <ktabwidget.h>
+#include <KLocalizedString>
+#include <KMessageBox>
+
+#include <QTabWidget>
+#include <QFileDialog>
 
 Document::Document( const QString &caption, const char *name )
 	: QObject( KTechlab::self() /* , name */ ),
 	b_modified(false),
-	m_pDocumentIface(0),
+	m_pDocumentIface(nullptr),
 	m_bDeleted(false),
-	m_pActiveView(0),
+	m_pActiveView(nullptr),
 	m_caption(caption),
 	m_bAddToProjectOnSave(false),
 	m_dcopID(0),
@@ -75,7 +76,7 @@ void Document::slotViewDestroyed( QObject *obj )
 	
 	if ( m_pActiveView == (QPointer<View>)view )
 	{
-		m_pActiveView = 0l;
+		m_pActiveView = nullptr;
 		emit viewUnfocused();
 	}
 	
@@ -104,11 +105,11 @@ void Document::setCaption( const QString &caption )
 
 bool Document::getURL( const QString &types )
 {
-	KUrl url = KFileDialog::getSaveUrl( KUrl(), types, KTechlab::self(), i18n("Save Location"));
+	QUrl url = QFileDialog::getSaveFileUrl(KTechlab::self(), i18n("Save Location"), QUrl(), types);
 	
 	if ( url.isEmpty() ) return false;
 	
-	if ( QFile::exists( url.path() ) )
+	if (url.isLocalFile() && QFile::exists(url.toLocalFile()))
 	{
 		int query = KMessageBox::warningYesNo( KTechlab::self(),
 			   i18n( "A file named \"%1\" already exists. Are you sure you want to overwrite it?", url.fileName() ),
@@ -130,21 +131,14 @@ bool Document::fileClose()
 		// If the filename is empty then it must  be an untitled file.
 		QString name = m_url.fileName().isEmpty() ? caption() : m_url.fileName();
 		
-		if ( ViewContainer * viewContainer = (activeView() ? activeView()->viewContainer() : 0l) )
+		if ( ViewContainer * viewContainer = (activeView() ? activeView()->viewContainer() : nullptr) )
 			KTechlab::self()->tabWidget()->setCurrentIndex( KTechlab::self()->tabWidget()->indexOf(viewContainer) );
 		
-		KGuiItem saveItem = KStandardGuiItem::yes();
-		saveItem.setText( i18n("Save") );
-		saveItem.setIconName( "document-save" );
-		
-		KGuiItem discardItem = KStandardGuiItem::no();
-		discardItem.setText( i18n("Discard") );
-		
 		int choice = KMessageBox::warningYesNoCancel( KTechlab::self(),
 				i18n("The document \'%1\' has been modified.\nDo you want to save it?", name),
 				i18n("Save Document?"),
-				saveItem,
-				discardItem );
+				KStandardGuiItem::save(),
+				KStandardGuiItem::discard() );
 		
 		if ( choice == KMessageBox::Cancel )
 			return false;
@@ -167,7 +161,7 @@ void Document::setModified( bool modified )
 }
 
 
-void Document::setURL( const KUrl &url )
+void Document::setURL( const QUrl &url )
 {
 	if ( m_url == url ) return;
 	
@@ -201,5 +195,3 @@ void Document::setDCOPID( unsigned id )
 		m_pDocumentIface->setObjId( "Document#" + docID );
 	}
 }
-
-#include "document.moc"
