@@ -13,8 +13,8 @@
 #include "drawpart.h"
 #include "variant.h"
 
-#include <klocalizedstring.h>
-#include <qbitarray.h>
+#include <KLocalizedString>
+#include <QBitArray>
 
 DrawPart::DrawPart( ItemDocument *itemDocument, bool newItem, const char *id )
 	: Item( itemDocument, newItem, id )
