@@ -20,7 +20,7 @@
 #include "junctionnode.h"
 #include "nodegroup.h"
 
-#include <kdebug.h>
+#include <QDebug>
 
 CircuitICNDocument::CircuitICNDocument( const QString &caption, const char *name)
 	: ICNDocument(caption, name )
@@ -34,7 +34,7 @@ CircuitICNDocument::~CircuitICNDocument()
 	KtlQCanvasItemList all = m_canvas->allItems();
 	const KtlQCanvasItemList::Iterator end = all.end();
 	for ( KtlQCanvasItemList::Iterator it= all.begin(); it != end; ++it )
-		(*it)->setCanvas(0l);
+		(*it)->setCanvas(nullptr);
 	
 	// Remove all items from the canvas
 	selectAll();
@@ -63,7 +63,7 @@ void CircuitICNDocument::deleteAllNodes() {
             ECNode *ecNode = it.value();
             //unregisterUID( ecNode->id() ); // do not use, will modify m_ecNodeList
             ICNDocument::unregisterUID( ecNode->id() );
-            ecNode->setICNDocument( NULL );
+            ecNode->setICNDocument( nullptr );
         }
 
 
@@ -91,7 +91,7 @@ bool CircuitICNDocument::canConnect( KtlQCanvasItem *qcanvasItem1, KtlQCanvasIte
 
 Connector * CircuitICNDocument::createConnector( Node *node, Connector *con, const QPoint &pos2, QPointList *pointList )
 {
-	if(!canConnect( node, con ) ) return 0;
+	if(!canConnect( node, con ) ) return nullptr;
 	
 	// FIXME dynamic_cast used, fix it in Connector class
 	
@@ -149,7 +149,7 @@ Connector * CircuitICNDocument::createConnector( Node *node, Connector *con, con
 
 Connector *CircuitICNDocument::createConnector(Connector *con1, Connector *con2, const QPoint &pos1, const QPoint &pos2, QPointList *pointList )
 {
-	if ( !canConnect( con1, con2 ) ) return 0;
+	if ( !canConnect( con1, con2 ) ) return nullptr;
 	
 	const bool con1UsedManual = con1->usesManualPoints();
 	const bool con2UsedManual = con2->usesManualPoints();
@@ -163,7 +163,7 @@ Connector *CircuitICNDocument::createConnector(Connector *con1, Connector *con2,
 	ECNode *node2a = dynamic_cast<ECNode*> ( con2->startNode() );
 	ECNode *node2b = dynamic_cast<ECNode*> ( con2->endNode(  ) );
 	
-	if ( !node1a || !node1b || !node2a || !node2b ) return 0;
+	if ( !node1a || !node1b || !node2a || !node2b ) return nullptr;
 	
 	con1->hide();	
 	con2->hide();
@@ -191,7 +191,7 @@ Connector *CircuitICNDocument::createConnector(Connector *con1, Connector *con2,
 	if(!con1a || !con1b || !con2a || !con2b ) {
 		// This should never happen, as the canConnect function should strictly
 		// determine whether the connectors could be created before hand.
-		kWarning() << k_funcinfo << "Not all the connectors were created, this should never happen" << endl;
+		qWarning() << Q_FUNC_INFO << "Not all the connectors were created, this should never happen" << endl;
 		
 		if(con1a) con1a->removeConnector();
 		if(con1b) con1b->removeConnector();
@@ -202,7 +202,7 @@ Connector *CircuitICNDocument::createConnector(Connector *con1, Connector *con2,
 		newNode2->removeNode();
 		
 		flushDeleteList();
-		return 0;
+		return nullptr;
 	}
 	
 	con1a->setRoutePoints(oldCon1Points.at(0), con1UsedManual );
@@ -258,16 +258,16 @@ Connector *CircuitICNDocument::createConnector( const QString &startNodeId, cons
 	ECNode *endNode = getEcNodeWithID(endNodeId);
 	
 	if ( !startNode || !endNode ) {
-		kDebug() << "Either/both the connector start node and end node could not be found" << endl;
-		return 0L;
+		qDebug() << "Either/both the connector start node and end node could not be found" << endl;
+		return nullptr;
 	}
 	
-	if ( !canConnect( startNode, endNode ) ) return 0l;
+	if ( !canConnect( startNode, endNode ) ) return nullptr;
 	
 	Connector *connector = endNode->createConnector(startNode);
 	if (!connector) {
-		kError() << k_funcinfo << "End node did not create the connector" << endl;
-		return 0l;
+		qCritical() << Q_FUNC_INFO << "End node did not create the connector" << endl;
+		return nullptr;
 	}
 
 	startNode->addConnector(connector);
@@ -291,14 +291,14 @@ Node *CircuitICNDocument::nodeWithID( const QString &id )
 {
 	if ( m_ecNodeList.contains( id ) )
 		return m_ecNodeList[id];
-	else	return 0;
+	else	return nullptr;
 }
 
 ECNode *CircuitICNDocument::getEcNodeWithID( const QString &id )
 {
 	if ( m_ecNodeList.contains( id ) )
 		return m_ecNodeList[id];
-	else	return 0;
+	else	return nullptr;
 }
 
 void CircuitICNDocument::slotAssignNodeGroups()
@@ -330,11 +330,11 @@ void CircuitICNDocument::flushDeleteList()
 	for ( KtlQCanvasItemList::iterator it = m_itemDeleteList.begin(); it != end; ++it )
 	{
 		if ( *it && (m_itemDeleteList.count( *it ) > 1) ) {
-			*it = 0;
+			*it = nullptr;
 		}
 	}
 
-	m_itemDeleteList.removeAll(0);
+	m_itemDeleteList.removeAll(nullptr);
 
 /* again we're spending time to figure out what special method to call instead of a generic call..*/
 	end = m_itemDeleteList.end();
@@ -349,12 +349,12 @@ void CircuitICNDocument::flushDeleteList()
 			m_ecNodeList.remove ( node->id() );
 		else if ( Connector * con = dynamic_cast<Connector*> ( qcanvasItem ) )
 			m_connectorList.removeAll ( con );
-		else	kError() << k_funcinfo << "Unknown qcanvasItem! "<<qcanvasItem << endl;
+		else	qCritical() << Q_FUNC_INFO << "Unknown qcanvasItem! "<<qcanvasItem << endl;
 
-		qcanvasItem->setCanvas(0);
+		qcanvasItem->setCanvas(nullptr);
 
 		delete qcanvasItem;
-		*it = 0;
+		*it = nullptr;
 	}
 
 // 	// Check connectors for merging
@@ -389,7 +389,7 @@ bool CircuitICNDocument::registerItem( KtlQCanvasItem *qcanvasItem )
 			m_connectorList.append(connector);
 			emit connectorAdded(connector);
 		} else {
-			kError() << k_funcinfo << "Unrecognised item"<<endl;
+			qCritical() << Q_FUNC_INFO << "Unrecognised item"<<endl;
 			return false;
 		}
 	}
@@ -440,8 +440,8 @@ bool CircuitICNDocument::joinConnectors( ECNode *node )
 	if ( conCount != 2 ) return false;
 
 	Connector *con1, *con2;
-	ECNode *startNode = NULL;
-    ECNode *endNode = NULL;
+	ECNode *startNode = nullptr;
+    ECNode *endNode = nullptr;
 	QPointList conPoints;
 
 	con1 = node->connectorList().at(0).data();
@@ -481,7 +481,3 @@ bool CircuitICNDocument::joinConnectors( ECNode *node )
 	
 	return true;
 }
-
-
-#include "circuiticndocument.moc"
-
