@@ -37,12 +37,13 @@
 #include "voltagesignal.h"
 #include "voltagesource.h"
 
+
 #include <cmath>
-#include <kdebug.h>
-#include <qbitarray.h>
-#include <qpainter.h>
-#include <qwidget.h>
-#include <qmatrix.h>
+#include <QMatrix>
+#include <QDebug>
+#include <QBitArray>
+#include <QPainter>
+#include <QWidget>
 
 #include <ktlconfig.h>
 
@@ -60,8 +61,8 @@ Component::Component( ICNDocument *icnDocument, bool newItem, const QString &id
 
     for ( int i=0; i<4; ++i )
     {
-        m_pPNode[i] = 0l;
-        m_pNNode[i] = 0l;
+        m_pPNode[i] = nullptr;
+        m_pNNode[i] = nullptr;
     }
 
     // Get configuration options
@@ -304,7 +305,7 @@ void Component::updateAttachedPositioning()
     for ( NodeInfoMap::iterator it = m_nodeMap.begin(); it != end; ++it )
     {
         if ( !it.value().node )
-            kError() << k_funcinfo << "Node in nodemap is null" << endl;
+            qCritical() << Q_FUNC_INFO << "Node in nodemap is null" << endl;
         else
         {
             int nx = int((std::cos(m_angleDegrees * RPD) * it.value().x) - (std::sin(m_angleDegrees * RPD) * it.value().y));
@@ -602,7 +603,7 @@ ECNode* Component::ecNodeWithID( const QString &ecNodeId )
 {
     if ( !p_icnDocument )
     {
-// 		kDebug() << "Warning: ecNodeWithID("<<ecNodeId<<") does not exist\n";
+// 		qDebug() << "Warning: ecNodeWithID("<<ecNodeId<<") does not exist\n";
         return createPin( 0, 0, 0, ecNodeId );
     }
 
@@ -679,7 +680,7 @@ LogicOut *Component::createLogicOut( ECNode *node, bool isHigh )
 
 MOSFET *Component::createMOSFET( ECNode * D, ECNode * G, ECNode * S, ECNode * B, int MOSFET_type )
 {
-    return createMOSFET( D->pin(), G->pin(), S->pin(), B ? B->pin() : 0, MOSFET_type );
+    return createMOSFET( D->pin(), G->pin(), S->pin(), B ? B->pin() : nullptr, MOSFET_type );
 }
 
 OpAmp *Component::createOpAmp( ECNode * nonInverting, ECNode * out, ECNode * inverting )
@@ -870,7 +871,7 @@ MOSFET * Component::createMOSFET( Pin * D, Pin * G, Pin * S, Pin * B, int MOSFET
     pins << D << G << S << B;
 
     /// \todo remove the following line removing body if null
-    pins.removeAll( 0 );
+    pins.removeAll(nullptr);
 
     ElementMapList::iterator it = handleElement( e, pins );
     setInterDependent( it, pins );
@@ -1158,13 +1159,8 @@ QColor Component::voltageColor( double v )
 //BEGIN class ElementMap
 ElementMap::ElementMap()
 {
-    e = 0;
+    e = nullptr;
     for ( int i = 0; i < 4; ++i )
-        n[i] = 0;
+        n[i] = nullptr;
 }
 //END class ElementMap
-
-
-#include "component.moc"
-
-
