@@ -9,11 +9,10 @@
 
 #include "componentmodellibrary.h"
 
-#include <kdebug.h>
-#include <kstandarddirs.h>
-
-#include <qdatetime.h>
-#include <qfile.h>
+#include <QDebug>
+#include <QTime>
+#include <QFile>
+#include <QStandardPaths>
 
 #include <cassert>
 
@@ -42,7 +41,7 @@ void ComponentModel::setProperty( const QString & name, double value )
 
 
 //BEGIN class ComponentModelLibrary
-ComponentModelLibrary * ComponentModelLibrary::m_pSelf = 0l;
+ComponentModelLibrary * ComponentModelLibrary::m_pSelf = nullptr;
 
 
 // static
@@ -81,23 +80,23 @@ void ComponentModelLibrary::loadModels()
 	QStringList::iterator end = files.end();
 	for ( QStringList::iterator it = files.begin(); it != end; ++it )
 	{
-		QString fileName = KStandardDirs::locate( "appdata", "models/" + *it );
+		QString fileName = QStandardPaths::locate( QStandardPaths::AppDataLocation, "models/" + *it );
 		if ( fileName.isEmpty() )
 		{
-			kWarning() << k_funcinfo << "Could not find library file \""<<*it<<"\".\n";
+			qWarning() << Q_FUNC_INFO << "Could not find library file \""<<*it<<"\".\n";
 			continue;
 		}
 
 		QFile file( fileName );
 		if ( !file.open( QIODevice::ReadOnly ) )
 		{
-			kWarning() << k_funcinfo << "Could not open library file \""<<fileName<<"\" for reading.\n";
+			qWarning() << Q_FUNC_INFO << "Could not open library file \""<<fileName<<"\" for reading.\n";
 			continue;
 		}
 
 		QString id;
 		QString typeString;
-		ComponentModel *model = 0;
+		ComponentModel *model = nullptr;
 
 		QTextStream stream( & file );
 		while ( !stream.atEnd() )
@@ -115,10 +114,10 @@ void ComponentModelLibrary::loadModels()
 				ModelType type = None;
 				if ( typeString == "NPN" ) type = NPN;
 				else if ( typeString == "PNP" ) type = PNP;
-				else	kError() << k_funcinfo << "Unknown type \""<<typeString<<"\".\n";
+				else	qCritical() << Q_FUNC_INFO << "Unknown type \""<<typeString<<"\".\n";
 
 				if ( m_componentModelIDs[type].contains( id ) )
-					kError() << k_funcinfo << "Already have model with id=\""<<id<<"\" for type=\""<<typeString<<"\".\n";
+					qCritical() << Q_FUNC_INFO << "Already have model with id=\""<<id<<"\" for type=\""<<typeString<<"\".\n";
 
 				if ( !m_componentModels.contains( type ) )
 				{
@@ -131,11 +130,11 @@ void ComponentModelLibrary::loadModels()
 
 				/* if ( int(modelCount[type] * 1.2) > maxComponentModels )  // 2018.08.14 - not needed
 				{
-					kWarning() << k_funcinfo << "There are "<<modelCount[type]<<" models for component type \""<<typeString<<"\". Consider enlarging the dictionary.\n";
+					qWarning() << Q_FUNC_INFO << "There are "<<modelCount[type]<<" models for component type \""<<typeString<<"\". Consider enlarging the dictionary.\n";
 				} */
 
 				// Reset the model
-				model = 0l;
+				model = nullptr;
 				id = QString::null;
 				typeString = QString::null;
 
@@ -168,17 +167,13 @@ void ComponentModelLibrary::loadModels()
 					double realValue = value.toDouble( & ok );
 					
 					if ( !ok )
-						kError() << k_funcinfo << "Could not convert \""<<value<<"\" to a real number (for property \""<<name<<"\".\n";
+						qCritical() << Q_FUNC_INFO << "Could not convert \""<<value<<"\" to a real number (for property \""<<name<<"\".\n";
 					else	model->setProperty( name, realValue );
 				}
 			}
 		}
 	}
 
-	kDebug() << k_funcinfo << "It took " << ct.elapsed() << " milliseconds to read in the component models.\n";
+	qDebug() << Q_FUNC_INFO << "It took " << ct.elapsed() << " milliseconds to read in the component models.\n";
 }
 //END class ComponentModelLibrary
-
-
-#include "componentmodellibrary.moc"
-
