@@ -16,8 +16,8 @@
 #include "libraryitem.h"
 #include "simulator.h"
 
-#include <klocalizedstring.h>
-#include <qpainter.h>
+#include <KLocalizedString>
+#include <QPainter>
 
 Item* BiDirLED::construct( ItemDocument *itemDocument, bool newItem, const char *id )
 {
