@@ -13,7 +13,7 @@
 
 #include <component.h>
 
-#include <qpointer.h>
+#include <QPointer>
 // #include <q3valuevector.h>
 
 class Wire;
@@ -24,17 +24,17 @@ class Wire;
 class BusSplitter : public Component
 {
 	public:
-		BusSplitter( ICNDocument *icnDocument, bool newItem, const char *id = 0L );
-		~BusSplitter();
+		BusSplitter( ICNDocument *icnDocument, bool newItem, const char *id = nullptr );
+		~BusSplitter() override;
 	
 		static Item* construct( ItemDocument *itemDocument, bool newItem, const char *id );
 		static LibraryItem *libraryItem();
-	
+
 	protected:
 		QString outNodeID( unsigned node ) const;
-		virtual void dataChanged();
-		virtual void drawShape( QPainter &p );
-		
+		void dataChanged() override;
+		void drawShape( QPainter &p ) override;
+
 		unsigned m_busSize;
 		QVector<QPointer<Wire> > m_pWires;
 		ECNode * m_pInNode;
