@@ -24,15 +24,15 @@ Simple capacitor
 class Capacitor : public Component
 {
 public:
-	Capacitor( ICNDocument *icnDocument, bool newItem, const char *id = 0L );
-	~Capacitor();
+	Capacitor( ICNDocument *icnDocument, bool newItem, const char *id = nullptr );
+	~Capacitor() override;
 	
 	static Item* construct( ItemDocument *itemDocument, bool newItem, const char *id );
 	static LibraryItem *libraryItem();
-	
+
 private:
-	void dataChanged();
-	virtual void drawShape( QPainter &p );
+	void dataChanged() override;
+	void drawShape( QPainter &p ) override;
 
 	Capacitance * m_capacitance;
 };
