@@ -22,21 +22,21 @@
 class Demultiplexer : public CallbackClass,  public Component
 {
 public:
-	Demultiplexer( ICNDocument *icnDocument, bool newItem, const char *id = 0L );
-	~Demultiplexer();
+	Demultiplexer( ICNDocument *icnDocument, bool newItem, const char *id = nullptr );
+	~Demultiplexer() override;
 	
 	static Item* construct( ItemDocument *itemDocument, bool newItem, const char *id );
 	static LibraryItem *libraryItem();
-	
+
 protected:
-	void dataChanged();
+	void dataChanged() override;
 	/**
 	 * Add / remove pins according to the number of inputs the user has requested
 	 */
 	void initPins( unsigned addressSize );
-	
+
 	void inStateChanged( bool newState );
-	
+
 	QVector<LogicIn*> m_aLogic;
 	QVector<LogicOut*> m_xLogic;
 	LogicIn * m_input;
