@@ -18,8 +18,8 @@
 #include "vccs.h"
 #include "vcvs.h"
 
-#include <klocalizedstring.h>
-#include <qpainter.h>
+#include <KLocalizedString>
+#include <QPainter>
 
 //BEGIN class DependentSource
 DependentSource::DependentSource( ICNDocument *icnDocument, bool newItem, const char *id )
