@@ -15,8 +15,8 @@
 #include "libraryitem.h"
 #include "simulator.h"
 
-#include <klocalizedstring.h>
-#include <qpainter.h>
+#include <KLocalizedString>
+#include <QPainter>
 
 
 //BEGIN class Inverter
