@@ -13,9 +13,8 @@
 #include "ecnode.h"
 #include "libraryitem.h"
 
-#include <kiconloader.h>
-#include <klocalizedstring.h>
-#include <qpainter.h>
+#include <KLocalizedString>
+#include <QPainter>
 
 Item * ECBJT::constructNPN( ItemDocument * itemDocument, bool newItem, const char * id )
 {
