@@ -14,10 +14,10 @@
 #include "libraryitem.h"
 #include "simulator.h"
 
-#include <klocalizedstring.h>
-#include <qpainter.h>
+#include <KLocalizedString>
+#include <QPainter>
 
-#include <qdebug.h>
+#include <QDebug>
 
 #include <cmath>
 
