@@ -20,14 +20,14 @@
 class ECGround : public Component
 {
 public:
-	ECGround( ICNDocument *icnDocument, bool newItem, const char *id = 0L );
-	~ECGround();
+	ECGround( ICNDocument *icnDocument, bool newItem, const char *id = nullptr );
+	~ECGround() override;
 	
 	static Item* construct( ItemDocument *itemDocument, bool newItem, const char *id );
 	static LibraryItem *libraryItem();
-	
+
 private:
-	virtual void drawShape( QPainter &p );
+	void drawShape( QPainter &p ) override;
 };
 
 #endif
