@@ -12,9 +12,8 @@
 #include "jfet.h"
 #include "libraryitem.h"
 
-#include <kiconloader.h>
-#include <klocalizedstring.h>
-#include <qpainter.h>
+#include <KLocalizedString>
+#include <QPainter>
 
 Item * ECJFET::constructNJFET( ItemDocument * itemDocument, bool newItem, const char * id )
 {
