@@ -22,18 +22,18 @@ class JFET;
 class ECJFET : public Component
 {
 	public:
-		ECJFET( int JFET_type, ICNDocument *icnDocument, bool newItem, const char * id = 0L );
-		~ECJFET();
-	
+		ECJFET( int JFET_type, ICNDocument *icnDocument, bool newItem, const char * id = nullptr );
+		~ECJFET() override;
+
 		static Item * constructNJFET( ItemDocument * itemDocument, bool newItem, const char * id );
 		static Item * constructPJFET( ItemDocument * itemDocument, bool newItem, const char * id );
 		static LibraryItem * libraryItemNJFET();
 		static LibraryItem * libraryItemPJFET();
-	
+
 	protected:
-		virtual void dataChanged();
-		virtual void drawShape( QPainter &p );
-		
+		void dataChanged() override;
+		void drawShape( QPainter &p ) override;
+
 		int m_JFET_type;
 		JFET * m_pJFET;
 };
