@@ -12,10 +12,10 @@
 #include "libraryitem.h"
 #include "mosfet.h"
 
-#include <kdebug.h>
-#include <kiconloader.h>
-#include <klocalizedstring.h>
-#include <qpainter.h>
+#include <KLocalizedString>
+
+#include <QPainter>
+#include <QDebug>
 
 Item * ECMOSFET::constructNEM( ItemDocument * itemDocument, bool newItem, const char * id )
 {
