@@ -13,8 +13,8 @@
 #include "ecnode.h"
 #include "libraryitem.h"
 
-#include <klocalizedstring.h>
-#include <qpainter.h>
+#include <KLocalizedString>
+#include <QPainter>
 
 Item* ECOpAmp::construct( ItemDocument *itemDocument, bool newItem, const char *id )
 {
