@@ -14,9 +14,9 @@
 #include "libraryitem.h"
 #include "resistance.h"
 
-#include <klocalizedstring.h>
-#include <qpainter.h>
-#include <qstyle.h>
+#include <KLocalizedString>
+#include <QPainter>
+#include <QStyle>
 
 Item* ECPotentiometer::construct( ItemDocument *itemDocument, bool newItem, const char *id )
 {
