@@ -14,7 +14,7 @@
 #include "diode.h"
 
 // #include <q3valuevector.h>
-#include <qstringlist.h>
+#include <QStringList>
 
 /**
 @author William Hillerby
@@ -28,41 +28,41 @@ class LEDPart
 	public:
 		LEDPart( Component *pParent, const QString& strPNode, const QString& strNNode );
 		~LEDPart();
-		
+
 		void setDiodeSettings( const DiodeSettings& ds );
 		void setColor( const QColor &color );
 		void step();
-		
+
 		void draw( QPainter &p, int x, int y, int w, int h );
-		
+
 	private:
 		Component *m_pParent;
 		Diode *m_pDiode;
 		DiodeSettings ds;
 		QString m_strPNode, m_strNNode;
-		
+
 		double r, g, b;
 		double lastUpdatePeriod;
 		double avg_brightness;
-		uint last_brightness;	
+		uint last_brightness;
 };
 
 class LEDBarGraphDisplay : public Component
 {
 	public:
-		LEDBarGraphDisplay( ICNDocument* icnDocument, bool newItem, const QString& id = 0L );
-		~LEDBarGraphDisplay();
-		
+		LEDBarGraphDisplay( ICNDocument* icnDocument, bool newItem, const QString& id = nullptr );
+		~LEDBarGraphDisplay() override;
+
 		static Item* construct( ItemDocument *itemDocument, bool newItem, const char *id );
 		static LibraryItem *libraryItem();
-	
+
 	private:
 		void initPins();
-		void dataChanged();
+		void dataChanged() override;
 		
-		virtual void stepNonLogic();
-		virtual bool doesStepNonLogic() const { return true; }
-		virtual void drawShape( QPainter &p );
+		void stepNonLogic() override;
+		bool doesStepNonLogic() const override { return true; }
+		void drawShape( QPainter &p ) override;
 
 		LEDPart* m_LEDParts[max_LED_rows];
 		unsigned int m_numRows;
