@@ -23,35 +23,36 @@ const unsigned max_md_height = 20;
 class MatrixDisplay : public Component
 {
 	public:
-		MatrixDisplay( ICNDocument *icnDocument, bool newItem, const char *id = 0L );
-		~MatrixDisplay();
+		MatrixDisplay( ICNDocument *icnDocument, bool newItem, const char *id = nullptr );
+		~MatrixDisplay() override;
 	
 		static Item* construct( ItemDocument *itemDocument, bool newItem, const char *id );
 		static LibraryItem *libraryItem();
 	
-		virtual void stepNonLogic();
-		virtual bool doesStepNonLogic() const { return true; }
+		void stepNonLogic() override;
+		bool doesStepNonLogic() const override { return true; }
 		
 	protected:
-		virtual void drawShape( QPainter &p );
-		virtual void dataChanged();
+		void drawShape( QPainter &p ) override;
+		void dataChanged() override;
+
 		void initPins( unsigned numRows, unsigned numCols );
 		QString colPinID( int col ) const;
 		QString rowPinID( int row ) const;
-		
-		
+
+
 		QVector< QVector<double> > m_avgBrightness;
 		QVector< QVector<unsigned> > m_lastBrightness;
 		QVector< QVector<Diode*> > m_pDiodes;
-		
+
 		ECNode * m_pRowNodes[max_md_height];
 		ECNode * m_pColNodes[max_md_width];
-		
+
 		double m_lastUpdatePeriod;
-		
+
 		double m_r, m_g, m_b;
 		bool m_bRowCathode;
-		
+
 		unsigned m_numRows;
 		unsigned m_numCols;
 };
