@@ -12,9 +12,9 @@
 #include "logic.h"
 #include "matrixdisplaydriver.h"
 
-#include <klocalizedstring.h>
-#include <qpainter.h>
-#include <qstring.h>
+#include <KLocalizedString>
+#include <QPainter>
+#include <QString>
 
 #include <cassert>
 
@@ -331,11 +331,11 @@ MatrixDisplayDriver::MatrixDisplayDriver( ICNDocument *icnDocument, bool newItem
 	initDIPSymbol( pins, 64 );
 	initDIP(pins);
 	
-	m_pValueLogic.resize( 8 /*, 0l - 2018.06.02 - initialized below */ );
+	m_pValueLogic.resize( 8 /*, nullptr - 2018.06.02 - initialized below */ );
 	for ( unsigned i = 0; i < 8; ++i )
 		m_pValueLogic[i] = createLogicIn( ecNodeWithID("D"+QString::number(i)) );
 	
-	m_pRowLogic.resize( 7 /*, 0l - 2018.06.02 - initialized below */ );
+	m_pRowLogic.resize( 7 /*, nullptr - 2018.06.02 - initialized below */ );
 	for ( unsigned i = 0; i < 7; ++i )
 	{
 		m_pRowLogic[i] = createLogicOut( ecNodeWithID("R"+QString::number(i)), false );
@@ -343,7 +343,7 @@ MatrixDisplayDriver::MatrixDisplayDriver( ICNDocument *icnDocument, bool newItem
 		m_pRowLogic[i]->setOutputHighVoltage(5.0);
 	}
 	
-	m_pColLogic.resize( 5 /*, 0l - 2018.06.02 - initialized below */ );
+	m_pColLogic.resize( 5 /*, nullptr - 2018.06.02 - initialized below */ );
 	for ( unsigned i = 0; i < 5; ++i )
 	{
 		m_pColLogic[i] = createLogicOut( ecNodeWithID("C"+QString::number(i)), false );
