@@ -19,8 +19,8 @@
 #include "simulator.h"
 
 #include <cmath>
-#include <klocalizedstring.h>
-#include <qpainter.h>
+#include <KLocalizedString>
+#include <QPainter>
 
 
 //BEGIN class Meter
