@@ -22,21 +22,21 @@
 class Multiplexer : public CallbackClass, public Component
 {
 public:
-	Multiplexer( ICNDocument *icnDocument, bool newItem, const char *id = 0L );
-	~Multiplexer();
-	
+	Multiplexer( ICNDocument *icnDocument, bool newItem, const char *id = nullptr );
+	~Multiplexer() override;
+
 	static Item* construct( ItemDocument *itemDocument, bool newItem, const char *id );
 	static LibraryItem *libraryItem();
-	
+
 protected:
-	void dataChanged();
+	void dataChanged() override;
 	/**
 	 * Add / remove pins according to the number of inputs the user has requested
 	 */
 	void initPins( unsigned addressSize );
-	
+
 	void inStateChanged( bool newState );
-	
+
 	QVector<LogicIn*> m_aLogic;
 	QVector<LogicIn*> m_xLogic;
 	LogicOut * m_output;
