@@ -15,7 +15,7 @@
 #include "piccomponent.h"
 #include "piccomponentpin.h"
 
-#include <kdebug.h>
+#include <QDebug>
 
 PICComponentPin::PICComponentPin( PICComponent * picComponent, PicPin picPin )
 	: m_id( picPin.pinID )
@@ -24,10 +24,10 @@ PICComponentPin::PICComponentPin( PICComponent * picComponent, PicPin picPin )
 	m_gOutLow = 0.0;
 	m_picPin = picPin;
 	m_pPICComponent = picComponent;
-	m_pLogicOut = 0l;
-	m_pLogicIn = 0l;
-	m_pIOPIN = 0l;
-	m_pStimulusNode = 0l;
+	m_pLogicOut = nullptr;
+	m_pLogicIn = nullptr;
+	m_pIOPIN = nullptr;
+	m_pStimulusNode = nullptr;
 	Zth = 0.0;
 	Vth = 0.0;
 	
@@ -72,9 +72,9 @@ PICComponentPin::PICComponentPin( PICComponent * picComponent, PicPin picPin )
 PICComponentPin::~PICComponentPin()
 {
 	if (m_pLogicIn)
-		m_pLogicIn->setCallback( 0, (CallbackPtr)0 );	
+		m_pLogicIn->setCallback( nullptr, (CallbackPtr)nullptr );	
 	if (m_pLogicOut)
-		m_pLogicOut->setCallback( 0, (CallbackPtr)0 );	
+		m_pLogicOut->setCallback( nullptr, (CallbackPtr)nullptr );	
 	
 	delete m_pStimulusNode;
 }
@@ -84,19 +84,19 @@ void PICComponentPin::attach( IOPIN * iopin )
 {
 	if (!iopin)
 	{
-		kWarning() << k_funcinfo << " iopin is NULL" << endl;
+		qWarning() << Q_FUNC_INFO << " iopin is nullptr" << endl;
 		return;
 	}
 	
 	if (m_pStimulusNode)
 	{
-		kWarning() << k_funcinfo << " Already have a node stimulus" << endl;
+		qWarning() << Q_FUNC_INFO << " Already have a node stimulus" << endl;
 		return;
 	}
 	
 	if (m_pIOPIN)
 	{
-		kWarning() << k_funcinfo << " Already have an iopin" << endl;
+		qWarning() << Q_FUNC_INFO << " Already have an iopin" << endl;
 		return;
 	}
 	
