@@ -14,7 +14,7 @@
 #include "variant.h"
 
 #include <cmath>
-#include <klocalizedstring.h>
+#include <KLocalizedString>
 
 Item* RAM::construct( ItemDocument *itemDocument, bool newItem, const char *id )
 {
@@ -38,10 +38,10 @@ RAM::RAM( ICNDocument *icnDocument, bool newItem, const char *id )
 {
 	m_name = i18n("RAM");
 	
-	//m_data = 0l; // should be initialized by the constructor anyway
-	m_pCS = 0l;
-	m_pOE = 0l;
-	m_pWE = 0l;
+	//m_data = nullptr; // should be initialized by the constructor anyway
+	m_pCS = nullptr;
+	m_pOE = nullptr;
+	m_pWE = nullptr;
 	m_wordSize = 0;
 	m_addressSize = 0;
 	
