@@ -14,7 +14,7 @@
 #include "component.h"
 #include "logic.h"
 
-#include <qbitarray.h>
+#include <QBitArray>
 //#include <q3ptrvector.h>  // 2018.10.17
 
 /**
@@ -23,25 +23,25 @@
 class RAM : public CallbackClass, public Component
 {
 	public:
-		RAM( ICNDocument *icnDocument, bool newItem, const char *id = 0L );
-		~RAM();
+		RAM( ICNDocument *icnDocument, bool newItem, const char *id = nullptr );
+		~RAM() override;
 	
 		static Item * construct( ItemDocument *itemDocument, bool newItem, const char *id );
 		static LibraryItem * libraryItem();
-	
+
 	protected:
 		void initPins();
-		virtual void dataChanged();
+		void dataChanged() override;
 		void inStateChanged( bool newState );
-	
+
 		QBitArray m_data;
 		LogicIn * m_pCS; // Chip select
 		LogicIn * m_pOE; // Output enable
 		LogicIn * m_pWE; // Write enable
-		
+
 		int m_wordSize;
 		int m_addressSize;
-		
+
 		QVector<LogicIn*> m_address;
 		QVector<LogicIn*> m_dataIn;
 		QVector<LogicOut*> m_dataOut;
