@@ -20,16 +20,16 @@
 class Resistor : public Component
 {
 	public:
-		Resistor( ICNDocument *icnDocument, bool newItem, const char *id = 0L );
-		~Resistor();
-	
+		Resistor( ICNDocument *icnDocument, bool newItem, const char *id = nullptr );
+		~Resistor() override;
+
 		static Item* construct( ItemDocument *itemDocument, bool newItem, const char *id );
 		static LibraryItem *libraryItem();
-	
+
 	protected:
-		virtual void dataChanged();
-		virtual void drawShape( QPainter & p );
-	
+		void dataChanged() override;
+		void drawShape( QPainter & p ) override;
+
 		Resistance * m_resistance;
 };
 
