@@ -17,9 +17,10 @@
 #include "pin.h"
 #include "resistance.h"
 
-#include <kdebug.h>
-#include <klocalizedstring.h>
-#include <qpainter.h>
+#include <KLocalizedString>
+
+#include <QDebug>
+#include <QPainter>
 
 #include <cmath>
 #include <termios.h>
@@ -56,7 +57,7 @@ SerialPortComponent::SerialPortComponent( ICNDocument *icnDocument, bool newItem
 	
 	m_pSerialPort = new SerialPort();
 	
-	ECNode * pin = 0;
+	ECNode * pin = nullptr;
 	
 	// Works
 	pin = createPin( -40,  32,   0, "CD" );
@@ -164,7 +165,7 @@ void SerialPortComponent::dataChanged()
 		baudRate = B38400;
 	else
 	{
-		kError() << k_funcinfo << "Unknown baud rate = \""<<baudString<<"\""<<endl;
+		qCritical() << Q_FUNC_INFO << "Unknown baud rate = \""<<baudString<<"\""<<endl;
 		return;
 	}
 	
