@@ -13,10 +13,11 @@
 #include "ecnode.h"
 #include "libraryitem.h"
 
-#include <klocalizedstring.h>
-#include <qpainter.h>
-#include <qstyle.h>
-#include <kdebug.h>
+#include <KLocalizedString>
+
+#include <QPainter>
+#include <QStyle>
+#include <QDebug>
 
 Item* VariableResistor::construct( ItemDocument *itemDocument, bool newItem, const char *id )
 {
