@@ -23,14 +23,15 @@
 
 #include <cassert>
 
-#include <kdebug.h>
-#include <klocalizedstring.h>
-#include <kmessagebox.h>
-#include <ktemporaryfile.h>
-#include <kstandarddirs.h>
-#include <qfile.h>
-#include <qtextstream.h>
-#include <qtimer.h>
+#include <KLocalizedString>
+#include <KMessageBox>
+
+#include <QDebug>
+#include <QTemporaryFile>
+#include <QDir>
+#include <QFile>
+#include <QTextStream>
+#include <QTimer>
 
 #include "gpsim/cod.h"
 #include "gpsim/interface.h"
@@ -84,13 +85,13 @@ GpsimProcessor::GpsimProcessor( QString symbolFile, QObject *parent )
 	
 	m_bCanExecuteNextCycle = true;
 	m_bIsRunning = false;
-	m_pPicProcessor = 0l;
+	m_pPicProcessor = nullptr;
 	m_codLoadStatus = CodUnknown;
-	m_pRegisterMemory = 0l;
+	m_pRegisterMemory = nullptr;
 	m_debugMode = GpsimDebugger::AsmDebugger;
-	m_pDebugger[0] = m_pDebugger[1] = 0l;
+	m_pDebugger[0] = m_pDebugger[1] = nullptr;
 	
-	Processor * tempProcessor = 0l;
+	Processor * tempProcessor = nullptr;
 	const char * fileName = symbolFile.toAscii();
 	
 #ifdef GPSIM_0_21_4
@@ -162,26 +163,26 @@ void GpsimProcessor::displayCodLoadStatus( )
 		case CodSuccess:
 			break;
 		case CodFileNotFound:
-			KMessageBox::sorry( 0l, i18n("The cod file \"%1\" was not found.", m_symbolFile), i18n("File Not Found") );
+			KMessageBox::sorry( nullptr, i18n("The cod file \"%1\" was not found.", m_symbolFile), i18n("File Not Found") );
 			break;
 		case CodUnrecognizedProcessor:
-			KMessageBox::sorry( 0l, i18n("The processor for cod file \"%1\" is unrecognized.", m_symbolFile), i18n("Unrecognized Processor") );
+			KMessageBox::sorry( nullptr, i18n("The processor for cod file \"%1\" is unrecognized.", m_symbolFile), i18n("Unrecognized Processor") );
 			break;
 		case CodFileNameTooLong:
-			KMessageBox::sorry( 0l, i18n("The file name \"%1\" is too long.", m_symbolFile), i18n("Filename Too Long") );
+			KMessageBox::sorry( nullptr, i18n("The file name \"%1\" is too long.", m_symbolFile), i18n("Filename Too Long") );
 			break;
 		case CodLstNotFound:
-			KMessageBox::sorry( 0l, i18n("The lst file associated with the cod file \"%1\" was not found.", m_symbolFile), i18n("LST File Not Found") );
+			KMessageBox::sorry( nullptr, i18n("The lst file associated with the cod file \"%1\" was not found.", m_symbolFile), i18n("LST File Not Found") );
 			break;
 		case CodBadFile:
-			KMessageBox::sorry( 0l, i18n("The cod file \"%1\" is bad.", m_symbolFile), i18n("Bad File") );
+			KMessageBox::sorry( nullptr, i18n("The cod file \"%1\" is bad.", m_symbolFile), i18n("Bad File") );
 			break;
 		case CodFileUnreadable:
-			KMessageBox::sorry( 0l, i18n("The cod file \"%1\" could not be read from.", m_symbolFile), i18n("Unreadable File") );
+			KMessageBox::sorry( nullptr, i18n("The cod file \"%1\" could not be read from.", m_symbolFile), i18n("Unreadable File") );
 			break;
 		case CodFailure:
 		case CodUnknown:
-			KMessageBox::sorry( 0l, i18n("An error occurred with the cod file \"%1\".", m_symbolFile), i18n("Error") );
+			KMessageBox::sorry( nullptr, i18n("An error occurred with the cod file \"%1\".", m_symbolFile), i18n("Error") );
 			break;
 	}
 }
@@ -283,8 +284,8 @@ void GpsimProcessor::reset()
 MicroInfo * GpsimProcessor::microInfo( ) const
 {
 	if ( !m_pPicProcessor ){
-		kWarning() << k_funcinfo << " m_pPicProcessor == NULL" << endl;
-		return 0l;
+		qWarning() << Q_FUNC_INFO << " m_pPicProcessor == nullptr" << endl;
+		return nullptr;
 	}
 	
 	return MicroLibrary::self()->microInfoWithID( m_pPicProcessor->name().c_str() );
@@ -311,7 +312,7 @@ int GpsimProcessor::operandLiteral( unsigned address )
 
 GpsimProcessor::ProgramFileValidity GpsimProcessor::isValidProgramFile( const QString & programFile )
 {
-	if ( !KStandardDirs::exists(programFile) )
+	if ( !QFile::exists(programFile) )
 		return DoesntExist;
 	
 	QString extension = programFile.right( programFile.length() - programFile.lastIndexOf('.') - 1 ).toLower();
@@ -359,8 +360,7 @@ QString GpsimProcessor::generateSymbolFile( const QString &fileName, QObject *re
 	}
 	else if ( extension == "flowcode" )
 	{
-        KTemporaryFile tmpFile;
-        tmpFile.setSuffix( ".hex" );
+        QTemporaryFile tmpFile(QDir::tempPath() + QLatin1String("/ktechlab_XXXXXX.hex"));
         if (!tmpFile.open()) {
             qWarning() << " failed to open " << tmpFile.fileName() << " error " << tmpFile.errorString();
             return QString::null;
@@ -458,8 +458,8 @@ GpsimDebugger::GpsimDebugger( Type type, GpsimProcessor * gpsim )
 {
 	m_pGpsim = gpsim;
 	m_type = type;
-	m_pBreakFromOldLine = 0l;
-	m_addressToLineMap = 0l;
+	m_pBreakFromOldLine = nullptr;
+	m_addressToLineMap = nullptr;
 	m_stackLevelLowerBreak = -1;
 	m_addressSize = 0;
 	
@@ -507,7 +507,7 @@ void GpsimDebugger::gpsimRunningStatusChanged( bool isRunning )
 	if (!isRunning)
 	{
 		m_stackLevelLowerBreak = -1;
-		m_pBreakFromOldLine = 0l;
+		m_pBreakFromOldLine = nullptr;
 		emitLineReached();
 	}
 }
@@ -517,7 +517,7 @@ void GpsimDebugger::associateLine( const QString & sourceFile, int sourceLine, c
 {
 	if ( assemblyLine < 0 || sourceLine < 0 )
 	{
-		kWarning() << k_funcinfo << "Invalid lines: assemblyLine="<<assemblyLine<<" sourceLine="<<sourceLine<<endl;
+		qWarning() << Q_FUNC_INFO << "Invalid lines: assemblyLine="<<assemblyLine<<" sourceLine="<<sourceLine<<endl;
 		return;
 	}
 	
@@ -526,7 +526,7 @@ void GpsimDebugger::associateLine( const QString & sourceFile, int sourceLine, c
 	
 	if ( m_sourceLineMap.contains(asmSource) )
 	{
-		kWarning() << k_funcinfo << "Already have an association for assembly (\""<<assemblyFile<<"\","<<assemblyLine<<")"<<endl;
+		qWarning() << Q_FUNC_INFO << "Already have an association for assembly (\""<<assemblyFile<<"\","<<assemblyLine<<")"<<endl;
 		return;
 	}
 	
@@ -573,7 +573,7 @@ void GpsimDebugger::initAddressToLineMap()
 			int fileID = m_pGpsim->picProcessor()->files.Find( stdAsmFile );
 			if ( fileID == -1 )
 			{
-				kWarning() << k_funcinfo << "Could not find FileContext (asmFile=\""<<asmFile<<"\")"<<endl;
+				qWarning() << Q_FUNC_INFO << "Could not find FileContext (asmFile=\""<<asmFile<<"\")"<<endl;
 				continue;
 			}
 	
@@ -582,7 +582,7 @@ void GpsimDebugger::initAddressToLineMap()
 	
 			if ( (asmFromLine < 0) || (asmToLine < asmFromLine) )
 			{
-				kWarning() << k_funcinfo << "Invalid lines: asmFromLine="<<asmFromLine<<" asmToLine="<<asmToLine<<endl;
+				qWarning() << Q_FUNC_INFO << "Invalid lines: asmFromLine="<<asmFromLine<<" asmToLine="<<asmToLine<<endl;
 				continue;
 			}
 	
@@ -719,7 +719,7 @@ void GpsimDebugger::stackStep( int dl )
 		initialStack = 0;
 	
 	// Reset any previous stackStep, and step
-	m_pBreakFromOldLine = 0l;
+	m_pBreakFromOldLine = nullptr;
 	m_stackLevelLowerBreak = -1;
 	m_pGpsim->picProcessor()->step_one(false);
 	
@@ -746,8 +746,8 @@ void GpsimDebugger::stackStep( int dl )
 RegisterSet::RegisterSet( pic_processor * picProcessor )
 {
 	unsigned numRegisters = picProcessor->rma.get_size();
-	kDebug() << k_funcinfo << "numRegisters="<<numRegisters<<endl;
-	m_registers.resize( numRegisters /*, 0l - 2018.06.02 - initialized below */ );
+	qDebug() << Q_FUNC_INFO << "numRegisters="<<numRegisters<<endl;
+	m_registers.resize( numRegisters /*, nullptr - 2018.06.02 - initialized below */ );
 	for ( unsigned i = 0; i < numRegisters; ++i )
 	{
 		RegisterInfo * info = new RegisterInfo( & picProcessor->rma[i] );
@@ -776,7 +776,7 @@ RegisterSet::~RegisterSet()
 
 RegisterInfo * RegisterSet::fromAddress( unsigned address )
 {
-	return (address < m_registers.size()) ? m_registers[address] : 0l;
+	return (address < m_registers.size()) ? m_registers[address] : nullptr;
 }
 
 
@@ -795,7 +795,7 @@ RegisterInfo * RegisterSet::fromName( const QString & name )
 			return it.value();
 	}
 	
-	return 0l;
+	return nullptr;
 }
 
 
@@ -899,7 +899,4 @@ DebugLine::DebugLine()
 }
 //END class DebugLine
 
-
-#include "gpsimprocessor.moc"
-
 #endif
