@@ -16,11 +16,11 @@
 
 #include "sourceline.h"
 
-#include <qmap.h>
+#include <QMap>
 // #include <q3valuevector.h>
-#include <qobject.h>
-#include <qlist.h>
-#include <qvector.h>
+#include <QObject>
+#include <QList>
+#include <QVector>
 
 class DebugLine;
 class GpsimProcessor;
@@ -37,6 +37,7 @@ class DebugLine : public SourceLine
 {
 	public:
 		DebugLine();
+		/// @param fileName a path to a file in the local filesystem
 		DebugLine( const QString & fileName, int line );
 		/**
 		 * Whether or not to break when we reach this line.
@@ -54,11 +55,11 @@ class DebugLine : public SourceLine
 		 * Used for efficiency purposes by GpsimProcessor.
 		 */
 		bool markedAsDeleted() const { return m_bMarkedAsDeleted; }
-		
+
 	protected:
 		bool m_bIsBreakpoint;
 		bool m_bMarkedAsDeleted;
-		
+
 	private:
 		DebugLine( const DebugLine & dl );
 		DebugLine & operator = ( const DebugLine & dl );
@@ -74,7 +75,7 @@ class RegisterInfo : public QObject
 	Q_OBJECT
 	public:
 		RegisterInfo( Register * reg );
-	
+
 		enum RegisterType
 		{
 			Invalid,
@@ -83,20 +84,20 @@ class RegisterInfo : public QObject
 			SFR,
 			Breakpoint
 		};
-		
+
 		RegisterType type() const { return m_type; }
 		QString name() const { return m_name; }
 		unsigned value() const;
 		static QString toString( RegisterType type );
-		
+
 		/**
 		 * Checks to see if the value has changed; if so, emit new value.
 		 */
 		void update();
-		
+
 	signals:
 		void valueChanged( unsigned newValue );
-		
+
 	protected:
 		QString m_name;
 		RegisterType m_type;
@@ -114,7 +115,7 @@ class RegisterSet
 	public:
 		RegisterSet( pic_processor * picProcessor );
 		~RegisterSet();
-		
+
 		/**
 		 * Calls update for each RegisterInfo in this set.
 		 */
@@ -123,10 +124,10 @@ class RegisterSet
 		 * Returns the number of registers.
 		 */
 		unsigned size() const { return m_registers.size(); }
-		
+
 		RegisterInfo * fromAddress( unsigned address );
 		RegisterInfo * fromName( const QString & name );
-		
+
 	protected:
 		typedef QMap< QString, RegisterInfo * > RegisterInfoMap;
 		RegisterInfoMap m_nameToRegisterMap;
@@ -141,25 +142,27 @@ class GpsimDebugger : public QObject
 {
 	friend class GpsimProcessor;
 	Q_OBJECT
-	
+
 	public:
 		enum Type
 		{
 			AsmDebugger = 0,
 			HLLDebugger = 1
 		};
-		
+
 		GpsimDebugger( Type type, GpsimProcessor * gpsim );
-		~GpsimDebugger();
-		
+		~GpsimDebugger() override;
+
 		GpsimProcessor * gpsim() const { return m_pGpsim; }
-		
+
 		/**
 		 * When an assembly file was generated by a high level language compiler
 		 * like SDCC, it will insert markers like ";#CSRC" that show which line
 		 * of source-code generated the given set of assembly instructions. This
 		 * matches up the assembly file lines with the associated source file
 		 * lines.
+		 * @param sourceFile the path to an assembly file in the local filesystem
+		 * @param assemblyFile the path to a source file in the local filesystem
 		 */
 		void associateLine( const QString & sourceFile, int sourceLine, const QString & assemblyFile, int assemblyLine );
 		/**
@@ -210,7 +213,7 @@ class GpsimDebugger : public QObject
 		 * the initial stack level (instead of <= initial).
 		 */
 		void stepOut();
-		
+
 	signals:
 		/**
 		 * Emitted when a line is reached. By default, this is the line of the
@@ -218,15 +221,15 @@ class GpsimDebugger : public QObject
 		 * the PIC memory can be changed with mapAddressBlockToLine.
 		 */
 		void lineReached( const SourceLine & sourceLine );
-		
+
 	protected slots:
 		void gpsimRunningStatusChanged( bool isRunning );
-		
+
 	protected:
 		void initAddressToLineMap();
 		void stackStep( int dl );
 		void emitLineReached();
-		
+
 		int m_stackLevelLowerBreak; // Set by step-over, for when the stack level decreases to the one given
 		SourceLine m_previousAtLineEmit; // Used for working out whether we should emit a new line reached signal
 		DebugLine ** m_addressToLineMap;
@@ -245,19 +248,19 @@ class GpsimProcessor : public QObject
 {
 	friend class GpsimDebugger;
 	Q_OBJECT
-	
+
 	public:
 		/**
 		 * Create a new gpsim processor. After calling this constructor, you
 		 * should always call codLoadStatus() to ensure that the cod file was
 		 * loaded successfully.
 		 */
-		GpsimProcessor( QString symbolFile, QObject *parent = 0 );
-		~GpsimProcessor();
-		
+		GpsimProcessor( QString symbolFile, QObject *parent = nullptr );
+		~GpsimProcessor() override;
+
 		void setDebugMode( GpsimDebugger::Type mode ) { m_debugMode = mode; }
 		GpsimDebugger * currentDebugger() const { return m_pDebugger[m_debugMode]; }
-		
+
 		enum CodLoadStatus
 		{
 			CodSuccess,
@@ -270,7 +273,7 @@ class GpsimProcessor : public QObject
 			CodFailure,
 			CodUnknown // Should never be this, but just in case load_symbol_file returns something funny
 		};
-		
+
 		enum InstructionType
 		{
 			LiteralOp,
@@ -278,7 +281,7 @@ class GpsimProcessor : public QObject
 			RegisterOp,
 			UnknownOp
 		};
-				
+
 		/**
 		 * @return status of opening the COD file
 		 * @see displayCodLoadStatus
@@ -291,6 +294,7 @@ class GpsimProcessor : public QObject
 		void displayCodLoadStatus();
 		/**
 		 * Returns a list of source files for the currently running program.
+		 * Each entry is a path in the local filesystem.
 		 */
 		QStringList sourceFileList();
 		/**
@@ -316,7 +320,7 @@ class GpsimProcessor : public QObject
 		 * Returns the microinfo describing this processor.
 		 */
 		MicroInfo * microInfo() const;
-		
+
 		pic_processor * picProcessor() const { return m_pPicProcessor; }
 		unsigned programMemorySize() const;
 		RegisterSet * registerMemory() const { return m_pRegisterMemory; }
@@ -334,7 +338,7 @@ class GpsimProcessor : public QObject
 		 * operation, and -1 otherwise.
 		 */
 		int operandLiteral( unsigned address );
-		
+
 		//BEGIN Convenience functions for PIC files
 		enum ProgramFileValidity { DoesntExist, IncorrectType, Valid };
 		/**
@@ -350,32 +354,32 @@ class GpsimProcessor : public QObject
 		 * @param receiver The slot to connect the assembled signal to
 		 * @see static bool isValidProgramFile( const QString &programFile )
 		 */
-		static QString generateSymbolFile( const QString &fileName, QObject *receiver, const char *successMember, const char * failMember = 0l );
+		static QString generateSymbolFile( const QString &fileName, QObject *receiver, const char *successMember, const char * failMember = nullptr );
 		/**
 		 *Compile microbe to output to the given filename
 		 */
-		static void compileMicrobe( const QString &filename, QObject *receiver, const char * successMember, const char * failMember = 0l );
+		static void compileMicrobe( const QString &filename, QObject *receiver, const char * successMember, const char * failMember = nullptr );
 		//END convenience functions for PIC files
-		
+
 	signals:
 		/**
 		 * Emitted when the running status of gpsim changes.
 		 */
 		void runningStatusChanged( bool isRunning );
-		
+
 	protected:
 		/**
 		 * Calls emitLineReached for each debugger.
 		 */
 		void emitLineReached();
-		
+
 		pic_processor * m_pPicProcessor;
 		CodLoadStatus m_codLoadStatus;
 		const QString m_symbolFile;
 		RegisterSet * m_pRegisterMemory;
 		GpsimDebugger::Type m_debugMode;
 		GpsimDebugger * m_pDebugger[2]; // Asm, HLL
-		
+
 		/**
 		 * We are called effectively for each cycle of the cycle of the
 		 * processor. This value is used as some instructions (e.g. goto) take
@@ -383,7 +387,7 @@ class GpsimProcessor : public QObject
 		 * realtime simulation.
 		 */
 		bool m_bCanExecuteNextCycle;
-		
+
 	private:
 		bool m_bIsRunning;
 };
