@@ -10,10 +10,9 @@
 
 #include "pin.h"
 
-#include <cassert>
-#include <kdebug.h>
+#include <QDebug>
 
-#include <qdebug.h>
+#include <cassert>
 
 Pin::Pin( ECNode * parent )
 {
@@ -41,7 +40,7 @@ Pin::~Pin()
 
 PinList Pin::localConnectedPins( ) const
 {
-// 	kDebug() << k_funcinfo << "Input wires: "<<m_inputWireList.size()<<"   Output wires: " << m_outputWireList.size() << "   Switch connected: " << m_switchConnectedPins.size() << endl;
+// 	qDebug() << Q_FUNC_INFO << "Input wires: "<<m_inputWireList.size()<<"   Output wires: " << m_outputWireList.size() << "   Switch connected: " << m_switchConnectedPins.size() << endl;
 	
 	PinList pins;
 	
@@ -153,8 +152,8 @@ void Pin::addOutputWire( Wire * wire )
 
 bool Pin::calculateCurrentFromWires()
 {
-	m_inputWireList.removeAll( (Wire*)0l );
-	m_outputWireList.removeAll( (Wire*)0l );
+	m_inputWireList.removeAll( (Wire*)nullptr );
+	m_outputWireList.removeAll( (Wire*)nullptr );
 	
 	const WireList inputs = m_inputWireList;
 	const WireList outputs = m_outputWireList;
