@@ -9,20 +9,20 @@
  ***************************************************************************/
 
 // This section should be kept at the top to handle detection of os
-#include <qglobal.h>
+#include <QtGlobal>
 #if defined(Q_OS_DARWIN) || defined(Q_OS_MACX)
 	#define DARWIN
 #endif
 
 #include "port.h"
-#include <kdebug.h>
+#include <QDebug>
 
 #include <errno.h>
 #include <fcntl.h>
 #include <sys/ioctl.h>
 #include <unistd.h>
 
-#ifndef DARWIN
+#if !defined(DARWIN) && !defined(__FreeBSD__)
 #include <linux/ppdev.h>
 #endif
 
@@ -39,7 +39,7 @@ Port::~Port()
 
 QStringList Port::ports( unsigned probeResult )
 {
-#ifndef DARWIN
+#if !defined(DARWIN) && !defined(__FreeBSD__)
 	return SerialPort::ports(probeResult) + ParallelPort::ports(probeResult);
 #else
 	return SerialPort::ports(probeResult);
@@ -97,12 +97,12 @@ void SerialPort::setPinState( Pin pin, bool state )
 	
 	if ( flags == -1 )
 	{
-		kError() << k_funcinfo << "Bad pin " << pin << endl;
+		qCritical() << Q_FUNC_INFO << "Bad pin " << pin << endl;
 		return;
 	}
 	
 	if ( ioctl( m_file, state ? TIOCMBIS : TIOCMBIC, & flags ) == -1 )
-		kError() << k_funcinfo << "Could not set pin " << pin << " errno = " << errno << endl;
+		qCritical() << Q_FUNC_INFO << "Could not set pin " << pin << " errno = " << errno << endl;
 }
 
 
@@ -141,14 +141,14 @@ bool SerialPort::pinState( Pin pin )
 	
 	if ( mask == 0 )
 	{
-		kError() << k_funcinfo << "Bad pin " << pin << endl;
+		qCritical() << Q_FUNC_INFO << "Bad pin " << pin << endl;
 		return false;
 	}
 	
 	int bits = 0;
 	if ( ioctl( m_file, TIOCMGET, & bits ) == -1 )
 	{
-		kError() << k_funcinfo << "Could not read pin" << pin << " errno = " << errno << endl;
+		qCritical() << Q_FUNC_INFO << "Could not read pin" << pin << " errno = " << errno << endl;
 		return false;
 	}
 	
@@ -180,7 +180,7 @@ bool SerialPort::openPort( const QString & port, speed_t baudRate )
 	m_file = open( port.toAscii(), O_NOCTTY | O_NONBLOCK | O_RDWR );
 	if ( m_file == -1 )
 	{
-		kError() << k_funcinfo << "Could not open port " << port << endl;
+		qCritical() << Q_FUNC_INFO << "Could not open port " << port << endl;
 		return false;
 	}
 	
@@ -264,7 +264,7 @@ const int INPUT_MODE_BIT = 1 << 21; // Controls if the data pins are input or ou
 
 // No code using these values will be reached on Darwin, this is just to
 // keep the preprocessor happy.
-#ifdef DARWIN
+#if defined(DARWIN) || defined(__FreeBSD__)
 	#define PPRDATA		0xFACADE
 	#define PPRCONTROL	0xC001D00D
 	#define PPWDATA		0xC0EDBABE
@@ -379,7 +379,7 @@ void ParallelPort::setControlState( uchar pins, bool state )
 //BEGIN Register-oriented operations
 uchar ParallelPort::readFromRegister( Register reg )
 {
-#ifdef DARWIN
+#if defined(DARWIN) || defined(__FreeBSD__)
 	return 0;
 #endif
 	
@@ -389,7 +389,7 @@ uchar ParallelPort::readFromRegister( Register reg )
 // 	uchar value = inb( m_lpBase + reg ) ^ INVERT_MASK[reg];
 	uchar value = 0;
 	if ( ioctl( m_file, IOCTL_REG_READ[reg], &value ) )
-		kError() << k_funcinfo << "errno=" << errno << endl;
+		qCritical() << Q_FUNC_INFO << "errno=" << errno << endl;
 	else
 		m_reg[reg] = value;
 	return value;
@@ -398,7 +398,7 @@ uchar ParallelPort::readFromRegister( Register reg )
 
 void ParallelPort::writeToRegister( Register reg, uchar value )
 {
-#ifdef DARWIN
+#if defined(DARWIN) || defined(__FreeBSD__)
 	return;
 #endif
 	
@@ -407,7 +407,7 @@ void ParallelPort::writeToRegister( Register reg, uchar value )
 	
 // 	outb( value ^ INVERT_MASK[reg], m_lpBase + reg );
 	if ( ioctl( m_file, IOCTL_REG_WRITE[reg], & value ) )
-		kError() << k_funcinfo << "errno=" << errno << endl;
+		qCritical() << Q_FUNC_INFO << "errno=" << errno << endl;
 	else
 		m_reg[reg] = value;
 }
@@ -469,7 +469,7 @@ void ParallelPort::setControlDirection( int pins, Direction dir )
 
 Port::ProbeResult ParallelPort::probe( const QString & port )
 {
-#ifdef DARWIN
+#if defined(DARWIN) || defined(__FreeBSD__)
 	return Port::DoesntExist;
 #endif
 	
@@ -493,7 +493,7 @@ QStringList ParallelPort::ports( unsigned probeResult )
 {
 	QStringList list;
 	
-#ifdef DARWIN
+#if defined(DARWIN) || defined(__FreeBSD__)
 	return list;
 #endif
 	
@@ -517,14 +517,17 @@ QStringList ParallelPort::ports( unsigned probeResult )
 
 bool ParallelPort::openPort( const QString & port )
 {
-#ifdef DARWIN
-	kWarning() << k_funcinfo << "Parallel ports disabled on Darwin" << endl;
+#if defined(__FreeBSD__)
+	qWarning() << Q_FUNC_INFO << "Parallel ports disabled on FreeBSD" << endl;
+	return false;
+#elif defined(DARWIN)
+	qWarning() << Q_FUNC_INFO << "Parallel ports disabled on Darwin" << endl;
 	return false;
 #endif
 	
 	if ( m_file != -1 )
 	{
-		kWarning() << k_funcinfo << "Port already open" << endl;
+		qWarning() << Q_FUNC_INFO << "Port already open" << endl;
 		return false;
 	}
 	
@@ -532,13 +535,13 @@ bool ParallelPort::openPort( const QString & port )
 	
 	if ( m_file == -1 )
 	{
-		kError() << k_funcinfo << "Could not open port \"" << port << "\": errno="<<errno<<endl;
+		qCritical() << Q_FUNC_INFO << "Could not open port \"" << port << "\": errno="<<errno<<endl;
 		return false;
 	}
 	
 	if ( ioctl( m_file, PPCLAIM ) )
 	{
-		kError() << k_funcinfo << "Port " << port << " must be RW" << endl;
+		qCritical() << Q_FUNC_INFO << "Port " << port << " must be RW" << endl;
 		close( m_file );
 		m_file = -1;
 		return false;
@@ -550,7 +553,7 @@ bool ParallelPort::openPort( const QString & port )
 
 void ParallelPort::closePort()
 {
-#ifdef DARWIN
+#if defined(DARWIN) || defined(__FreeBSD__)
 	return;
 #endif
 	
@@ -561,7 +564,7 @@ void ParallelPort::closePort()
 	close( m_file );
 	
 	if ( res )
-		kError() << k_funcinfo << "res="<<res<<endl;
+		qCritical() << Q_FUNC_INFO << "res="<<res<<endl;
 	
 	m_file = -1;
 }
