@@ -22,14 +22,14 @@ class CurrentSource : public Element
 {
 public:
 	CurrentSource( const double current );
-	virtual ~CurrentSource();
+	~CurrentSource() override;
 	
-	virtual Type type() const { return Element_CurrentSource; }
+	Type type() const override { return Element_CurrentSource; }
 	void setCurrent( const double i );
 
 protected:
-	virtual void updateCurrents();
-	virtual void add_initial_dc();
+	void updateCurrents() override;
+	void add_initial_dc() override;
 	
 private:
 	double m_i; // Current
