@@ -12,8 +12,8 @@
 #include <stdlib.h> // for rand
 #include <time.h>
 
-#include <kdebug.h>
-#include <qtimer.h>
+#include <QDebug>
+#include <QTimer>
 
 #include "circuitdocument.h"
 #include "component.h"
@@ -27,7 +27,7 @@ Switch::Switch(Component *parent, Pin *p1, Pin *p2, State state) {
 	m_bouncePeriod_ms = 5;
 	m_bBounce = false;
 	m_bounceStart = 0;
-	m_pBounceResistance = 0;
+	m_pBounceResistance = nullptr;
 	m_pP1 = p1;
 	m_pP2 = p2;
 	m_pComponent = parent;
@@ -69,7 +69,7 @@ void Switch::startBouncing() {
 
 	if (!m_pComponent->circuitDocument()) return;
 
-// 	kDebug() << k_funcinfo << endl;
+// 	qDebug() << Q_FUNC_INFO << endl;
 
 	m_pBounceResistance = m_pComponent->createResistance(m_pP1, m_pP2, 10000);
 	m_bounceStart = Simulator::self()->time();
@@ -79,10 +79,10 @@ void Switch::startBouncing() {
 // contaminate that many other classes.
 
 //	Simulator::self()->attachSwitch( this );
-// 	kDebug() << "m_bounceStart="<<m_bounceStart<<" m_bouncePeriod_ms="<<m_bouncePeriod_ms<<endl;
+// 	qDebug() << "m_bounceStart="<<m_bounceStart<<" m_bouncePeriod_ms="<<m_bouncePeriod_ms<<endl;
 
 	// initialize random generator
-	srand(time(NULL));
+	srand(time(nullptr));
 
 	// Give our bounce resistor an initial value
 	bounce();
@@ -110,7 +110,7 @@ void Switch::bounce() {
 void Switch::stopBouncing() {
 //	Simulator::self()->detachSwitch( this );
 	m_pComponent->removeElement(m_pBounceResistance, true);
-	m_pBounceResistance = 0;
+	m_pBounceResistance = nullptr;
 
 	bool connected = (m_state == Closed);
 
@@ -189,6 +189,3 @@ bool Switch::calculateCurrent() {
 
 	return true;
 }
-
-#include "switch.moc"
-
