@@ -12,8 +12,10 @@
 #include "textdocument.h"
 #include "textview.h"
 
-#include <kconfig.h>
+#include <KConfigGroup>
+#include <KConfig>
 
+#include <QStandardPaths>
 
 //BEGIN class MetaInfo
 MetaInfo::MetaInfo()
@@ -38,7 +40,7 @@ void MetaInfo::save( KConfigGroup* conf )
 	conf->writeEntry( "Bookmarks", bookmarks() );
 	conf->writeEntry( "Breakpoints", breakpoints() );
 	conf->writeEntry( "OutputMethod", toID(outputMethodInfo().method()) );
-	conf->writePathEntry( "OutputPath", outputMethodInfo().outputFile().prettyUrl() );
+	conf->writePathEntry( "OutputPath", outputMethodInfo().outputFile().toDisplayString(QUrl::PreferLocalFile) );
 	conf->writeEntry( "OutputPicID", outputMethodInfo().picID() );
 	conf->writeEntry( "CursorLine", cursorLine() );
 	conf->writeEntry( "CursorColumn", cursorColumn() );
@@ -50,7 +52,7 @@ void MetaInfo::load( KConfigGroup* conf )
 	setBookmarks( conf->readEntry("Bookmarks", IntList()) );
 	setBreakpoints( conf->readEntry("Breakpoints", IntList()) );
 	m_outputMethodInfo.setMethod( toMethod( conf->readEntry("OutputMethod") ) );
-	m_outputMethodInfo.setOutputFile( conf->readPathEntry("OutputPath", QString()) );
+	m_outputMethodInfo.setOutputFile( QUrl::fromUserInput(conf->readPathEntry("OutputPath", QString())) );
 	m_outputMethodInfo.setPicID( conf->readEntry("OutputPicID") );
 	setCursorLine( conf->readEntry( "CursorLine", 0 ) );
 	setCursorColumn( conf->readEntry( "CursorColumn", 0 ) );
@@ -92,7 +94,7 @@ FileMetaInfo::FileMetaInfo()
 	: QObject()
 {
 	//m_metaInfoConfig = new KConfig( "metainfo", false, false, "appdata" );
-    m_metaInfoConfig = new KConfig( "metainfo", "appdata" );
+    m_metaInfoConfig = new KConfig( "metainfo", KConfig::SimpleConfig, QStandardPaths::AppDataLocation );
 	loadAllMetaInfo();
 }
 
@@ -104,7 +106,7 @@ FileMetaInfo::~FileMetaInfo()
 }
 
 
-void FileMetaInfo::grabMetaInfo( const KUrl & url, TextDocument * textDocument )
+void FileMetaInfo::grabMetaInfo( const QUrl & url, TextDocument * textDocument )
 {
 	if (!textDocument)
 		return;
@@ -114,7 +116,7 @@ void FileMetaInfo::grabMetaInfo( const KUrl & url, TextDocument * textDocument )
 }
 
 
-void FileMetaInfo::initializeFromMetaInfo( const KUrl & url, TextDocument * textDocument )
+void FileMetaInfo::initializeFromMetaInfo( const QUrl & url, TextDocument * textDocument )
 {
 	if (!textDocument)
 		return;
@@ -124,7 +126,7 @@ void FileMetaInfo::initializeFromMetaInfo( const KUrl & url, TextDocument * text
 }
 
 
-void FileMetaInfo::grabMetaInfo( const KUrl & url, TextView * textView )
+void FileMetaInfo::grabMetaInfo( const QUrl & url, TextView * textView )
 {
 	if (!textView)
 		return;
@@ -134,7 +136,7 @@ void FileMetaInfo::grabMetaInfo( const KUrl & url, TextView * textView )
 }
 
 
-void FileMetaInfo::initializeFromMetaInfo( const KUrl & url, TextView * textView )
+void FileMetaInfo::initializeFromMetaInfo( const QUrl & url, TextView * textView )
 {
 	if (!textView)
 		return;
@@ -143,7 +145,7 @@ void FileMetaInfo::initializeFromMetaInfo( const KUrl & url, TextView * textView
 }
 
 
-void FileMetaInfo::grabMetaInfo( const KUrl & url, OutputMethodDlg * dlg )
+void FileMetaInfo::grabMetaInfo( const QUrl & url, OutputMethodDlg * dlg )
 {
 	if (!dlg)
 		return;
@@ -152,7 +154,7 @@ void FileMetaInfo::grabMetaInfo( const KUrl & url, OutputMethodDlg * dlg )
 }
 
 
-void FileMetaInfo::initializeFromMetaInfo( const KUrl & url, OutputMethodDlg * dlg )
+void FileMetaInfo::initializeFromMetaInfo( const QUrl & url, OutputMethodDlg * dlg )
 {
 	if ( !dlg || url.isEmpty() || !m_metaInfoMap.contains(url) )
 		return;
@@ -173,11 +175,11 @@ void FileMetaInfo::saveAllMetaInfo()
 	for ( MetaInfoMap::iterator it = m_metaInfoMap.begin(); it != end; ++it )
 	{
 		if ( it.value().hasDefaultData() )
-			m_metaInfoConfig->deleteGroup(it.key().prettyUrl());
+			m_metaInfoConfig->deleteGroup(it.key().toDisplayString());
 		
 		else
 		{
-			KConfigGroup grUrl = m_metaInfoConfig->group( it.key().prettyUrl() );
+			KConfigGroup grUrl = m_metaInfoConfig->group( it.key().toDisplayString() );
 			it.value().save( &grUrl );
 		}
 	}
@@ -191,9 +193,7 @@ void FileMetaInfo::loadAllMetaInfo()
 	for ( QStringList::iterator it = urlList.begin(); it != end; ++it )
 	{
 		KConfigGroup grUrl = m_metaInfoConfig->group(*it);
-		m_metaInfoMap[*it].load(&grUrl);
+		m_metaInfoMap[QUrl::fromUserInput(*it)].load(&grUrl);
 	}
 }
 //END class FileMetaInfo
-
-#include "filemetainfo.moc"
