@@ -25,19 +25,19 @@
 #include "programmerdlg.h"
 #include "textdocument.h"
 
-#include <kdebug.h>
-#include <klocalizedstring.h>
-#include <kmessagebox.h>
+#include <KLocalizedString>
+
+#include <QDebug>
 
 FlowCodeDocument::FlowCodeDocument( const QString &caption, const char *name )
 	: FlowICNDocument( caption, name )
 {
 	m_pDocumentIface = new FlowCodeDocumentIface(this);
 	m_type = Document::dt_flowcode;
-	m_microInfo = 0L;
-	m_microSettings = 0L;
-	m_picItem = 0L;
-	m_pLastTextOutputTarget = 0l;
+	m_microInfo = nullptr;
+	m_microSettings = nullptr;
+	m_picItem = nullptr;
+	m_pLastTextOutputTarget = nullptr;
 	
 	m_cmManager->addManipulatorInfo( CMSelect::manipulatorInfo() );
 	m_cmManager->addManipulatorInfo( CMDraw::manipulatorInfo() );
@@ -77,7 +77,7 @@ void FlowCodeDocument::setPicType( const QString &id )
 	MicroInfo *microInfo = MicroLibrary::self()->microInfoWithID(id);
 	
 	if ( !microInfo ) {
-		kWarning() << "FlowCodeDocument::setPicType: Could not set the pic type to PIC \""<<id<<"\"\n";
+		qWarning() << "FlowCodeDocument::setPicType: Could not set the pic type to PIC \""<<id<<"\"\n";
 		return;
 	}
 	
@@ -177,9 +177,9 @@ void FlowCodeDocument::convertToMicrobe()
 	OutputMethodDlg *dlg = new OutputMethodDlg( i18n("Microbe Code Output"), url(), false, activeView() );
 	dlg->setOutputExtension(".microbe");
 	dlg->setFilter( QString("*.microbe|Microbe (*.microbe)\n*|%1").arg(i18n("All Files")) );
-	dlg->exec();
 
-	if (!dlg->isAccepted()) {
+    const int accepted = dlg->exec();
+    if (accepted != QDialog::Accepted) {
 		delete dlg;
 		return;
 	}
@@ -199,9 +199,9 @@ void FlowCodeDocument::convertToAssembly()
 	OutputMethodDlg *dlg = new OutputMethodDlg( i18n("Assembly Code Output"), url(), false, activeView() );
 	dlg->setOutputExtension(".asm");
 	dlg->setFilter( QString("*.asm *.src *.inc|%1 (*.asm, *.src, *.inc)\n*|%2").arg(i18n("Assembly Code")).arg(i18n("All Files")) );
-	dlg->exec();
 
-	if (!dlg->isAccepted()) {
+    const int accepted = dlg->exec();
+    if (accepted != QDialog::Accepted) {
 		delete dlg;
 		return;
 	}
@@ -221,9 +221,9 @@ void FlowCodeDocument::convertToHex()
 	OutputMethodDlg *dlg = new OutputMethodDlg( i18n("Hex Code Output"), url(), false, KTechlab::self() );
 	dlg->setOutputExtension(".hex");
 	dlg->setFilter( QString("*.hex|Hex (*.hex)\n*|%1").arg(i18n("All Files")) );
-	dlg->exec();
 
-	if (!dlg->isAccepted()) {
+    const int accepted = dlg->exec();
+    if (accepted != QDialog::Accepted) {
 		delete dlg;
 		return;
 	}
@@ -241,9 +241,9 @@ void FlowCodeDocument::convertToHex()
 void FlowCodeDocument::convertToPIC()
 {
 	ProgrammerDlg * dlg = new ProgrammerDlg( microSettings()->microInfo()->id(), (QWidget*)KTechlab::self(), "Programmer Dlg" );
-	dlg->exec();
 
-	if ( !dlg->isAccepted() ) {
+    const int accepted = dlg->exec();
+    if (accepted != QDialog::Accepted) {
 		dlg->deleteLater();
 		return;
 	}
@@ -293,6 +293,3 @@ void FlowCodeDocument::varNameChanged( const QString &newValue, const QString &o
 			flowPart->updateVarNames();
 	}
 }
-
-
-#include "flowcodedocument.moc"
