@@ -13,7 +13,7 @@
 
 #include "flowicndocument.h"
 
-#include <qpointer.h>
+#include <QPointer>
 
 class KTechlab;
 class FlowCode;
@@ -35,10 +35,11 @@ class FlowCodeDocument : public FlowICNDocument
 {
 	Q_OBJECT
 	public:
-		FlowCodeDocument( const QString &caption, const char *name = 0L);
-		~FlowCodeDocument();
-	
-		virtual View *createView( ViewContainer *viewContainer, uint viewAreaId, const char *name = 0l );
+		FlowCodeDocument( const QString &caption, const char *name = nullptr);
+		~FlowCodeDocument() override;
+
+		View *createView( ViewContainer *viewContainer, uint viewAreaId, const char *name = nullptr ) override;
+
 
 		/**
 		 * Returns a pointer used for the MicroSettings in this FlowCode document
@@ -68,25 +69,25 @@ class FlowCodeDocument : public FlowICNDocument
 
 	signals:
 		void pinMappingsChanged();
-	
+
 	public slots:
 		/**
 		 * @param target as ConvertToTarget
 		 */
 		void slotConvertTo( QAction* action );
-		void convertToMicrobe();
-		void convertToAssembly();
-		void convertToHex();
-		void convertToPIC();
+		void convertToMicrobe() override;
+		void convertToAssembly() override;
+		void convertToHex() override;
+		void convertToPIC() override;
 		/**
 		 * Called when a variable name has changed (from an entry box)
 		 */
 		void varNameChanged( const QString &newValue, const QString &oldValue );
 
 	protected:
-		virtual bool isValidItem( Item *item );
-		virtual bool isValidItem( const QString &itemId );
-		
+		bool isValidItem( Item *item ) override;
+		bool isValidItem( const QString &itemId ) override;
+
 	private slots:
 		void setLastTextOutputTarget( TextDocument * target );
 
