@@ -20,16 +20,16 @@
 class Count : public FlowPart
 {
 public:
-	Count( ICNDocument *icnDocument, bool newItem, const char *id = 0L );
-	~Count();
-	
+	Count( ICNDocument *icnDocument, bool newItem, const char *id = nullptr );
+	~Count() override;
+
 	static Item* construct( ItemDocument *itemDocument, bool newItem, const char *id );
 	static LibraryItem *libraryItem();
-	
-	virtual void generateMicrobe( FlowCode *code );
+
+	void generateMicrobe( FlowCode *code ) override;
 
 protected:
-	void dataChanged();
+	void dataChanged() override;
 };
 
 #endif
