@@ -20,17 +20,17 @@
 class Embed : public FlowPart
 {
 public:
-	Embed( ICNDocument *icnDocument, bool newItem, const char *id = 0L );
-	~Embed();
-	
+	Embed( ICNDocument *icnDocument, bool newItem, const char *id = nullptr );
+	~Embed() override;
+
 	static Item* construct( ItemDocument *itemDocument, bool newItem, const char *id );
 	static LibraryItem *libraryItem();
-	
-	virtual void generateMicrobe( FlowCode *code );
+
+	void generateMicrobe( FlowCode *code ) override;
 	bool typeIsMicrobe() const;
-	
+
 protected:
-	void dataChanged();
+	void dataChanged() override;
 };
 
 #endif
