@@ -12,7 +12,7 @@
 #include "libraryitem.h"
 #include "flowcode.h"
 
-#include <klocalizedstring.h>
+#include <KLocalizedString>
 
 Item* InputButton::construct( ItemDocument *itemDocument, bool newItem, const char *id )
 {
