@@ -19,15 +19,16 @@
 #include "pinmapping.h"
 #include "viewcontainer.h"
 
-#include <kdebug.h>
-#include <klocalizedstring.h>
-#include <kstdaccel.h>
-#include <kstandardshortcut.h>
+#include <KLocalizedString>
+#include <KStandardShortcut>
 
-#include <qapplication.h>
-#include <qframe.h>
-#include <qlayout.h>
-#include <qaction.h>
+#include <QApplication>
+#include <QDebug>
+#include <QFrame>
+#include <QAction>
+#include <QDialogButtonBox>
+#include <QPushButton>
+#include <QVBoxLayout>
 
 
 //BEGIN class PinMapping
@@ -52,18 +53,17 @@ PinMapping::~PinMapping()
 
 //BEGIN class PinMapEditor
 PinMapEditor::PinMapEditor( PinMapping * pinMapping, MicroInfo * picInfo, QWidget * parent, const char * name )
-	: //KDialog( parent, name, true, i18n("Pin Map Editor"), Ok|Apply|Cancel, KDialog::Ok, true )
-	  KDialog( parent ) //, name, true, i18n("Pin Map Editor"), Ok|Apply|Cancel, KDialog::Ok, true )
+    : QDialog(parent)
 {
     setObjectName(name);
     setModal(true);
-    setCaption(i18n("Pin Map Editor"));
-    setButtons(KDialog::Ok | KDialog::Apply | KDialog::Cancel);
-    setDefaultButton(KDialog::Ok);
-    showButtonSeparator(true);
+    setWindowTitle(i18n("Pin Map Editor"));
+
+    QVBoxLayout *mainLayout = new QVBoxLayout;
+    setLayout(mainLayout);
 
 	m_pPinMapping = pinMapping;
-	
+
 	m_pPinMapDocument = new PinMapDocument();
 
     {
@@ -74,19 +74,19 @@ PinMapEditor::PinMapEditor( PinMapping * pinMapping, MicroInfo * picInfo, QWidge
     }
     {
         QAction * actionSelAll = new QAction( this );
-        actionSelAll->setShortcut( KStandardShortcut::selectAll().primary() );
+        actionSelAll->setShortcut( KStandardShortcut::selectAll().first() );
         connect(actionSelAll, SIGNAL(triggered(bool)), m_pPinMapDocument, SLOT(selectAll()) );
         addAction(actionSelAll);
     }
     {
         QAction * actionUndo = new QAction( this );
-        actionUndo->setShortcut( KStandardShortcut::undo().primary() );
+        actionUndo->setShortcut( KStandardShortcut::undo().first() );
         connect(actionUndo, SIGNAL(triggered(bool)), m_pPinMapDocument, SLOT(undo()) );
         addAction(actionUndo);
     }
     {
         QAction * actionRedo = new QAction( this );
-        actionRedo->setShortcut( KStandardShortcut::redo().primary() );
+        actionRedo->setShortcut( KStandardShortcut::redo().first() );
         connect(actionRedo, SIGNAL(triggered(bool)), m_pPinMapDocument, SLOT(redo()) );
         addAction(actionRedo);
     }
@@ -94,7 +94,7 @@ PinMapEditor::PinMapEditor( PinMapping * pinMapping, MicroInfo * picInfo, QWidge
 	QFrame * f = new QFrame(this);
 	f->setMinimumWidth( 480 );
 	f->setMinimumHeight( 480 );
-	
+
 	f->setFrameShape( QFrame::Box );
 	f->setFrameShadow( QFrame::Plain );
 	QVBoxLayout * fLayout = new QVBoxLayout; // ( f, 1, 0, "fLayout" ); // 2018.08.18 - use non-deprected constructor
@@ -102,33 +102,39 @@ PinMapEditor::PinMapEditor( PinMapping * pinMapping, MicroInfo * picInfo, QWidge
     fLayout->setSpacing(0);
     fLayout->setObjectName("fLayout");
 
-	ViewContainer * vc = new ViewContainer( 0, f );
+	ViewContainer * vc = new ViewContainer( nullptr, f );
 	fLayout->addWidget( vc );
-	
-	m_pPinMapView = static_cast<PinMapView*>(m_pPinMapDocument->createView( vc, 0 ));
-	
-	//qApp->processEvents(); // 2015.07.07 - do not process events, if it is not urgently needed; might generate crashes?
-	
-	m_pPinMapDocument->init( *m_pPinMapping, picInfo );
-	
-    showButtonSeparator( false );
-	// enableButtonSeparator( false );
 
-	setMainWidget(f);
+	m_pPinMapView = static_cast<PinMapView*>(m_pPinMapDocument->createView( vc, 0 ));
+
+	//qApp->processEvents(); // 2015.07.07 - do not process events, if it is not urgently needed; might generate crashes?
+
+	m_pPinMapDocument->init( *m_pPinMapping, picInfo );
+
+    mainLayout->addWidget(f);
+
+    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok|QDialogButtonBox::Cancel|QDialogButtonBox::Apply);
+    mainLayout->addWidget(buttonBox);
+    QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
+    okButton->setDefault(true);
+    okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
+    connect(buttonBox, &QDialogButtonBox::accepted, this, &PinMapEditor::slotOk);
+    connect(buttonBox, &QDialogButtonBox::rejected, this, &QDialog::reject);
+    connect(buttonBox->button(QDialogButtonBox::Apply), &QPushButton::clicked,
+            this, &PinMapEditor::slotApply);
 }
 
 
 void PinMapEditor::slotApply()
 {
 	savePinMapping();
-	KDialog::applyClicked();// slotApply();
 }
 
 
 void PinMapEditor::slotOk()
 {
 	savePinMapping();
-	KDialog::okClicked();// slotOk();
+    accept();
 }
 
 
@@ -142,13 +148,13 @@ void PinMapEditor::savePinMapping()
 
 //BEGIN class PinMapDocument
 PinMapDocument::PinMapDocument()
-	: CircuitICNDocument( 0, 0 )
+	: CircuitICNDocument( nullptr, nullptr )
 {
-	m_pPicComponent = 0l;
-	m_pKeypad = 0l;
-	m_pSevenSegment = 0l;
+	m_pPicComponent = nullptr;
+	m_pKeypad = nullptr;
+	m_pSevenSegment = nullptr;
 	m_type = dt_pinMapEditor;
-	
+
 	m_cmManager->addManipulatorInfo( CMSelect::manipulatorInfo() );
 }
 
@@ -161,21 +167,21 @@ PinMapDocument::~PinMapDocument()
 void PinMapDocument::init( const PinMapping & pinMapping, MicroInfo * microInfo )
 {
 	m_pinMappingType = pinMapping.type();
-	
+
 	m_pPicComponent = static_cast<PIC_IC*>( addItem( "PIC_IC", QPoint( 336, 224 ), true ) );
 	m_pPicComponent->initPackage( microInfo );
-	
+
 	const QStringList pins = pinMapping.pins();
 	const QStringList::const_iterator end = pins.end();
-	
+
 	int keypadCols = -1; // -1 means no keypad
-	
+
 	switch ( m_pinMappingType )
 	{
 		case PinMapping::SevenSegment:
 		{
 			m_pSevenSegment = static_cast<ECSevenSegment*>( addItem( "ec/seven_segment", QPoint( 144, 232 ), true ) );
-			
+
 			char ssPin = 'a';
 			for ( QStringList::const_iterator it = pins.begin(); it != end; ++it )
 			{
@@ -183,37 +189,37 @@ void PinMapDocument::init( const PinMapping & pinMapping, MicroInfo * microInfo
 						 m_pPicComponent->childNode(*it) );
 				ssPin++;
 			}
-			
+
 			break;
 		}
-			
+
 		case PinMapping::Keypad_4x3:
 			m_pKeypad = static_cast<ECKeyPad*>( addItem( "ec/keypad", QPoint( 144, 232 ), true ) );
 			m_pKeypad->property("numCols")->setValue(3);
 			keypadCols = 3;
 			break;
-			
+
 		case PinMapping::Keypad_4x4:
 			m_pKeypad = static_cast<ECKeyPad*>( addItem( "ec/keypad", QPoint( 144, 232 ), true ) );
 			m_pKeypad->property("numCols")->setValue(4);
 			keypadCols = 4;
 			break;
-			
+
 		case PinMapping::Invalid:
-			kDebug() << k_funcinfo << "m_pinMappingType == Invalid" << endl;
+			qDebug() << Q_FUNC_INFO << "m_pinMappingType == Invalid" << endl;
 			break;
 	}
-	
+
 	if ( keypadCols != -1 )
 	{
 		QStringList::const_iterator it = pins.begin();
 		for ( unsigned row = 0; (row < 4) && (it != end); ++row, ++it )
 			ICNDocument::createConnector( m_pKeypad->childNode( QString("row_%1").arg( row ) ), m_pPicComponent->childNode( *it ) );
-		
+
 		for ( int col = 0; (col < keypadCols) && (it != end); ++col, ++it )
 			ICNDocument::createConnector( m_pKeypad->childNode( QString("col_%1").arg( col ) ), m_pPicComponent->childNode( *it ) );
 	}
-	
+
 	clearHistory(); // Don't allow undoing of initial creation of stuff
 }
 
@@ -228,22 +234,22 @@ bool PinMapDocument::isValidItem( const QString & id )
 {
 	if ( !m_pPicComponent && id == "PIC_IC" )
 		return true;
-	
+
 	switch ( m_pinMappingType )
 	{
 		case PinMapping::SevenSegment:
 			return ( !m_pSevenSegment && id == "ec/seven_segment" );
-			
+
 		case PinMapping::Keypad_4x3:
 			return ( !m_pKeypad && id == "ec/keypad" );
-			
+
 		case PinMapping::Keypad_4x4:
 			return ( !m_pKeypad && id == "ec/keypad" );
-			
+
 		case PinMapping::Invalid:
 			return false;
 	}
-	
+
 	return false;
 }
 
@@ -253,7 +259,7 @@ void PinMapDocument::deleteSelection()
 	m_selectList->removeQCanvasItem( m_pPicComponent );
 	m_selectList->removeQCanvasItem( m_pSevenSegment );
 	m_selectList->removeQCanvasItem( m_pKeypad );
-	
+
 	ICNDocument::deleteSelection();
 }
 
@@ -262,11 +268,11 @@ PinMapping PinMapDocument::pinMapping() const
 {
 	const NodeInfoMap picNodeInfoMap = m_pPicComponent->nodeMap();
 	const NodeInfoMap::const_iterator picNodeInfoMapEnd = picNodeInfoMap.end();
-	
+
 	QStringList picPinIDs;
 	QStringList attachedIDs;
-	Component * attached = 0l;
-	
+	Component * attached = nullptr;
+
 	switch ( m_pinMappingType )
 	{
 		case PinMapping::SevenSegment:
@@ -274,30 +280,30 @@ PinMapping PinMapDocument::pinMapping() const
 				attachedIDs << QChar('a'+i);
 			attached = m_pSevenSegment;
 			break;
-			
+
 		case PinMapping::Keypad_4x3:
 			for ( unsigned i = 0; i < 4; ++i )
-				attachedIDs << QString("row_%1").arg(i);
+				attachedIDs << QString::fromLatin1("row_%1").arg(i);
 			for ( unsigned i = 0; i < 3; ++i )
-				attachedIDs << QString("col_%1").arg(i);
+				attachedIDs << QString::fromLatin1("col_%1").arg(i);
 			attached = m_pKeypad;
 			break;
-			
+
 		case PinMapping::Keypad_4x4:
 			for ( unsigned i = 0; i < 4; ++i )
-				attachedIDs << QString("row_%1").arg(i);
+				attachedIDs << QString::fromLatin1("row_%1").arg(i);
 			for ( unsigned i = 0; i < 4; ++i )
-				attachedIDs << QString("col_%1").arg(i);
+				attachedIDs << QString::fromLatin1("col_%1").arg(i);
 			attached = m_pKeypad;
 			break;
-			
+
 		case PinMapping::Invalid:
 			break;
 	}
-	
+
 	if ( !attached )
 		return PinMapping();
-	
+
 	QStringList::iterator end = attachedIDs.end();
 	for ( QStringList::iterator attachedIt = attachedIDs.begin(); attachedIt != end; ++ attachedIt )
 	{
@@ -312,13 +318,13 @@ PinMapping PinMapDocument::pinMapping() const
 				break;
 			}
 		}
-				
+
 		picPinIDs << pinID;
 	}
-	
+
 	PinMapping pinMapping( m_pinMappingType );
 	pinMapping.setPins( picPinIDs );
-	
+
 	return pinMapping;
 }
 //END class PinMapDocument
@@ -349,8 +355,8 @@ Item* PIC_IC::construct( ItemDocument *itemDocument, bool newItem, const char *i
 LibraryItem* PIC_IC::libraryItem()
 {
 	return new LibraryItem(
-            QStringList(QString("PIC_IC")),
-            0, 0, LibraryItem::lit_other, PIC_IC::construct );
+            QStringList(QString::fromLatin1("PIC_IC")),
+            nullptr, nullptr, LibraryItem::lit_other, PIC_IC::construct );
 }
 
 
@@ -368,18 +374,18 @@ PIC_IC::~PIC_IC()
 void PIC_IC::initPackage( MicroInfo * microInfo )
 {
 	// The code in this function is a stripped down version of that in PICComponent::initPackage
-	
+
 	if (!microInfo)
 		return;
-	
+
 	MicroPackage * microPackage = microInfo->package();
 	if (!microPackage)
 		return;
-	
+
 	//BEGIN Get pin IDs
 	QStringList allPinIDs = microPackage->pinIDs();
 	QStringList ioPinIDs = microPackage->pinIDs( PicPin::type_bidir | PicPin::type_input | PicPin::type_open );
-	
+
 	// Now, we make the unwanted pin ids blank, so a pin is not created for them
 	const QStringList::iterator allPinIDsEnd = allPinIDs.end();
 	for ( QStringList::iterator it = allPinIDs.begin(); it != allPinIDsEnd; ++it )
@@ -388,15 +394,15 @@ void PIC_IC::initPackage( MicroInfo * microInfo )
 			*it = "";
 	}
 	//END Get pin IDs
-	
-	
+
+
 	//BEGIN Remove old stuff
 	// Remove old text
 	TextMap textMapCopy = m_textMap;
 	const TextMap::iterator textMapEnd = textMapCopy.end();
 	for ( TextMap::iterator it = textMapCopy.begin(); it != textMapEnd; ++it )
 		removeDisplayText(it.key());
-	
+
 	// Remove old nodes
 	NodeInfoMap nodeMapCopy = m_nodeMap;
 	const NodeInfoMap::iterator nodeMapEnd = nodeMapCopy.end();
@@ -406,17 +412,15 @@ void PIC_IC::initPackage( MicroInfo * microInfo )
 			removeNode( it.key() );
 	}
 	//END Remove old stuff
-	
-	
-	
+
+
+
 	//BEGIN Create new stuff
 	initDIPSymbol( allPinIDs, 80 );
 	initDIP(allPinIDs);
 	//END Create new stuff
-	
-	
+
+
 	addDisplayText( "picid", QRect(offsetX(), offsetY()-16, width(), 16), microInfo->id() );
 }
 //END class PIC_IC
-
-#include "pinmapping.moc"
