@@ -20,16 +20,16 @@
 class Unary : public FlowPart
 {
 public:
-	Unary( ICNDocument *icnDocument, bool newItem, const char *id = 0L );
-	~Unary();
-	
+	Unary( ICNDocument *icnDocument, bool newItem, const char *id = nullptr );
+	~Unary() override;
+
 	static Item* construct( ItemDocument *itemDocument, bool newItem, const char *id );
 	static LibraryItem *libraryItem();
-	
-	virtual void generateMicrobe( FlowCode *code );
-	
+
+	void generateMicrobe( FlowCode *code ) override;
+
 protected:
-	void dataChanged();
+	void dataChanged() override;
 };
 
 #endif
