@@ -10,11 +10,11 @@
 
 #include "colorcombo.h"
 
-#include <kcolordialog.h>
-#include <klocalizedstring.h>
+#include <KLocalizedString>
 
-#include <qpainter.h>
-#include <qdebug.h>
+#include <QPainter>
+#include <QColorDialog>
+#include <QDebug>
 
 bool ColorCombo::createdPalettes = false;
 QColor * ColorCombo::palette[ NumberOfSchemes ];
@@ -104,8 +104,9 @@ void ColorCombo::slotActivated( int index )
 {
 	if ( index == 0 )
 	{
-		if ( KColorDialog::getColor( customColor, this ) == QDialog::Accepted )
-		{
+        const QColor selectedColor = QColorDialog::getColor(customColor, this);
+        if (selectedColor.isValid()) {
+            customColor = selectedColor;
 			QPainter painter;
 			QPen pen;
 			QRect rect( 0, 0, width(), QFontMetrics(font()).height()+4);
@@ -199,6 +200,3 @@ void ColorCombo::addColors()
         }
 	}
 }
-
-
-#include "colorcombo.moc"
