@@ -11,15 +11,14 @@
 #include "cnitem.h"
 #include "doublespinbox.h"
 
-#include <kdebug.h>
-#include <kglobal.h>
-#include <klocale.h>
-#include <klocalizedstring.h>
+#include <KLocalizedString>
 
-#include <qlineedit.h>
-#include <qregexp.h>
-#include <qtimer.h>
-#include <qdebug.h>
+#include <QDebug>
+#include <QLocale>
+#include <QLineEdit>
+#include <QRegExp>
+#include <QTimer>
+#include <QDebug>
 
 #include <algorithm>
 #include <cmath>
@@ -332,19 +331,19 @@ double DoubleSpinBox::valueFromText( const QString & text ) const {
 
     DoubleSpinbox_qDebug() << Q_FUNC_INFO << "text = " << text;
 
-    KLocale * locale = KGlobal::locale();
+    QLocale locale;
 
     // Fetch the characters that we don't want to discard
-    const QString exclude = locale->decimalSymbol()
-            + locale->thousandsSeparator()
-            + locale->positiveSign()
-            + locale->negativeSign();
+    const QString exclude = QString(locale.decimalPoint())
+            + locale.groupSeparator()
+            + locale.positiveSign()
+            + locale.negativeSign();
 
     QString textToStrip( text );
     QString numberToRead = textToStrip.remove( QRegExp("[^"+exclude+"\\d]") );
 
     bool ok;
-    double value = locale->readNumber( numberToRead, &ok );
+    double value = locale.toDouble(numberToRead, &ok);
     if (!ok) {
         DoubleSpinbox_qDebug() << Q_FUNC_INFO << "numberToRead = |" << numberToRead << "| NOT OK";
         value = 0;
@@ -429,8 +428,7 @@ QString DoubleSpinBox::textFromValue(double value) const
 
     DoubleSpinbox_qDebug() << Q_FUNC_INFO << "toDisplayNr = " << toDisplayNr;
 
-    KLocale * locale = KGlobal::locale();
-    QString numberStr = locale->formatNumber( toDisplayNr, 0 /* 3-leftDigits */ );
+    QString numberStr = QLocale().toString( toDisplayNr, 'f', 0 /* 3-leftDigits */ );
 
     QString magStr = Item::getNumberMag( value );
 
@@ -515,6 +513,3 @@ double DoubleSpinBox::roundToOneSF( double value )
 //
 // 	setValue( value );
 // }
-
-#include "doublespinbox.moc"
-
