@@ -11,19 +11,19 @@
 #include "componentmodellibrary.h"
 #include "componentmodelwidget.h"
 
-#include <kdebug.h>
-#include <klineedit.h>
-#include <klocalizedstring.h>
-#include <ktoolbar.h>
+#include <KLineEdit>
+#include <KLocalizedString>
+#include <KToolBar>
 //#include <ktoolbarbutton.h> // converted to QToolButton
 
-#include <qlistwidget.h>
-#include <qlabel.h>
-#include <qlayout.h>
+#include <QDebug>
+#include <QListWidget>
+#include <QLabel>
+#include <QVBoxLayout>
 // #include <q3header.h> // needed?
-#include <qpainter.h>
-#include <qtoolbutton.h>
-#include <qpalette.h>
+#include <QPainter>
+#include <QToolButton>
+#include <QPalette>
 
 
 //BEGIN class ComponentModelWidget
@@ -40,7 +40,7 @@ ComponentModelWidget::ComponentModelWidget( QWidget *parent, const char *name )
 	//BEGIN Filter lineedit
     QHBoxLayout *h1Layout = new QHBoxLayout;
     h1Layout->setMargin(0);
-	KToolBar * bar = new KToolBar( this, "ComponentModelSearch" );
+	KToolBar * bar = new KToolBar( QStringLiteral("ComponentModelSearch"), this );
 	bar->setIconSize( QSize( 22, 22 ) /*, false  ?? */ ); //looks more sensible
 	//bar->setFlat( true ); //removes the ugly frame
     bar->setMovable( false ); //removes the ugly frame
@@ -201,5 +201,3 @@ void ClickLineEdit::focusOutEvent( QFocusEvent *ev )
 	QLineEdit::focusOutEvent( ev );
 }
 //END class ClickLineEdit
-
-#include "componentmodelwidget.moc"
