@@ -22,27 +22,26 @@
 
 #include "drawparts/drawpart.h"
 
-#include <klocalizedstring.h>
-#include <kdebug.h>
-#include <kpushbutton.h>
-#include <kicon.h>
+#include <KLocalizedString>
+#include <KIconLoader>
 
-#include <qevent.h>
-#include <qfontmetrics.h>
-#include <qtimer.h>
-#include <qapplication.h>
-#include <qeventloop.h>
-#include <qstyleditemdelegate.h>
+#include <QPushButton>
+#include <QApplication>
+#include <QDebug>
+#include <QEvent>
+#include <QFontMetrics>
+#include <QHeaderView>
+#include <QIcon>
+#include <QTimer>
+#include <QStyledItemDelegate>
 
-// #include <q3header.h>
-#include <qheaderview.h>
 
 struct PropertyEditorStyledItemColProperty : public QStyledItemDelegate {
     PropertyEditor *m_propEditor;
 
     PropertyEditorStyledItemColProperty(PropertyEditor *propEditor) : m_propEditor(propEditor) { }
 
-    virtual void paint(QPainter * painter, const QStyleOptionViewItem & option, const QModelIndex & index) const {
+    void paint(QPainter * painter, const QStyleOptionViewItem & option, const QModelIndex & index) const override {
 //         if ( depth() == 0 )
 //             return;
         QTableWidgetItem *itemPtr = m_propEditor->item( index.row(), index.column());
@@ -111,7 +110,7 @@ struct PropertyEditorStyledItemColValue : public QStyledItemDelegate {
 
     PropertyEditorStyledItemColValue(PropertyEditor *propEditor) : m_propEditor(propEditor) { }
 
-    virtual void paint(QPainter * painter, const QStyleOptionViewItem & option, const QModelIndex & index) const {
+    void paint(QPainter * painter, const QStyleOptionViewItem & option, const QModelIndex & index) const override {
 //         if ( depth() == 0 )
 //             return;
 
@@ -242,8 +241,8 @@ PropertyEditor::PropertyEditor( QWidget * parent, const char * name )
  , justClickedItem(false)
  , m_lastCellWidgetRow(-1)
  , m_lastCellWidgetCol(-1)
- , m_colPropertyDelegate(NULL)
- , m_colValueDelegate(NULL)
+ , m_colPropertyDelegate(nullptr)
+ , m_colValueDelegate(nullptr)
 {
     setObjectName( name );
 	//m_items.setAutoDelete(false); // 2018.08.13 - unused
@@ -262,8 +261,8 @@ PropertyEditor::PropertyEditor( QWidget * parent, const char * name )
     m_colValueDelegate = new PropertyEditorStyledItemColValue(this);
     setItemDelegateForColumn(1, m_colValueDelegate);
 
-	m_topItem = 0;
-	m_editItem = 0;
+	m_topItem = nullptr;
+	m_editItem = nullptr;
 
 	connect(this, SIGNAL(clicked(const QModelIndex&)), this, SLOT(slotClicked(const QModelIndex&)));
 	connect(this, SIGNAL(itemActivated(QTableWidgetItem*)), this, SLOT(slotCurrentChanged(QTableWidgetItem *)));
@@ -276,10 +275,10 @@ PropertyEditor::PropertyEditor( QWidget * parent, const char * name )
 // 	connect(header(), SIGNAL(clicked( int )), this, SLOT(moveEditor()));
 // 	connect(header(), SIGNAL(sectionHandleDoubleClicked ( int )), this, SLOT(slotColumnSizeChanged( int )));
 
-	m_defaults = new KPushButton(viewport());
+	m_defaults = new QPushButton(viewport());
 	m_defaults->setFocusPolicy(Qt::NoFocus);
 	setFocusPolicy(Qt::ClickFocus);
-	m_defaults->setIcon(KIcon("edit-undo"));
+	m_defaults->setIcon(QIcon::fromTheme("edit-undo"));
 	m_defaults->setToolTip(i18n("Undo changes"));
 	m_defaults->hide();
 	connect(m_defaults, SIGNAL(clicked()), this, SLOT(resetItem()));
@@ -314,7 +313,7 @@ void PropertyEditor::slotClicked(const QModelIndex& index)
 {
 	if (!index.isValid())
 		return;
-	
+
 // 2019.01.19 - moved to slotCurrentCellChanged()
 //     if (index.column() == 1) {
 //         // PropertyEditorItem *i = static_cast<PropertyEditorItem *>(item);// 2018.08.13 - not needed
@@ -388,11 +387,11 @@ void PropertyEditor::createEditor( const QModelIndex& index )
         m_lastCellWidgetRow = -1;
         m_lastCellWidgetCol = -1;
     }
-    m_currentEditor = 0;
+    m_currentEditor = nullptr;
 
 	m_editItem = i;
 
-	PropertySubEditor *editor=0;
+	PropertySubEditor *editor = nullptr;
 	switch ( i->type() )
 	{
 		case Variant::Type::String:
@@ -410,24 +409,24 @@ void PropertyEditor::createEditor( const QModelIndex& index )
 		case Variant::Type::KeyPad:
 			editor = new PropertyEditorList( viewport(), i->property() );
 			break;
-			
+
 		case Variant::Type::FileName:
             qDebug() << Q_FUNC_INFO << "creating PropertyEditorFile";
 			editor = new PropertyEditorFile( viewport(), i->property() );
 			break;
-			
+
 		case Variant::Type::Int:
 			editor = new PropertyEditorSpin( viewport(), i->property() );
 			break;
-			
+
 		case Variant::Type::Double:
 			editor = new PropertyEditorDblSpin( viewport(), i->property() );
 			break;
-			
+
 		case Variant::Type::Color:
 			editor = new PropertyEditorColor( viewport(), i->property() );
 			break;
-			
+
 		case Variant::Type::Bool:
 			editor = new PropertyEditorBool( viewport(), i->property() );
 			break;
@@ -450,7 +449,7 @@ void PropertyEditor::createEditor( const QModelIndex& index )
 
 		editor->setFocus();
 	}
-	
+
 	m_currentEditor = editor;
 	showDefaultsButton( i->property()->changed() );
 }
@@ -539,15 +538,15 @@ void PropertyEditor::reset()
         m_lastCellWidgetRow = -1;
         m_lastCellWidgetCol = -1;
     }
-    m_currentEditor = 0;
-	
+    m_currentEditor = nullptr;
+
 	if ( m_defaults->isVisible() )
 		m_defaults->hide();
 
 	//clear();
     QTableWidget::reset();
-	m_editItem = 0;
-	m_topItem = 0;
+	m_editItem = nullptr;
+	m_topItem = nullptr;
 }
 
 
@@ -564,10 +563,10 @@ void PropertyEditor::create( ItemGroup * b )
 {
     qDebug() << Q_FUNC_INFO << "b=" << b;
 	m_pItemGroup = b;
-	
+
 	//QCString selectedPropertyName1, selectedPropertyName2;
 //     QByteArray selectedPropertyName1, selectedPropertyName2;     // 2018.08. 13 - dead code
-	
+
 	fill();
 /* 2018.08. 13 - dead code
 	//select prev. selecteed item
@@ -591,7 +590,7 @@ void PropertyEditor::create( ItemGroup * b )
 void PropertyEditor::fill()
 {
 	reset();
-	
+
 	if ( !m_pItemGroup || !m_pItemGroup->activeItem() ) {
         qWarning() << Q_FUNC_INFO << " no active item " << m_pItemGroup;
 		return;
@@ -642,7 +641,7 @@ void PropertyEditor::fill()
 				// These are not handled by the ItemEditor
 				continue;
 		}
-		
+
         const int nextRow = rowCount();
         setRowCount(nextRow + 1);
         {
@@ -659,7 +658,7 @@ void PropertyEditor::fill()
             setItem(nextRow, 1, itemPropValue);
         }
 		//m_items.insert( v->id().latin1(), item ); // 2018.08.13 - unused
-		
+
 	}
 }
 
@@ -706,7 +705,7 @@ void PropertyEditor::moveEditor()
 {
 	if ( !m_currentEditor )
 		return;
-	
+
 	QPoint p = QPoint(0, visualItemRect(m_editItem).y()); //  = contentsToViewport(QPoint(0, itemPos(m_editItem))); // TODO
 	m_currentEditor->move(m_currentEditor->x(), p.y());
 	if( m_defaults->isVisible() ) {
@@ -796,7 +795,7 @@ bool PropertyEditor::handleKeyPress( QKeyEvent* /*ev*/ )
 PropertyEditorItem *PropertyEditor::selectedItem() {
     QModelIndexList selList = selectedIndexes();
     if (selList.empty()) {
-        return NULL;
+        return nullptr;
     }
     if (selList.size() > 1) {
         qWarning() << Q_FUNC_INFO << " unexpected selection size of " << selList.size();
@@ -808,5 +807,3 @@ PropertyEditorItem *PropertyEditor::selectedItem() {
     }
     return itemProp;
 }
-
-#include "propertyeditor.moc"
