@@ -13,9 +13,9 @@
 #ifndef PROPERTYEDITOR_H
 #define PROPERTYEDITOR_H
 
-#include <qvariant.h>
-#include <qpointer.h>
-#include <qtablewidget.h>
+#include <QVariant>
+#include <QPointer>
+#include <QTableWidget>
 
 // #include <q3dict.h>
 //#include <q3listview.h> // 2018.08.13 - ported to QTableWidget
@@ -26,7 +26,7 @@
 class ItemGroup;
 class Variant;
 class PropertySubEditor;
-class KPushButton;
+class QPushButton;
 class QStyledItemDelegate;
 
 //! A list view to edit any type of properties
@@ -37,13 +37,13 @@ class PropertyEditor : public QTableWidget // K3ListView
 	public:
 		/*! Creates an empty PropertyEditor with \a parent as parent widget.
 		*/
-		PropertyEditor( QWidget * parent = 0, const char * name = 0 );
-		virtual ~PropertyEditor();
+		PropertyEditor( QWidget * parent = nullptr, const char * name = nullptr );
+		~PropertyEditor() override;
 
 		/*! Reset the list, ie clears all items in the list.
 		   if \a editorOnly is true, then only the current editor will be cleared, not the whole list.
 		*/
-		void reset();
+		void reset() override;
 
 		/**
 		 * Updates the list of Property editors from the items selected in
@@ -51,7 +51,7 @@ class PropertyEditor : public QTableWidget // K3ListView
 		 */
 		void create( ItemGroup * itemGroup );
 
-		virtual QSize sizeHint() const;
+		QSize sizeHint() const override;
 		/**
 		 * @internal used by PropertySubEditor and PropertyEditor.
 		 */
@@ -77,7 +77,7 @@ class PropertyEditor : public QTableWidget // K3ListView
 		void resetItem();
 		/**
 		 * This slot updates the positions of current editor and revert button.
-		 * It is called when double-clicking list's header. 
+		 * It is called when double-clicking list's header.
 		 */
 		void moveEditor();
 		/**
@@ -119,7 +119,7 @@ class PropertyEditor : public QTableWidget // K3ListView
 		 * Reimplemented from K3ListView to update editor and revert button
 		 * position.
 		 */
-		void resizeEvent(QResizeEvent *ev);
+		void resizeEvent(QResizeEvent *ev) override;
 
 		void showDefaultsButton( bool show );
 
@@ -131,7 +131,7 @@ class PropertyEditor : public QTableWidget // K3ListView
 		QPointer<PropertySubEditor> m_currentEditor;
 		PropertyEditorItem *m_editItem;
 		PropertyEditorItem *m_topItem; //The top item is used to control the drawing of every branches.
-		KPushButton *m_defaults; // "Revert to defaults" button
+		QPushButton *m_defaults; // "Revert to defaults" button
 		//PropertyEditorItem::Dict m_items; // 2018.08.13 - unused
 		int m_baseRowHeight;
 		//! Used in setFocus() to prevent scrolling to previously selected item on mouse click
