@@ -13,14 +13,12 @@
 #include "property.h"
 #include "propertyeditorcolor.h"
 
-#include <klocalizedstring.h>
-#include <kfontdialog.h>
-#include <kpushbutton.h>
-#include <kdebug.h>
+#include <KLocalizedString>
 
-#include <qlabel.h>
-#include <qstring.h>
-#include <qevent.h>
+#include <QDebug>
+#include <QLabel>
+#include <QString>
+#include <QKeyEvent>
 
 //BEGIN class PropertyEditorColor
 PropertyEditorColor::PropertyEditorColor( QWidget * parent, Property * property, const char * name )
@@ -59,6 +57,3 @@ bool PropertyEditorColor::eventFilter(QObject* watched, QEvent* e)
 	return PropertySubEditor::eventFilter(watched, e);
 }
 //END class PropertyEditorColor
-
-#include "propertyeditorcolor.moc"
-
