@@ -12,10 +12,9 @@
 #define PROPERTYEDITORFILE_H
 
 #include "propertysubeditor.h"
-#include <kurl.h>
 
 class KLineEdit;
-class KPushButton;
+class QPushButton;
 class QResizeEvent;
 class QLabel;
 class Variant;
@@ -26,18 +25,18 @@ class PropertyEditorFile : public PropertySubEditor
 	Q_OBJECT
 
 	public:
-		PropertyEditorFile( QWidget * parent, Property * property, const char * name = 0 );
-		~PropertyEditorFile() {;}
-		
-		void resizeEvent(QResizeEvent *ev);
-		bool eventFilter( QObject * watched, QEvent * e );
+		PropertyEditorFile( QWidget * parent, Property * property, const char * name = nullptr );
+		~PropertyEditorFile() override {;}
+
+		void resizeEvent(QResizeEvent *ev) override;
+		bool eventFilter( QObject * watched, QEvent * e ) override;
 
 	protected slots:
 		void selectFile();
 
 	protected:
 		KLineEdit * m_lineedit;
-		KPushButton * m_button;
+		QPushButton * m_button;
 };
 
 
