@@ -14,17 +14,16 @@
 #include "propertyeditor.h"
 #include "propertyeditoritem.h"
 
-#include <kdebug.h>
-#include <kiconloader.h>
-#include <klocalizedstring.h>
+#include <KLocalizedString>
 
-#include <qcolor.h>
-#include <qcursor.h>
-#include <qfont.h>
-#include <qpainter.h>
-#include <qpixmap.h>
-#include <qpoint.h>
-#include <qsize.h>
+#include <QDebug>
+#include <QColor>
+#include <QCursor>
+#include <QFont>
+#include <QPainter>
+#include <QPixmap>
+#include <QPoint>
+#include <QSize>
 
 
 //BEGIN Class PropertyEditorItem
@@ -52,7 +51,7 @@ PropertyEditorItem::PropertyEditorItem(QTableWidget* parent, const QString& text
     setParent(parent);
     setText(text);
 
-	m_property = 0;
+	m_property = nullptr;
     setFlags(flags() &= (~Qt::ItemIsSelectable));
 	//setSelectable(false);
 	//setOpen(true);
@@ -224,5 +223,3 @@ void PropertyEditorItem::updateValue(bool alsoParent)
 // {
 // }
 //END class PropertyEditorItem
-
-#include "propertyeditoritem.moc"
