@@ -13,18 +13,17 @@
 #include "propertyeditorlist.h"
 #include "property.h"
 
-#include <kdebug.h>
-#include <kiconloader.h>
 //#include <klistbox.h>
-#include <klocalizedstring.h>
+#include <KLocalizedString>
 
-#include <qcursor.h>
+#include <QDebug>
+#include <QCursor>
 //#include <q3hbox.h>
-#include <qboxlayout.h>
-#include <qstringlist.h>
-#include <qtoolbutton.h>
-#include <qevent.h>
-#include <qlineedit.h>
+#include <QHBoxLayout>
+#include <QStringList>
+#include <QToolButton>
+#include <QInputEvent>
+#include <QLineEdit>
 
 
 //BEGIN class PropComboBox
@@ -154,6 +153,3 @@ void PropertyEditorList::valueChanged( const QString & text )
 	ItemInterface::self()->setProperty( m_property );
 }
 //END class PropertyEditorList
-
-
-#include "propertyeditorlist.moc"
