@@ -8,19 +8,18 @@
  *   (at your option) any later version.                                   *
  ***************************************************************************/
 
-#include <qvariant.h>
-#include <qevent.h>
-
-#include <kdebug.h>
-
 #include "propertysubeditor.h"
 #include "propertyeditor.h"
 
+#include <QVariant>
+#include <QKeyEvent>
+#include <QDebug>
+
 PropertySubEditor::PropertySubEditor( QWidget * parent, Property * property, const char * name )
  : QWidget( parent /*, name */ )
 {
     setObjectName( name );
-	m_childWidget = 0;
+	m_childWidget = nullptr;
 	m_property = property;
 	m_leaveTheSpaceForRevertButton = false;
 }
@@ -75,6 +74,3 @@ PropertySubEditor::setWidget(QWidget *w, QWidget* focusProxy)
 PropertySubEditor::~PropertySubEditor()
 {
 }
-
-
-#include "propertysubeditor.moc"
