@@ -19,16 +19,16 @@
 #include "mechanicsdocument.h"
 #include "katemdi.h"
 
-#include <kapplication.h>
-#include <kconfig.h>
-#include <kdebug.h>
-#include <klocalizedstring.h>
-#include <kconfiggroup.h>
+#include <KSharedConfig>
+#include <KLocalizedString>
+#include <KConfigGroup>
 
 // #include <q3dragobject.h>
-#include <qlayout.h>
+#include <QDebug>
 // #include <q3popupmenu.h>
-#include <qmenu.h>
+#include <QLayout>
+#include <QMenu>
+#include <QMimeData>
 
 #include <cassert>
 
@@ -38,7 +38,7 @@ ILVItem::ILVItem( QTreeWidget *parent, const QString &id )
     setData(0, DataRole_ID, QVariant(id));
     // 	m_id = id;  // 2018.08.12 - use value()
 	b_isRemovable = false;
-	m_pProjectItem = 0l;
+	m_pProjectItem = nullptr;
 }
 
 ILVItem::ILVItem( QTreeWidgetItem *parent, const QString &id )
@@ -47,7 +47,7 @@ ILVItem::ILVItem( QTreeWidgetItem *parent, const QString &id )
 	//m_id = id;    // 2018.08.12 - use value()
     setData(0, DataRole_ID, QVariant(id));
 	b_isRemovable = false;
-	m_pProjectItem = 0l;
+	m_pProjectItem = nullptr;
 }
 
 
@@ -79,7 +79,7 @@ ItemSelector::ItemSelector( QWidget *parent, const char *name )
     }
 
     setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding); // ?
-	
+
 // 	connect( this, SIGNAL(executed(K3ListViewItem*) ), this, SLOT(slotItemExecuted(K3ListViewItem*)) );
 	connect( this, SIGNAL(itemClicked(QTreeWidgetItem*,int)), this, SLOT(slotItemClicked(QTreeWidgetItem*,int)) );
 	connect( this, SIGNAL(itemDoubleClicked(QTreeWidgetItem*,int)), this, SLOT(slotItemDoubleClicked(QTreeWidgetItem*,int)) );
@@ -107,13 +107,13 @@ void ItemSelector::clear()
 void ItemSelector::addItem( const QString & caption, const QString & id, const QString & _category, const QPixmap & icon, bool removable )
 {
     qDebug() << Q_FUNC_INFO << "id=" << id;
-	ILVItem *parentItem = 0L;
-	
+	ILVItem *parentItem = nullptr;
+
 	QString category = _category;
 	if ( !category.startsWith("/") ) {
 		category.prepend('/');
 	}
-	
+
 	do
 	{
 		category.remove(0,1);
@@ -122,13 +122,13 @@ void ItemSelector::addItem( const QString & caption, const QString & id, const Q
 		int pos = category.indexOf('/');
 		if ( pos == -1 ) cat = category;
 		else cat = category.left( pos );
-		
+
 		cat.replace( "|", "/" );
-	
+
 		if ( m_categories.indexOf(cat) == -1 )
 		{
 			m_categories.append(cat);
-			
+
 			if (parentItem) {
 				parentItem = new ILVItem( parentItem, "" );
 			}
@@ -138,7 +138,7 @@ void ItemSelector::addItem( const QString & caption, const QString & id, const Q
             //parentItem->setExpandable(true); // 2018.08.12 - is it needed?
 
 			parentItem->setExpanded( readOpenState(cat) );
-			
+
 			parentItem->setText( 0, cat );
 		}
 		else
@@ -149,16 +149,16 @@ void ItemSelector::addItem( const QString & caption, const QString & id, const Q
             }
             parentItem = dynamic_cast<ILVItem*>( foundList.front() );
 		}
-		
+
 		category.remove( 0, pos );
 	} while ( category.contains('/') );
-	
+
 	if ( !parentItem )
 	{
-		kError() << "Unexpected error in finding parent item for category list"<<endl;
+		qCritical() << "Unexpected error in finding parent item for category list"<<endl;
 		return;
 	}
-	
+
 	ILVItem *item = new ILVItem( parentItem, id );
 	//item->setPixmap( 0, icon );  // 2018.08.12 - replaced with line below
     item->setIcon( 0, QIcon(icon) );
@@ -172,10 +172,10 @@ void ItemSelector::addItem( const QString & caption, const QString & id, const Q
 void ItemSelector::writeOpenStates()
 {
 	//KConfig *config = kapp->config();
-    KSharedConfigPtr configPtr = KGlobal::config();
+    KSharedConfigPtr configPtr = KSharedConfig::openConfig();
 	//config->setGroup( name() );
     KConfigGroup configGroup = configPtr->group( objectName() );
-	
+
 	const QStringList::iterator end = m_categories.end();
 	for ( QStringList::iterator it = m_categories.begin(); it != end; ++it )
 	{
@@ -195,17 +195,17 @@ void ItemSelector::writeOpenStates()
 bool ItemSelector::readOpenState( const QString &id )
 {
 	//KConfig *config = kapp->config();
-    KSharedConfigPtr configPtr = KGlobal::config();
+    KSharedConfigPtr configPtr = KSharedConfig::openConfig();
 	//config->setGroup( name() );
     KConfigGroup configGroup = configPtr->group( objectName() );
-	
+
 	return configGroup.readEntry<bool>( id+"IsOpen", true );
 }
 
 QTreeWidgetItem *ItemSelector::selectedItem() const {
     QList< QTreeWidgetItem*> selectedList = selectedItems();
     if (selectedList.empty()) {
-        return NULL;
+        return nullptr;
     }
     if (selectedList.size() > 1) {
         qWarning() << Q_FUNC_INFO << " expected 1 item in selection, got " << selectedList.size();
@@ -221,7 +221,7 @@ QMimeData * ItemSelector::mimeData(const QList<QTreeWidgetItem *> items) const {
     QTreeWidgetItem *theItem = items.first();
     if (!theItem) {
         qWarning() << Q_FUNC_INFO << "unexpected null item";
-        return NULL;
+        return nullptr;
     }
     qDebug() << Q_FUNC_INFO << " theItem = " << theItem;
     QVariant idAsVariant = theItem->data(0, ILVItem::DataRole_ID);
@@ -229,7 +229,7 @@ QMimeData * ItemSelector::mimeData(const QList<QTreeWidgetItem *> items) const {
     const QString id = idAsVariant.toString();
     qDebug() << Q_FUNC_INFO << "id='" << id << "'";
 
-    QMimeData * mime = new QMimeData;
+    QMimeData * mime = new QMimeData();
 
     QByteArray data;
     QDataStream stream( &data, QIODevice::WriteOnly );
@@ -260,7 +260,7 @@ void ItemSelector::slotContextMenuRequested(const QPoint& pos)
 	if ( !item || !(static_cast<ILVItem*>(item))->isRemovable() ) {
 		return;
 	}
-	
+
 	QMenu *menu = new QMenu(this);
 	/* menu->insertItem(
         //, Qt::Key_Delete // 2015.12.29 - do not specify shortcut key, because it does not work
@@ -285,7 +285,7 @@ void ItemSelector::slotRemoveSelectedItem()
         qDebug() << Q_FUNC_INFO << "no selected item to remove";
 		return;
     }
-	
+
 	emit itemRemoved( item->data(0, ILVItem::DataRole_ID).toString() /*key( 0, 0 ) */ );
 	ILVItem *parent = dynamic_cast<ILVItem*>(item->QTreeWidgetItem::parent());
 	delete item;
@@ -311,7 +311,7 @@ void ItemSelector::slotItemSelected( )
 	if (!item) {
 		return;
     }
-	
+
 	emit itemSelected( item->data(0, ILVItem::DataRole_ID).toString() /* item->key( 0, 0 ) */ );
 }
 
@@ -320,10 +320,10 @@ void ItemSelector::slotItemClicked( QTreeWidgetItem *item, int )
 {
 	if (!item)
 		return;
-	
+
 	if ( ItemDocument * itemDocument = dynamic_cast<ItemDocument*>(DocManager::self()->getFocusedDocument()) )
 		itemDocument->slotUnsetRepeatedItemId();
-	
+
     const QString &itemIdString = item->data(0, ILVItem::DataRole_ID).toString();
 
 	emit itemClicked( itemIdString /* item->key( 0, 0 ) */ );
@@ -334,22 +334,22 @@ void ItemSelector::slotItemDoubleClicked( QTreeWidgetItem *item, int )
 {
 	if (!item)
 		return;
-	
+
 	//QString id = item->key( 0, 0 );
     const QString &id = item->data(0, ILVItem::DataRole_ID).toString();
-	
+
 	if ( Document * doc = DocManager::self()->getFocusedDocument() )
 	{
 		if ( doc->type() == Document::dt_flowcode && id.startsWith("flow/") )
 			(static_cast<FlowCodeDocument*>(doc))->slotSetRepeatedItemId(id);
-		
+
 		else if ( doc->type() == Document::dt_circuit && (id.startsWith("ec/") || id.startsWith("sc/")) )
 			(static_cast<CircuitDocument*>(doc))->slotSetRepeatedItemId(id);
-		
+
 		else if ( doc->type() == Document::dt_mechanics && id.startsWith("mech/") )
 			(static_cast<MechanicsDocument*>(doc))->slotSetRepeatedItemId(id);
 	}
-	
+
 	emit itemDoubleClicked(id);
 }
 
@@ -358,7 +358,7 @@ void ItemSelector::slotItemDoubleClicked( QTreeWidgetItem *item, int )
 // {
 // 	const QString &id = currentItem()->data(0, ILVItem::DataRole_ID).toString() /* key(0,0) */;
 //
-// 	Q3StoredDrag * d = 0l;
+// 	Q3StoredDrag * d = nullptr;
 //
 // 	if ( id.startsWith("flow/") )
 // 		d = new Q3StoredDrag( "ktechlab/flowpart", this );
@@ -392,7 +392,7 @@ void ItemSelector::slotItemDoubleClicked( QTreeWidgetItem *item, int )
 
 
 //BEGIN class ComponentSelector
-ComponentSelector * ComponentSelector::m_pSelf = 0l;
+ComponentSelector * ComponentSelector::m_pSelf = nullptr;
 
 
 ComponentSelector * ComponentSelector::self( KateMDI::ToolView * parent )
@@ -413,14 +413,14 @@ ComponentSelector::ComponentSelector( KateMDI::ToolView * parent )
 
 	setWhatsThis( i18n(
 			"Add components to the circuit diagram by dragging them into the circuit.<br><br>"
-			
+
 			"To add more than one component of the same type, doubleclick on a component, and click repeatedly in the circuit to place the component. Right click to stop placement.<br><br>"
-			
+
 			"Some components (such as subcircuits) can be removed by right clicking on the item and selecting \"Remove\"."
 							   ) );
-	
+
 	setListCaption( i18n("Component") );
-	
+
 	LibraryItemList *items = itemLibrary()->items();
     qDebug() << Q_FUNC_INFO << " there are " << items->count() << " items";
 	const LibraryItemList::iterator end = items->end();
@@ -435,7 +435,7 @@ ComponentSelector::ComponentSelector( KateMDI::ToolView * parent )
 
 
 //BEGIN class FlowPartSelector
-FlowPartSelector * FlowPartSelector::m_pSelf = 0l;
+FlowPartSelector * FlowPartSelector::m_pSelf = nullptr;
 
 
 FlowPartSelector * FlowPartSelector::self( KateMDI::ToolView * parent )
@@ -453,9 +453,9 @@ FlowPartSelector::FlowPartSelector( KateMDI::ToolView * parent )
 	: ItemSelector( (QWidget*)parent, "Part Selector" )
 {
 	setWhatsThis( i18n("Add FlowPart to the FlowCode document by dragging them there.<br><br>To add more than one FlowPart of the same type, doubleclick on a FlowPart, and click repeatedly in the FlowChart to place the component. Right click to stop placement.") );
-	
+
 	setListCaption( i18n("Flow Part") );
-	
+
 	LibraryItemList *items = itemLibrary()->items();
 	const LibraryItemList::iterator end = items->end();
 	for ( LibraryItemList::iterator it = items->begin(); it != end; ++it )
@@ -468,7 +468,7 @@ FlowPartSelector::FlowPartSelector( KateMDI::ToolView * parent )
 
 
 //BEGIN class MechanicsSelector
-MechanicsSelector * MechanicsSelector::m_pSelf = 0l;
+MechanicsSelector * MechanicsSelector::m_pSelf = nullptr;
 
 
 MechanicsSelector * MechanicsSelector::self( KateMDI::ToolView * parent )
@@ -486,7 +486,7 @@ MechanicsSelector::MechanicsSelector( QWidget *parent )
 	: ItemSelector( (QWidget*)parent, "Mechanics Selector" )
 {
 	setWhatsThis( i18n("Add mechanical parts to the mechanics work area by dragging them there.") );
-	
+
 	LibraryItemList *items = itemLibrary()->items();
 	const LibraryItemList::iterator end = items->end();
 	for ( LibraryItemList::iterator it = items->begin(); it != end; ++it )
@@ -498,6 +498,3 @@ MechanicsSelector::MechanicsSelector( QWidget *parent )
 	}
 }
 //END class MechanicsSelector
-
-
-#include "itemselector.moc"
