@@ -10,14 +10,14 @@
 
 #include "logview.h"
 
-#include <kdebug.h>
-#include <kiconloader.h>
 #include <katemdi.h>
-#include <klocalizedstring.h>
+#include <KLocalizedString>
 
+#include <QDebug>
 // #include <q3popupmenu.h>
-#include <qmenu.h>
-#include <qevent.h>
+#include <QMenu>
+#include <QLayout>
+#include <QEvent>
 
 //BEGIN class LogView
 LogView::LogView( KateMDI::ToolView * parent, const char *name )
@@ -154,6 +154,3 @@ MessageInfo::MessageInfo( QString fileURL, int fileLine )
 	m_fileLine = fileLine;
 }
 //END class MessageInfo
-
-
-#include "logview.moc"
