@@ -14,8 +14,8 @@
 class KTechlab;
 // class Q3PopupMenu;
 
-#include <ktextedit.h>
-#include <qmap.h>
+#include <KTextEdit>
+#include <QMap>
 
 namespace KateMDI { class ToolView; }
 
@@ -24,10 +24,10 @@ class MessageInfo
 	public:
 		MessageInfo();
 		MessageInfo( QString fileURL, int fileLine );
-		
+
 		QString fileURL() const { return m_fileURL; }
 		int fileLine() const { return m_fileLine; }
-			
+
 	protected:
 		QString m_fileURL;
 		int m_fileLine;
@@ -44,8 +44,8 @@ class LogView : public KTextEdit
 {
 	Q_OBJECT
 	public:
-		LogView( KateMDI::ToolView * parent, const char *name = 0 );
-		~LogView();
+		LogView( KateMDI::ToolView * parent, const char *name = nullptr );
+		~LogView() override;
 	
 		enum OutputType
 		{
@@ -55,17 +55,17 @@ class LogView : public KTextEdit
 			ot_warning,		// Grey
 			ot_error		// Red
 		};
-		
+
 	signals:
 		/**
 		 * Emitted when the user clicks on a paragraph in the log view
 		 */
 		void paraClicked( const QString &text, MessageInfo messageInfo );
-	
+
 	public slots:
 		virtual void clear();
 		void addOutput( QString text, OutputType outputType, MessageInfo messageInfo = MessageInfo() );
-	
+
 	protected:
 		virtual QMenu * createPopupMenu( const QPoint & pos );
 		/**
@@ -76,11 +76,11 @@ class LogView : public KTextEdit
 		 * Replaces "&lt;" with "<", "&amp;" with "&", etc
 		 */
 		void untidyText( QString &t );
-	
+
 		MessageInfoMap m_messageInfoMap;
 
-        virtual void mouseDoubleClickEvent ( QMouseEvent * e );
-	
+        void mouseDoubleClickEvent ( QMouseEvent * e ) override;
+
 	private slots:
 		void slotParaClicked( int para, int pos );
 };
