@@ -12,7 +12,7 @@
 #define MICROSELECTWIDGET_H
 
 // #include <q3groupbox.h>
-#include <qgroupbox.h>
+#include <QGroupBox>
 
 class QVBoxLayout;
 class QHBoxLayout;
@@ -30,8 +30,8 @@ class MicroSelectWidget : public QGroupBox
 	Q_OBJECT
 
 	public:
-		MicroSelectWidget( QWidget* parent = 0, const char* name = 0, Qt::WFlags fl = 0 );
-		~MicroSelectWidget();
+		MicroSelectWidget( QWidget* parent = nullptr, const char* name = nullptr, Qt::WindowFlags f = {} );
+		~MicroSelectWidget() override;
 
 		void setMicro( const QString & id );
 		QString micro() const;
