@@ -11,10 +11,9 @@
 #ifndef MICROSETTINGSDLG_H
 #define MICROSETTINGSDLG_H
 
-#include <kdialog.h>
-
-#include <qmap.h>
-#include <qvalidator.h>
+#include <QDialog>
+#include <QMap>
+#include <QValidator>
 // #include <q3valuevector.h>
 
 class KLineEdit;
@@ -22,6 +21,7 @@ class MicroSettings;
 class MicroSettingsWidget;
 class NewPinMappingWidget;
 class PinMapping;
+class QPushButton;
 
 typedef QMap< QString, PinMapping > PinMappingMap;
 
@@ -29,16 +29,16 @@ typedef QMap< QString, PinMapping > PinMappingMap;
 /**
 @author David Saxton
 */
-class MicroSettingsDlg : public KDialog
+class MicroSettingsDlg : public QDialog
 {
 	Q_OBJECT
 	public:
-		MicroSettingsDlg( MicroSettings *_microSettings, QWidget *parent = 0L, const char *name = 0L );
-		~MicroSettingsDlg();
+		MicroSettingsDlg( MicroSettings *_microSettings, QWidget *parent = nullptr, const char *name = nullptr );
+		~MicroSettingsDlg() override;
+
+		void reject() override;
+		void accept() override;
 
-		void reject();
-		void accept();
-		
 		/**
 		 * @param pinMapName the pinMapName; may be changed to make it valid
 		 * (e.g. spaces replaced with underscores).
@@ -47,7 +47,7 @@ class MicroSettingsDlg : public KDialog
 		 * in use, and Acceptable otherwise.
 		 */
 		QValidator::State validatePinMapName( QString & pinMapName ) const;
-    
+
 	public slots:
 		/**
 		 * Saves the port details in the given row to the MicroSettings class.
@@ -83,18 +83,23 @@ class MicroSettingsDlg : public KDialog
 		 * Called when the dialog is Applied or OK'd.
 		 */
 		void slotSaveStuff();
-		
+
+    signals:
+        void applyClicked();
+
 	protected slots:
 		void slotCheckNewPinMappingName( const QString & name );
-		
+        void slotApplyClicked();
+
 	protected:
 		/**
 		 * Set each button enabled / disabled as appropriate.
 		 */
 		void updatePinMapButtons();
-		
+
 		NewPinMappingWidget * m_pNewPinMappingWidget; // Used for checking that the variable name is ok
-		KDialog * m_pNewPinMappingDlg;
+        QDialog * m_pNewPinMappingDlg;
+        QPushButton *m_pNewPinMappingOkButton;
 		MicroSettingsWidget * m_pWidget;
 		MicroSettings * m_pMicroSettings;
 		PinMappingMap m_pinMappings;
@@ -111,21 +116,22 @@ class PinMappingNameValidator : public QValidator
 		 * Create a validator. If oldName is not empty, then the input is
 		 * allowed to be oldName.
 		 */
-		PinMappingNameValidator( MicroSettingsDlg * dlg, const QString & oldName = 0 )
-			: QValidator(0)
+		PinMappingNameValidator( MicroSettingsDlg * dlg, const QString & oldName = nullptr )
+			: QValidator(nullptr)
 		{
 			m_pDlg = dlg;
 			m_oldName = oldName;
 		}
-		
-		virtual State validate( QString & input, int & ) const
+
+        State validate( QString & input, int & ) const override
+
 		{
 			if ( (!m_oldName.isEmpty()) && (input == m_oldName) )
 				return QValidator::Acceptable;
-			
+
 			return m_pDlg->validatePinMapName( input );
 		}
-		
+
 	protected:
 		MicroSettingsDlg * m_pDlg;
 		QString m_oldName;
