@@ -17,18 +17,21 @@
 #include "projectmanager.h"
 #include "textdocument.h"
 
-#include <kcombobox.h>
-#include <kdebug.h>
-#include <klineedit.h>
-// #include <k3iconview.h>
-#include <klocalizedstring.h>
-#include <kiconloader.h>
-
 #include <canvas.h>
-#include <qcheckbox.h>
-#include <qdir.h>
-#include <qfile.h>
-#include <qlabel.h>
+
+#include <KLineEdit>
+// #include <k3iconview.h>
+#include <KLocalizedString>
+#include <KIconLoader>
+
+#include <QDebug>
+#include <QCheckBox>
+#include <QDir>
+#include <QFile>
+#include <QLabel>
+#include <QDialogButtonBox>
+#include <QPushButton>
+#include <QVBoxLayout>
 // #include <q3paintdevicemetrics.h>
 
 #include <ui_newfilewidget.h>
@@ -42,19 +45,16 @@ class NewFileWidget : public QWidget, public Ui::NewFileWidget {
 };
 
 NewFileDlg::NewFileDlg( QWidget *parent )
-    :
-    //KDialog( parent, "newfiledlg", true, "New File", KDialog::Ok|KDialog::Cancel, KDialog::Ok, true )
-    KDialog( parent ) // , "newfiledlg", true, "New File", KDialog::Ok|KDialog::Cancel, KDialog::Ok, true )
+    : QDialog(parent)
 {
     setObjectName("newfiledlg");
     setModal(true);
-    setCaption(i18n("New File"));
-    setButtons(KDialog::Ok | KDialog::Cancel);
-    setDefaultButton(KDialog::Ok);
-    showButtonSeparator(true);
+    setWindowTitle(i18n("New File"));
+
+    QVBoxLayout *mainLayout = new QVBoxLayout;
+    setLayout(mainLayout);
 
 	m_pMainParent = parent;
-    m_bAccepted = false;
     m_pNewFileWidget = new NewFileWidget(this);
 
 	 m_pNewFileWidget->typeIconView->setSelectionMode(QAbstractItemView::SingleSelection /*Q3IconView::Single*/);
@@ -96,9 +96,15 @@ NewFileDlg::NewFileDlg( QWidget *parent )
         flags &= (~Qt::ItemIsDragEnabled);
         (*it)->setFlags(flags);
 
-        qDebug() << Q_FUNC_INFO << "W = " << (*it)->icon().availableSizes().first().width() << " H=" << (*it)->icon().availableSizes().first().height();
-		minWidth += (*it)->icon().availableSizes().first().width() + 20;
-		minHeight = qMax( minHeight, (*it)->icon().availableSizes().first().height()+20 );
+        QList<QSize> listAvSizes = (*it)->icon().availableSizes();
+        if (listAvSizes.isEmpty()) {
+            qWarning() << Q_FUNC_INFO << "no available sizes for " << (*it)->text();
+        } else {
+            qDebug() << Q_FUNC_INFO << "W = " << (*it)->icon().availableSizes().first().width()
+                << " H=" << (*it)->icon().availableSizes().first().height();
+            minWidth += (*it)->icon().availableSizes().first().width() + 20;
+            minHeight = qMax( minHeight, (*it)->icon().availableSizes().first().height()+20 );
+        }
 	}
 	qDebug() << Q_FUNC_INFO << "minW = " << minWidth << " minH=" << minHeight;
 	m_pNewFileWidget->typeIconView->setMinimumSize( minWidth, minHeight );
@@ -107,12 +113,21 @@ NewFileDlg::NewFileDlg( QWidget *parent )
 	m_pNewFileWidget->addToProjectCheck->setEnabled( ProjectManager::self()->currentProject() );
 	microSelectWidget()->setAllowedFlowCodeSupport( MicroInfo::FullSupport | MicroInfo::PartialSupport );
     
-	setMainWidget(m_pNewFileWidget);
+	mainLayout->addWidget(m_pNewFileWidget);
     
 	// Our behaviour is to have single click selects and double click accepts the dialog
 	connect( m_pNewFileWidget->typeIconView, SIGNAL(itemSelectionChanged()), this, SLOT(fileTypeChanged()) );
 	connect( m_pNewFileWidget->typeIconView, SIGNAL(doubleClicked(const QModelIndex &)), this, SLOT(accept()));
 
+    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok|QDialogButtonBox::Cancel);
+    mainLayout->addWidget(buttonBox);
+
+    QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
+    okButton->setDefault(true);
+    okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
+    connect(buttonBox, &QDialogButtonBox::accepted, this, &QDialog::accept);
+    connect(buttonBox, &QDialogButtonBox::rejected, this, &QDialog::reject);
+
     setAcceptDrops(true);
 
 	m_pNewFileWidget->typeIconView->adjustSize();
@@ -122,8 +137,7 @@ NewFileDlg::NewFileDlg( QWidget *parent )
 
 void NewFileDlg::accept()
 {
-	hide();
-	m_bAccepted = true;
+    QDialog::accept();
 	
 	const QString fileText = m_pNewFileWidget->typeIconView->currentItem()->text();
 	
@@ -163,13 +177,6 @@ void NewFileDlg::accept()
 }
 
 
-void NewFileDlg::reject()
-{
-    hide();
-    m_bAccepted = false;
-}
-
-
 void NewFileDlg::fileTypeChanged()
 {
     bool doEnableMicros = false;
@@ -185,6 +192,3 @@ MicroSelectWidget * NewFileDlg::microSelectWidget() const
 {
 	return m_pNewFileWidget->m_pMicroSelect;
 }
-
-
-#include "newfiledlg.moc"
