@@ -11,7 +11,7 @@
 #ifndef NEWFILEDLG_H
 #define NEWFILEDLG_H
 
-#include <kdialog.h>
+#include <QDialog>
 
 class MicroSelectWidget;
 class NewFileWidget;
@@ -22,32 +22,29 @@ A standard dialog for getting file details from the user for a new project
 @short Dialog for new file details
 @author David Saxton
 */
-class NewFileDlg : public KDialog
+class NewFileDlg : public QDialog
 {
 	Q_OBJECT
 	public:
 		NewFileDlg( QWidget *parent );
 
-		void reject();
-		void accept();
-		
-		bool accepted() const { return m_bAccepted; }
+		void accept() override;
+
 		int fileType() const { return m_fileType; }
 		int codeType() const { return m_codeType; }
 		bool addToProject() const { return m_bAddToProject; }
 		QString microID() const { return m_microID; }
 		MicroSelectWidget * microSelectWidget() const;
-    
+
 	public slots:
 		void fileTypeChanged();
-		
+
 	protected:
-		bool m_bAccepted;
 		int m_fileType;
 		int m_codeType;
 		bool m_bAddToProject;
 		QString m_microID;
-		
+
 		NewFileWidget * m_pNewFileWidget;
 		QWidget * m_pMainParent;
 };
