@@ -14,25 +14,26 @@
 #include "probepositioner.h"
 #include "simulator.h"
 
-#include <kconfig.h>
-#include <kdebug.h>
-#include <klocalizedstring.h>
-#include <kglobal.h>
+#include <KConfigGroup>
+#include <KLocalizedString>
+#include <KSharedConfig>
 // #include <k3popupmenu.h>
 
-#include <qcheckbox.h>
-#include <qcursor.h>
-#include <qevent.h>
-#include <qlabel.h>
-#include <qpainter.h>
-#include <qpixmap.h>
-#include <qscrollbar.h>
-#include <qmenu.h>
-#include <qtimer.h>
+#include <QCheckBox>
+#include <QCursor>
+#include <QDebug>
+#include <QPaintEvent>
+#include <QLabel>
+#include <QPainter>
+#include <QPixmap>
+#include <QScrollBar>
+#include <QMenu>
+#include <QTimer>
 
 #include <algorithm>
 #include <cmath>
 
+
 using namespace std;
 
 inline uint64_t min( uint64_t a, uint64_t b)
@@ -44,7 +45,7 @@ inline uint64_t min( uint64_t a, uint64_t b)
 OscilloscopeView::OscilloscopeView( QWidget *parent, const char *name)
 	: QFrame( parent /*, name */ /*, Qt::WNoAutoErase */ ),
 	b_needRedraw(true),
-	m_pixmap(0),
+	m_pixmap(nullptr),
 	m_fps(10),
 	m_sliderValueAtClick(-1),
 	m_clickOffsetPos(-1),
@@ -53,7 +54,7 @@ OscilloscopeView::OscilloscopeView( QWidget *parent, const char *name)
 {
     setObjectName( name );
 	//KGlobal::config()->setGroup("Oscilloscope");
-    KConfigGroup grOscill = KGlobal::config()->group("Oscilloscope");
+    KConfigGroup grOscill(KSharedConfig::openConfig(), "Oscilloscope");
 	m_fps = grOscill.readEntry( "FPS", 25);
 
 	//setBackgroundMode(Qt::NoBackground); // 2018.12.07
@@ -116,11 +117,11 @@ void OscilloscopeView::mousePressEvent( QMouseEvent *event)
 			setCursor( Qt::SizeAllCursor);
 			return;
 		}
-		
+
 		case Qt::RightButton:
 		{
 			event->accept();
-	
+
 			QMenu fpsMenu;
 			//fpsMenu.insertTitle( i18n("Framerate")); // 2017.12.27 - use setTitle
             //fpsMenu.insertItem( i18n("Framerate"), 1 );   // 2018.12.07 - use actions
@@ -132,9 +133,9 @@ void OscilloscopeView::mousePressEvent( QMouseEvent *event)
             }
             //fpsMenu.insertSeparator(); // 2018.12.07
             fpsMenu.addSeparator();
-	
+
 			const int fps[] = { 10, 25, 50, 75, 100 };
-	
+
 			for( uint i=0; i<5; ++i)
 			{
 				const int num = fps[i];
@@ -143,12 +144,12 @@ void OscilloscopeView::mousePressEvent( QMouseEvent *event)
                 QAction *a = fpsMenu.addAction( i18n("%1 fps", QString::number(num)) );
                 a->setData( num );
 			}
-	
+
 			connect( &fpsMenu, SIGNAL(triggered(QAction*)), this, SLOT(slotSetFrameRate(QAction*)));
 			fpsMenu.exec( event->globalPos());
 			return;
 		}
-		
+
 		default:
 		{
 			QFrame::mousePressEvent(event);
@@ -162,7 +163,7 @@ void OscilloscopeView::mouseMoveEvent( QMouseEvent *event)
 {
 	event->accept();
 	updateTimeLabel();
-	
+
 	if( m_sliderValueAtClick != -1)
 	{
 		int dx = event->pos().x() - m_clickOffsetPos;
@@ -176,7 +177,7 @@ void OscilloscopeView::mouseReleaseEvent( QMouseEvent *event)
 {
 	if( m_sliderValueAtClick == -1)
 		return QFrame::mouseReleaseEvent(event);
-	
+
 	event->accept();
 	m_sliderValueAtClick = -1;
 	setCursor( Qt::ArrowCursor);
@@ -188,7 +189,7 @@ void OscilloscopeView::slotSetFrameRate( QAction *action)
     int fps = action->data().toInt();
 	m_fps = fps;
 	//KGlobal::config()->setGroup("Oscilloscope");
-    KConfigGroup grOscill = KGlobal::config()->group("Oscilloscope");
+    KConfigGroup grOscill(KSharedConfig::openConfig(), "Oscilloscope");
 	grOscill.writeEntry( "FPS", m_fps);
 }
 
@@ -203,12 +204,12 @@ static double lld_modulus( int64_t a, double b)
 void OscilloscopeView::paintEvent( QPaintEvent *e)
 {
 	QRect r = e->rect();
-	
+
 	if(b_needRedraw)
 	{
 		updateOutputHeight();
 		const double pixelsPerSecond = Oscilloscope::self()->pixelsPerSecond();
-		
+
         if (!m_pixmap) {
             qWarning() << Q_FUNC_INFO << " unexpected null m_pixmap in " << this;
             return;
@@ -223,55 +224,55 @@ void OscilloscopeView::paintEvent( QPaintEvent *e)
         }
 
 		p.setClipRegion(e->region());
-		
+
 		//BEGIN Draw vertical marker lines
 		const double divisions = 5.0;
 		const double min_sep = 10.0;
-		
+
 		double spacing = pixelsPerSecond/(std::pow( divisions, std::floor(std::log(pixelsPerSecond/min_sep)/std::log(divisions))));
-		
+
 		// Pixels offset is the number of pixels that the view is scrolled along
 		const int64_t pixelsOffset = int64_t(Oscilloscope::self()->scrollTime()*pixelsPerSecond/LOGIC_UPDATE_RATE);
 		double linesOffset = - lld_modulus( pixelsOffset, spacing);
-		
+
 		int blackness = 256 - int(184.0 * spacing / (min_sep*divisions*divisions));
 		p.setPen( QColor( blackness, blackness, blackness));
-		
+
 		for( double i = linesOffset; i <= frameRect().width(); i += spacing)
 			p.drawLine( int(i), 1, int(i), frameRect().height()-2);
-		
-		
-		
+
+
+
 		spacing *= divisions;
 		linesOffset = - lld_modulus( pixelsOffset, spacing);
-		
+
 		blackness = 256 - int(184.0 * spacing / (min_sep*divisions*divisions));
 		p.setPen( QColor( blackness, blackness, blackness));
-		
+
 		for( double i = linesOffset; i <= frameRect().width(); i += spacing)
 			p.drawLine( int(i), 1, int(i), frameRect().height()-2);
-		
-		
-		
+
+
+
 		spacing *= divisions;
 		linesOffset = - lld_modulus( pixelsOffset, spacing);
-		
+
 		blackness = 256 - int(184.0);
 		p.setPen( QColor( blackness, blackness, blackness));
-		
+
 		for( double i = linesOffset; i <= frameRect().width(); i += spacing)
 			p.drawLine( int(i), 1, int(i), frameRect().height()-2);
 		//END Draw vertical marker lines
-		
+
 		drawLogicData(p);
 		drawFloatingData(p);
-		
+
 		p.setPen(Qt::black);
 		p.drawRect( frameRect());
-		
+
 		b_needRedraw = false;
 	}
-	
+
 	//bitBlt( this, r.x(), r.y(), m_pixmap, r.x(), r.y(), r.width(), r.height()); // 2018.12.07
 	QPainter p;
     const bool paintStarted = p.begin(this);
@@ -292,7 +293,7 @@ void OscilloscopeView::updateOutputHeight()
 void OscilloscopeView::drawLogicData( QPainter & p)
 {
 	const double pixelsPerSecond = Oscilloscope::self()->pixelsPerSecond();
-	
+
 	const LogicProbeDataMap::iterator end = Oscilloscope::self()->m_logicProbeDataMap.end();
 	for( LogicProbeDataMap::iterator it = Oscilloscope::self()->m_logicProbeDataMap.begin(); it != end; ++it)
 	{
@@ -304,25 +305,25 @@ void OscilloscopeView::drawLogicData( QPainter & p)
 		// between pixels ( = deltaAt / totalDeltaAt)
 		int64_t deltaAt = 1;
 		int totalDeltaAt = 1;
-		
+
 		LogicProbeData * probe = it.value();
 
 		vector<LogicDataPoint> *data = probe->m_data;
 		if(!data->size()) continue;
-		
+
 		const int midHeight = Oscilloscope::self()->probePositioner->probePosition(probe);
 		const int64_t timeOffset = Oscilloscope::self()->scrollTime();
-		
+
 		// Draw the horizontal line indicating the midpoint of our output
 		p.setPen( QColor( 228, 228, 228));
 		p.drawLine( 0, midHeight, width(), midHeight);
-		
+
 		// Set the pen colour according to the colour the user has selected for the probe
 		p.setPen( probe->color());
-		
+
 		// The smallest time step that will display in our oscilloscope
 		const int minTimeStep = int(LOGIC_UPDATE_RATE/pixelsPerSecond);
-		
+
 		int64_t at = probe->findPos(timeOffset);
 		const int64_t maxAt = probe->m_data->size();
 		int64_t prevTime = (*data)[at].time;
@@ -334,14 +335,14 @@ void OscilloscopeView::drawLogicData( QPainter & p)
 			// Search for the next pos which will show up at our zoom level
 			int64_t previousAt = at;
 			int64_t dAt = deltaAt / totalDeltaAt;
-			
+
 			while ( (dAt > 1) && (at < maxAt) && ( (int64_t((*data)[at].time) - prevTime) != minTimeStep))
 			{
 				// Search forwards until we overshoot
 				while ( at < maxAt && ( int64_t((*data)[at].time) - prevTime) < minTimeStep)
 					at += dAt;
 				dAt /= 2;
-				
+
 				// Search backwards until we undershoot
 				while ( (at < maxAt) && ( int64_t((*data)[at].time) - prevTime) > minTimeStep)
 				{
@@ -351,7 +352,7 @@ void OscilloscopeView::drawLogicData( QPainter & p)
 				}
 				dAt /= 2;
 			}
-			
+
 			// Possibly increment the value of at found by one (or more if this is the first go)
 			while ( (previousAt == at) || ((at < maxAt) && ( int64_t((*data)[at].time) - prevTime) < minTimeStep))
 				at++;
@@ -361,14 +362,14 @@ void OscilloscopeView::drawLogicData( QPainter & p)
 			// Update the average values
 			deltaAt += at - previousAt;
 			totalDeltaAt++;
-			
+
 			bool nextHigh = (*data)[at].value;
 			if( nextHigh == prevHigh) continue;
 
 			int64_t nextTime = (*data)[at].time;
 			int nextX = int((nextTime - timeOffset)*(pixelsPerSecond/LOGIC_UPDATE_RATE));
 			int nextY = midHeight + int(nextHigh ? -m_halfOutputHeight : +m_halfOutputHeight);
-			
+
 			p.drawLine( prevX, prevY, nextX, prevY);
 			p.drawLine( nextX, prevY, nextX, nextY);
 
@@ -379,7 +380,7 @@ void OscilloscopeView::drawLogicData( QPainter & p)
 
 			if( nextX > width()) break;
 		};
-		
+
 		// If we could not draw right to the end; it is because we exceeded
 		// maxAt
 		if( prevX < width())
@@ -415,15 +416,18 @@ void OscilloscopeView::drawFloatingData(QPainter &p)
 		p.setPen( probe->color());
 
 		int64_t at = probe->findPos(timeOffset);
-		const int64_t maxAt = probe->m_data->size();
-		if(at > maxAt) at = maxAt;
+		const int64_t atEnd = probe->m_data->size();
+		if (at > atEnd) at = atEnd;
 		int64_t prevTime = probe->toTime(at);
 
-		double v = (*data)[(at>0)?at:0];
+		double v = 0;
+        if (at < atEnd) {
+            v = (*data)[(at>0)?at:0];
+        }
 		int prevY = v_to_y;
 		int prevX = int((prevTime - timeOffset)*(pixelsPerSecond/LOGIC_UPDATE_RATE));
 
-		while ( at < maxAt) {
+		while ( at < atEnd - 1) {
 			at++;
 
 			uint64_t nextTime = prevTime + uint64_t(LOGIC_UPDATE_RATE * LINEAR_UPDATE_PERIOD);
@@ -447,5 +451,3 @@ void OscilloscopeView::drawFloatingData(QPainter &p)
 			p.drawLine( prevX, prevY, width(), prevY);
 	}
 }
-
-#include "oscilloscopeview.moc"
