@@ -13,10 +13,10 @@
 #include "oscilloscopeview.h"
 #include "probepositioner.h"
 
-#include <qevent.h>
-#include <qpainter.h>
+#include <QPaintEvent>
+#include <QPainter>
 // #include <q3pointarray.h> // 2018.08.14
-#include <qdebug.h>
+#include <QDebug>
 
 #include <algorithm>
 #include <cmath>
@@ -26,12 +26,12 @@ ProbePositioner::ProbePositioner(QWidget *parent, const char *name)
 {
     setObjectName( name );
 	m_probePosOffset = 0;
-	p_draggedProbe = 0l;
+	p_draggedProbe = nullptr;
 	setFixedWidth( int(probeArrowWidth) );
 	//setBackgroundMode(Qt::NoBackground); // 2018.12.07
     setBackgroundRole( QPalette::NoRole );
 	b_needRedraw = true;
-	m_pixmap = 0l;
+	m_pixmap = nullptr;
 }
 
 
@@ -108,7 +108,7 @@ ProbeData* ProbePositioner::probeAtPosition( const QPoint &pos )
 			return probeData;
 	}
 	m_probePosOffset = 0;
-	return 0l;
+	return nullptr;
 }
 
 
@@ -224,6 +224,3 @@ void ProbePositioner::paintEvent( QPaintEvent *e )
     }
     p.drawImage(r, m_pixmap->toImage(), r);
 }
-
-
-#include "probepositioner.moc"
