@@ -17,11 +17,12 @@
 #include "ui_programmerwidget.h"
 
 
-#include <qcombobox.h>
+#include <QComboBox>
+#include <QDialogButtonBox>
+#include <QPushButton>
+#include <QVBoxLayout>
 
-#include <kguiitem.h>
-#include <klocalizedstring.h>
-#include <kstdguiitem.h>
+#include <KLocalizedString>
 
 
 class ProgrammerWidget : public QWidget, public Ui::ProgrammerWidget {
@@ -32,24 +33,18 @@ class ProgrammerWidget : public QWidget, public Ui::ProgrammerWidget {
 };
 
 ProgrammerDlg::ProgrammerDlg( const QString & picID, QWidget *parent, const char *name )
-	: KDialog( parent ) // , name, true, i18n("PIC Programmer"), Ok|Cancel )
+    : QDialog(parent)
 {
     setObjectName(name);
     setModal(true);
-    setCaption(i18n("PIC Programmer"));
-    setButtons(Ok|Cancel);
+    setWindowTitle(i18n("PIC Programmer"));
 
-	// Change the "Ok" button to a "Burn" button
-	KGuiItem burnItem = KStandardGuiItem::ok();
-	burnItem.setText( i18n("Burn") );
-	//setButtonOK( burnItem );
-    setButtonGuiItem(Ok, burnItem);
+    QVBoxLayout *mainLayout = new QVBoxLayout;
+    setLayout(mainLayout);
 
-
-	m_bAccepted = false;
 	m_pProgrammerWidget = new ProgrammerWidget( this );
 	m_pProgrammerSettings = new PicProgrammerSettings;
-	
+
 	// Setup the list of programmers
 	QComboBox * programmerCombo = m_pProgrammerWidget->m_pProgrammerProgram;
 	QStringList programmerNames = m_pProgrammerSettings->configNames( false );
@@ -84,12 +79,21 @@ ProgrammerDlg::ProgrammerDlg( const QString & picID, QWidget *parent, const char
         else
             c->setItemText(c->currentIndex(), text);
     }
-	
+
 	// Set the pic type to the one requested
 	if ( !picID.isEmpty() )
 		m_pProgrammerWidget->m_pMicroSelect->setMicro( picID );
-	
-	setMainWidget( m_pProgrammerWidget );
+
+    mainLayout->addWidget(m_pProgrammerWidget);
+
+    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Cancel);
+    QPushButton *burnButton = new QPushButton(QIcon::fromTheme(QStringLiteral("dialog-ok")), i18n("Burn"), buttonBox);
+    buttonBox->addButton(burnButton, QDialogButtonBox::AcceptRole);
+    burnButton->setDefault(true);
+    burnButton->setShortcut(Qt::CTRL | Qt::Key_Return);
+    mainLayout->addWidget(buttonBox);
+    connect(buttonBox, &QDialogButtonBox::accepted, this, &QDialog::accept);
+    connect(buttonBox, &QDialogButtonBox::rejected, this, &QDialog::reject);
 }
 
 
@@ -102,31 +106,13 @@ void ProgrammerDlg::initOptions( ProcessOptions * options )
 {
 	if ( !options )
 		return;
-	
+
 	options->m_picID = m_pProgrammerWidget->m_pMicroSelect->micro();
 	options->m_port = m_pProgrammerWidget->m_pPicProgrammerPort->currentText();
 	options->m_program = m_pProgrammerWidget->m_pProgrammerProgram->currentText();
 }
 
-
-void ProgrammerDlg::accept()
-{
-	m_bAccepted = true;
-	hide();
-}
-
-
-void ProgrammerDlg::reject()
-{
-    hide();
-	m_bAccepted = false;
-}
-
-
 MicroSelectWidget * ProgrammerDlg::microSelect( ) const
 {
 	return m_pProgrammerWidget->m_pMicroSelect;
 }
-
-
-#include "programmerdlg.moc"
