@@ -9,27 +9,30 @@
 
 #include "richtexteditor.h"
 
-//#include <kactionclasses.h>
-#include <ktoolbarpopupaction.h>
-#include <ktoggleaction.h>
-#include <kcolordialog.h>
-#include <kicon.h>
-#include <klocalizedstring.h>
+#include <KToolBarPopupAction>
+#include <KToggleAction>
+
+#include <KLocalizedString>
 // #include <k3popupmenu.h>
-#include <ktextedit.h>
-#include <ktoolbar.h>
-#include <kactioncollection.h>
-#include <kmenu.h>
-#include <qtextedit.h>
+#include <KTextEdit>
+#include <KToolBar>
+#include <KActionCollection>
+
+#include <QTextEdit>
+#include <QDebug>
+#include <QFont>
+#include <QIcon>
+//#include <qmime.h>
+#include <QTextList>
+#include <QTextListFormat>
+#include <QRegExp>
+#include <QDir>
+#include <QMenu>
+#include <QColorDialog>
+#include <QDialogButtonBox>
+#include <QPushButton>
+#include <QVBoxLayout>
 
-#include <qdebug.h>
-#include <qfont.h>
-#include <qlayout.h>
-#include <qmime.h>
-#include <qtextlist.h>
-#include <qtextformat.h>
-#include <qregexp.h>
-#include <qdir.h>
 // #include <q3vbox.h>
 // #include <q3textedit.h>
 // #include <q3stylesheet.h>
@@ -45,26 +48,26 @@ RichTextEditor::RichTextEditor(QWidget *parent, const char *name)
 	m_pEditor = new QTextEdit( this ); //, "RichTextEdit" );
 	m_pEditor->setObjectName("RichTextEdit");
 	layout->addWidget( m_pEditor );
-	
+
 	//m_pEditor->setTextFormat( Qt::RichText ); // 2018.12.07 - just use toHtml() and html()
-	
+
 	connect( m_pEditor, SIGNAL( textChanged() ), SIGNAL( textChanged() ) );
     connect( m_pEditor, SIGNAL( currentCharFormatChanged(const QTextCharFormat &) ), this, SLOT( slotCurrentCharFormatChanged( const QTextCharFormat &) ) );
 	//connect( m_pEditor, SIGNAL( currentFontChanged( const QFont & ) ), this, SLOT( fontChanged( const QFont & ) ) ); // 2018.01.03 - use slotCurrentCharFormatChanged
 	//connect( m_pEditor, SIGNAL( currentColorChanged( const QColor & ) ), this, SLOT( colorChanged( const QColor & ) ) ); // 2018.01.03 - use slotCurrentCharFormatChanged
 	//connect( m_pEditor, SIGNAL( currentAlignmentChanged( int ) ), this, SLOT( alignmentChanged( int ) ) ); // 2018.01.03 - use slotCurrentCharFormatChanged
 	//connect( m_pEditor, SIGNAL( currentVerticalAlignmentChanged( Q3TextEdit::VerticalAlignment ) ), this, SLOT(verticalAlignmentChanged()) ); // 2018.01.03 - use slotCurrentCharFormatChanged
-	
-	KToolBar * tools = new KToolBar( this, "RichTextEditorToops" );
+
+	KToolBar * tools = new KToolBar( QStringLiteral("RichTextEditorToops"), this );
 	layout->addWidget( tools );
 	KActionCollection * ac = new KActionCollection( m_pEditor );
-	
-	
+
+
 	//m_pTextBold = new KToggleAction( i18n("Bold"), "format-text-bold", Qt::CTRL + Qt::Key_B, 0, 0, ac, "format_bold" );
     m_pTextBold = new KToggleAction( i18n("Bold"), ac);
     m_pTextBold->setObjectName("text_bold");
     m_pTextBold->setShortcut(Qt::CTRL + Qt::Key_B);
-    m_pTextBold->setIcon( KIcon("format-text-bold") );
+    m_pTextBold->setIcon( QIcon::fromTheme("format-text-bold") );
 	connect( m_pTextBold, SIGNAL(toggled(bool)), this, SLOT(slotSetBold(bool)) );
 	//m_pTextBold->plug( tools );
     tools->addAction(m_pTextBold);
@@ -73,7 +76,7 @@ RichTextEditor::RichTextEditor(QWidget *parent, const char *name)
     m_pTextItalic = new KToggleAction( i18n("Italic"), ac);
     m_pTextItalic->setObjectName("text_italic");
     m_pTextItalic->setShortcut( Qt::CTRL + Qt::Key_I );
-    m_pTextItalic->setIcon( KIcon("format-text-italic") );
+    m_pTextItalic->setIcon( QIcon::fromTheme("format-text-italic") );
 	connect( m_pTextItalic, SIGNAL(toggled(bool)), this, SLOT(slotSetItalic(bool)) );
 	//m_pTextItalic->plug( tools );
     tools->addAction(m_pTextItalic);
@@ -82,89 +85,89 @@ RichTextEditor::RichTextEditor(QWidget *parent, const char *name)
     m_pTextUnderline = new KToggleAction( i18n("Underline"), ac);
     m_pTextUnderline->setObjectName("text_under");
     m_pTextUnderline->setShortcut( Qt::CTRL + Qt::Key_U );
-    m_pTextItalic->setIcon( KIcon("format-text-underline") );
+    m_pTextItalic->setIcon( QIcon::fromTheme("format-text-underline") );
 	connect( m_pTextUnderline, SIGNAL(toggled(bool)), this, SLOT(slotSetUnderline(bool)) );
 	//m_pTextUnderline->plug( tools );
     tools->addAction(m_pTextUnderline);
-	
+
 	//m_pTextList = new KToggleAction( i18n("List"), "unsorted_list", Qt::CTRL + Qt::Key_L, 0, 0, ac, "format_list" );
     m_pTextList = new KToggleAction( i18n("List"), ac);
     m_pTextList->setObjectName("unsorted_list");
     m_pTextList->setShortcut( Qt::CTRL + Qt::Key_L );
-    m_pTextItalic->setIcon( KIcon("format-list-unordered") );
+    m_pTextItalic->setIcon( QIcon::fromTheme("format-list-unordered") );
 	connect( m_pTextList, SIGNAL(toggled(bool)), SLOT(slotSetList(bool)) );
 	//m_pTextList->plug( tools );
     tools->addAction( m_pTextList );
-	
-	
+
+
 	//BEGIN Text horizontal-alignment actions
 	//m_pTextAlignment = new KToolBarPopupAction( i18n("Text Alignment"), "format-justify-left", 0, 0, 0, ac, "text_alignment" );
     m_pTextAlignment = new KToolBarPopupAction(
-            KIcon("format-justify-left"),
+            QIcon::fromTheme("format-justify-left"),
             i18n("Text Alignment"),
             ac);
     m_pTextAlignment->setObjectName("text_left");
 	//m_pTextAlignment->plug( tools );
     tools->addAction(m_pTextAlignment);
 	m_pTextAlignment->setDelayed(false);
-	
+
 	//K3PopupMenu * m = m_pTextAlignment->menu();
     QMenu * m = m_pTextAlignment->menu();
     //m->insertTitle( i18n("Text Alignment") );
     m->setTitle( i18n("Text Alignment"));
 	//m->setCheckable( true ); // 2018.12.07
-	
-	//m->insertItem( KIcon( "format-justify-left" ), i18n("Align Left"),		Qt::AlignLeft );
-    m->addAction( KIcon( "format-justify-left" ), i18n("Align Left") )->setData( Qt::AlignLeft );
-	//m->insertItem( KIcon( "format-justify-center"), i18n("Align Center"),	Qt::AlignHCenter );
-    m->addAction( KIcon( "format-justify-center"), i18n("Align Center") )->setData( Qt::AlignHCenter );
-	//m->insertItem( KIcon( "format-justify-right" ), i18n("Align Right"),	Qt::AlignRight );
-    m->addAction( KIcon( "format-justify-right" ), i18n("Align Right") )->setData( Qt::AlignRight );
-	//m->insertItem( KIcon( "format-justify-fill" ), i18n("Align Block"),	Qt::AlignJustify );
-    m->addAction( KIcon( "format-justify-fill" ), i18n("Align Block") )->setData( Qt::AlignJustify );
+
+	//m->insertItem( QIcon::fromTheme( "format-justify-left" ), i18n("Align Left"),		Qt::AlignLeft );
+    m->addAction( QIcon::fromTheme( "format-justify-left" ), i18n("Align Left") )->setData( Qt::AlignLeft );
+	//m->insertItem( QIcon::fromTheme( "format-justify-center"), i18n("Align Center"),	Qt::AlignHCenter );
+    m->addAction( QIcon::fromTheme( "format-justify-center"), i18n("Align Center") )->setData( Qt::AlignHCenter );
+	//m->insertItem( QIcon::fromTheme( "format-justify-right" ), i18n("Align Right"),	Qt::AlignRight );
+    m->addAction( QIcon::fromTheme( "format-justify-right" ), i18n("Align Right") )->setData( Qt::AlignRight );
+	//m->insertItem( QIcon::fromTheme( "format-justify-fill" ), i18n("Align Block"),	Qt::AlignJustify );
+    m->addAction( QIcon::fromTheme( "format-justify-fill" ), i18n("Align Block") )->setData( Qt::AlignJustify );
 	connect( m, SIGNAL(triggered(QAction*)), this, SLOT(slotSetAlignment(QAction*)) );
 	//END Text horizontal-alignment actions
-	
-	
+
+
 	//BEGIN Text vertical-alignment actions
 	//m_pTextVerticalAlignment = new KToolBarPopupAction( i18n("Text Vertical Alignment"), "text", 0, 0, 0, ac, "text_vertical_alignment" );
     m_pTextVerticalAlignment = new KToolBarPopupAction(
-            KIcon(QString("text_vertical_alignment")),
+            QIcon::fromTheme(QString("text_vertical_alignment")),
             i18n("Text Vertical Alignment"),
             ac);
     m_pTextVerticalAlignment->setObjectName("text");
 	//m_pTextVerticalAlignment->plug( tools );
     tools->addAction(m_pTextVerticalAlignment);
 	m_pTextVerticalAlignment->setDelayed(false);
-	
+
 	m = m_pTextVerticalAlignment->menu();
 	//m->insertTitle( i18n("Text Vertical Alignment") );
     m->setTitle( i18n("Text Vertical Alignment") );
 	//m->setCheckable( true ); // 2018.12.07
-	
-    m->addAction(  KIcon( "format-text-superscript" ),
+
+    m->addAction(  QIcon::fromTheme( "format-text-superscript" ),
                    i18n("Superscript") )->setData(QTextCharFormat::AlignSuperScript );
-	//m->insertItem( KIcon( "format-text-superscript" ), i18n("Superscript"),	QTextCharFormat::AlignSuperScript );
+	//m->insertItem( QIcon::fromTheme( "format-text-superscript" ), i18n("Superscript"),	QTextCharFormat::AlignSuperScript );
     m->addAction( i18n("Normal") )->setData( QTextCharFormat::AlignNormal );
 	//m->insertItem(						i18n("Normal"),			QTextCharFormat::AlignNormal );
-    m->addAction( KIcon( "format-text-subscript" ), i18n("Subscript") )->setData( QTextCharFormat::AlignSubScript );
-	//m->insertItem( KIcon( "format-text-subscript" ), i18n("Subscript"),		QTextCharFormat::AlignSubScript );
+    m->addAction( QIcon::fromTheme( "format-text-subscript" ), i18n("Subscript") )->setData( QTextCharFormat::AlignSubScript );
+	//m->insertItem( QIcon::fromTheme( "format-text-subscript" ), i18n("Subscript"),		QTextCharFormat::AlignSubScript );
 	connect( m, SIGNAL(triggered(QAction*)), this, SLOT(slotSetVerticalAlignment(QAction*)) );
 	//END Text vertical-alignment actions
-	
-	
+
+
 	QPixmap pm( 16, 16 );
 	pm.fill( Qt::black );
 	//m_pTextColor = new KAction( i18n("Text Color..."), pm, 0, this, SLOT(textColor()), ac, "format_color" );
-    m_pTextColor = new KAction( i18n("Text Color..."), this);
+    m_pTextColor = new QAction( i18n("Text Color..."), this);
     m_pTextColor->setIcon(pm);
     m_pTextColor->setObjectName("format_color");
-    connect(m_pTextColor, SIGNAL(activated(int)), this, SLOT(textColor()));
+    connect(m_pTextColor, SIGNAL(triggered(bool)), this, SLOT(textColor()));
 	//m_pTextColor->plug( tools );
     ac->addAction("format_color", m_pTextColor);
     tools->addAction(m_pTextColor);
-	
-	
+
+
 }
 
 
@@ -177,17 +180,17 @@ void RichTextEditor::makeUseStandardFont( QString * html )
 {
 	if ( !html )
 		return;
-	
+
 	QFont f;
 	QString bodyString = QString("<body style=\"font-size:%1pt;font-family:%2\">").arg( f.pointSize() ).arg( f.family() );
-	
+
 	if ( html->contains("<body>") )
 	{
 		// Set the correct font size
 		QFont f;
 		html->replace( "<body>", bodyString );
 	}
-	
+
 	else if ( !html->startsWith("<html>") )
 	{
 		html->prepend( "<html>" + bodyString );
@@ -209,7 +212,7 @@ void RichTextEditor::setText( QString text )
 		// Format the text to be HTML
 		text.replace( '\n', "<br>" );
 	}
-	
+
 	m_pEditor->setText( text );
 }
 
@@ -218,10 +221,10 @@ void RichTextEditor::setText( QString text )
 QString RichTextEditor::text() const
 {
 	QString text = m_pEditor->toHtml().trimmed();
-	
+
 	// Remove the style info (e.g. style="font-size:8pt;font-family:DejaVu Sans") inserted into the body tag.
 	text.replace( QRegExp( "<body style=\"[^\"]*\">"), "<body>" );
-	
+
 	// Replace all non-latin1 characters with HTML codes to represent them
 	QString nonAsciiChars;
 	for ( int i = 0; i < text.length(); ++i )
@@ -238,7 +241,7 @@ QString RichTextEditor::text() const
 	{
 		text.replace( nonAsciiChars[i], QString("&#%1;").arg( nonAsciiChars[i].unicode() ) );
 	}
-	
+
 	return text;
 }
 
@@ -353,9 +356,8 @@ void RichTextEditor::fontChanged( const QFont & f )
 
 void RichTextEditor::textColor()
 {
-	QColor c = m_pEditor->textColor();
-	int ret = KColorDialog::getColor( c, this );
-	if ( ret == QDialog::Accepted ) {
+    const QColor c = QColorDialog::getColor(m_pEditor->textColor(), this);
+    if (c.isValid()) {
 		m_pEditor->setTextColor( c );
     }
 }
@@ -372,19 +374,19 @@ void RichTextEditor::colorChanged( const QColor & c )
 void RichTextEditor::alignmentChanged( int a )
 {
 	if ( /*( a == Qt::AlignAuto ) || */ ( a & Qt::AlignLeft ))
-		m_pTextAlignment->setIcon( KIcon("format-justify-left") );
+		m_pTextAlignment->setIcon( QIcon::fromTheme("format-justify-left") );
 	else if ( ( a & Qt::AlignHCenter ) )
-		m_pTextAlignment->setIcon( KIcon("format-justify-center") );
+		m_pTextAlignment->setIcon( QIcon::fromTheme("format-justify-center") );
 	else if ( ( a & Qt::AlignRight ) )
-		m_pTextAlignment->setIcon( KIcon("format-justify-right") );
+		m_pTextAlignment->setIcon( QIcon::fromTheme("format-justify-right") );
 	else if ( ( a & Qt::AlignJustify ) )
-		m_pTextAlignment->setIcon( KIcon("format-justify-fill") );
+		m_pTextAlignment->setIcon( QIcon::fromTheme("format-justify-fill") );
 }
 
 
 void RichTextEditor::verticalAlignmentChanged()
 {
-// 	QTextEdit::VerticalAlignment a = 
+// 	QTextEdit::VerticalAlignment a =
 // 	if ( a == KTextEdit::AlignNormal )
 // 		m_pTextVerticalAlignment->setIcon( "text" );
 // 	else if ( a == KTextEdit::AlignSuperScript )
@@ -429,25 +431,25 @@ void RichTextEditor::setResourcePaths( const QStringList & paths )
 
 //BEGIN class RichTextEditorDlg
 RichTextEditorDlg::RichTextEditorDlg( QWidget * parent, const QString & caption )
-	: //KDialog( parent, "RichTextEditorDlg", true, caption, KDialog::Ok|KDialog::Cancel, KDialog::Ok, true )
-	KDialog( parent )
+    : QDialog(parent)
 {
     setObjectName("RichTextEditorDlg");
     setModal(true);
-    setCaption(caption);
-    setButtons(KDialog::Ok | KDialog::Cancel);
-    setDefaultButton(KDialog::Ok);
-    showButtonSeparator(true);
+    setWindowTitle(caption);
 
+    QVBoxLayout *mainLayout = new QVBoxLayout;
+    setLayout(mainLayout);
 
-	//QVBox * page = makeVBoxMainWidget();
-    QWidget * page = new QWidget(this);
-    QVBoxLayout *pageLayout = new QVBoxLayout;
-    m_pEditor = new RichTextEditor( page );
-    pageLayout->addWidget(m_pEditor);
-    page->setLayout(pageLayout);
-    setMainWidget(page);
+    m_pEditor = new RichTextEditor(this);
+    mainLayout->addWidget(m_pEditor);
+
+    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok|QDialogButtonBox::Cancel);
+    mainLayout->addWidget(buttonBox);
+
+    QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
+    okButton->setDefault(true);
+    okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
+    connect(buttonBox, &QDialogButtonBox::accepted, this, &QDialog::accept);
+    connect(buttonBox, &QDialogButtonBox::rejected, this, &QDialog::reject);
 }
 //END class RichTextEditorDlg
-
-#include "richtexteditor.moc"
