@@ -1,3 +1,4 @@
+
 /***************************************************************************
  *   Copyright (C) 2006 by David Saxton - david@bluehaze.org               *
  *                                                                         *
@@ -10,12 +11,8 @@
 #ifndef RICHTEXTEDITOR_H
 #define RICHTEXTEDITOR_H
 
-#include <qwidget.h>
+#include <QDialog>
 
-#include <kdialog.h>
-//#include <kdialog.h>
-
-class KAction;
 class QTextEdit;
 class KToggleAction;
 class KToolBarPopupAction;
@@ -29,9 +26,9 @@ class RichTextEditor : public QWidget
 {
 	Q_OBJECT
 	public:
-		RichTextEditor( QWidget *parent = 0, const char *name = 0 );
+		RichTextEditor( QWidget *parent = nullptr, const char *name = nullptr );
 
-		~RichTextEditor();
+		~RichTextEditor() override;
 		/**.
 		 * @return the text in the editor (tidied up).
 		 */
@@ -50,12 +47,12 @@ class RichTextEditor : public QWidget
 		 * These are the paths that are used for to search for images, etc.
 		 */
 		void setResourcePaths( const QStringList & paths );
-		
+
 		QWidget * editorViewport() const;
-		
+
 	signals:
 		void textChanged();
-		
+
 	public slots:
 		/**
 		 * Inserts a url in the editor at the current cursor position with the
@@ -68,7 +65,7 @@ class RichTextEditor : public QWidget
 		 * HTML code, replacing less-thans, etc.
 		 */
 		void insertHTML( const QString & html );
-		
+
 	protected slots:
         void slotSetBold(bool);
         void slotSetItalic(bool);
@@ -86,7 +83,7 @@ class RichTextEditor : public QWidget
 		void alignmentChanged( int a );
 		void verticalAlignmentChanged();
 		void textColor();
-		
+
 	protected:
 		KToggleAction * m_pTextBold;
 		KToggleAction * m_pTextItalic;
@@ -94,7 +91,7 @@ class RichTextEditor : public QWidget
 		KToggleAction * m_pTextList;
 		KToolBarPopupAction * m_pTextAlignment;
 		KToolBarPopupAction * m_pTextVerticalAlignment;
-		KAction * m_pTextColor;
+		QAction * m_pTextColor;
 		QTextEdit * m_pEditor;
 };
 
@@ -103,11 +100,11 @@ class RichTextEditor : public QWidget
 Popup dialog for editing rich text
 @author David Saxton
 */
-class RichTextEditorDlg : public KDialog /* or KPageDialog ? */ // KDialog
+class RichTextEditorDlg : public QDialog
 {
 	public:
-		RichTextEditorDlg( QWidget * parent = 0, const QString & caption = QString::null );
-		
+		RichTextEditorDlg( QWidget * parent = nullptr, const QString & caption = QString::null );
+
 		/**
 		 * Sets the text being edited (passes it to RichTextEditor).
 		 */
@@ -116,7 +113,7 @@ class RichTextEditorDlg : public KDialog /* or KPageDialog ? */ // KDialog
 		 * @return the text in the RichTextEditor.
 		 */
 		QString text() const { return m_pEditor->text(); }
-		
+
 	protected:
 		RichTextEditor * m_pEditor;
 };
