@@ -17,19 +17,15 @@
 
 #include <cmath>
 
-#include <kconfig.h>
-#include <kdebug.h>
-#include <kglobal.h>
-#include <kiconloader.h>
-#include <klocalizedstring.h>
-#include <knuminput.h>
+#include <KLocalizedString>
 
+#include <QDebug>
 // #include <q3button.h>
-#include <qlabel.h>
-#include <qscrollbar.h>
-#include <qslider.h>
-#include <qtimer.h>
-#include <qtoolbutton.h>
+#include <QLabel>
+#include <QScrollBar>
+#include <QSlider>
+#include <QTimer>
+#include <QToolButton>
 
 #include <cassert>
 
@@ -52,13 +48,10 @@ ScopeScreen::~ScopeScreen()
 
 ScopeScreen * ScopeScreen::self( KateMDI::ToolView * parent )
 {
-	static ScopeScreen * pSelf = 0L;
+	static ScopeScreen * pSelf = nullptr;
 	if(pSelf)
 		return pSelf;
 	assert(parent);
 	pSelf = new ScopeScreen(parent);
 	return pSelf;
 }
-
-
-#include "scopescreen.moc"
