@@ -15,9 +15,9 @@
 #include "simulator.h"
 #include "probepositioner.h"
 
-#include <qpainter.h>
-#include <qtimer.h>
-#include <kdebug.h>
+#include <QPainter>
+#include <QTimer>
+#include <QDebug>
 
 #include <cmath>
 #define FADESPEED 1
@@ -52,7 +52,7 @@ void ScopeScreenView::drawContents(QPainter * p)
 	const double ticksPerPixel = m_intervalsX * m_ticksPerIntervalX / cr.width();	
 	//draw the current time
 	int curTimeX = ((Simulator::self()->time() + m_offsetX) % (ticksPerScreen)) * pixelsPerTick;
-	//kDebug() << curTimeX <<endl;
+	//qDebug() << curTimeX <<endl;
 	p->drawLine(curTimeX, cr.top(), curTimeX, cr.bottom());
 	
 	//the following is liberally borrowed from OscilloscopeView::drawFloatingData
@@ -102,7 +102,7 @@ void ScopeScreenView::drawContents(QPainter * p)
 			{
 				prevX = 0;
 			}
-			//kDebug() <<at<<" "<<nextX<<" "<<nextY<<" "<<nextTime<<endl;
+			//qDebug() <<at<<" "<<nextX<<" "<<nextY<<" "<<nextTime<<endl;
 			p->drawLine( prevX, prevY, nextX, nextY );
 			
 			prevTime = nextTime;
@@ -274,6 +274,3 @@ void ScopeScreenView::drawProbe( QPainter & p, LogicProbeData * probe )
 void ScopeScreenView::drawProbe( QPainter & p, FloatingProbeData * probe )
 {
 }
-
-#include "scopescreenview.moc"
-
