@@ -14,9 +14,9 @@
 #include "oscilloscopedata.h"
 #include "probepositioner.h"
 
-#include <qpainter.h>
-#include <qevent.h>
-#include <qdebug.h>
+#include <QPainter>
+#include <QPaintEvent>
+#include <QDebug>
 
 //for testing 
 //#include <valgrind/callgrind.h>
@@ -24,7 +24,7 @@
 ScopeViewBase::ScopeViewBase(QWidget *parent, const char *name)
 : QFrame(parent /* ,name */ /* , Qt::WNoAutoErase*/ ),
 b_needRedraw(true),
-m_pixmap(0L),
+m_pixmap(nullptr),
 m_halfOutputHeight(0.0)
 {
     setObjectName( name );
@@ -117,4 +117,3 @@ void ScopeViewBase::drawProbeMap( QPainter & p, QMap< int, T * > & map )
 		drawProbe( p, probe );
 	}
 }
-#include "scopeviewbase.moc"
