@@ -14,14 +14,15 @@
 #ifndef SYMBOLVIEWER_H
 #define SYMBOLVIEWER_H
 
-#include <qtablewidget.h>
-#include <qpointer.h>
+#include <QTableWidget>
+#include <QPointer>
+
+#include <gpsimprocessor.h>
 
 class KComboBox;
-class RegisterInfo;
-class RegisterSet;
-class SymbolViewer;
 class KConfig;
+class SymbolViewer;
+
 namespace KateMDI { class ToolView; }
 
 
@@ -32,10 +33,10 @@ class SymbolViewer : public QWidget
 {
 	Q_OBJECT
 	public:
-		static SymbolViewer * self( KateMDI::ToolView * parent = 0l );
+		static SymbolViewer * self( KateMDI::ToolView * parent = nullptr );
 		static QString toolViewIdentifier() { return "SymbolViewer"; }
-		~SymbolViewer();
-		
+		~SymbolViewer() override;
+
 		enum Radix
 		{
 			Binary = 2,
@@ -43,9 +44,9 @@ class SymbolViewer : public QWidget
 			Decimal = 10,
 			Hexadecimal = 16
 		};
-		
+
 		Radix valueRadix() const { return m_valueRadix; }
-		
+
 		//QTableWidget * symbolList() const { return m_pSymbolList; } // 2016.06.02 - unused
 		/**
 		 * Write the current properties (such as currently selected radix) to
@@ -57,20 +58,20 @@ class SymbolViewer : public QWidget
 		 * config file.
 		 */
 		void readProperties( KConfig * config );
-		
+
 		void setContext( GpsimProcessor * gpsim );
-		/** 
+		/**
 		 * Converts the value to a string for display according to the currently
 		 * selected radix.
 		 */
 		QString toDisplayString( unsigned value ) const;
-		
+
 	signals:
 		void valueRadixChanged( SymbolViewer::Radix newRadix );
-		
+
 	public slots:
 		void selectRadix( int selectIndex );
-		
+
 	protected:
 		QPointer<GpsimProcessor> m_pGpsim;
 		RegisterSet * m_pCurrentContext;
@@ -89,11 +90,11 @@ class SymbolViewerItem : public QObject, public QTableWidgetItem
 	Q_OBJECT
 	public:
 		SymbolViewerItem( SymbolViewer* symbolViewer, const RegisterInfo* registerInfo, int intendedColumn);
-		
+
 	public slots:
 		void valueChanged( unsigned newValue );
 		void radixChanged();
-		
+
 	protected:
 		const RegisterInfo * m_pRegisterInfo;
 		SymbolViewer * m_pSymbolViewer;
