@@ -25,32 +25,32 @@
 #include "pin.h"
 #include "resizeoverlay.h"
 #include "simulator.h"
+#include "imageexportdlg.h"
 
-#include <kdebug.h>
-#include <kfiledialog.h>
-#include <kiconloader.h>
-#include <klocalizedstring.h>
-#include <kmessagebox.h>
+#include <KLocalizedString>
+#include <KMessageBox>
 // #include <k3popupmenu.h>
 //#include <kprinter.h>
-#include <kactionmenu.h>
-#include <kxmlguifactory.h>
+#include <KActionMenu>
+#include <KXMLGUIFactory>
 
-#include <qapplication.h>
-#include <qcheckbox.h>
-#include <qclipboard.h>
-#include <qcursor.h>
-#include <qimage.h>
-#include <qmenu.h>
+#include <QDebug>
+#include <QApplication>
+#include <QCheckBox>
+#include <QClipboard>
+#include <QCursor>
+#include <QImage>
+#include <QMenu>
 // #include <q3paintdevicemetrics.h>
-#include <qpainter.h>
-#include <qpicture.h>
-#include <qregexp.h>
+#include <QPainter>
+#include <QPicture>
+#include <QRegExp>
 // #include <q3simplerichtext.h> // 2018.08.13 - not needed
-#include <qtimer.h>
-#include <qprinter.h>
-#include <qtextedit.h>
-#include <qprintdialog.h>
+#include <QTimer>
+#include <QPrinter>
+#include <QTextEdit>
+#include <QPrintDialog>
+#include <QFile>
 
 #include <cmath>
 #include <cassert>
@@ -66,24 +66,24 @@ ItemDocument::ItemDocument( const QString &caption, const char *name)
 {
 	m_queuedEvents = 0;
 	m_nextIdNum = 1;
-	m_savedState = 0;
-	m_currentState = 0;
+	m_savedState = nullptr;
+	m_currentState = nullptr;
 	m_bIsLoading = false;
-	
+
 	m_canvas = new Canvas( this, "canvas" );
 	m_canvasTip = new CanvasTip(this,m_canvas);
 	m_cmManager = new CMManager(this);
-	
+
 	updateBackground();
-	
+
 	m_pUpdateItemViewScrollbarsTimer = new QTimer(this);
 	connect( m_pUpdateItemViewScrollbarsTimer, SIGNAL(timeout()), this, SLOT(updateItemViewScrollbars()) );
-	
+
 	m_pEventTimer = new QTimer(this);
 	connect( m_pEventTimer, SIGNAL(timeout()), this, SLOT(processItemDocumentEvents()) );
-	
+
 	connect( this, SIGNAL(selectionChanged()), this, SLOT(slotInitItemActions()) );
-	
+
 	connect( ComponentSelector::self(),	SIGNAL(itemClicked(const QString& )),	this, SLOT(slotUnsetRepeatedItemId()) );
 	connect( FlowPartSelector::self(),	SIGNAL(itemClicked(const QString& )),	this, SLOT(slotUnsetRepeatedItemId()) );
 #ifdef MECHANICS
@@ -92,15 +92,15 @@ ItemDocument::ItemDocument( const QString &caption, const char *name)
 
 	m_pAlignmentAction = new KActionMenu( i18n("Alignment") /*, "format-justify-right" */ , this );
     m_pAlignmentAction->setObjectName("rightjust");
-    m_pAlignmentAction->setIcon( KIcon("format-justify-right") );
-	
+    m_pAlignmentAction->setIcon( QIcon::fromTheme("format-justify-right") );
+
 	slotUpdateConfiguration();
 }
 
 ItemDocument::~ItemDocument()
 {
 	m_bDeleted = true;
-	
+
 //	ItemMap toDelete = m_itemList;
 
 	const ItemMap::iterator end = m_itemList.end();
@@ -128,9 +128,9 @@ void ItemDocument::handleNewView( View * view )
 bool ItemDocument::registerItem(KtlQCanvasItem *qcanvasItem)
 {
 	if (!qcanvasItem) return false;
-	
+
 	requestEvent( ItemDocument::ItemDocumentEvent::ResizeCanvasToItems );
-	
+
 	if(Item *item = dynamic_cast<Item*>(qcanvasItem) )
 	{
 		m_itemList[ item->id() ] = item;
@@ -138,7 +138,7 @@ bool ItemDocument::registerItem(KtlQCanvasItem *qcanvasItem)
 		itemAdded(item);
 		return true;
 	}
-	
+
 	return false;
 }
 
@@ -177,7 +177,7 @@ void ItemDocument::fileSaveAs()
 {
 	if ( !getURL(m_fileExtensionInfo) ) return;
 	writeFile();
-	
+
 	// Our modified state may not have changed, but we emit this to force the
 	// main window to update our caption.
 	emit modifiedStateChanged();
@@ -188,7 +188,7 @@ void ItemDocument::writeFile()
 {
 	ItemDocumentData data( type() );
 	data.saveDocumentState(this);
-	
+
 	if ( data.saveData(url()) )
 	{
 		m_savedState = m_currentState;
@@ -197,39 +197,39 @@ void ItemDocument::writeFile()
 }
 
 
-bool ItemDocument::openURL( const KUrl &url )
+bool ItemDocument::openURL( const QUrl &url )
 {
 	ItemDocumentData data( type() );
-	
+
 	if ( !data.loadData(url) )
 		return false;
-	
+
 	// Why do we stop simulating while loading a document?
 	// Crash possible when loading a circuit document, and the Qt event loop is
 	// reentered (such as when a PIC component pops-up a message box), which
 	// will then call the Simulator::step function, which might use components
 	// that have not fully initialized themselves.
-	
+
 	m_bIsLoading = true;
 	bool wasSimulating = Simulator::self()->isSimulating();
 	Simulator::self()->slotSetSimulating( false );
 	data.restoreDocument(this);
 	Simulator::self()->slotSetSimulating( wasSimulating );
 	m_bIsLoading = false;
-	
+
 	setURL(url);
 	clearHistory();
 	m_savedState = m_currentState;
 	setModified(false);
-	
+
 	if ( FlowCodeDocument *fcd = dynamic_cast<FlowCodeDocument*>(this) )
 	{
 		// We need to tell all pic-depedent components about what pic type is in use
 		emit fcd->picTypeChanged();
 	}
-	
+
 	requestEvent( ItemDocument::ItemDocumentEvent::ResizeCanvasToItems );
-	
+
 	// Load Z-position info
 	m_zOrder.clear();
 	ItemMap::iterator end = m_itemList.end();
@@ -237,35 +237,35 @@ bool ItemDocument::openURL( const KUrl &url )
 	{
 		if ( !*it || (*it)->parentItem() )
 			continue;
-		
+
 		m_zOrder[(*it)->baseZ()] = *it;
 	}
 	slotUpdateZOrdering();
-	
+
 	return true;
 }
 
 void ItemDocument::print()
 {
 	static QPrinter * printer = new QPrinter;
-	
+
 	//if ( ! printer->setup( KTechlab::self() ) )
 	//	return;
     QPrintDialog printDialog(printer, KTechlab::self());
     if ( ! printDialog.exec() ) {
         return;
     }
-	
+
 	// setup the printer.  with Qt, you always "print" to a
 	// QPainter.. whether the output medium is a pixmap, a screen,
 	// or paper
 	QPainter p;
 	p.begin( printer );
-	
+
 	// we let our view do the actual printing
 	//Q3PaintDeviceMetrics metrics( printer ); // 2018.08.13 - replaced with method call
     QRect pageRect = printer->pageRect();
-	
+
 	// Round to 16 so that we cut in the middle of squares
 	int w = pageRect.width();
 	w = (w & 0xFFFFFFF0) + ((w << 1) & 0x10);
@@ -275,33 +275,34 @@ void ItemDocument::print()
 
 	p.setClipping( true );
 	p.setClipRect( 0, 0, w, h, /* QPainter::CoordPainter */ Qt::ReplaceClip ); // TODO is this correct?
-	
+
 	// Send off the painter for drawing
-	m_canvas->setBackgroundPixmap( 0 );
+    // note: What was this doing?? // set "null" background, so the background horiznotal and vertial lines are not visible
+	m_canvas->setBackgroundPixmap( QPixmap(0,0) /* 0 */ );
 	
 	QRect bounding = canvasBoundingRect();
 	unsigned int rows = (unsigned) std::ceil( double( bounding.height() ) / double( h ) );
 	unsigned int cols = (unsigned) std::ceil( double( bounding.width() ) / double( w ) );
 	int offset_x = bounding.x();
 	int offset_y = bounding.y();
-	
+
 	for ( unsigned row = 0; row < rows; ++row )
 	{
 		for ( unsigned col = 0; col < cols; ++col )
 		{
 			if ( row != 0 || col != 0 )
 				printer->newPage();
-			
+
 			QRect drawArea( offset_x + (col * w), offset_y + (row * h), w, h );
 			m_canvas->drawArea( drawArea, & p );
-			
+
 			p.translate( -w, 0 );
 		}
 		p.translate( w * cols, -h );
 	}
-	
+
 	updateBackground();
-	
+
 	// and send the result to the printer
 	p.end();
 }
@@ -309,17 +310,17 @@ void ItemDocument::print()
 void ItemDocument::requestStateSave( int actionTicket )
 {
 	if ( m_bIsLoading ) return;
-	
+
 	cleanClearStack( m_redoStack );
 
 	if ( (actionTicket >= 0) && (actionTicket == m_currentActionTicket) )
 	{
 		delete m_currentState;
-		m_currentState = 0;
+		m_currentState = nullptr;
 	}
-	
+
 	m_currentActionTicket = actionTicket;
-	
+
 	//FIXME: it is possible, that we push something here, also nothing has changed, yet.
 	// to reproduce do:
 	// 1. select an item -> something is pushed onto undoStack, but nothing changed
@@ -329,17 +330,17 @@ void ItemDocument::requestStateSave( int actionTicket )
 	// this way you can fill up the redoStack, as you like :-/
 	if (m_currentState)
 		m_undoStack.push(m_currentState);
-	
+
 	m_currentState = new ItemDocumentData( type() );
 	m_currentState->saveDocumentState(this);
-	
+
 	if (!m_savedState)
 		m_savedState = m_currentState;
-	
+
 	setModified( m_savedState != m_currentState );
-	
+
 	emit undoRedoStateChanged();
-	
+
 	//FIXME To resize undo queue, have to pop and push everything
 	// In Qt4 QStack is used and QStack inherits QVector, that should
 	// make it a bit more easy
@@ -372,7 +373,7 @@ void ItemDocument::clearHistory()
 	cleanClearStack( m_undoStack );
 	cleanClearStack( m_redoStack );
 	delete m_currentState;
-	m_currentState = 0;
+	m_currentState = nullptr;
 	requestStateSave();
 }
 
@@ -413,13 +414,13 @@ void ItemDocument::redo()
     }
 	ItemDocumentData *idd = m_redoStack.pop();
 	if (!idd) return;
-	
+
 	if (m_currentState)
 		m_undoStack.push(m_currentState);
-	
+
 	idd->restoreDocument(this);
 	m_currentState = idd;
-	
+
 	setModified( m_savedState != m_currentState );
 	emit undoRedoStateChanged();
 }
@@ -436,18 +437,18 @@ void ItemDocument::paste()
 	QString xml = QApplication::clipboard()->text( QClipboard::Clipboard );
 	if ( xml.isEmpty() )
 		return;
-	
+
 	unselectAll();
-	
+
 	ItemDocumentData data( type() );
-	
+
 	if ( !data.fromXML(xml) )
 		return;
-	
+
 	data.generateUniqueIDs(this);
 //	data.translateContents( 64, 64 );
 	data.mergeWithDocument( this, true );
-	
+
 	// Get rid of any garbage that shouldn't be around / merge connectors / etc
 	flushDeleteList();
 
@@ -459,7 +460,7 @@ Item *ItemDocument::itemWithID( const QString &id )
 {
 	if ( m_itemList.contains( id ) )
 		return m_itemList[id];
-	else	return 0;
+	else	return nullptr;
 }
 
 
@@ -482,7 +483,7 @@ void ItemDocument::select( const KtlQCanvasItemList & list )
 	const KtlQCanvasItemList::const_iterator end = list.end();
 	for ( KtlQCanvasItemList::const_iterator it = list.begin(); it != end; ++it )
 		selectList()->addQCanvasItem(*it);
-	
+
 	selectList()->setSelected(true);
 }
 
@@ -519,12 +520,12 @@ KtlQCanvasItem* ItemDocument::itemAtTop( const QPoint &pos ) const
 		} else {
 			if ( ConnectorLine * l = dynamic_cast<ConnectorLine*>(item) )
 				return l->parent();
-			
+
 			return item;
 		}
 	}
 
-	return 0;
+	return nullptr;
 }
 
 
@@ -577,14 +578,14 @@ QString ItemDocument::generateUID( QString name )
 {
 	name.remove( QRegExp("__.*") ); // Change 'node__13' to 'node', for example
 	QString idAttempt = name;
-	
+
 	while ( !registerUID(idAttempt) )
 		idAttempt = name + "__" + QString::number(m_nextIdNum++);
-	
+
 	return idAttempt;
 }
 
-// FIXME: popup menu doesn't seem to work these days. =( 
+// FIXME: popup menu doesn't seem to work these days. =(
 void ItemDocument::canvasRightClick( const QPoint &pos, KtlQCanvasItem* item )
 {
 	if (item) {
@@ -611,21 +612,21 @@ void ItemDocument::canvasRightClick( const QPoint &pos, KtlQCanvasItem* item )
 void ItemDocument::fillContextMenu( const QPoint & pos )
 {
 	Q_UNUSED(pos);
-	
+
 	ItemView * activeItemView = dynamic_cast<ItemView*>(activeView());
 	if ( !KTechlab::self() || !activeItemView )
 		return;
-	
+
 	QAction * align_actions[] = {
 		activeItemView->actionByName("align_horizontally"),
 		activeItemView->actionByName("align_vertically"),
 		activeItemView->actionByName("distribute_horizontally"),
 		activeItemView->actionByName("distribute_vertically") };
-	
+
 	bool enableAlignment = selectList()->itemCount() > 1;
 
 	if ( !enableAlignment ) return;
-	
+
 	for ( unsigned i = 0; i < 4; ++i )
 	{
 		align_actions[i]->setEnabled(true);
@@ -633,7 +634,6 @@ void ItemDocument::fillContextMenu( const QPoint & pos )
 		//m_pAlignmentAction->insert( align_actions[i] );
         m_pAlignmentAction->addAction( align_actions[i] );
 	}
-	//Q3PtrList<KAction> alignment_actions;
     QList<QAction*> alignment_actions;
 	alignment_actions.append( m_pAlignmentAction );
 	KTechlab::self()->plugActionList( "alignment_actionlist", alignment_actions );
@@ -645,13 +645,13 @@ void ItemDocument::slotInitItemActions()
 	ItemView * activeItemView = dynamic_cast<ItemView*>(activeView());
 	if ( !KTechlab::self() || !activeItemView )
 		return;
-	
+
 	QAction * align_actions[] = {
 		activeItemView->actionByName("align_horizontally"),
 		activeItemView->actionByName("align_vertically"),
 		activeItemView->actionByName("distribute_horizontally"),
 		activeItemView->actionByName("distribute_vertically") };
-	
+
 	bool enableAlignment = selectList()->itemCount() > 1;
 	for ( unsigned i = 0; i < 4; ++i )
 		align_actions[i]->setEnabled(enableAlignment);
@@ -661,26 +661,26 @@ void ItemDocument::slotInitItemActions()
 void ItemDocument::updateBackground()
 {
 	// Also used in the constructor to make the background initially.
-	
+
 	// Thoughts.
 	// ~The pixmap could be done somehow with 1bpp. It might save some waste
 	// I expect it won't hurt for now.
-	// ~This is all rather static, only works with square etc... should be no prob. for most uses. IMO. 
+	// ~This is all rather static, only works with square etc... should be no prob. for most uses. IMO.
 	// ~If you want, decide what maximum and minimum spacing should be, then enforce them
 	// in the Config (I suppose you can use <max></max> tags?)
 	// ~Defaults based on the existing grid background png. It should produce identical results, to your
 	// original png.
-	
+
 	// **** Below where it says "interval * 10", that decides how big the pixmap will be (always square)
 	// Originally I set this to 32, which give 256x256 with 8 spacing, as that was the size of your pixmap
 	// Are there any good reasons to make the a certain size? (i.e. big or small ?).
-	
+
 	int interval = 8;
 	int bigness = interval * 10;
 	QPixmap pm( bigness, bigness );
 // 	pm.fill( KTLConfig::bgColor() ); // first fill the background colour in
 	pm.fill( Qt::white );
-	
+
 	if( KTLConfig::showGrid() ){
 		//QPainter p(&pm); // setup painter to draw on pixmap
         QPainter p;
@@ -722,18 +722,18 @@ void ItemDocument::processItemDocumentEvents()
 	// Copy it incase we have new events requested while doing this...
 	unsigned queuedEvents = m_queuedEvents;
 	m_queuedEvents = 0;
-	
+
 	if ( queuedEvents & ItemDocumentEvent::ResizeCanvasToItems )
 		resizeCanvasToItems();
-	
+
 	if ( queuedEvents & ItemDocumentEvent::UpdateZOrdering )
 		slotUpdateZOrdering();
-	
+
 	ICNDocument * icnd = dynamic_cast<ICNDocument*>(this);
-	
+
 	if ( icnd && (queuedEvents & ItemDocumentEvent::UpdateNodeGroups) )
 		icnd->slotAssignNodeGroups();
-	
+
 	if ( icnd && (queuedEvents & ItemDocumentEvent::RerouteInvalidatedConnectors) )
 		icnd->rerouteInvalidatedConnectors();
 }
@@ -742,31 +742,31 @@ void ItemDocument::processItemDocumentEvents()
 void ItemDocument::resizeCanvasToItems()
 {
 	QRect bound = canvasBoundingRect();
-	
-	m_viewList.removeAll((View*)0);
+
+	m_viewList.removeAll((View*)nullptr);
 	const ViewList::iterator end = m_viewList.end();
 	for ( ViewList::iterator it = m_viewList.begin(); it != end; ++it ) {
 		ItemView * iv = static_cast<ItemView*>((View*)*it);
 		CVBEditor * cvbEditor = iv->cvbEditor();
-		
+
 		QPoint topLeft = iv->mousePosToCanvasPos( QPoint( 0, 0 ) );
 		int width = int( cvbEditor->visibleWidth() / iv->zoomLevel() );
 		int height = int( cvbEditor->visibleHeight() / iv->zoomLevel() );
 		QRect r( topLeft, QSize( width, height ) );
-		
+
 		bound |= r;
-		
-// 		kDebug() << "r="<<r<<endl;
-// 		kDebug() << "bound="<<bound<<endl;
+
+// 		qDebug() << "r="<<r<<endl;
+// 		qDebug() << "bound="<<bound<<endl;
 	}
-	
+
 	// Make it so that the rectangular offset is a multiple of 8
 	bound.setLeft( bound.left() - (bound.left()%8) );
 	bound.setTop( bound.top() - (bound.top()%8) );
-	
+
     m_pUpdateItemViewScrollbarsTimer->setSingleShot(true);
 	m_pUpdateItemViewScrollbarsTimer->start( 10 /*, true */ );
-	
+
 	bool changedSize = canvas()->rect() != bound;
 	if ( changedSize ) {
 		canvas()->resize( bound );
@@ -781,7 +781,7 @@ void ItemDocument::updateItemViewScrollbars()
 {
 	int w = canvas()->width();
 	int h = canvas()->height();
-	
+
 	const ViewList::iterator end = m_viewList.end();
 	for ( ViewList::iterator it = m_viewList.begin(); it != end; ++it )
 	{
@@ -797,40 +797,40 @@ void ItemDocument::updateItemViewScrollbars()
 QRect ItemDocument::canvasBoundingRect() const
 {
 	QRect bound;
-	
+
 	// Don't include items used for dragging
-	Item *dragItem = 0;
+	Item *dragItem = nullptr;
 	const ViewList::const_iterator viewsEnd = m_viewList.end();
 	for ( ViewList::const_iterator it = m_viewList.begin(); it != viewsEnd; ++it )
 	{
 		dragItem = (static_cast<ItemView*>((View*)*it))->dragItem();
 		if ( dragItem ) break;
 	}
-	
+
 	const KtlQCanvasItemList allItems = canvas()->allItems();
 	const KtlQCanvasItemList::const_iterator end = allItems.end();
 
 	for ( KtlQCanvasItemList::const_iterator it = allItems.begin(); it != end; ++it )
 	{
 		if( !(*it)->isVisible() ) continue;
-		
+
 		if(dragItem ) {
 			if(*it == dragItem ) continue;
-			
+
 			if(Node *n = dynamic_cast<Node*>(*it) ) {
 				if ( n->parentItem() == dragItem )
 					continue;
 			}
-		
+
 			if(GuiPart *gp = dynamic_cast<GuiPart*>(*it) ) {
 				if ( gp->parent() == dragItem )
 					continue;
 			}
 		}
-		
+
 		bound |= (*it)->boundingRect();
 	}
-	
+
 	if ( !bound.isNull() )
 	{
 		bound.setLeft( bound.left() - 16 );
@@ -838,7 +838,7 @@ QRect ItemDocument::canvasBoundingRect() const
 		bound.setRight( bound.right() + 16 );
 		bound.setBottom( bound.bottom() + 16 );
 	}
-	
+
 	return bound;
 }
 
@@ -849,78 +849,49 @@ void ItemDocument::exportToImage()
 	// this slot is called whenever the File->Export menu is selected,
 	// the Export shortcut is pressed or the Export toolbar
 	// button is clicked
-	
-	// widget for the kfiledialog
-	// It is the bit that says "Crop circuit?"
-	// Okay need to think of something way better to say here.
-	// gotme here, KFileDialog makes itself parent so tries to destroy cropCheck when it is deleted.
-	// therefore we use a pointer.
-	QString cropMessage;
 
-	cropMessage = i18n("Crop image");
-	
-	QCheckBox *cropCheck = new QCheckBox( cropMessage, KTechlab::self() /*, "cropCheck" */ );
-    cropCheck->setObjectName( "cropCheck" );
-	cropCheck->setChecked(true); // yes by default?
-	
 	// we need an object so we can retrieve which image type was selected by the user
 	// so setup the filedialog.
-	QString f;
-	f = QString("*.png|%1\n*.bmp|%2\n*.svg|%3").arg( i18n("PNG Image") ).arg( i18n("BMP Image") ).arg( i18n("SVG Image") );
-	//KFileDialog exportDialog( KUrl() /*QString::null */, f, KTechlab::self(), i18n("Export As Image"), true, cropCheck);
-    KFileDialog exportDialog( KUrl(), f, KTechlab::self(), /*i18n("Export As Image"),*/ /* true, */ cropCheck);
-    exportDialog.setModal(true);
-    exportDialog.setCaption(i18n("Export As Image"));
+    ImageExportDialog exportDialog(KTechlab::self());
 	
-	exportDialog.setOperationMode( KFileDialog::Saving );
 	// now actually show it
 	if ( exportDialog.exec() == QDialog::Rejected )
 		return;
-	KUrl url = exportDialog.selectedUrl();
+	const QString filePath = exportDialog.filePath();
 
-	if ( url.isEmpty() ) return;
-	
-	if ( QFile::exists( url.path() ) )
+	if ( filePath.isEmpty() ) return;
+
+	if ( QFile::exists(filePath) )
 	{
 		int query = KMessageBox::warningYesNo(
             KTechlab::self(),
-            i18n( "A file named \"%1\" already exists. " "Are you sure you want to overwrite it?", url.fileName() ),
+            i18n( "A file named \"%1\" already exists. " "Are you sure you want to overwrite it?", filePath ),
             i18n( "Overwrite File?" ));
 
 		if ( query == KMessageBox::No ) return;
 	}
-	
+
+    const bool crop = exportDialog.isCropSelected();
 	// with Qt, you always "print" to a
 	// QPainter.. whether the output medium is a pixmap, a screen,
 	// or paper
-	
+
 	// needs to be something like QPicture to do SVG etc...
-	
+
 	QRect saveArea;
-	QString type;
 	QRect cropArea;
 	QPaintDevice *outputImage;
-	QString filter = exportDialog.currentFilter();
-	filter = filter.toLower(); // gently soften the appearance of the letters.
-	
+	const QString type = exportDialog.formatType();
+
 	// did have a switch here but seems you can't use that on strings
-	if ( filter == "*.png") 	type = "PNG";
-	else if ( filter == "*.bmp")	type = "BMP";
-	else if ( filter == "*.svg" ) {
-		KMessageBox::information( NULL, i18n("SVG export is sub-functional"), i18n("Export As Image") );
-		type = "SVG";
-	}
-	// I don't like forcing people to use the right extension (personally)
-	// but it is the easiest way to decide image type.
-	else {
-		KMessageBox::sorry( NULL, i18n("Unknown extension, please select one from the filter list."), i18n("Export As Image") );
-		return;
+	if ( type == "SVG" ) {
+		KMessageBox::information( nullptr, i18n("SVG export is sub-functional"), i18n("Export As Image") );
 	}
 
-	if ( cropCheck->isChecked() ) {
+	if (crop) {
 		cropArea = canvasBoundingRect();
 		if ( cropArea.isNull() ) {
-			KMessageBox::sorry( 0l, i18n("There is nothing to crop"), i18n("Export As Image") );
+			KMessageBox::sorry( nullptr, i18n("There is nothing to crop"), i18n("Export As Image") );
 			return;
 		} else {
 			cropArea &= canvas()->rect();
@@ -937,10 +908,10 @@ void ItemDocument::exportToImage()
 		// svg can't be cropped using the qimage method.
 		saveArea = cropArea;
 	} else {
-		kWarning() << "Unknown type!" << endl;
+		qWarning() << "Unknown type!" << endl;
 		return;
 	}
-	
+
 //2018.05.05 - extract to a method
 // 	//QPainter p(outputImage); // 2016.05.03 - explicitly initialize painter
 // 	QPainter p;
@@ -957,13 +928,12 @@ void ItemDocument::exportToImage()
     exportToImageDraw(saveArea, *outputImage);
 
 	bool saveResult;
-	
+
 	// if cropping we need to convert to an image,
 	// crop, then save.
-	if ( cropCheck->isChecked() )
-	{
+	if (crop) {
 		if( type == "SVG" )
-			saveResult = dynamic_cast<QPicture*>(outputImage)->save( url.path(), type.toLatin1().data());
+			saveResult = dynamic_cast<QPicture*>(outputImage)->save(filePath, type.toLatin1().data());
 		else {
 			QImage img = dynamic_cast<QPixmap*>(outputImage)->toImage();
             if ( saveArea.x() < 0 ) {
@@ -974,17 +944,17 @@ void ItemDocument::exportToImage()
             }
             qDebug() << Q_FUNC_INFO << " cropArea " << cropArea;
 			QImage imgCropped = img.copy(cropArea);
-			saveResult = imgCropped.save(url.path(),type.toLatin1().data());
+			saveResult = imgCropped.save(filePath,type.toLatin1().data());
 		}
 	} else {
 		if ( type=="SVG" )
-			saveResult = dynamic_cast<QPicture*>(outputImage)->save( url.path(), type.toLatin1().data() );
-		else	saveResult = dynamic_cast<QPixmap*>(outputImage)->save( url.path(), type.toLatin1().data() );
+			saveResult = dynamic_cast<QPicture*>(outputImage)->save( filePath, type.toLatin1().data() );
+		else	saveResult = dynamic_cast<QPixmap*>(outputImage)->save( filePath, type.toLatin1().data() );
 	}
-	
+
 	//if(saveResult == true)	KMessageBox::information( this, i18n("Sucessfully exported to \"%1\"", url.filename() ), i18n("Image Export") );
 	//else KMessageBox::information( this, i18n("Export failed"), i18n("Image Export") );
-	
+
 	if ( type == "SVG" ) setSVGExport(false);
 
 	if (saveResult == false)
@@ -1032,26 +1002,26 @@ void ItemDocument::raiseZ()
 void ItemDocument::raiseZ( const ItemList & itemList )
 {
 	if ( m_zOrder.isEmpty() ) slotUpdateZOrdering();
-	
+
 	if ( m_zOrder.isEmpty() ) return;
-	
+
 	IntItemMap::iterator begin = m_zOrder.begin();
 	IntItemMap::iterator previous = m_zOrder.end();
 	IntItemMap::iterator it = --m_zOrder.end();
 	do {
-		Item * previousData = (previous == m_zOrder.end()) ? 0l : previous.value();
+		Item * previousData = (previous == m_zOrder.end()) ? nullptr : previous.value();
 		Item * currentData = it.value();
-		
+
 		if ( currentData && previousData && itemList.contains(currentData) && !itemList.contains(previousData) )
 		{
 			previous.value() = currentData;
 			it.value() = previousData;
 		}
-		
+
 		previous = it;
 		--it;
 	} while ( previous != begin );
-	
+
 	slotUpdateZOrdering();
 }
 
@@ -1064,25 +1034,25 @@ void ItemDocument::lowerZ()
 void ItemDocument::lowerZ( const ItemList &itemList )
 {
 	if ( m_zOrder.isEmpty() ) slotUpdateZOrdering();
-	
+
 	if ( m_zOrder.isEmpty() ) return;
-	
+
 	IntItemMap::iterator previous = m_zOrder.begin();
 	IntItemMap::iterator end = m_zOrder.end();
 	for ( IntItemMap::iterator it = m_zOrder.begin(); it != end; ++it )
 	{
 		Item * previousData = previous.value();
 		Item * currentData = it.value();
-		
+
 		if ( currentData && previousData && itemList.contains(currentData) && !itemList.contains(previousData) )
 		{
 			previous.value() = currentData;
 			it.value() = previousData;
 		}
-		
+
 		previous = it;
 	}
-	
+
 	slotUpdateZOrdering();
 }
 
@@ -1096,34 +1066,34 @@ void ItemDocument::itemAdded( Item * )
 void ItemDocument::slotUpdateZOrdering()
 {
 	ItemMap toAdd = m_itemList;
-	
+
 	IntItemMap newZOrder;
 	int atLevel = 0;
-	
+
 	IntItemMap::iterator zEnd = m_zOrder.end();
 	for ( IntItemMap::iterator it = m_zOrder.begin(); it != zEnd; ++it )
-	{	
+	{
 		Item * item = it.value();
 		if (!item) continue;
-		
+
 		toAdd.remove( item->id() );
-		
+
 		if ( !item->parentItem() && item->isMovable() )
 			newZOrder[atLevel++] = item;
 	}
-	
+
 	ItemMap::iterator addEnd = toAdd.end();
 	for ( ItemMap::iterator it = toAdd.begin(); it != addEnd; ++it )
 	{
 		Item * item = *it;
 		if ( item->parentItem() || !item->isMovable() )
 			continue;
-		
+
 		newZOrder[atLevel++] = item;
 	}
-	
+
 	m_zOrder = newZOrder;
-	
+
 	zEnd = m_zOrder.end();
 	for ( IntItemMap::iterator it = m_zOrder.begin(); it != zEnd; ++it )
 		it.value()->updateZ( it.key() );
@@ -1144,7 +1114,7 @@ void ItemDocument::update( )
 ItemList ItemDocument::itemList( ) const
 {
 	ItemList l;
-	
+
 	ItemMap::const_iterator end = m_itemList.end();
 	for ( ItemMap::const_iterator it = m_itemList.begin(); it != end; ++it )
 		l << it.value();
@@ -1172,12 +1142,12 @@ void CanvasTip::displayVI( ECNode *node, const QPoint &pos )
 {
 	if ( !node || !updateVI() )
 		return;
-	
+
 	unsigned num = node->numPins();
-	
+
 	m_v.resize(num);
 	m_i.resize(num);
-	
+
 	for ( unsigned i = 0; i < num; i++ )
 	{
 		if ( Pin * pin = node->pin(i) )
@@ -1186,7 +1156,7 @@ void CanvasTip::displayVI( ECNode *node, const QPoint &pos )
 			m_i[i] = pin->current();
 		}
 	}
-	
+
 	display(pos);
 }
 
@@ -1195,12 +1165,12 @@ void CanvasTip::displayVI( Connector *connector, const QPoint &pos )
 {
 	if ( !connector || !updateVI())
 		return;
-	
+
 	unsigned num = connector->numWires();
-	
+
 	m_v.resize(num);
 	m_i.resize(num);
-	
+
 	for ( unsigned i = 0; i < num; i++ )
 	{
 		if ( Wire * wire = connector->wire(i) )
@@ -1209,7 +1179,7 @@ void CanvasTip::displayVI( Connector *connector, const QPoint &pos )
 			m_i[i] = std::abs(wire->current());
 		}
 	}
-	
+
 	display(pos);
 }
 
@@ -1219,7 +1189,7 @@ bool CanvasTip::updateVI()
 	CircuitDocument *circuitDocument = dynamic_cast<CircuitDocument*>(p_itemDocument);
 	if ( !circuitDocument || !Simulator::self()->isSimulating() )
 		return false;
-	
+
 	circuitDocument->calculateConnectorCurrents();
 	return true;
 }
@@ -1228,19 +1198,19 @@ bool CanvasTip::updateVI()
 void CanvasTip::display( const QPoint &pos )
 {
 	unsigned num = m_v.size();
-	
+
 	for ( unsigned i = 0; i < num; i++ ) {
 		if ( !std::isfinite(m_v[i]) || std::abs(m_v[i]) < 1e-9 )
 			m_v[i] = 0.;
-		
+
 		if ( !std::isfinite(m_i[i]) || std::abs(m_i[i]) < 1e-9 )
 			m_i[i] = 0.;
 	}
-	
+
 	move( pos.x()+20, pos.y()+4 );
-	
+
 	if ( num == 0 ) return;
-	
+
 	if ( num == 1 )
 		setText( displayText(0) );
 	else {
@@ -1256,7 +1226,7 @@ QString CanvasTip::displayText( unsigned num ) const
 {
 	if ( m_v.size() <= (int)num )
 		return QString::null;
-	
+
 	return QString("%1%2V  %3%4A")
 			.arg( QString::number( m_v[num] / CNItem::getMultiplier(m_v[num]), 'g', 3 ) )
 			.arg( CNItem::getNumberMag( m_v[num] ) )
@@ -1270,11 +1240,11 @@ void CanvasTip::draw( QPainter &p )
 	CircuitDocument *circuitDocument = dynamic_cast<CircuitDocument*>(p_itemDocument);
 	if ( !circuitDocument || !Simulator::self()->isSimulating() )
 		return;
-	
+
 	p.setBrush( QColor( 0xff, 0xff, 0xdc ) );
 	p.setPen( Qt::black );
 	p.drawRect( boundingRect() );
-	
+
 	QRect textRect = boundingRect();
 	textRect.setLeft( textRect.left() + 3 );
 	textRect.setTop( textRect.top() + 1 );
@@ -1286,7 +1256,7 @@ void CanvasTip::setText( const QString & text )
 {
 	m_text = text;
 	canvas()->setChanged( boundingRect() );
-	
+
 	QRect r = QFontMetrics( qApp->font() ).boundingRect( 0, 0, 0, 0, 0, m_text );
 	setSize( r.width() + 4, r.height() - 1 );
 }
@@ -1316,14 +1286,14 @@ void Canvas::resize( const QRect & size )
 void Canvas::setMessage( const QString & message )
 {
 	m_message = message;
-	
+
 	if ( message.isEmpty() ) {
 		m_pMessageTimeout->stop();
     } else {
         m_pMessageTimeout->setSingleShot(true);
         m_pMessageTimeout->start( 2000 /*, true */ );
     }
-	
+
 	setAllChanged();
 }
 
@@ -1336,16 +1306,16 @@ void Canvas::drawBackground ( QPainter &p, const QRect & clip )
 	const int ecx = (int)((clip.right()+4)/8);
 	const int scy = (int)((clip.top()-4)/8);
 	const int ecy = (int)((clip.bottom()+4)/8);
-	
+
 	ICNDocument * icnd = dynamic_cast<ICNDocument*>(p_itemDocument);
 	if ( !icnd )
 		return;
-	
+
 	Cells * c = icnd->cells();
-	
+
 	if ( !c->haveCell( scx, scy ) || !c->haveCell( ecx, ecy ) )
 		return;
-	
+
 	for ( int x=scx; x<=ecx; x++ )
 	{
 		for ( int y=scy; y<=ecy; y++ )
@@ -1368,33 +1338,33 @@ void Canvas::drawBackground ( QPainter &p, const QRect & clip )
 void Canvas::drawForeground ( QPainter &p, const QRect & clip )
 {
 	KtlQCanvas::drawForeground( p, clip );
-	
+
 	if ( !m_pMessageTimeout->isActive() )
 		return;
 
 	// Following code stolen and adapted from amarok/src/playlist.cpp :)
-	
+
 	// Find out width of smallest view
 	QSize minSize;
 	const ViewList viewList = p_itemDocument->viewList();
 	ViewList::const_iterator end = viewList.end();
-	View * firstView = 0l;
+	View * firstView = nullptr;
 	for ( ViewList::const_iterator it = viewList.begin(); it != end; ++it )
 	{
 		if ( !*it ) continue;
-		
+
 		if ( !firstView )
 		{
 			firstView = *it;
 			minSize = (*it)->size();
 		} else	minSize = minSize.boundedTo( (*it)->size() );
 	}
-	
+
 	if ( !firstView ) return;
-	
+
 // 	Q3SimpleRichText * t = new Q3SimpleRichText( m_message, QApplication::font() );
     QTextEdit * t = new QTextEdit( m_message );
-	
+
     {
         QFont tf = t->document()->defaultFont();
         QFontMetrics tfm(tf);
@@ -1408,14 +1378,14 @@ void Canvas::drawForeground ( QPainter &p, const QRect & clip )
 	int x = rect().left() + 15;
 	int y = rect().top() + 15;
 	int b = 10; // text padding
-	
+
 // 	if ( w+2*b >= minSize.width() || h+2*b >= minSize.height() )
 // 	{
 //         qWarning() << Q_FUNC_INFO << "size not good w=" << w << " h=" << h << "b=" << b << " minSize=" << minSize;
 // 		delete t;
 // 		return;
 // 	}
-	
+
     //p.setBrush( firstView->colorGroup().background() ); // 2018.12.02
 	p.setBrush( firstView->palette().window() );
 	p.drawRoundRect( x, y, w+2*b, h+2*b, (8*200)/(w+2*b), (8*200)/(h+2*b) );
@@ -1434,6 +1404,3 @@ void Canvas::update()
 	KtlQCanvas::update();
 }
 //END class Canvas
-
-#include "itemdocument.moc"
-
