@@ -21,21 +21,20 @@
 #include "ktechlab.h"
 #include "lineedit.h"
 
-#include <kcombobox.h>
-#include <kdebug.h>
-#include <klineedit.h>
-#include <knuminput.h>
-#include <kurlrequester.h>
-#include <ktoolbar.h>
-#include <kxmlguifactory.h>
+#include <KComboBox>
+#include <KUrlRequester>
+#include <KToolBar>
+#include <KXMLGUIFactory>
 
-#include <qapplication.h>
-#include <qlabel.h>
-#include <qcheckbox.h>
+#include <QDebug>
+#include <QApplication>
+#include <QLabel>
+#include <QCheckBox>
+#include <QSpinBox>
 
 #include <cassert>
 
-ItemInterface * ItemInterface::m_pSelf = 0l;
+ItemInterface * ItemInterface::m_pSelf = nullptr;
 
 ItemInterface * ItemInterface::self()
 {
@@ -50,10 +49,10 @@ ItemInterface::ItemInterface()
 	: QObject( KTechlab::self() )
     , m_isInTbDataChanged(false)
 {
-	m_pActiveItemEditorToolBar = 0;
-	p_cvb = 0l;
-	p_itemGroup = 0l;
-	p_lastItem = 0l;
+	m_pActiveItemEditorToolBar = nullptr;
+	p_cvb = nullptr;
+	p_itemGroup = nullptr;
+	p_lastItem = nullptr;
 	m_currentActionTicket = -1;
 	m_toolBarWidgetID = -1;
 }
@@ -78,7 +77,7 @@ void ItemInterface::slotItemDocumentChanged( ItemDocument * doc )
 		disconnect( itemDocument, SIGNAL(selectionChanged()), this, SLOT(slotUpdateItemInterface()) );
 	}
 	
-	p_itemGroup = 0l;
+	p_itemGroup = nullptr;
 	p_cvb = doc;
 	
 	slotGetActionTicket();
@@ -110,7 +109,7 @@ void ItemInterface::slotClearAll()
 	ContextHelp::self()->slotClear();
 	ItemEditor::self()->slotClear();
 	clearItemEditorToolBar();
-	p_lastItem = 0l;
+	p_lastItem = nullptr;
 }
 
 
@@ -119,7 +118,7 @@ void ItemInterface::slotMultipleSelected()
 	ContextHelp::self()->slotMultipleSelected();
 	ItemEditor::self()->slotMultipleSelected();
 	clearItemEditorToolBar();
-	p_lastItem = 0l;
+	p_lastItem = nullptr;
 }
 
 
@@ -177,7 +176,7 @@ void ItemInterface::slotUpdateItemInterface()
 
 void ItemInterface::updateItemActions()
 {
-	ItemView * itemView = ((ItemDocument*)p_cvb) ? dynamic_cast<ItemView*>(p_cvb->activeView()) : 0l;
+	ItemView * itemView = ((ItemDocument*)p_cvb) ? dynamic_cast<ItemView*>(p_cvb->activeView()) : nullptr;
 	if ( !itemView )
 		return;
 	
@@ -244,7 +243,7 @@ void ItemInterface::itemEditTBCleared()
 QWidget * ItemInterface::configWidget()
 {
 	if ( !p_itemGroup || !p_itemGroup->activeItem() || !m_pActiveItemEditorToolBar )
-		return 0l;
+		return nullptr;
 	
 	VariantDataMap *variantMap = p_itemGroup->activeItem()->variantMap();
 	
@@ -281,7 +280,7 @@ QWidget * ItemInterface::configWidget()
 		if ( type != Variant::Type::Bool && !toolbarCaption.isEmpty() )
 			configLayout->addWidget( new QLabel( toolbarCaption, configWidget ) );
 		
-		QWidget * editWidget = 0l; // Should be set to the created widget
+		QWidget * editWidget = nullptr; // Should be set to the created widget
 		
 		switch( type )
 		{
@@ -328,7 +327,7 @@ QWidget * ItemInterface::configWidget()
 				
 				KUrlComboRequester * urlreq = new KUrlComboRequester( configWidget );
 				urlreq->setFilter( vait.value()->filter() );
-				connectMapWidget( urlreq, SIGNAL(urlSelected(const KUrl &)) );
+				connectMapWidget( urlreq, SIGNAL(urlSelected(QUrl)) );
 				m_stringURLReqMap[vait.key()] = urlreq;
 				
 				KComboBox * box = urlreq->comboBox();
@@ -336,7 +335,7 @@ QWidget * ItemInterface::configWidget()
 				box->setEditable( true );
 				
 				// Note this has to be called after inserting the allowed list
-				urlreq->setUrl( vait.value()->value().toString() );
+				urlreq->setUrl(QUrl::fromLocalFile(vait.value()->value().toString()));
 				
 				// Generally we only want a file name once the user has finished typing out the full file name.
 				connectMapWidget( box, SIGNAL(returnPressed(const QString &)));
@@ -362,8 +361,10 @@ QWidget * ItemInterface::configWidget()
 			}
 			case Variant::Type::Int:
 			{
-				KIntSpinBox *spin = new KIntSpinBox( (int)vait.value()->minValue(), (int)vait.value()->maxValue(), 1, vait.value()->value().toInt(),
-                                                     configWidget, 10 );
+				QSpinBox *spin = new QSpinBox(configWidget);
+				spin->setMinimum((int)vait.value()->minValue());
+				spin->setMaximum((int)vait.value()->maxValue());
+				spin->setValue(vait.value()->value().toInt());
 				
 				connectMapWidget( spin, SIGNAL(valueChanged(int)) );
 				m_intSpinBoxMap[vait.key()] = spin;
@@ -489,19 +490,19 @@ void ItemInterface::connectMapWidget( QWidget *widget, const char *_signal )
 struct BoolLock {
     bool *m_flagPtr;
     BoolLock(bool *flagPtr) : m_flagPtr(flagPtr) {
-        if (m_flagPtr == NULL) {
-            qCritical() << Q_FUNC_INFO << "NULL flagPtr";
+        if (m_flagPtr == nullptr) {
+            qCritical() << Q_FUNC_INFO << "nullptr flagPtr";
             return;
         }
         if (*m_flagPtr == true) {
             qWarning() << Q_FUNC_INFO << "flag expected to be false, addr=" << m_flagPtr << " Doing nothing";
-            m_flagPtr = NULL;
+            m_flagPtr = nullptr;
         } else {
             *m_flagPtr = true;
         }
     }
     ~BoolLock() {
-        if (m_flagPtr != NULL) {
+        if (m_flagPtr != nullptr) {
             *m_flagPtr = false;
         }
     }
@@ -590,7 +591,7 @@ void ItemInterface::slotSetData( const QString &id, QVariant value )
 	
 	if ( !p_itemGroup->itemsAreSameType() )
 	{
-		kDebug() << k_funcinfo << "Items are not the same type!"<<endl;
+		qDebug() << Q_FUNC_INFO << "Items are not the same type!"<<endl;
 		return;
 	}
 	qDebug() << Q_FUNC_INFO << "id=" << id << " value=" << value;
@@ -611,5 +612,3 @@ void ItemInterface::slotSetData( const QString &id, QVariant value )
 	if (p_cvb)
 		p_cvb->requestStateSave(m_currentActionTicket);
 }
-
-#include "iteminterface.moc"
