@@ -10,11 +10,11 @@
 #ifndef ITEMLIBRARY_H
 #define ITEMLIBRARY_H
 
-#include <klocalizedstring.h>
+#include <KLocalizedString>
 
-#include <qcolor.h>
-#include <qobject.h>
-#include <qmap.h>
+#include <QColor>
+#include <QObject>
+#include <QMap>
 
 class Component;
 class Document;
@@ -39,7 +39,7 @@ class ItemLibrary : public QObject
 {
 	Q_OBJECT
 	public:
-		~ItemLibrary();
+		~ItemLibrary() override;
 		/**
 		 * Returns a QPixmap of the item icon
 		 */
@@ -59,7 +59,7 @@ class ItemLibrary : public QObject
 		/**
 		 * Creates a new item with the given id, and returns a pointer to it
 		 */
-		Item * createItem( const QString &id, ItemDocument * itemDocument, bool newItem, const char *newId = 0L, bool finishCreation = true );
+		Item * createItem( const QString &id, ItemDocument * itemDocument, bool newItem, const char *newId = nullptr, bool finishCreation = true );
 		/**
 		 * Returns an image of the given component. As QPixmap::toImage is
 		 * a slow function, this will cache the result and return that for large
