@@ -23,22 +23,24 @@
 #include "utils.h"
 
 //#include <kaccel.h>
-#include <kaction.h>
-#include <kstandardaction.h>
-#include <kdebug.h>
-#include <kiconloader.h>
-#include <klocalizedstring.h>
+#include <KStandardAction>
+#include <KLocalizedString>
 // #include <k3popupmenu.h>
-#include <ktoolbarpopupaction.h>
-#include <kactioncollection.h>
+#include <KToolBarPopupAction>
+#include <KActionCollection>
 
-#include <qapplication.h>
-#include <qcursor.h>
-#include <qtimer.h>
-#include <qmatrix.h>
+#include <QMatrix>
+#include <QDebug>
+#include <QApplication>
+#include <QVBoxLayout>
+#include <QCursor>
+#include <QTimer>
+#include <QMimeData>
+#include <QMouseEvent>
+#include <QMimeData>
+#include <QMenu>
 
 #include <cmath>
-#include <kmenu.h>
 
 #include <ktlconfig.h>
 
@@ -48,25 +50,25 @@ ItemView::ItemView( ItemDocument * itemDocument, ViewContainer *viewContainer, u
 	: View( itemDocument, viewContainer, viewAreaId, name )
 {
 	KActionCollection * ac = actionCollection();
-	
+
 	KStandardAction::selectAll(	itemDocument,	SLOT(selectAll()),	ac );
 	KStandardAction::zoomIn(	this,		SLOT(zoomIn()),		ac );
 	KStandardAction::zoomOut(	this,		SLOT(zoomOut()),	ac );
 	KStandardAction::actualSize(	this,		SLOT(actualSize()),	ac )->setEnabled(false);
-	
-	
+
+
 	//KAccel *pAccel = new KAccel(this);
 	//pAccel->insert( "Cancel", i18n("Cancel"), i18n("Cancel the current operation"), Qt::Key_Escape, itemDocument, SLOT(cancelCurrentOperation()) );
 	//pAccel->readSettings(); // TODO what does this do?
-    KAction *pAccel = new KAction( KIcon("process-stop"), i18n("Cancel"), ac);
+    QAction *pAccel = new QAction( QIcon::fromTheme("process-stop"), i18n("Cancel"), ac);
     pAccel->setObjectName("cancelCurrentOperation");
     pAccel->setShortcut(Qt::Key_Escape);
     connect(pAccel, SIGNAL(triggered(bool)), itemDocument, SLOT(cancelCurrentOperation()));
     ac->addAction("cancelCurrentOperation", pAccel);
-	
+
     {
 	//new KAction( i18n("Delete"), "edit-delete", Qt::Key_Delete, itemDocument, SLOT(deleteSelection()), ac, "edit_delete" );
-        KAction *action = new KAction( KIcon("edit-delete"), i18n("Delete"), ac);
+        QAction *action = new QAction( QIcon::fromTheme("edit-delete"), i18n("Delete"), ac);
         action->setObjectName("edit_delete");
         action->setShortcut( Qt::Key_Delete );
         connect(action, SIGNAL(triggered(bool)), itemDocument, SLOT(deleteSelection()));
@@ -74,68 +76,68 @@ ItemView::ItemView( ItemDocument * itemDocument, ViewContainer *viewContainer, u
     }
     {
 	//new KAction( i18n("Export as Image..."), 0, 0, itemDocument, SLOT(exportToImage()), ac, "file_export_image");
-        KAction *action = new KAction( KIcon("document-export"), i18n("Export as Image..."), ac);
+        QAction *action = new QAction( QIcon::fromTheme("document-export"), i18n("Export as Image..."), ac);
         action->setObjectName("file_export_image");
         connect(action, SIGNAL(triggered(bool)), itemDocument, SLOT(exportToImage()));
         ac->addAction("file_export_image", action);
     }
-	
+
 	//BEGIN Item Alignment actions
 	{
 	//new KAction( i18n("Align Horizontally"), 0, 0, itemDocument, SLOT(alignHorizontally()), ac, "align_horizontally" );
-        KAction *action = new KAction( KIcon("align-horizontal-center"), i18n("Align Horizontally"), ac);
+        QAction *action = new QAction( QIcon::fromTheme("align-horizontal-center"), i18n("Align Horizontally"), ac);
         action->setObjectName("align_horizontally");
         connect(action, SIGNAL(triggered(bool)), itemDocument, SLOT(alignHorizontally()));
         ac->addAction("align_horizontally", action);
     }
     {
 	//new KAction( i18n("Align Vertically"), 0, 0, itemDocument, SLOT(alignVertically()), ac, "align_vertically" );
-        KAction *action = new KAction( KIcon("align-vertical-center"), i18n("Align Vertically"), ac);
+        QAction *action = new QAction( QIcon::fromTheme("align-vertical-center"), i18n("Align Vertically"), ac);
         action->setObjectName("align_vertically");
         connect(action, SIGNAL(triggered(bool)), itemDocument, SLOT(alignVertically()));
         ac->addAction("align_vertically", action);
     }
     {
 	//new KAction( i18n("Distribute Horizontally"), 0, 0, itemDocument, SLOT(distributeHorizontally()), ac, "distribute_horizontally" );
-        KAction *action = new KAction( KIcon("distribute-horizontal-x"), i18n("Distribute Horizontally"), ac);
+        QAction *action = new QAction( QIcon::fromTheme("distribute-horizontal-x"), i18n("Distribute Horizontally"), ac);
         action->setObjectName("distribute_horizontally");
         connect(action, SIGNAL(triggered(bool)), itemDocument, SLOT(distributeHorizontally()));
         ac->addAction("distribute_horizontally", action);
     }
     {
 	//new KAction( i18n("Distribute Vertically"), 0, 0, itemDocument, SLOT(distributeVertically()), ac, "distribute_vertically" );
-        KAction *action = new KAction( KIcon("distribute-vertical-y"), i18n("Distribute Vertically"), ac);
+        QAction *action = new QAction( QIcon::fromTheme("distribute-vertical-y"), i18n("Distribute Vertically"), ac);
         action->setObjectName("distribute_vertically");
         connect(action, SIGNAL(triggered(bool)), itemDocument, SLOT(distributeVertically()));
         ac->addAction("distribute_vertically", action);
     }
 	//END Item Alignment actions
-	
-	
+
+
 	//BEGIN Draw actions
 	//KToolBarPopupAction * pa = new KToolBarPopupAction( i18n("Draw"), "paintbrush", 0, 0, 0, ac, "edit_draw" );
-	KToolBarPopupAction * pa = new KToolBarPopupAction( KIcon("draw-brush"), i18n("Draw"), ac);
+	KToolBarPopupAction * pa = new KToolBarPopupAction( QIcon::fromTheme("draw-brush"), i18n("Draw"), ac);
     pa->setObjectName("edit_draw");
 	pa->setDelayed(false);
     ac->addAction("edit_draw", pa);
-	
+
 	QMenu * m = pa->menu();
 	m->setTitle( i18n("Draw") );
-	
-	m->addAction( KIcon( "draw-text" ), i18n("Text"))->setData(DrawPart::da_text );
-	m->addAction( KIcon( "draw-line" ), i18n("Line"))->setData(DrawPart::da_line );
-	m->addAction( KIcon( "draw-arrow"  ), i18n("Arrow"))->setData(DrawPart::da_arrow );
-	m->addAction( KIcon( "draw-ellipse" ), i18n("Ellipse"))->setData(DrawPart::da_ellipse );
-	m->addAction( KIcon( "draw-rectangle" ), i18n("Rectangle"))->setData(DrawPart::da_rectangle );
-	m->addAction( KIcon( "insert-image" ), i18n("Image"))->setData(DrawPart::da_image );
+
+	m->addAction( QIcon::fromTheme( "draw-text" ), i18n("Text"))->setData(DrawPart::da_text );
+	m->addAction( QIcon::fromTheme( "draw-line" ), i18n("Line"))->setData(DrawPart::da_line );
+	m->addAction( QIcon::fromTheme( "draw-arrow"  ), i18n("Arrow"))->setData(DrawPart::da_arrow );
+	m->addAction( QIcon::fromTheme( "draw-ellipse" ), i18n("Ellipse"))->setData(DrawPart::da_ellipse );
+	m->addAction( QIcon::fromTheme( "draw-rectangle" ), i18n("Rectangle"))->setData(DrawPart::da_rectangle );
+	m->addAction( QIcon::fromTheme( "insert-image" ), i18n("Image"))->setData(DrawPart::da_image );
 	connect( m, SIGNAL(triggered(QAction*)), itemDocument, SLOT(slotSetDrawAction(QAction*)) );
 	//END Draw actions
-	
-	
+
+
 	//BEGIN Item Control actions
     {
 	//new KAction( i18n("Raise Selection"), "object-order-raise", Qt::Key_PageUp,   itemDocument, SLOT(raiseZ()), ac, "edit_raise" );
-        KAction * action = new KAction( KIcon("object-order-raise"), i18n("Raise Selection"), ac);
+        QAction * action = new QAction( QIcon::fromTheme("object-order-raise"), i18n("Raise Selection"), ac);
         action->setObjectName("edit_raise");
         action->setShortcut(Qt::Key_PageUp);
         connect(action, SIGNAL(triggered(bool)), itemDocument, SLOT(raiseZ()));
@@ -143,39 +145,39 @@ ItemView::ItemView( ItemDocument * itemDocument, ViewContainer *viewContainer, u
     }
     {
 	//new KAction( i18n("Lower Selection"), "object-order-lower", Qt::Key_PageDown, itemDocument, SLOT(lowerZ()), ac, "edit_lower" );
-        KAction *action = new KAction( KIcon("object-order-lower"), i18n("Lower Selection"), ac);
+        QAction *action = new QAction( QIcon::fromTheme("object-order-lower"), i18n("Lower Selection"), ac);
         action->setObjectName("edit_lower");
         action->setShortcut(Qt::Key_PageDown);
         connect(action, SIGNAL(triggered(bool)), itemDocument, SLOT(lowerZ()));
         ac->addAction("edit_lower", action);
     }
 	//END Item Control actions
-	
-	
+
+
 	{
 	//KAction * na = new KAction( "", 0, 0, 0, 0, ac, "null_action" );
-    KAction * na = new KAction( "", ac);
+    QAction * na = new QAction( "", ac);
     na->setObjectName("null_action");
 	na->setEnabled(false);
     }
-	
+
 	setXMLFile( "ktechlabitemviewui.rc" );
-	
+
 	m_pUpdateStatusTmr = new QTimer(this);
 	connect( m_pUpdateStatusTmr, SIGNAL(timeout()), this, SLOT(updateStatus()) );
 	connect( this, SIGNAL(unfocused()), this, SLOT(stopUpdatingStatus()) );
-	
-	m_pDragItem = 0l;
+
+	m_pDragItem = nullptr;
 	p_itemDocument = itemDocument;
 	m_zoomLevel = 1.;
 	m_CVBEditor = new CVBEditor( p_itemDocument->canvas(), this, "cvbEditor" );
 	m_CVBEditor->setLineWidth(1);
-	
+
 	connect( m_CVBEditor, SIGNAL(horizontalSliderReleased()), itemDocument, SLOT(requestCanvasResize()) );
 	connect( m_CVBEditor, SIGNAL(verticalSliderReleased()), itemDocument, SLOT(requestCanvasResize()) );
-	
+
 	m_layout->insertWidget( 0, m_CVBEditor );
-	
+
 	setAcceptDrops(true);
 
 	setFocusWidget( m_CVBEditor->viewport() );
@@ -208,22 +210,22 @@ void ItemView::zoomIn( const QPoint & center )
 {
 	// NOTE The code in this function is nearly the same as that in zoomOut.
 	// Any updates to this code should also be done to zoomOut
-	
+
 	// Previous position of center in widget coordinates
 	QPoint previous = center * zoomLevel() - QPoint( cvbEditor()->contentsX(), cvbEditor()->contentsY() );
-	
+
 	// Don't repaint the view until we've also shifted it
 	cvbEditor()->viewport()->setUpdatesEnabled( false );
-	
+
 	zoomIn();
-	
+
 	// Adjust the contents' position to ensure that "previous" remains fixed
 	QPoint offset = center * zoomLevel() - previous;
 	cvbEditor()->setContentsPos( offset.x(), offset.y() );
-	
+
 	cvbEditor()->viewport()->setUpdatesEnabled( true );
 	cvbEditor()->viewport()->update();
-	
+
 }
 
 
@@ -231,19 +233,19 @@ void ItemView::zoomOut( const QPoint & center )
 {
 	// NOTE The code in this function is nearly the same as that in zoomIn.
 	// Any updates to this code should also be done to zoomIn
-	
+
 	// Previous position of center in widget coordinates
 	QPoint previous = center * zoomLevel() - QPoint( cvbEditor()->contentsX(), cvbEditor()->contentsY() );
-	
+
 	// Don't repaint the view until we've also shifted it
 	cvbEditor()->viewport()->setUpdatesEnabled( false );
-	
+
 	zoomOut();
-	
+
 	// Adjust the contents' position to ensure that "previous" remains fixed
 	QPoint offset = center * zoomLevel() - previous;
 	cvbEditor()->setContentsPos( offset.x(), offset.y() );
-	
+
 	cvbEditor()->viewport()->setUpdatesEnabled( true );
 	cvbEditor()->viewport()->update();
 }
@@ -253,16 +255,16 @@ void ItemView::zoomIn()
 {
 	int currentZoomPercent = int(std::floor((100*m_zoomLevel)+0.5));
 	int newZoom = currentZoomPercent;
-	
+
 	if ( currentZoomPercent < 100 )
 		newZoom += 25;
 	else if ( currentZoomPercent < 200 )
 		newZoom += 50;
 	else	newZoom += 100;
-	
+
 	m_zoomLevel = newZoom/100.0;
 	m_CVBEditor->updateWorldMatrix();
-	
+
 	p_itemDocument->requestEvent( ItemDocument::ItemDocumentEvent::ResizeCanvasToItems );
 	updateZoomActions();
 }
@@ -272,7 +274,7 @@ void ItemView::zoomOut()
 {
 	int currentZoomPercent = int(std::floor((100*m_zoomLevel)+0.5));
 	int newZoom = currentZoomPercent;
-	
+
 	if ( currentZoomPercent <= 25 )
 		return;
 	if ( currentZoomPercent <= 100 )
@@ -280,10 +282,10 @@ void ItemView::zoomOut()
 	else if ( currentZoomPercent <= 200 )
 		newZoom -= 50;
 	else	newZoom -= 100;
-	
+
 	m_zoomLevel = newZoom/100.0;
 	m_CVBEditor->updateWorldMatrix();
-	
+
 	p_itemDocument->requestEvent( ItemDocument::ItemDocumentEvent::ResizeCanvasToItems );
 	updateZoomActions();
 }
@@ -294,7 +296,7 @@ void ItemView::actualSize()
 	m_zoomLevel = 1.0;
 	QMatrix m( m_zoomLevel, 0.0, 0.0, m_zoomLevel, 1.0, 1.0 );
 	m_CVBEditor->setWorldMatrix(m);
-	
+
 	p_itemDocument->requestEvent( ItemDocument::ItemDocumentEvent::ResizeCanvasToItems );
 	updateZoomActions();
 }
@@ -311,30 +313,40 @@ void ItemView::updateZoomActions()
 void ItemView::dropEvent( QDropEvent *event )
 {
 	removeDragItem();
-	
-	if ( KUrl::List::canDecode( event->mimeData() ) )
+    const QMimeData* mimeData = event->mimeData();
+
+	if (mimeData->hasUrls())
 	{
 		// Then it is URLs that we can decode :)
-		const KUrl::List urls = KUrl::List::fromMimeData( event->mimeData() );
-		foreach ( const KUrl &u, urls )
-		{
+		const QList<QUrl> urls = mimeData->urls();
+		for (const QUrl &u : urls) {
 			DocManager::self()->openURL(u);
 		}
 		return;
 	}
-	
-	if ( !QString(event->format()).startsWith("ktechlab/") )
+
+    QString matchingFormat;
+    for (QString format: mimeData->formats()) {
+        if (format.startsWith("ktechlab/")) {
+            matchingFormat = format;
+            break;
+        }
+    }
+	if (matchingFormat.isEmpty()) {
 		return;
-	
+    }
+    event->acceptProposedAction();
+
 	QString text;
 	//QDataStream stream( event->encodedData(event->format()), QIODevice::ReadOnly );
-    QByteArray byteArray( event->encodedData(event->format()) );
+    QByteArray byteArray( mimeData->data(matchingFormat) );
+
     QDataStream stream( &byteArray, QIODevice::ReadOnly);
 	stream >> text;
 
 	// Get a new component item
 	p_itemDocument->addItem( text, mousePosToCanvasPos( event->pos() ), true );
-	
+
 	setFocus();
 }
 
@@ -345,29 +357,29 @@ void ItemView::scrollToMouse( const QPoint & pos )
 	viewPos *= m_zoomLevel;
 	int x = viewPos.x();
 	int y = viewPos.y();
-	
+
 	int left = m_CVBEditor->contentsX();
 	int top = m_CVBEditor->contentsY();
 	int width = m_CVBEditor->contentsWidth();
 	int height = m_CVBEditor->contentsHeight();
 	int right = left + m_CVBEditor->visibleWidth();
 	int bottom = top + m_CVBEditor->visibleHeight();
-	
+
 	// A magic "snap" region whereby if the mouse is near the edge of the canvas,
 	// then assume that we want to scroll right up to it
 	int snapMargin = 32;
-	
+
 	if ( x < snapMargin ) x = 0;
 	else if ( x > width - snapMargin )
 		x = width;
-	
+
 	if ( y < snapMargin ) y = 0;
 	else if ( y > height - snapMargin )
 		y = height;
-	
+
 	if ( x < left )		m_CVBEditor->scrollBy( x - left, 0 );
 	else if ( x > right )	m_CVBEditor->scrollBy( x - right, 0 );
-	
+
 	if ( y < top )		m_CVBEditor->scrollBy( 0, y - top  );
 	else if ( y > bottom )	m_CVBEditor->scrollBy( 0, y - bottom);
 }
@@ -376,13 +388,13 @@ void ItemView::scrollToMouse( const QPoint & pos )
 void ItemView::contentsMousePressEvent( QMouseEvent *e )
 {
 	if (!e) return;
-	
+
 	e->accept();
-	
+
 	if(!p_itemDocument ) return;
-	
+
 	EventInfo eventInfo( this, e );
-	
+
 	if ( eventInfo.isRightClick && m_pDragItem )
 	{
 		// We are dragging an item, and the user has right clicked.
@@ -392,10 +404,10 @@ void ItemView::contentsMousePressEvent( QMouseEvent *e )
 		/// flowparts, or nothing if the item isn't rotatable).
 		if ( Component * c = dynamic_cast<Component*>( m_pDragItem ) )
 			c->setAngleDegrees( c->angleDegrees() + 90 );
-		
+
 		return;
 	}
-	
+
 	p_itemDocument->canvas()->setMessage( QString::null );
 	p_itemDocument->m_cmManager->mousePressEvent( eventInfo );
 }
@@ -404,9 +416,9 @@ void ItemView::contentsMousePressEvent( QMouseEvent *e )
 void ItemView::contentsMouseDoubleClickEvent( QMouseEvent *e )
 {
 	if (!e) return;
-	
+
 	e->accept();
-	
+
 	//HACK: Pass this of as a single press event if widget underneath
 	KtlQCanvasItem * atTop = p_itemDocument->itemAtTop( e->pos()/zoomLevel() );
 	if ( dynamic_cast<Widget*>(atTop) )
@@ -417,15 +429,15 @@ void ItemView::contentsMouseDoubleClickEvent( QMouseEvent *e )
 
 void ItemView::contentsMouseMoveEvent( QMouseEvent *e )
 {
-// 	kDebug() << k_funcinfo << "state = " << e->state() << endl;
-	
+// 	qDebug() << Q_FUNC_INFO << "state = " << e->state() << endl;
+
 	if ( !e || !p_itemDocument )
 		return;
-	
+
 	e->accept();
-	
+
 	EventInfo eventInfo( this, e );
-	
+
 	p_itemDocument->m_cmManager->mouseMoveEvent( eventInfo );
 	if ( !m_pUpdateStatusTmr->isActive() )
 		startUpdatingStatus();
@@ -435,9 +447,9 @@ void ItemView::contentsMouseMoveEvent( QMouseEvent *e )
 void ItemView::contentsMouseReleaseEvent( QMouseEvent *e )
 {
 	if (!e) return;
-	
+
 	e->accept();
-	
+
 	p_itemDocument->m_cmManager->mouseReleaseEvent( EventInfo( this, e ) );
 }
 
@@ -445,20 +457,20 @@ void ItemView::contentsMouseReleaseEvent( QMouseEvent *e )
 void ItemView::contentsWheelEvent( QWheelEvent *e )
 {
 	if (!e) return;
-	
+
 	e->accept();
 	EventInfo eventInfo( this, e );
 	if ( eventInfo.ctrlPressed )
 	{
 		// Zooming in or out
-		
+
 		if ( eventInfo.scrollDelta > 0 )
 			zoomIn( eventInfo.pos );
 		else	zoomOut( eventInfo.pos );
-		
+
 		return;
 	}
-	
+
 	p_itemDocument->m_cmManager->wheelEvent( eventInfo );
 }
 
@@ -466,8 +478,8 @@ void ItemView::contentsWheelEvent( QWheelEvent *e )
 void ItemView::dragEnterEvent( QDragEnterEvent *event )
 {
 	startUpdatingStatus();
-	
-	if ( KUrl::List::canDecode( event->mimeData() ) ) {
+
+	if (event->mimeData()->hasUrls()) {
 		event->setAccepted(true);
 		// Then it is URLs that we can decode later :)
 		return;
@@ -478,26 +490,39 @@ void ItemView::dragEnterEvent( QDragEnterEvent *event )
 void ItemView::createDragItem( QDragEnterEvent * e )
 {
 	removeDragItem();
-	
-	if ( !QString(e->format()).startsWith("ktechlab/") )
+
+    const QMimeData* mimeData = e->mimeData();
+    QString matchingFormat;
+    for (QString format: mimeData->formats()) {
+        if (format.startsWith("ktechlab/")) {
+            matchingFormat = format;
+            break;
+        }
+    }
+	if (matchingFormat.isEmpty()) {
+        qWarning() << Q_FUNC_INFO << "Invalid mime data" << mimeData->formats();
 		return;
-	
+    }
+
 	e->accept();
-	
+
 	QString text;
 	//QDataStream stream( e->encodedData(e->format()), QIODevice::ReadOnly );
-    QByteArray byteArray( e->encodedData(e->format()) );
+    //QByteArray byteArray( e->encodedData(e->format()) );
+    QByteArray byteArray( mimeData->data(matchingFormat) );
     QDataStream stream( &byteArray, QIODevice::ReadOnly );
 	stream >> text;
 
 	QPoint p = mousePosToCanvasPos( e->pos() );
-	
+
 	m_pDragItem = itemLibrary()->createItem( text, p_itemDocument, true );
-	
-	if ( CNItem * cnItem = dynamic_cast<CNItem*>(m_pDragItem) )
+
+	if ( CNItem * cnItem = dynamic_cast<CNItem*>(m_pDragItem) ) {
 		cnItem->move( snapToCanvas(p.x()), snapToCanvas(p.y()) );
-	else m_pDragItem->move( p.x(), p.y() );
-	
+    } else {
+        m_pDragItem->move( p.x(), p.y() );
+    }
+
 	m_pDragItem->show();
 }
 
@@ -505,10 +530,10 @@ void ItemView::createDragItem( QDragEnterEvent * e )
 void ItemView::removeDragItem()
 {
 	if ( !m_pDragItem ) return;
-	
+
 	m_pDragItem->removeItem();
 	p_itemDocument->flushDeleteList();
-	m_pDragItem = 0l;
+	m_pDragItem = nullptr;
 }
 
 
@@ -517,10 +542,12 @@ void ItemView::dragMoveEvent( QDragMoveEvent * e )
 	if ( !m_pDragItem ) return;
 
 	QPoint p = mousePosToCanvasPos( e->pos() );
-	
-	if ( CNItem * cnItem = dynamic_cast<CNItem*>(m_pDragItem) )
+
+	if ( CNItem * cnItem = dynamic_cast<CNItem*>(m_pDragItem) ) {
 		cnItem->move( snapToCanvas(p.x()), snapToCanvas(p.y()) );
-	else	m_pDragItem->move( p.x(), p.y() );
+    } else	{
+        m_pDragItem->move( p.x(), p.y() );
+    }
 }
 
 
@@ -541,13 +568,13 @@ void ItemView::leaveEvent( QEvent * e )
 {
 	Q_UNUSED(e);
 	stopUpdatingStatus();
-	
+
 	// Cleanup
 	setCursor(Qt::ArrowCursor);
-	
+
 	if ( KTechlab::self() )
 		KTechlab::self()->slotChangeStatusbar(QString::null);
-	
+
 	if ( p_itemDocument )
 		p_itemDocument->m_canvasTip->setVisible(false);
 }
@@ -563,7 +590,7 @@ void ItemView::slotUpdateConfiguration()
     QPalette pe;
     pe.setColor(m_CVBEditor->backgroundRole(), Qt::white );
     m_CVBEditor->setPalette(pe);
-	
+
 	if ( m_pUpdateStatusTmr->isActive() )
 		startUpdatingStatus();
 }
@@ -585,17 +612,17 @@ void ItemView::stopUpdatingStatus()
 void ItemView::updateStatus()
 {
 	QPoint pos = mousePosToCanvasPos( m_CVBEditor->mapFromGlobal( QCursor::pos() ) );
-	
+
 	ItemDocument * itemDocument = static_cast<ItemDocument*>(document());
 	if ( !itemDocument ) return;
-	
+
 	CMManager * cmManager = itemDocument->m_cmManager;
 	CanvasTip * canvasTip = itemDocument->m_canvasTip;
-	
+
 	bool displayTip = false;
 	QCursor cursor = Qt::ArrowCursor;
 	QString statusbar;
-	
+
 	if ( cmManager->cmState() & CMManager::cms_repeated_add ) {
 		cursor = Qt::CrossCursor;
 		statusbar = i18n("Left click to add. Right click to resume normal editing");
@@ -625,20 +652,17 @@ void ItemView::updateStatus()
 			default:
 				break;
 		}
-				
+
 	} else if ( KtlQCanvasItem *qcanvasItem = itemDocument->itemAtTop(pos) ) {
-		if ( Connector * con = dynamic_cast<Connector*>(qcanvasItem) )
-		{
+		if ( Connector * con = dynamic_cast<Connector*>(qcanvasItem) ) {
 			cursor = Qt::CrossCursor;
-			if ( itemDocument->type() == Document::dt_circuit )
-			{
+			if ( itemDocument->type() == Document::dt_circuit ) {
 				canvasTip->displayVI( con, pos );
 				displayTip = true;
 			}
 		} else if ( Node * node = dynamic_cast<Node*>(qcanvasItem) ) {
 			cursor = Qt::CrossCursor;
-			if ( ECNode * ecnode = dynamic_cast<ECNode*>(node) )
-			{
+			if ( ECNode * ecnode = dynamic_cast<ECNode*>(node) ) {
 				canvasTip->displayVI( ecnode, pos );
 				displayTip = true;
 			}
@@ -647,10 +671,10 @@ void ItemView::updateStatus()
 		}
 	}
 	setCursor(cursor);
-	
+
 	if ( KTechlab::self() )
 		KTechlab::self()->slotChangeStatusbar(statusbar);
-	
+
 	canvasTip->setVisible(displayTip);
 }
 
@@ -667,7 +691,7 @@ CVBEditor::CVBEditor( Canvas *canvas, ItemView *itemView, const char *name )
 	b_ignoreEvents = false;
 	b_passEventsToView = true;
 	p_itemView = itemView;
-	
+
 	setMouseTracking(true);
 	viewport()->setMouseTracking(true);
 	setAcceptDrops(true);
@@ -687,7 +711,7 @@ CVBEditor::CVBEditor( Canvas *canvas, ItemView *itemView, const char *name )
         pv.setColor(viewport()->backgroundRole(), Qt::white );
         viewport()->setPalette(pv);
     }
-	
+
 	connect( canvas, SIGNAL(resized( const QRect&, const QRect& )), this, SLOT(canvasResized( const QRect&, const QRect& )) );
 }
 
@@ -695,11 +719,11 @@ CVBEditor::CVBEditor( Canvas *canvas, ItemView *itemView, const char *name )
 void CVBEditor::canvasResized( const QRect & oldSize, const QRect & newSize )
 {
 	updateWorldMatrix();
-	
+
 	return;
-	
-	kDebug() << k_funcinfo << endl;
-	
+
+	qDebug() << Q_FUNC_INFO << endl;
+
 	QPoint delta = oldSize.topLeft() - newSize.topLeft();
 	delta *= p_itemView->zoomLevel();
 	scrollBy( delta.x(), delta.y() );
@@ -725,12 +749,12 @@ void CVBEditor::contentsWheelEvent( QWheelEvent * e )
 			e->globalPos(), e->delta(),
             //e->state()
             e->buttons(), e->modifiers());
-	
+
 	if ( e->orientation() == Qt::Horizontal && horizontalScrollBar() )
 		QApplication::sendEvent( horizontalScrollBar(), e);
 	else  if (e->orientation() == Qt::Vertical && verticalScrollBar() )
 		QApplication::sendEvent( verticalScrollBar(), e);
-	
+
 #if 0
 	if ( b_ignoreEvents )
 		return;
@@ -748,59 +772,59 @@ bool CVBEditor::event( QEvent * e )
 		bool isWheel = e->type() == QEvent::Wheel;
 		if ( isWheel && b_ignoreEvents )
 			return false;
-		
+
 		b_ignoreEvents = isWheel;
 		bool accepted = KtlQCanvasView::event( e );
 		b_ignoreEvents = false;
 		return accepted;
 	}
-	
+
 	switch ( e->type() )
 	{
 		case QEvent::MouseButtonPress:
 			p_itemView->contentsMousePressEvent( (QMouseEvent*)e );
 			return ((QMouseEvent*)e)->isAccepted();
-			
+
 		case QEvent::MouseButtonRelease:
 			p_itemView->contentsMouseReleaseEvent( (QMouseEvent*)e );
 			return ((QMouseEvent*)e)->isAccepted();
-			
+
 		case QEvent::MouseButtonDblClick:
 			p_itemView->contentsMouseDoubleClickEvent( (QMouseEvent*)e );
 			return ((QMouseEvent*)e)->isAccepted();
-			
+
 		case QEvent::MouseMove:
 			p_itemView->contentsMouseMoveEvent( (QMouseEvent*)e );
 			return ((QMouseEvent*)e)->isAccepted();
-			
+
 		case QEvent::DragEnter:
 			p_itemView->dragEnterEvent((QDragEnterEvent*)e );
 			return true;
-			
+
 		case QEvent::DragMove:
 			p_itemView->dragMoveEvent((QDragMoveEvent*)e );
 			return true;
-			
+
 		case QEvent::DragLeave:
 			p_itemView->dragLeaveEvent((QDragLeaveEvent*)e );
 			return true;
-			
+
 		case QEvent::Drop:
 			p_itemView->dropEvent( (QDropEvent*)e );
 			return true;
-			
+
 		case QEvent::Enter:
 			p_itemView->enterEvent( e );
 			return true;
-			
+
 		case QEvent::Leave:
 			p_itemView->leaveEvent(e);
 			return true;
-			
+
 		case QEvent::Wheel:
 			p_itemView->contentsWheelEvent( (QWheelEvent*)e );
 			return ((QWheelEvent*)e)->isAccepted();
-			
+
 		default:
 			return KtlQCanvasView::event( e );
 	}
@@ -815,5 +839,3 @@ void CVBEditor::viewportResizeEvent( QResizeEvent * e )
     p_itemView->requestDocumentResizeToCanvasItems();
 }
 //END class CVBEditor
-
-#include "itemview.moc"
