@@ -22,20 +22,23 @@
 
 #include "katemdi.h"
 
-#include <kdebug.h>
-#include <kglobalsettings.h>
-#include <kapplication.h>
-#include <klocalizedstring.h>
-#include <kconfig.h>
-#include <kiconloader.h>
+
+#include <KLocalizedString>
+#include <KSharedConfig>
 //#include <kpopupmenu.h>
-#include <kactioncollection.h>
-#include <kxmlguifactory.h>
-#include <kconfiggroup.h>
-#include <kmenu.h>
+#include <KActionCollection>
+#include <KXMLGUIFactory>
+#include <KConfigGroup>
+#include <KWindowConfig>
 
 // #include <q3intdict.h>
-#include <qevent.h>
+#include <QContextMenuEvent>
+#include <QVBoxLayout>
+#include <QHBoxLayout>
+#include <QDebug>
+#include <QEvent>
+#include <QMenu>
+#include <QIcon>
 
 
 typedef QList<int> IntList;
@@ -87,50 +90,6 @@ int Splitter::idAfter ( QWidget * w ) const
 //END SPLITTER
 
 
-//BEGIN TOGGLETOOLVIEWACTION
-
-ToggleToolViewAction::ToggleToolViewAction ( const QString& text, const KShortcut& cut, ToolView *tv,
-                                             QObject* parent, const char* name )
- : KToggleAction(text /* ,cut */, parent /*,name*/)
- , m_tv(tv)
-{
-    setObjectName(name);
-    KToggleAction::setShortcut(cut.primary());
-
-  connect(this,SIGNAL(toggled(bool)),this,SLOT(slotToggled(bool)));
-  connect(m_tv,SIGNAL(visibleChanged(bool)),this,SLOT(visibleChanged(bool)));
-
-  setChecked(m_tv->visible());
-}
-
-ToggleToolViewAction::~ToggleToolViewAction()
-{
-  //unplugAll(); // TODO is this needed?
-}
-
-void ToggleToolViewAction::visibleChanged(bool)
-{
-  if (isChecked() != m_tv->visible())
-    setChecked (m_tv->visible());
-}
-
-void ToggleToolViewAction::slotToggled(bool t)
-{
-  if (t)
-  {
-    m_tv->mainWindow()->showToolView (m_tv);
-    m_tv->setFocus ();
-  }
-  else
-  {
-    m_tv->mainWindow()->hideToolView (m_tv);
-    m_tv->mainWindow()->centralWidget()->setFocus ();
-  }
-}
-
-//END TOGGLETOOLVIEWACTION
-
-
 //BEGIN GUICLIENT
 
 GUIClient::GUIClient ( MainWindow *mw )
@@ -149,7 +108,7 @@ GUIClient::GUIClient ( MainWindow *mw )
 
   // read shortcuts
   //actionCollection()->readShortcutSettings( "Shortcuts", kapp->config() );
-  KConfigGroup grShortcuts = KGlobal::config()->group("Shortcuts");
+  KConfigGroup grShortcuts = KSharedConfig::openConfig()->group("Shortcuts");
   actionCollection()->readSettings(&grShortcuts);
 }
 
@@ -162,7 +121,7 @@ void GUIClient::registerToolView (ToolView *tv)
   QString aname = QString("kate_mdi_toolview_") + tv->id;
 
   // try to read the action shortcut
-  KShortcut sc;
+//   KShortcut sc;
 
 //   KConfig *cfg = kapp->config();
 //   QString _grp = cfg->group();
@@ -170,8 +129,8 @@ void GUIClient::registerToolView (ToolView *tv)
 //   sc = KShortcut( cfg->readEntry( aname, "" ) );
 //   cfg->setGroup( _grp );
 
-  KConfigGroup grSh = KGlobal::config()->group("Shortcuts");
-  sc = KShortcut( grSh.readEntry(aname, "") );
+  KConfigGroup grSh = KSharedConfig::openConfig()->group("Shortcuts");
+//   sc = KShortcut( grSh.readEntry(aname, "") );
 }
 
 void GUIClient::clientAdded( KXMLGUIClient *client )
@@ -243,8 +202,8 @@ Sidebar::Sidebar (KMultiTabBar::KMultiTabBarPosition pos, MainWindow *mainwin, Q
       //(pos == KMultiTabBar::Top || pos == KMultiTabBar::Bottom) ? KMultiTabBar::Horizontal : KMultiTabBar::Vertical, parent)
       pos, parent)
   , m_mainWin (mainwin)
-  , m_splitter (0)
-  , m_ownSplit (0)
+  , m_splitter (nullptr)
+  , m_ownSplit (nullptr)
   , m_lastSize (0)
 {
   setObjectName(  (QString("Sidebar-%1").arg(pos)).toLatin1().data() );
@@ -274,7 +233,6 @@ void Sidebar::setSplitter (Splitter *sp)
   m_splitter = sp;
   Qt::Orientation splitOrient = (sidebarPosition() == KMultiTabBar::Top || sidebarPosition() == KMultiTabBar::Bottom) ? Qt::Horizontal : Qt::Vertical;
   m_ownSplit = new Splitter (splitOrient, m_splitter, "own-Split");
-  m_ownSplit->setOpaqueResize( KGlobalSettings::opaqueResize() );
   m_ownSplit->setChildrenCollapsible( false );
   //m_splitter->setResizeMode( m_ownSplit, QSplitter::KeepSize ); // 2018.11.22
   m_splitter->setStretchFactor( m_splitter->indexOf(m_ownSplit), 0);
@@ -308,7 +266,7 @@ ToolView *Sidebar::addWidget (const QPixmap &icon, const QString &text, ToolView
   {
     widget->hide ();
     //widget->reparent (m_ownSplit, 0, QPoint()); // 2018.11.22
-    widget->setParent(m_ownSplit, 0);
+    widget->setParent(m_ownSplit, nullptr);
     QPoint p;
     widget->setGeometry(p.x(),p.y(),width(),height());
     widget->m_sidebar = this;
@@ -331,22 +289,22 @@ ToolView *Sidebar::addWidget (const QPixmap &icon, const QString &text, ToolView
 
 void Sidebar::updateMinimumSize()
 {
-// 	kDebug() << "layout()->margin()="<<layout()->margin()<<endl;
-	
+// 	qDebug() << "layout()->margin()="<<layout()->margin()<<endl;
+
 	QSize minSize;
-	
+
 	QList<ToolView*>::iterator end = m_toolviews.end();
 	for ( QList<ToolView*>::iterator it = m_toolviews.begin(); it != end; ++it )
 	{
 		QSize s = (*it)->childrenRect().size();
 		minSize = minSize.expandedTo( s );
-// 		kDebug() << "s="<<s<<"(*it)->minimumSize()="<<(*it)->minimumSize()<<endl;
-// 		kDebug() << "(*it)->layout()->margin()="<<(*it)->margin()<<endl;
+// 		qDebug() << "s="<<s<<"(*it)->minimumSize()="<<(*it)->minimumSize()<<endl;
+// 		qDebug() << "(*it)->layout()->margin()="<<(*it)->margin()<<endl;
 	}
-	
+
 	minSize.setWidth( minSize.width() - 30 );
 	minSize.setHeight( minSize.height() - 30 );
-	
+
 	for ( QList<ToolView*>::iterator it = m_toolviews.begin(); it != end; ++it )
 	{
 		(*it)->setMinimumSize( minSize );
@@ -471,7 +429,7 @@ bool Sidebar::eventFilter(QObject *obj, QEvent *ev)
     KMultiTabBarTab *bt = dynamic_cast<KMultiTabBarTab*>(obj);
     if (bt)
     {
-      kDebug()<<"Request for popup"<<endl;
+      qDebug()<<"Request for popup"<<endl;
 
       m_popupButton = bt->id();
 
@@ -479,33 +437,33 @@ bool Sidebar::eventFilter(QObject *obj, QEvent *ev)
 
       if (w)
       {
-        KMenu *p = new KMenu (this);
+        QMenu *p = new QMenu (this);
 
-        p->addTitle(SmallIcon("view_remove"), i18n("Behavior"), 0 /*0 */);
+        p->addSection(QIcon::fromTheme("view_remove"), i18n("Behavior"));
 
         //p->insertItem(w->persistent ? SmallIcon("view-restore") : SmallIcon("view-fullscreen"), w->persistent ? i18n("Make Non-Persistent") : i18n("Make Persistent"), 10); // 2018.11.22
         p->addAction(
-            w->persistent ? SmallIcon("view-restore") : SmallIcon("view-fullscreen"),
+            w->persistent ? QIcon::fromTheme("view-restore") : QIcon::fromTheme("view-fullscreen"),
             w->persistent ? i18n("Make Non-Persistent") : i18n("Make Persistent")
         )->setData(10);
 
-        p->addTitle(SmallIcon("transform-move"), i18n("Move To"), 0 /* 51 ? */);
+        p->addSection(QIcon::fromTheme("transform-move"), i18n("Move To"));
 
 		if (sidebarPosition() != 0)
           //p->insertItem(SmallIcon("go-previous"), i18n("Left Sidebar"),0);  // 2018.11.22
-          p->addAction(SmallIcon("go-previous"), i18n("Left Sidebar"))->setData(0);
+          p->addAction(QIcon::fromTheme("go-previous"), i18n("Left Sidebar"))->setData(0);
 
 		if (sidebarPosition() != 1)
           //p->insertItem(SmallIcon("go-next"), i18n("Right Sidebar"),1); // 2018.11.22
-          p->addAction(SmallIcon("go-next"), i18n("Right Sidebar"))->setData(1);
+          p->addAction(QIcon::fromTheme("go-next"), i18n("Right Sidebar"))->setData(1);
 
 		if (sidebarPosition() != 2)
           //p->insertItem(SmallIcon("go-up"), i18n("Top Sidebar"),2); // 2018.11.22
-          p->addAction(SmallIcon("go-up"), i18n("Top Sidebar"))->setData(2);
+          p->addAction(QIcon::fromTheme("go-up"), i18n("Top Sidebar"))->setData(2);
 
 		if (sidebarPosition() != 3) {
           //p->insertItem(SmallIcon("go-down"), i18n("Bottom Sidebar"),3); // 2018.11.22
-          p->addAction(SmallIcon("go-down"), i18n("Bottom Sidebar"))->setData(3);
+          p->addAction(QIcon::fromTheme("go-down"), i18n("Bottom Sidebar"))->setData(3);
         }
         connect(p, SIGNAL(triggered(QAction*)),
               this, SLOT(buttonPopupActivate(QAction*)));
@@ -681,8 +639,8 @@ void Sidebar::saveSession (KConfigGroup *config)
 //BEGIN MAIN WINDOW
 
 MainWindow::MainWindow (QWidget* parentWidget, const char* name)
- : KParts::MainWindow( parentWidget, (Qt::WindowFlags)KDE_DEFAULT_WINDOWFLAGS )
- , m_restoreConfig (0)
+ : KParts::MainWindow(parentWidget)
+ , m_restoreConfig (nullptr)
  , m_guiClient (new GUIClient (this))
 {
     setObjectName(name);
@@ -699,7 +657,6 @@ MainWindow::MainWindow (QWidget* parentWidget, const char* name)
   hbl->addWidget( m_sidebars[KMultiTabBar::Left] );
 
   m_hSplitter = new Splitter (Qt::Horizontal, hb);
-  m_hSplitter->setOpaqueResize( KGlobalSettings::opaqueResize() );
   m_hSplitter->setObjectName("Main-Left-Splitter");
   hbl->addWidget( m_hSplitter );
 
@@ -718,7 +675,6 @@ MainWindow::MainWindow (QWidget* parentWidget, const char* name)
 
   m_vSplitter = new Splitter (Qt::Vertical, vb);
   m_vSplitter->setObjectName("Main-Top-Splitter");
-  m_vSplitter->setOpaqueResize( KGlobalSettings::opaqueResize() );
   vbl->addWidget( m_vSplitter );
 
   m_sidebars[KMultiTabBar::Top]->setSplitter (m_vSplitter);
@@ -763,7 +719,7 @@ QWidget *MainWindow::centralWidget () const
 ToolView *MainWindow::createToolView (const QString &identifier, KMultiTabBar::KMultiTabBarPosition pos, const QPixmap &icon, const QString &text)
 {
   if (m_idToWidget[identifier])
-    return 0;
+    return nullptr;
 
   // try the restore config to figure out real pos
   if (m_restoreConfig && m_restoreConfig->hasGroup (m_restoreGroup))
@@ -772,7 +728,7 @@ ToolView *MainWindow::createToolView (const QString &identifier, KMultiTabBar::K
     pos = (KMultiTabBar::KMultiTabBarPosition) grRest.readEntry (QString ("Kate-MDI-ToolView-%1-Position").arg(identifier), (int) pos);
   }
 
-  ToolView *v  = m_sidebars[pos]->addWidget (icon, text, 0);
+  ToolView *v  = m_sidebars[pos]->addWidget (icon, text, nullptr);
   v->id = identifier;
 
   m_idToWidget.insert (identifier, v);
@@ -882,13 +838,13 @@ void MainWindow::startRestore (KConfig *config, const QString &group)
 	  m_hSplitter->setSizes(hs);
 	  m_vSplitter->setSizes(vs);
 	  //END Added stuff specifically for ktechlab
-	  
+
     return;
   }
 
   // apply size once, to get sizes ready ;)
   KConfigGroup grRestWnd = m_restoreConfig->group (m_restoreGroup);
-  restoreWindowSize (grRestWnd);
+  KWindowConfig::restoreWindowSize(windowHandle(), grRestWnd);
 
   //m_restoreConfig->group (m_restoreGroup);
 
@@ -936,7 +892,7 @@ void MainWindow::finishRestore ()
   }
 
   // clear this stuff, we are done ;)
-  m_restoreConfig = 0;
+  m_restoreConfig = nullptr;
   m_restoreGroup = "";
 }
 
@@ -981,6 +937,3 @@ void KateMDI::MainWindow::updateSidebarMinimumSizes( )
 //END MAIN WINDOW
 
 }
-
-#include "katemdi.moc"
-
