@@ -21,19 +21,22 @@
 #ifndef __KATE_MDI_H__
 #define __KATE_MDI_H__
 
-#include <kparts/mainwindow.h>
+#include <KParts/MainWindow>
 
-#include <kmultitabbar.h>
-#include <ktoggleaction.h>
+#include <KMultiTabBar>
 
 // #include <q3dict.h>
 // #include <q3intdict.h>
 // #include <q3vbox.h>
-#include <qsplitter.h>
+#include <QSplitter>
+#include <QMap>
+
+class QAction;
 
 namespace KateMDI {
 
 class MainWindow;
+class ToolView;
 
 /** This class is needed because QSplitter cant return an index for a widget. */
 class Splitter : public QSplitter
@@ -41,8 +44,8 @@ class Splitter : public QSplitter
   Q_OBJECT
 
   public:
-    Splitter(Qt::Orientation o, QWidget* parent=0, const char* name=0);
-    ~Splitter();
+    Splitter(Qt::Orientation o, QWidget* parent = nullptr, const char* name = nullptr);
+    ~Splitter() override;
 
     /** Since there is supposed to be only 2 childs of a katesplitter,
      * any child other than the last is the first.
@@ -55,31 +58,13 @@ class Splitter : public QSplitter
     //int idAfter ( QWidget * w ) const;
 };
 
-class ToggleToolViewAction : public KToggleAction
-{
-  Q_OBJECT
-
-  public:
-    ToggleToolViewAction ( const QString& text, const KShortcut& cut,
-                           class ToolView *tv, QObject* parent = 0, const char* name = 0 );
-
-    virtual ~ToggleToolViewAction();
-
-  protected slots:
-    void slotToggled(bool);
-    void visibleChanged(bool);
-
-  private:
-    ToolView *m_tv;
-};
-
 class GUIClient : public QObject, public KXMLGUIClient
 {
   Q_OBJECT
 
   public:
     GUIClient ( MainWindow *mw );
-    virtual ~GUIClient();
+    ~GUIClient() override;
 
     void registerToolView (ToolView *tv);
 
@@ -117,7 +102,7 @@ class ToolView : public QWidget
      * destuct me, this is allowed for all, will care itself that the toolview is removed
      * from the mainwindow and sidebar
      */
-    virtual ~ToolView ();
+    ~ToolView () override;
 
   signals:
     /**
@@ -140,7 +125,7 @@ class ToolView : public QWidget
     bool visible () const;
 
   protected:
-    void childEvent ( QChildEvent *ev );
+    void childEvent ( QChildEvent *ev ) override;
 
   private:
     MainWindow *m_mainWin;
@@ -171,10 +156,10 @@ class Sidebar : public KMultiTabBar
 
   public:
     Sidebar (KMultiTabBar::KMultiTabBarPosition pos, MainWindow *mainwin, QWidget *parent);
-    virtual ~Sidebar ();
+    ~Sidebar () override;
 
     void setSplitter (Splitter *sp);
-	
+
 	//HACK use these functions intead of their respective functions in
 	//KMultiTabBar so that we know what they were set to.
 	void setSidebarPosition( KMultiTabBarPosition pos );
@@ -214,13 +199,13 @@ class Sidebar : public KMultiTabBar
     void tabClicked(int);
 
   protected:
-    bool eventFilter(QObject *obj, QEvent *ev);
+    bool eventFilter(QObject *obj, QEvent *ev) override;
 
   private slots:
     void buttonPopupActivate (QAction* action);
 
   private:
-	  
+
     MainWindow *m_mainWin;
 
 	KMultiTabBar::KMultiTabBarStyle m_sidebarTabStyle;
@@ -256,12 +241,12 @@ class MainWindow : public KParts::MainWindow
     /**
      * Constructor
      */
-    MainWindow (QWidget* parentWidget = 0, const char* name = 0);
+    MainWindow (QWidget* parentWidget = nullptr, const char* name = nullptr);
 
     /**
      * Destructor
      */
-    virtual ~MainWindow ();
+    ~MainWindow () override;
 
   //
   // public interfaces
@@ -304,7 +289,7 @@ class MainWindow : public KParts::MainWindow
      * @return toolview's tabbar style
      */
     KMultiTabBar::KMultiTabBarStyle toolViewStyle () const;
-    
+
   protected:
     /**
      * called by toolview destructor
@@ -359,7 +344,7 @@ class MainWindow : public KParts::MainWindow
      * @param config config object to use
      */
     void saveSession (KConfigGroup *config);
-	
+
 	void updateSidebarMinimumSizes();
 
   /**
