@@ -11,12 +11,12 @@
 #ifndef KTECHLAB_H
 #define KTECHLAB_H
 
-#include "katemdi.h"
+#include <katemdi.h>
 
-#include <kurl.h>
-
-#include <qmap.h>
-#include <qlist.h>
+#include <QUrl>
+#include <QMap>
+#include <QList>
+#include <QPointer>
 
 class CircuitDocument;
 class TextDocument;
@@ -35,13 +35,9 @@ class ViewContainer;
 typedef QMap< int, QString > IntStringMap;
 typedef QList< QPointer<ViewContainer> > ViewContainerList;
 
-class KAction;
-class KActionCollection;
 class RecentFilesAction;
-class KTabWidget;
-class KToolBar;
+class QTabWidget;
 class KToggleAction;
-class KUrl;
 class QLabel;
 
 /**
@@ -59,7 +55,7 @@ class KTechlab : public KateMDI::MainWindow
 
 	public:
 		KTechlab();
-		~KTechlab();
+		~KTechlab() override;
 		
 		/**
 		 * @return pointer to the main KTechlab object. This is set to null when
@@ -80,7 +76,7 @@ class KTechlab : public KateMDI::MainWindow
 		 * @param allowMultiple Whether to allow the user to select more than
 		 * one URL.
 		 */
-		static KUrl::List getFileURLs( bool allowMultiple = true );
+		static QList<QUrl> getFileURLs( bool allowMultiple = true );
 		/**
 		 * Returns a list of the recently opened/saved files
 		 */
@@ -93,7 +89,7 @@ class KTechlab : public KateMDI::MainWindow
 		/**
 		 * Returns the tabwidget that shows the list of view containers.
 		 */
-		KTabWidget * tabWidget() const { return m_pViewContainerTabWidget; }
+		QTabWidget * tabWidget() const { return m_pViewContainerTabWidget; }
 		/**
 		 * Registers the viewcontainer with the internal list.
 		 */
@@ -116,9 +112,9 @@ class KTechlab : public KateMDI::MainWindow
 		 * Opens a file in the given ViewArea.
 		 */
 		void openFile( ViewArea * viewArea );
-		
+
 		virtual void show();
-		
+
 	signals:
 		/**
 		 * Emitted when the user changes the configuration settings in the config dialog
@@ -127,17 +123,17 @@ class KTechlab : public KateMDI::MainWindow
 		/**
 		 * Emitted when a recent file is added
 		 */
-		void recentFileAdded( const KUrl &url );
+		void recentFileAdded( const QUrl &url );
 		/**
 		 * Emitted when ViewContainers should update their captions.
 		 */
 		void needUpdateCaptions();
-	
+
 	public slots:
 		/**
 		 * The user right clicked on a tab item.
 		 */
-		void slotTabContext( QWidget* widget,const QPoint & pos );
+		void slotTabContext(const QPoint & pos);
 		/**
 		 * The user clicked on an item in the tab-menu (from right clicking).
 		 */
@@ -147,23 +143,23 @@ class KTechlab : public KateMDI::MainWindow
 		 * Open the document at the given url. If viewArea is non-null, then the
 		 * new view will be put into viewArea.
 		 */
-		void load( const KUrl & url, ViewArea * viewArea = 0l );
+		void load( const QUrl & url, ViewArea * viewArea = nullptr );
 		void slotUpdateConfiguration();
 		/**
 		 * Adds a url to the list of recently opened files
 		 */
-		void addRecentFile( const KUrl &url );
+		void addRecentFile( const QUrl &url );
 		/**
-		 * A document had its modified state changed; will update actions, 
+		 * A document had its modified state changed; will update actions,
 		 * tab titles, etc as appropriate.
 		 */
 		void slotDocModifiedChanged();
 		/**
-		 * A document had its undo/redo state changed; will update actions, 
+		 * A document had its undo/redo state changed; will update actions,
 		 * tab titles, etc as appropriate.
 		 */
 		void slotDocUndoRedoChanged();
-	
+
 		void slotFileNewAssembly();
 		void slotFileNewMicrobe();
 		void slotFileNewC();
@@ -181,8 +177,8 @@ class KTechlab : public KateMDI::MainWindow
 		/**
 		 * Overridden virtuals for Qt drag 'n drop (XDND)
 		 */
-		virtual void dragEnterEvent(QDragEnterEvent *event);
-		virtual void dropEvent(QDropEvent *event);
+		void dragEnterEvent(QDragEnterEvent *event) override;
+		void dropEvent(QDropEvent *event) override;
 		/**
 		 * This function is called when it is time for the app to save its
 		 * properties for session management purposes.
@@ -199,10 +195,10 @@ class KTechlab : public KateMDI::MainWindow
 		 * This function doesn't actually close the main window; it only queries the user and closes the active view.
 		 * To quit the appliaction completly, you should use KTechlab::slotFileQuit()
 		 */
-		virtual bool queryClose();
+		bool queryClose() override;
 	
 	protected slots:
-		void slotViewContainerActivated( QWidget * viewContainer );
+		void slotViewContainerActivated( int index );
 		void slotUpdateTabWidget();
 		/**
 		 * Updates the tab and window captions from what is currently open and
@@ -222,14 +218,14 @@ class KTechlab : public KateMDI::MainWindow
 		 */
 		void openExample(QAction*);
 		void slotViewContainerDestroyed( QObject * obj );
-	
+
 		// Editing operations
 		void slotEditUndo();
 		void slotEditRedo();
 		void slotEditCut();
 		void slotEditCopy();
 		void slotEditPaste();
-	
+
 		/**
 		 * Split the current view into two
 		 */
@@ -240,7 +236,7 @@ class KTechlab : public KateMDI::MainWindow
 		void slotViewSplitTopBottom();
 		void slotViewContainerClose();
 		void slotViewClose();
-	
+
 		void slotOptionsShowStatusbar();
 		void slotOptionsConfigureKeys();
 		void slotOptionsConfigureToolbars();
@@ -252,11 +248,11 @@ class KTechlab : public KateMDI::MainWindow
 		void setupToolDocks();
 		void setupView();
 		void setupTabWidget();
-	
+
 		RecentFilesAction * m_recentFiles;
 		RecentFilesAction * m_recentProjects;
 		KToggleAction * m_statusbarAction;
-		KTabWidget * m_pViewContainerTabWidget;
+		QTabWidget * m_pViewContainerTabWidget;
 		QString m_lastStatusBarMessage;
 		QList<KXMLGUIClient*> m_noRemoveGUIClients;
 		QLabel * m_pToolBarOverlayLabel;
@@ -265,9 +261,9 @@ class KTechlab : public KateMDI::MainWindow
 		QTimer * m_pUpdateCaptionsTimer;
 		IntStringMap m_exampleFiles;
 		QFont m_itemFont;
-		
+
 		static KTechlab * m_pSelf;
-	
+
 		QPointer<ViewContainer> m_pContextMenuContainer;
 		QPointer<ViewContainer> m_pFocusedContainer;
 		QPointer<ViewContainer> m_pContainerDropSource;
