@@ -10,13 +10,13 @@
 
 #include "ktlfindqobjectchild.h"
 
-#include <qobject.h>
+#include <QObject>
 
 #include <string.h>
 
 QObject *ktlFindQObjectChild(QObject *parent, const char *className) {
-    QObjectList children = parent->children();
-    Q_FOREACH(QObject *child, children) {
+    const QObjectList children = parent->children();
+    for (QObject *child : children) {
         if (0 == strcmp( child->metaObject()->className(), className )) {
             return child;
         }
@@ -25,5 +25,5 @@ QObject *ktlFindQObjectChild(QObject *parent, const char *className) {
             return ret;
         }
     }
-    return NULL;
+    return nullptr;
 }
