@@ -41,18 +41,20 @@
 
 #include "ktlq3scrollview.h"
 
-#include "qwidget.h"
-#include "qscrollbar.h"
-#include "qpainter.h"
-#include "qpixmap.h"
-#include "qcursor.h"
+#include <QWidget>
+#include <QScrollBar>
+#include <QPainter>
+#include <QPixmap>
+#include <QCursor>
 // #include "q3ptrdict.h"
-#include "qhash.h"
-#include "qapplication.h"
-#include "qtimer.h"
-#include "qstyle.h"
+#include <QHash>
+#include <QApplication>
+#include <QTimer>
+#include <QStyle>
 // #include "q3ptrlist.h"
-#include "qevent.h"
+#include <QDragEnterEvent>
+#include <QDragLeaveEvent>
+#include <QContextMenuEvent>
 //#include "q3listview.h"
 // #ifdef Q_WS_MAC      // 2018.10.18 - do not depend on internal headers
 // # include "private/qt_mac_p.h"
@@ -106,7 +108,7 @@ void QSVChildRec::hideOrShow(KtlQ3ScrollView* sv, QWidget* clipped_viewport)
 }
 
 // QT_BEGIN_INCLUDE_NAMESPACE
-// #include "ktlq3scrollview.moc"
+
 // QT_END_INCLUDE_NAMESPACE
 
 class KtlQ3ScrollViewData {
@@ -115,7 +117,7 @@ public:
         hbar(new QScrollBar(Qt::Horizontal, parent /*, "qt_hbar"*/)),
         vbar(new QScrollBar(Qt::Vertical, parent /*, "qt_vbar" */)),
         viewport(new KtlQAbstractScrollAreaWidget(parent, "qt_viewport", QFlag(vpwflags))),
-        clipped_viewport(0),
+        clipped_viewport(nullptr),
         flags(vpwflags),
         vx(0), vy(0), vwidth(1), vheight(1),
 #ifndef QT_NO_DRAGANDDROP
@@ -135,7 +137,7 @@ public:
         viewport->ensurePolished();
         vMode = KtlQ3ScrollView::Auto;
         hMode = KtlQ3ScrollView::Auto;
-        corner = 0;
+        corner = nullptr;
         // vbar->setSteps(20, 1/*set later*/);
         vbar->setSingleStep(20); vbar->setPageStep(1);
         //hbar->setSteps(20, 1/*set later*/);
@@ -229,7 +231,7 @@ inline KtlQ3ScrollViewData::~KtlQ3ScrollViewData()
         QSVChildRec *r = *it;
         delete r;
     }
-    children.removeAll(NULL);
+    children.removeAll(nullptr);
 }
 
 QSVChildRec* KtlQ3ScrollViewData::ancestorRec(QWidget* w)
@@ -237,12 +239,12 @@ QSVChildRec* KtlQ3ScrollViewData::ancestorRec(QWidget* w)
     if (clipped_viewport) {
         while (w->parentWidget() != clipped_viewport) {
             w = w->parentWidget();
-            if (!w) return 0;
+            if (!w) return nullptr;
         }
     } else {
         while (w->parentWidget() != viewport) {
             w = w->parentWidget();
-            if (!w) return 0;
+            if (!w) return nullptr;
         }
     }
     return rec(w);
@@ -617,13 +619,13 @@ KtlQ3ScrollView::~KtlQ3ScrollView()
     // order is important
     // ~QWidget may cause a WM_ERASEBKGND on Windows
     delete d->vbar;
-    d->vbar = 0;
+    d->vbar = nullptr;
     delete d->hbar;
-    d->hbar = 0;
+    d->hbar = nullptr;
     delete d->viewport;
-    d->viewport = 0;
+    d->viewport = nullptr;
     delete d;
-    d = 0;
+    d = nullptr;
 }
 
 /*!
@@ -691,7 +693,7 @@ bool KtlQ3ScrollView::isVerticalSliderPressed()
 */
 void KtlQ3ScrollView::styleChange(QStyle& old)
 {
-    QWidget::styleChange(old);
+    //QWidget::styleChange(old); // 2019.04.14
     updateScrollBars();
     d->cachedSizeHint = QSize();
 }
@@ -701,7 +703,7 @@ void KtlQ3ScrollView::styleChange(QStyle& old)
 */
 void KtlQ3ScrollView::fontChange(const QFont &old)
 {
-    QWidget::fontChange(old);
+    //QWidget::fontChange(old); // 2019.04.14
     updateScrollBars();
     d->cachedSizeHint = QSize();
 }
@@ -1121,7 +1123,7 @@ void KtlQ3ScrollView::resize(const QSize& s)
 */
 void KtlQ3ScrollView::resizeEvent(QResizeEvent* event)
 {
-    KtlQ3Frame::resizeEvent(event);
+    //KtlQ3Frame::resizeEvent();
 
 #if 0
     if (QApplication::reverseLayout()) {
@@ -1375,7 +1377,7 @@ void KtlQ3ScrollView::removeChild(QObject* child)
 {
     // KtlQ3Frame::removeChild(child); // 2018.11.30
     if (child) {
-        child->setParent(0);
+        child->setParent(nullptr);
     }
 }
 
@@ -2609,7 +2611,7 @@ void KtlQ3ScrollView::enableClipper(bool y)        // note: this method as of 20
         d->clipped_viewport->show();
     } else {
         delete d->clipped_viewport;
-        d->clipped_viewport = 0;
+        d->clipped_viewport = nullptr;
     }
 }
 
@@ -2855,5 +2857,3 @@ QSize KtlQ3ScrollView::cachedSizeHint() const
 }
 
 // QT_END_NAMESPACE
-
-// #include "ktlq3scrollview.moc"
