@@ -12,11 +12,11 @@
 #include "config.h"
 #include "gpsimprocessor.h"
 
-#include <kdebug.h>
 
-#include <qfile.h>
-#include <qregexp.h>
-#include <qstringlist.h>
+#include <QDebug>
+#include <QFile>
+#include <QRegExp>
+#include <QStringList>
 
 AsmParser::AsmParser( const QString &url )
 	: m_url(url)
@@ -87,7 +87,7 @@ bool AsmParser::parse( GpsimDebugger * debugger )
 			int fileLineAt = line.lastIndexOf(" ");
 			
 			if ( fileLineAt == -1 )
-				kWarning() << k_funcinfo << "Syntax error in line \"" << line << "\" while looking for file-line" << endl;
+				qWarning() << Q_FUNC_INFO << "Syntax error in line \"" << line << "\" while looking for file-line" << endl;
 			else {
 				// 7 = length_of(";#CSRC\t")
 				QString fileName = line.mid( 7, fileLineAt-7 );
@@ -103,7 +103,7 @@ bool AsmParser::parse( GpsimDebugger * debugger )
 				int fileLine = fileLineString.toInt(&ok) - 1;
 				if ( ok && fileLine >= 0 )
 					debugger->associateLine( fileName, fileLine, m_url, inputAtLine );
-				else	kDebug() << k_funcinfo << "Not a valid line number: \"" << fileLineString << "\"" << endl;
+				else	qDebug() << Q_FUNC_INFO << "Not a valid line number: \"" << fileLineString << "\"" << endl;
 			}
 		}
 
@@ -114,12 +114,12 @@ bool AsmParser::parse( GpsimDebugger * debugger )
 			//QStringList lineParts = QStringList::split( '\t', line ); // 2018.12.01
             QStringList lineParts = line.split( '\t' , QString::SkipEmptyParts );
 			if ( lineParts.size() < 2 )
-				kWarning() << k_funcinfo << "Line is in wrong format for extracing source line and file: \""<<line<<"\""<<endl;
+				qWarning() << Q_FUNC_INFO << "Line is in wrong format for extracing source line and file: \""<<line<<"\""<<endl;
 			else {
 				const QString lineAndFile = lineParts[1];
 				int lineFileSplit = lineAndFile.indexOf("; ");
 				if ( lineFileSplit == -1 )
-					kDebug() << k_funcinfo << "Could not find file / line split in \""<<lineAndFile<<"\""<<endl;
+					qDebug() << Q_FUNC_INFO << "Could not find file / line split in \""<<lineAndFile<<"\""<<endl;
 				else {
 					QString fileName = lineAndFile.mid( lineFileSplit + 2 );
 					QString fileLineString = lineAndFile.left( lineFileSplit );
@@ -134,7 +134,7 @@ bool AsmParser::parse( GpsimDebugger * debugger )
 					int fileLine = fileLineString.toInt(&ok) - 1;
 					if ( ok && fileLine >= 0 )
 						debugger->associateLine( fileName, fileLine, m_url, inputAtLine );
-					else kDebug() << k_funcinfo << "Not a valid line number: \"" << fileLineString << "\"" << endl;
+					else qDebug() << Q_FUNC_INFO << "Not a valid line number: \"" << fileLineString << "\"" << endl;
 				}
 			}
 		}
