@@ -12,17 +12,17 @@
 #include "languagemanager.h"
 #include "logview.h"
 
-#include <kdebug.h>
-#include <kprocess.h>
-#include <kshell.h>
+#include <KProcess>
+#include <KShell>
 
-#include <qregexp.h>
-#include <qtimer.h>
+#include <QDebug>
+#include <QRegExp>
+#include <QTimer>
 
 ExternalLanguage::ExternalLanguage( ProcessChain *processChain, const QString &name )
  : Language( processChain, name )
 {
-	m_languageProcess = 0l;
+	m_languageProcess = nullptr;
 }
 
 
@@ -44,7 +44,7 @@ void ExternalLanguage::deleteLanguageProcess()
 	m_languageProcess->kill();
 	m_languageProcess->deleteLater();
 	
-	m_languageProcess = 0L;
+	m_languageProcess = nullptr;
 }
 
 
@@ -100,7 +100,7 @@ void ExternalLanguage::processStderr()
 void ExternalLanguage::processExited( int, QProcess::ExitStatus )
 {
 	if ( !m_languageProcess ) {
-        qDebug() << Q_FUNC_INFO << " m_languageProcess == NULL, returning";
+        qDebug() << Q_FUNC_INFO << " m_languageProcess == nullptr, returning";
 		return;
     }
 	bool allOk = processExited( (m_languageProcess->exitStatus() == QProcess::NormalExit) && (m_errorCount == 0) );
@@ -177,6 +177,3 @@ void ExternalLanguage::displayProcessCommand()
 	outputMessage( quotedArguments.join(" ") );
 // 	LanguageManager::self()->logView()->addOutput( quotedArguments.join(" "), LogView::ot_info );
 }
-
-
-#include "externallanguage.moc"
