@@ -20,15 +20,15 @@ class Gplib : public ExternalLanguage
 {
 	public:
 		Gplib( ProcessChain *processChain );
-		~Gplib();
+		~Gplib() override;
 	
-		virtual void processInput( ProcessOptions options );
-		virtual MessageInfo extractMessageInfo( const QString &text );
-		virtual ProcessOptions::ProcessPath::Path outputPath( ProcessOptions::ProcessPath::Path inputPath ) const;
+		void processInput( ProcessOptions options ) override;
+		MessageInfo extractMessageInfo( const QString &text ) override;
+		ProcessOptions::ProcessPath::Path outputPath( ProcessOptions::ProcessPath::Path inputPath ) const override;
 	
 	protected:
-		virtual bool isError( const QString &message ) const;
-		virtual bool isWarning( const QString &message ) const;
+		bool isError( const QString &message ) const override;
+		bool isWarning( const QString &message ) const override;
 };
 
 #endif
