@@ -22,15 +22,14 @@
 #include "gpdasm.h"
 
 // #include <k3dockwidget.h>
-#include <kiconloader.h>
-#include <klocalizedstring.h>
+#include <KLocalizedString>
 
 #include <cassert>
 
 #include <ktlconfig.h>
 
 
-LanguageManager * LanguageManager::m_pSelf = 0l;
+LanguageManager * LanguageManager::m_pSelf = nullptr;
 
 
 LanguageManager * LanguageManager::self( KateMDI::ToolView * parent )
@@ -100,7 +99,5 @@ void LanguageManager::slotMessage( const QString &error, MessageInfo messageInfo
 void LanguageManager::slotParaClicked( const QString& message, MessageInfo messageInfo )
 {
 	Q_UNUSED(message);
-	DocManager::self()->gotoTextLine( messageInfo.fileURL(), messageInfo.fileLine() );
+	DocManager::self()->gotoTextLine(QUrl::fromUserInput(messageInfo.fileURL()), messageInfo.fileLine() );
 }
-
-#include "languagemanager.moc"
