@@ -10,20 +10,19 @@
 
 #include "languagemanager.h"
 #include "picprogrammer.h"
+#include "logview.h"
 
-#include <kapplication.h>
-#include <kconfig.h>
-#include <kdebug.h>
-#include <klocalizedstring.h>
-#include <kmessagebox.h>
-#include <kshell.h>
+#include <KSharedConfig>
+#include <KLocalizedString>
+#include <KMessageBox>
+#include <KShell>
+#include <KProcess>
 
-#include <qapplication.h>
-#include <qfile.h>
-#include <kprocess.h>
-#include <qregexp.h>
-#include <qtextstream.h>
-#include <qdatetime.h>
+#include <QApplication>
+#include <QDebug>
+#include <QFile>
+#include <QRegExp>
+#include <QTextStream>
 
 #include <stdio.h>
 
@@ -64,7 +63,7 @@ void PicProgrammerSettings::initStaticConfigs()
 {
 	m_bDoneStaticConfigsInit = true;
 	ProgrammerConfig config;
-	
+
 	config.description = i18n("Supported programmers: %1", QString("JuPic, PICStart Plus, Warp-13"));
 	config.description += i18n("<br>Interface: Serial Port");
 	config.initCommand = "";
@@ -75,8 +74,8 @@ void PicProgrammerSettings::initStaticConfigs()
 	config.eraseCommand = "picp %port %device -e";
 // 	config.executable = "picp";
 	m_staticConfigs[ "PICP" ] = config;
-	
-	
+
+
 	config.description = i18n("Supported programmers: %1", QString("Epic Plus"));
 	config.description += i18n("<br>Interface: Parallel Port");
 	config.initCommand = "odyssey init";
@@ -87,8 +86,8 @@ void PicProgrammerSettings::initStaticConfigs()
 	config.eraseCommand = "odyssey %device erase";
 // 	config.executable = "odyssey";
 	m_staticConfigs[ "Odyssey" ] = config;
-	
-	
+
+
 	config.description = i18n("Supported programmers: %1", QString("JDM PIC-Programmer 2, PIC-PG2C"));
 	config.description += i18n("<br>Interface: Serial Port");
 	config.initCommand = "";
@@ -98,8 +97,8 @@ void PicProgrammerSettings::initStaticConfigs()
 	config.blankCheckCommand = "";
 	config.eraseCommand = "picprog --erase --pic %device";
 	m_staticConfigs[ "PICProg" ] = config;
-	
-	
+
+
 	config.description = i18n("Supported programmers: %1", QString("Epic Plus"));
 	config.description += i18n("<br>Interface: Parallel Port");
 	config.initCommand = "";
@@ -109,8 +108,8 @@ void PicProgrammerSettings::initStaticConfigs()
 	config.blankCheckCommand = "";
 	config.eraseCommand = "prog84 --clear";
 	m_staticConfigs[ "prog84" ] = config;
-	
-	
+
+
 	config.description = i18n("Supported programmers: %1", QString("Kit 149, Kit 150"));
 	config.description += i18n("<br>Interface: USB Port");
 	config.initCommand = "";
@@ -120,8 +119,8 @@ void PicProgrammerSettings::initStaticConfigs()
 	config.blankCheckCommand = "";
 	config.eraseCommand = "pp -d %device -e";
 	m_staticConfigs[ "PP" ] = config;
-	
-	
+
+
 	config.description = i18n("Supported programmers: %1", QString("Wisp628"));
 	config.description += i18n("<br>Interface: Serial Port");
 	config.initCommand = "";
@@ -131,8 +130,8 @@ void PicProgrammerSettings::initStaticConfigs()
 	config.blankCheckCommand = "";
 	config.eraseCommand = "xwisp ID %device PORT %device ERASE";
 	m_staticConfigs[ "XWisp" ] = config;
-	
-	
+
+
 #if 0
 	config.description = i18n("Supported programmers: %1", QString("Epic Plus, JDM PIC-Programmer 2, PICCOLO, PICCOLO Grande, Trivial HVP Programmer"));
 	config.description += i18n("<br>Interface: Serial Port and Parallel Port");
@@ -145,8 +144,8 @@ void PicProgrammerSettings::initStaticConfigs()
 	config.executable = "pkp";
 	m_staticConfigs[ "PiKdev" ] = config;
 	config.executable = "";
-	
-	
+
+
 	config.description = i18n("Supported programmers: %1", QString("Trivial LVP programmer, Trivial HVP Programmer"));
 	config.description += i18n("<br>Interface: Parallel Port");
 	config.initCommand = "";
@@ -156,8 +155,8 @@ void PicProgrammerSettings::initStaticConfigs()
 	config.blankCheckCommand = "";
 	config.eraseCommand = "";
 	m_staticConfigs[ "PicPrg2" ] = config;
-	
-	
+
+
 	config.description = i18n("Supported programmers: %1", QString("El Cheapo"));
 	config.description += i18n("<br>Interface: Parallel Port");
 	config.initCommand = "";
@@ -167,8 +166,8 @@ void PicProgrammerSettings::initStaticConfigs()
 	config.blankCheckCommand = "";
 	config.eraseCommand = "";
 	m_staticConfigs[ "PP06" ] = config;
-	
-	
+
+
 	config.description = i18n("Supported programmers: %1", QString("NOPPP"));
 	config.description += i18n("<br>Interface: Parallel Port");
 	config.initCommand = "";
@@ -178,8 +177,8 @@ void PicProgrammerSettings::initStaticConfigs()
 	config.blankCheckCommand = "";
 	config.eraseCommand = "";
 	m_staticConfigs[ "NOPPP" ] = config;
-	
-	
+
+
 	config.description = i18n("Supported programmers: %1", QString("SNOPPP"));
 	config.description += i18n("<br>Interface: Parallel Port");
 	config.initCommand = "";
@@ -204,7 +203,7 @@ void PicProgrammerSettings::load( KConfig * config )
 		{
 			//config->setGroup(*it);
             KConfigGroup grProg = config->group(*it);
-			
+
 			ProgrammerConfig pc;
 			pc.initCommand = grProg.readEntry( "InitCommand" );
 			pc.readCommand = grProg.readEntry( "ReadCommand" );
@@ -212,7 +211,7 @@ void PicProgrammerSettings::load( KConfig * config )
 			pc.verifyCommand = grProg.readEntry( "VerifyCommand" );
 			pc.blankCheckCommand = grProg.readEntry( "BlankCheckCommand" );
 			pc.eraseCommand = grProg.readEntry( "EraseCommand" );
-			
+
 			QString name = grProg.readEntry( "Name" );
 			m_customConfigs[name] = pc;
 		}
@@ -230,7 +229,7 @@ void PicProgrammerSettings::save( KConfig * config )
 		if ( (*it).startsWith("CustomProgrammer_") )
 			config->deleteGroup(*it);
 	}
-	
+
 	int at = 0;
 	ProgrammerConfigMap::iterator end = m_customConfigs.end();
 	for ( ProgrammerConfigMap::iterator it = m_customConfigs.begin(); it != end; ++it )
@@ -254,23 +253,23 @@ ProgrammerConfig PicProgrammerSettings::config( const QString & name )
 {
 	if ( name.isEmpty() )
 		return ProgrammerConfig();
-	
+
 	QString l = name.toLower();
-		
+
 	ProgrammerConfigMap::const_iterator end = m_customConfigs.end();
 	for ( ProgrammerConfigMap::const_iterator it = m_customConfigs.begin(); it != end; ++it )
 	{
 		if ( it.key().toLower() == l )
 			return *it;
 	}
-	
+
 	end = m_staticConfigs.end();
 	for ( ProgrammerConfigMap::const_iterator it = m_staticConfigs.begin(); it != end; ++it )
 	{
 		if ( it.key().toLower() == l )
 			return *it;
 	}
-	
+
 	return m_customConfigs[ name ];
 }
 
@@ -279,12 +278,12 @@ void PicProgrammerSettings::removeConfig( const QString & name )
 {
 	if ( isPredefined( name ) )
 	{
-		kWarning() << k_funcinfo << "Cannot remove a predefined PIC programmer configuration." << endl;
+		qWarning() << Q_FUNC_INFO << "Cannot remove a predefined PIC programmer configuration." << endl;
 		return;
 	}
-	
+
 	QString l = name.toLower();
-	
+
 	ProgrammerConfigMap::iterator end = m_customConfigs.end();
 	for ( ProgrammerConfigMap::iterator it = m_customConfigs.begin(); it != end; ++it )
 	{
@@ -301,12 +300,12 @@ void PicProgrammerSettings::saveConfig( const QString & name, const ProgrammerCo
 {
 	if ( isPredefined( name ) )
 	{
-		kWarning() << k_funcinfo << "Cannot save to a predefined PIC programmer configuration." << endl;
+		qWarning() << Q_FUNC_INFO << "Cannot save to a predefined PIC programmer configuration." << endl;
 		return;
 	}
-	
+
 	QString l = name.toLower();
-	
+
 	ProgrammerConfigMap::iterator end = m_customConfigs.end();
 	for ( ProgrammerConfigMap::iterator it = m_customConfigs.begin(); it != end; ++it )
 	{
@@ -316,7 +315,7 @@ void PicProgrammerSettings::saveConfig( const QString & name, const ProgrammerCo
 			return;
 		}
 	}
-	
+
 	m_customConfigs[ name ] = config;
 }
 
@@ -325,17 +324,17 @@ QStringList PicProgrammerSettings::configNames( bool makeLowercase ) const
 {
 	if ( !makeLowercase )
 		return m_customConfigs.keys() + m_staticConfigs.keys();
-	
+
 	QStringList names;
-	
+
 	ProgrammerConfigMap::const_iterator end = m_customConfigs.end();
 	for ( ProgrammerConfigMap::const_iterator it = m_customConfigs.begin(); it != end; ++it )
 		names << it.key().toLower();
-	
+
 	end = m_staticConfigs.end();
 	for ( ProgrammerConfigMap::const_iterator it = m_staticConfigs.begin(); it != end; ++it )
 		names << it.key().toLower();
-	
+
 	return names;
 }
 
@@ -343,14 +342,14 @@ QStringList PicProgrammerSettings::configNames( bool makeLowercase ) const
 bool PicProgrammerSettings::isPredefined( const QString & name ) const
 {
 	QString l = name.toLower();
-	
+
 	ProgrammerConfigMap::const_iterator end = m_staticConfigs.end();
 	for ( ProgrammerConfigMap::const_iterator it = m_staticConfigs.begin(); it != end; ++it )
 	{
 		if ( it.key().toLower() == l )
 			return true;
 	}
-	
+
 	return false;
 }
 //END class PicProgrammerSettings
@@ -375,31 +374,31 @@ void PicProgrammer::processInput( ProcessOptions options )
 {
 	resetLanguageProcess();
 	m_processOptions = options;
-	
+
 	PicProgrammerSettings settings;
 	//settings.load( kapp->config() );
-    KSharedConfigPtr cfgPtr = KGlobal::config();
+    KSharedConfigPtr cfgPtr = KSharedConfig::openConfig();
     settings.load( cfgPtr.data() );
-	
+
 	QString program = options.m_program;
 	if ( !settings.configNames( true ).contains( program.toLower() ) )
 	{
-		kError() << k_funcinfo << "Invalid program" << endl;
+		qCritical() << Q_FUNC_INFO << "Invalid program" << endl;
 		finish( false );
 		return;
 	}
-	
+
 	ProgrammerConfig config = settings.config( program );
-	
+
 	QString command = config.writeCommand;
 	command.replace( "%port", options.m_port );
 	command.replace( "%device", QString( options.m_picID ).remove("P") );
 	command.replace( "%file", KShell::quoteArg( options.inputFiles().first() ) );
-	
+
 	//m_languageProcess->setUseShell( true ); // 2017.10.08 - port to KProcess
 	//*m_languageProcess << command;
     m_languageProcess->setShellCommand( command );
-	
+
 	if ( !start() )
 	{
 // 		KMessageBox::sorry( LanguageManager::self()->logView(), i18n("Could not program PIC.") );
@@ -428,7 +427,7 @@ ProcessOptions::ProcessPath::Path PicProgrammer::outputPath( ProcessOptions::Pro
 		case ProcessOptions::ProcessPath::PIC_AssemblyAbsolute:
 		case ProcessOptions::ProcessPath::Program_PIC:
 			return ProcessOptions::ProcessPath::None;
-		
+
 		case ProcessOptions::ProcessPath::AssemblyAbsolute_PIC:
 		case ProcessOptions::ProcessPath::AssemblyAbsolute_Program:
 		case ProcessOptions::ProcessPath::AssemblyRelocatable_Library:
@@ -456,7 +455,7 @@ ProcessOptions::ProcessPath::Path PicProgrammer::outputPath( ProcessOptions::Pro
 		case ProcessOptions::ProcessPath::None:
 			return ProcessOptions::ProcessPath::Invalid;
 	}
-	
+
 	return ProcessOptions::ProcessPath::Invalid;
 }
 //END class PicProgrammer
