@@ -28,11 +28,13 @@
 #include "picprogrammer.h"
 #include "sdcc.h"
 
-#include <kdebug.h>
-#include <klocalizedstring.h>
-#include <ktemporaryfile.h>
-#include <qfile.h>
-#include <qtimer.h>
+#include <KLocalizedString>
+
+#include <QDebug>
+#include <QFile>
+#include <QTimer>
+#include <QTemporaryFile>
+#include <QDir>
 
 #include <ktlconfig.h>
 
@@ -42,14 +44,14 @@ ProcessChain::ProcessChain( ProcessOptions options, const char *name )
 	: QObject( KTechlab::self() /*, name */ )
 {
     setObjectName( name );
-	m_pFlowCode = 0l;
-	m_pGpasm = 0l;
-	m_pGpdasm = 0l;
-	m_pGplib = 0l;
-	m_pGplink = 0l;
-	m_pMicrobe = 0l;
-	m_pPicProgrammer = 0l;
-	m_pSDCC = 0l;
+	m_pFlowCode = nullptr;
+	m_pGpasm = nullptr;
+	m_pGpdasm = nullptr;
+	m_pGplib = nullptr;
+	m_pGplink = nullptr;
+	m_pMicrobe = nullptr;
+	m_pPicProgrammer = nullptr;
+	m_pSDCC = nullptr;
 	m_processOptions = options;
 	
 	QString target;
@@ -85,7 +87,7 @@ void ProcessChain::compile()
 	{
 		if ( ProjectInfo * projectInfo = ProjectManager::self()->currentProject() )
 		{
-			ProjectItem * projectItem = projectInfo->findItem( m_processOptions.inputFiles().first() );
+			ProjectItem * projectItem = projectInfo->findItem(QUrl::fromLocalFile(m_processOptions.inputFiles().first()));
 			if (projectItem)
 				m_processOptions.m_picID = projectItem->microID();
 		}
@@ -101,8 +103,7 @@ void ProcessChain::compile()
 #define INDIRECT_PROCESS( path, processor, extension ) \
         case ProcessOptions::ProcessPath::path: \
             { \
-                KTemporaryFile f; \
-                f.setSuffix( extension ); \
+                QTemporaryFile f(QDir::tempPath() + QLatin1String("/ktechlab_XXXXXX") + QLatin1String(extension)); \
                 f.open(); \
                 f.close(); \
                 m_processOptions.setIntermediaryOutput( f.fileName() ); \
@@ -139,10 +140,10 @@ void ProcessChain::compile()
 #undef INDIRECT_PROCESS
 			
 		case ProcessOptions::ProcessPath::Invalid:
-			kWarning() << k_funcinfo << "Process path is invalid" << endl;
+			qWarning() << Q_FUNC_INFO << "Process path is invalid" << endl;
 			
 		case ProcessOptions::ProcessPath::None:
-			kWarning() << k_funcinfo << "Nothing to do" << endl;
+			qWarning() << Q_FUNC_INFO << "Nothing to do" << endl;
 			break;
 	}
 }
@@ -153,16 +154,16 @@ void ProcessChain::slotFinishedCompile(Language *language)
 	ProcessOptions options = language->processOptions();
 	
 	if ( options.b_addToProject && ProjectManager::self()->currentProject() )
-		ProjectManager::self()->currentProject()->addFile( KUrl(options.targetFile()) );
+		ProjectManager::self()->currentProject()->addFile( QUrl::fromLocalFile(options.targetFile()) );
 	
 	ProcessOptions::ProcessPath::MediaType typeTo = ProcessOptions::ProcessPath::to( m_processOptions.processPath() );
 	
-	TextDocument * editor = 0l;
+	TextDocument * editor = nullptr;
 	if ( KTLConfig::reuseSameViewForOutput() )
 	{
 		editor = options.textOutputTarget();
 		if ( editor && (!editor->url().isEmpty() || editor->isModified()) )
-			editor = 0l;
+			editor = nullptr;
 	}
 	
 	switch (typeTo)
@@ -191,7 +192,7 @@ void ProcessChain::slotFinishedCompile(Language *language)
 					if ( !f.open( QIODevice::ReadOnly ) )
 					{
 						editor->deleteLater();
-						editor = 0l;
+						editor = nullptr;
 						break;
 					}
 				
@@ -208,7 +209,7 @@ void ProcessChain::slotFinishedCompile(Language *language)
 			
 				case ProcessOptions::Method::Load:
 				{
-					editor = dynamic_cast<TextDocument*>( DocManager::self()->openURL(options.targetFile()) );
+					editor = dynamic_cast<TextDocument*>( DocManager::self()->openURL(QUrl::fromLocalFile(options.targetFile())) );
 					break;
 				}
 			
@@ -329,6 +330,3 @@ void ProcessListChain::slotProcessChainFailed()
 	emit failed();
 }
 //END class ProcessListChain
-
-
-#include "processchain.moc"
