@@ -12,11 +12,12 @@
 #include "mechanicsitem.h"
 #include "mechanicsdocument.h"
 
-#include <kdebug.h>
-#include <klocalizedstring.h>
-#include <qbitarray.h>
-#include <qpainter.h>
-#include <qmatrix.h>
+#include <KLocalizedString>
+
+#include <QDebug>
+#include <QBitArray>
+#include <QPainter>
+#include <QMatrix>
 #include <cmath>
 
 #define DPR ( 180.0 / M_PI )
@@ -417,6 +418,3 @@ CombinedMechanicsInfo::CombinedMechanicsInfo( const MechanicsInfo &info )
 	x = 0.;
 	y = 0.;
 }
-
-
-#include "mechanicsitem.moc"
