@@ -13,7 +13,7 @@
 #include "mechanicssimulation.h"
 
 #include <cmath>
-#include <qtimer.h>
+#include <QTimer>
 
 MechanicsSimulation::MechanicsSimulation( MechanicsDocument *mechanicsDocument )
 	: QObject(mechanicsDocument)
@@ -40,7 +40,7 @@ void MechanicsSimulation::slotAdvance()
 RigidBody::RigidBody( MechanicsDocument *mechanicsDocument )
 {
 	p_mechanicsDocument = mechanicsDocument;
-	p_overallParent = 0l;
+	p_overallParent = nullptr;
 }
 
 
@@ -76,11 +76,11 @@ void RigidBody::rotateBy( double dtheta )
 
 bool RigidBody::findOverallParent()
 {
-	p_overallParent = 0l;
+	p_overallParent = nullptr;
 	if ( m_mechanicsItemList.isEmpty() )
 		return false;
 	
-	m_mechanicsItemList.removeAll(0l);
+	m_mechanicsItemList.removeAll(nullptr);
 	
 	const MechanicsItemList::iterator end = m_mechanicsItemList.end();
 	for ( MechanicsItemList::iterator it = m_mechanicsItemList.begin(); it != end; ++it )
@@ -100,7 +100,7 @@ bool RigidBody::findOverallParent()
 		
 		if ( p_overallParent != parentItem )
 		{
-			p_overallParent = 0l;
+			p_overallParent = nullptr;
 			return false;
 		}
 	}
@@ -133,7 +133,3 @@ RigidBodyState::RigidBodyState()
 {
 	angularMomentum = 0.;
 }
-
-
-
-#include "mechanicssimulation.moc"
