@@ -12,6 +12,8 @@
 #include "mechanicsview.h"
 #include "viewiface.h"
 
+#include <QDragEnterEvent>
+#include <QMimeData>
 
 MechanicsView::MechanicsView( MechanicsDocument *mechanicsDocument, ViewContainer *viewContainer, uint viewAreaId, const char *name )
 	: ItemView( mechanicsDocument, viewContainer, viewAreaId, name )
@@ -33,7 +35,6 @@ void MechanicsView::dragEnterEvent( QDragEnterEvent * e )
 	if ( e->isAccepted() )
 		return;
 	
-	e->setAccepted( e->provides("ktechlab/mechanical") );
+	//e->setAccepted( e->provides("ktechlab/mechanical") ); // 2019.04.14
+    e->setAccepted( e->mimeData()->hasFormat("ktechlab/mechanical") );
 }
-
-#include "mechanicsview.moc"
