@@ -11,7 +11,7 @@
 #include "microinfo.h"
 #include "microlibrary.h"
 
-#include <kdebug.h>
+// #include <QDebug>
 // #include <k3staticdeleter.h>
 
 #include "picinfo12bit.h"
@@ -20,12 +20,12 @@
 
 #include "micropackage.h"
 
-#include <kglobal.h>
+#include <QGlobalStatic>
 
-// MicroLibrary * MicroLibrary::m_pSelf = 0l;
+// MicroLibrary * MicroLibrary::m_pSelf = nullptr;
 // static K3StaticDeleter<MicroLibrary> staticMicroLibraryDeleter;
 
-K_GLOBAL_STATIC( MicroLibrary, globalMicroLibrary);
+Q_GLOBAL_STATIC( MicroLibrary, globalMicroLibrary);
 
 MicroLibrary * MicroLibrary::self()
 {
@@ -90,8 +90,8 @@ MicroInfo *MicroLibrary::microInfoWithID( QString id )
 	{
 		if ( (*it)->id() == id ) return *it;
 	}
-	
-	return 0L;
+
+	return nullptr;
 }
 
 void MicroLibrary::addMicroInfo( MicroInfo *microInfo )
@@ -103,7 +103,7 @@ void MicroLibrary::addMicroInfo( MicroInfo *microInfo )
 QStringList MicroLibrary::microIDs( unsigned asmSet, unsigned gpsimSupport, unsigned flowCodeSupport, unsigned microbeSupport )
 {
 	QStringList ids;
-	
+
 	const MicroInfoList::iterator end = m_microInfoList.end();
 	for ( MicroInfoList::iterator it = m_microInfoList.begin(); it != end; ++it )
 	{
