@@ -14,15 +14,14 @@
 #include "itemdocumentdata.h"
 #include "node.h"
 
-#include <kdebug.h>
-
-#include <qpainter.h>
+#include <QDebug>
+#include <QPainter>
 
 QColor Node::m_selectedColor = QColor( 101, 134, 192 );
 
 Node::Node( ICNDocument *icnDocument, Node::node_type type, int dir, const QPoint &pos, QString *id )
 	: //QObject(),
-	  KtlQCanvasPolygon( icnDocument ? icnDocument->canvas() : 0 )
+	  KtlQCanvasPolygon( icnDocument ? icnDocument->canvas() : nullptr )
 {
     QString name("Node");
     if (id) {
@@ -34,28 +33,28 @@ Node::Node( ICNDocument *icnDocument, Node::node_type type, int dir, const QPoin
     qDebug() << Q_FUNC_INFO << " this=" << this;
 
 	m_length = 8;
-	p_nodeGroup = 0l;
-	p_parentItem = 0L;
+	p_nodeGroup = nullptr;
+	p_parentItem = nullptr;
 	b_deleted = false;
 	m_dir = dir;
 	m_type = type;
 	p_icnDocument = icnDocument;
 	m_level = 0;
-	
+
 	if ( p_icnDocument ) {
 		if (id) {
 			m_id = *id;
 			if ( !p_icnDocument->registerUID(*id) )
-				kError() << k_funcinfo << "Could not register id " << *id << endl;
+				qCritical() << Q_FUNC_INFO << "Could not register id " << *id << endl;
 		} else m_id = p_icnDocument->generateUID("node"+QString::number(type));
 	}
-	
+
 	initPoints();
 	move( pos.x(), pos.y() );
 	setBrush( Qt::black );
 	setPen( QPen( Qt::black ) );
 	show();
-	
+
 	emit (moved(this));
 }
 
@@ -102,21 +101,21 @@ void Node::initPoints()
 void Node::setVisible( bool yes )
 {
 	if ( isVisible() == yes ) return;
-	
+
 	KtlQCanvasPolygon::setVisible(yes);
 }
 
 void Node::setParentItem( CNItem *parentItem )
 {
 	if (!parentItem) {
-		kError() << k_funcinfo << "no parent item" << endl;
+		qCritical() << Q_FUNC_INFO << "no parent item" << endl;
 		return;
 	}
 
 	p_parentItem = parentItem;
-	
+
 	setLevel(p_parentItem->level());
-	
+
 	connect( p_parentItem, SIGNAL(movedBy(double, double )), this, SLOT(moveBy(double, double)) );
 	connect( p_parentItem, SIGNAL(removed(Item*)), this, SLOT(removeNode(Item*)) );
 }
@@ -153,9 +152,9 @@ void Node::setNodeSelected( bool yes )
 {
 	if ( isSelected() == yes )
 		return;
-	
+
 	KtlQCanvasItem::setSelected(yes);
-	
+
 	setPen(   yes ? m_selectedColor : Qt::black );
 	setBrush( yes ? m_selectedColor : Qt::black );
 }
@@ -172,5 +171,3 @@ void Node::deinitPainter( QPainter & p )
 	p.rotate( -m_dir );
 	p.translate( -int(x()), -int(y()) );
 }
-
-#include "node.moc"
