@@ -19,24 +19,49 @@
 #include "projectmanager.h"
 #include "recentfilesaction.h"
 
-#include <kdebug.h>
-#include <kfiledialog.h>
-#include <kiconloader.h>
-#include <kio/netaccess.h>
-#include <klocalizedstring.h>
-#include <kmessagebox.h> 
-#include <kmimetype.h>
-#include <kstandarddirs.h>
-#include <kxmlguifactory.h>
+#include <KIO/FileCopyJob>
+#include <KJobWidgets>
+#include <KLocalizedString>
+#include <KMessageBox>
+#include <KXMLGUIFactory>
 
-#include <qdom.h>
+#include <QDebug>
+#include <QFileDialog>
+#include <QDomDocument>
+#include <QDomElement>
 // #include <q3popupmenu.h>
-#include <qmenu.h>
+#include <QMenu>
+#include <QStandardPaths>
+#include <QMimeDatabase>
+#include <QMimeType>
+#include <QDir>
+#include <QTemporaryFile>
+#include <QScopedPointer>
 
 #include <cassert>
 
 #include <ktlconfig.h>
 
+static QString relativeUrl(const QUrl& baseDirUrl, const QUrl& url)
+{
+    if (baseDirUrl.scheme() == url.scheme() && baseDirUrl.host() == url.host() &&
+        baseDirUrl.port() == url.port() && baseDirUrl.userInfo() == url.userInfo())
+    {
+        return QDir(baseDirUrl.path()).relativeFilePath(url.path());
+    }
+
+    return url.toDisplayString(QUrl::PreferLocalFile);
+}
+
+static QString resolvedLocalFile(const QString& baseDir, const QString& path)
+{
+    Q_ASSERT(baseDir.endsWith(QLatin1Char('/')));
+    if (QDir::isAbsolutePath(path))
+        return path;
+
+    return QDir::cleanPath(baseDir + path);
+}
+
 //BEGIN class LinkerOptions
 LinkerOptions::LinkerOptions()
 {
@@ -44,8 +69,7 @@ LinkerOptions::LinkerOptions()
 	m_bOutputMapFile = false;
 }
 
-
-QDomElement LinkerOptions::toDomElement( QDomDocument & doc, const KUrl & baseURL ) const
+QDomElement LinkerOptions::toDomElement( QDomDocument & doc, const QUrl & baseDirUrl ) const
 {
 	QDomElement node = doc.createElement("linker");
 	
@@ -55,12 +79,15 @@ QDomElement LinkerOptions::toDomElement( QDomDocument & doc, const KUrl & baseUR
 	node.setAttribute( "linker-script", linkerScript() );
 	node.setAttribute( "other", linkerOther() );
 	
+	// internal are always local files, like the project base dir
+	// so can always get relative path from a QDir
+	const QDir baseDir(baseDirUrl.toLocalFile());
 	QStringList::const_iterator end = m_linkedInternal.end();
 	for ( QStringList::const_iterator it = m_linkedInternal.begin(); it != end; ++it )
 	{
 		QDomElement child = doc.createElement("linked-internal");
 		node.appendChild(child);
-		child.setAttribute( "url", KUrl::relativeUrl( baseURL, *it ) );
+		child.setAttribute( "url", baseDir.relativeFilePath(*it));
 	}
 	
 	end = m_linkedExternal.end();
@@ -75,7 +102,7 @@ QDomElement LinkerOptions::toDomElement( QDomDocument & doc, const KUrl & baseUR
 }
 
 
-void LinkerOptions::domElementToLinkerOptions( const QDomElement & element, const KUrl & baseURL )
+void LinkerOptions::domElementToLinkerOptions( const QDomElement & element, const QUrl & baseDirUrl )
 {
 	setHexFormat( stringToHexFormat( element.attribute( "hex-format", QString::null ) ) );
 	setOutputMapFile( element.attribute( "output-map-file", "0" ).toInt() );
@@ -85,7 +112,11 @@ void LinkerOptions::domElementToLinkerOptions( const QDomElement & element, cons
 	
 	m_linkedInternal.clear();
 	m_linkedExternal.clear();
-	
+
+    QString baseDir = baseDirUrl.toLocalFile();
+    if (!baseDir.endsWith(QLatin1Char('/'))) {
+        baseDir.append(QLatin1Char('/'));
+    }
 	QDomNode node = element.firstChild();
 	while ( !node.isNull() )
 	{
@@ -95,13 +126,12 @@ void LinkerOptions::domElementToLinkerOptions( const QDomElement & element, cons
 			const QString tagName = childElement.tagName();
 			
 			if ( tagName == "linked-internal" )
-				m_linkedInternal << KUrl( baseURL, childElement.attribute( "url", QString::null ) ).url();
-			
+				m_linkedInternal << ::resolvedLocalFile(baseDir, childElement.attribute("url", QString()));
 			else if ( tagName == "linked-external" )
 				m_linkedExternal << childElement.attribute( "url", QString::null );
 			
 			else
-				kError() << k_funcinfo << "Unrecognised element tag name: "<<tagName<<endl;
+				qCritical() << Q_FUNC_INFO << "Unrecognised element tag name: "<<tagName<<endl;
 		}
 		
 		node = node.nextSibling();
@@ -161,20 +191,20 @@ ProcessingOptions::~ProcessingOptions()
 }
 
 
-QDomElement ProcessingOptions::toDomElement( QDomDocument & doc, const KUrl & baseURL ) const
+QDomElement ProcessingOptions::toDomElement( QDomDocument & doc, const QUrl & baseDirUrl ) const
 {
 	QDomElement node = doc.createElement("processing");
 	
-	node.setAttribute( "output", KUrl::relativeUrl( baseURL, outputURL().url() ) );
+	node.setAttribute( "output", ::relativeUrl( baseDirUrl, outputURL() ) );
 	node.setAttribute( "micro", m_microID );
 	
 	return node;
 }
 
 
-void ProcessingOptions::domElementToProcessingOptions( const QDomElement & element, const KUrl & baseURL )
+void ProcessingOptions::domElementToProcessingOptions( const QDomElement & element, const QUrl & baseDirUrl )
 {
-	setOutputURL( KUrl( baseURL, element.attribute( "output", QString::null ) ) );
+	setOutputURL( baseDirUrl.resolved(QUrl(element.attribute( "output", QString()))));
 	setMicroID( element.attribute("micro", QString::null ) );
 }
 //END class ProcessingOptions
@@ -186,7 +216,7 @@ ProjectItem::ProjectItem( ProjectItem * parent, Type type, ProjectManager * proj
 	: QObject()
 {
 	m_pParent = parent;
-	m_pILVItem = 0l;
+	m_pILVItem = nullptr;
 	m_pProjectManager = projectManager;
 	m_type = type;
 }
@@ -194,7 +224,7 @@ ProjectItem::ProjectItem( ProjectItem * parent, Type type, ProjectManager * proj
 
 ProjectItem::~ProjectItem()
 {
-	m_children.removeAll( (ProjectItem*)0l );
+	m_children.removeAll( (ProjectItem*)nullptr );
 	ProjectItemList::iterator end = m_children.end();
 	for ( ProjectItemList::iterator it = m_children.begin(); it != end; ++it )
 		(*it)->deleteLater();
@@ -230,7 +260,7 @@ void ProjectItem::updateILVItemPixmap()
 		case ProgramType:
 		{
 			QPixmap pm;
-			pm.load( KStandardDirs:: locate( "appdata", "icons/project_program.png" ) );
+			pm.load( QStandardPaths::locate( QStandardPaths::AppDataLocation, "icons/project_program.png" ) );
 			m_pILVItem->setIcon( 0, QIcon( pm ) );
 			break;
 		}
@@ -238,16 +268,16 @@ void ProjectItem::updateILVItemPixmap()
 		case LibraryType:
 		{
 			QPixmap pm;
-			pm.load( KStandardDirs:: locate( "appdata", "icons/project_library.png" ) );
+			pm.load( QStandardPaths::locate( QStandardPaths::AppDataLocation, "icons/project_library.png" ) );
 			m_pILVItem->setIcon( 0, QIcon( pm ) );
 			break;
 		}
 		
 		case FileType:
 		{
-			KMimeType::Ptr m = KMimeType::findByPath( url().path() );
+			QMimeType m = QMimeDatabase().mimeTypeForFile( url().path() );
 			//m_pILVItem->setPixmap( 0, m->pixmap( KIconLoader::Small ) );
-            m_pILVItem->setIcon( 0, QIcon( KIconLoader::global()->loadMimeTypeIcon( m->iconName(), KIconLoader::Small ) ) );
+            m_pILVItem->setIcon(0, QIcon::fromTheme(m.iconName()));
 			break;
 		}
 	}
@@ -285,7 +315,7 @@ void ProjectItem::updateControlChildMicroIDs()
 			break;
 	}
 	
-	m_children.removeAll( (ProjectItem*)0l );
+	m_children.removeAll( (ProjectItem*)nullptr );
 	ProjectItemList::iterator end = m_children.end();
 	for ( ProjectItemList::iterator it = m_children.begin(); it != end; ++it )
 		(*it)->setUseParentMicroID( control );
@@ -300,7 +330,7 @@ void ProjectItem::setObjectName( const QString & name )
 }
 
 
-void ProjectItem::setURL( const KUrl & url )
+void ProjectItem::setURL( const QUrl & url )
 {
 	m_url = url;
 	
@@ -337,9 +367,12 @@ void ProjectItem::setURL( const KUrl & url )
 		
 		if ( !newExtension.isEmpty() )
 		{
-			const QString fileName = url.url();
-			QString extension = fileName.right( fileName.length() - fileName.lastIndexOf('.') );
-			setOutputURL( QString(fileName).replace( extension, newExtension ) );
+			QString fileName = url.path();
+			fileName.chop(fileName.length() - fileName.lastIndexOf('.'));
+			fileName.append(newExtension );
+			QUrl newUrl(url);
+			newUrl.setPath(fileName);
+			setOutputURL(newUrl);
 		}
 	}
 	
@@ -376,7 +409,7 @@ ProjectItem::OutputType ProjectItem::outputType() const
 			switch ( type() )
 			{
 				case ProjectItem::ProjectType:
-					kWarning() << k_funcinfo << "Parent item and this item are both project items" << endl;
+					qWarning() << Q_FUNC_INFO << "Parent item and this item are both project items" << endl;
 					return UnknownOutput;
 						
 				case ProjectItem::FileType:
@@ -391,7 +424,7 @@ ProjectItem::OutputType ProjectItem::outputType() const
 				
 		case ProjectItem::FileType:
 		{
-			kWarning() << k_funcinfo << "Don't know how to handle parent item being a file" << endl;
+			qWarning() << Q_FUNC_INFO << "Don't know how to handle parent item being a file" << endl;
 			return UnknownOutput;
 		}
 				
@@ -413,7 +446,7 @@ bool ProjectItem::build( ProcessOptionsList * pol )
 	ProcessOptionsList::iterator polEnd = pol->end();
 	for ( ProcessOptionsList::iterator it = pol->begin(); it != polEnd; ++it )
 	{
-		if ( (*it).targetFile() == outputURL().path() )
+		if ( (*it).targetFile() == outputURL().toLocalFile() )
 			return true;
 	}
 	
@@ -422,7 +455,7 @@ bool ProjectItem::build( ProcessOptionsList * pol )
 	
 	if ( outputURL().isEmpty() )
 	{
-		KMessageBox::sorry( 0l, i18n("Do not know how to build \"%1\" (output URL is empty).", name()) );
+		KMessageBox::sorry( nullptr, i18n("Do not know how to build \"%1\" (output URL is empty).", name()) );
 		return false;
 	}
 	
@@ -430,10 +463,10 @@ bool ProjectItem::build( ProcessOptionsList * pol )
 	QStringList::iterator send = m_linkedInternal.end();
 	for ( QStringList::iterator it = m_linkedInternal.begin(); it != send; ++it )
 	{
-		ProjectItem * lib = projectInfo->findItem( projectInfo->directory() + *it );
+		ProjectItem * lib = projectInfo->findItem(QUrl::fromLocalFile(projectInfo->directory() + *it));
 		if ( !lib )
 		{
-			KMessageBox::sorry( 0l, i18n("Do not know how to build \"%1\" (library does not exist in project).", *it) );
+			KMessageBox::sorry( nullptr, i18n("Do not know how to build \"%1\" (library does not exist in project).", *it) );
 			return false;
 		}
 		
@@ -443,7 +476,7 @@ bool ProjectItem::build( ProcessOptionsList * pol )
 	
 	
 	// Build all children
-	m_children.removeAll( (ProjectItem*)0l );
+	m_children.removeAll( (ProjectItem*)nullptr );
 	ProjectItemList::iterator cend = m_children.end();
 	for ( ProjectItemList::iterator it = m_children.begin(); it != cend; ++it )
 	{
@@ -455,7 +488,7 @@ bool ProjectItem::build( ProcessOptionsList * pol )
 	// Now build ourself
 	ProcessOptions po;
 	po.b_addToProject = false;
-	po.setTargetFile( outputURL().path() );
+	po.setTargetFile( outputURL().toLocalFile() );
 	po.m_picID = microID();
 	
 	ProcessOptions::ProcessPath::MediaType typeTo = ProcessOptions::ProcessPath::Unknown;
@@ -463,7 +496,7 @@ bool ProjectItem::build( ProcessOptionsList * pol )
 	switch ( outputType() )
 	{
 		case UnknownOutput:
-			KMessageBox::sorry( 0l, i18n("Do not know how to build \"%1\" (unknown output type).", name()) );
+			KMessageBox::sorry( nullptr, i18n("Do not know how to build \"%1\" (unknown output type).", name()) );
 			return false;
 			
 		case ProgramOutput:
@@ -485,21 +518,22 @@ bool ProjectItem::build( ProcessOptionsList * pol )
 			// Nothing to do
 			return true;
 			
-		case FileType:
-			po.setInputFiles( QStringList( url().path() ) );
-			po.setProcessPath( ProcessOptions::ProcessPath::path( ProcessOptions::guessMediaType( url().url() ), typeTo ) );
+		case FileType: {
+			const QString fileName = url().toLocalFile();
+			po.setInputFiles( QStringList( fileName ) );
+			po.setProcessPath( ProcessOptions::ProcessPath::path( ProcessOptions::guessMediaType( fileName ), typeTo ) );
 			break;
-			
+                }
 		case ProgramType:
 		case LibraryType:
 			// Build up a list of input urls
 			QStringList inputFiles;
 			
 			// Link child objects
-			m_children.removeAll( (ProjectItem*)0l );
+			m_children.removeAll( (ProjectItem*)nullptr );
 			ProjectItemList::iterator cend = m_children.end();
 			for ( ProjectItemList::iterator it = m_children.begin(); it != cend; ++it )
-				inputFiles << (*it)->outputURL().path();
+				inputFiles << (*it)->outputURL().toLocalFile();
 			
 			po.setInputFiles(inputFiles);
 			po.setProcessPath( ProcessOptions::ProcessPath::path( ProcessOptions::ProcessPath::Object, typeTo ) );
@@ -536,9 +570,8 @@ void ProjectItem::upload( ProcessOptionsList * pol )
 	
 	ProgrammerDlg * dlg = new ProgrammerDlg( microID(), (QWidget*)KTechlab::self(), "Programmer Dlg" );
 	
-	dlg->exec();
-	if ( !dlg->isAccepted() )
-	{
+    const int accepted = dlg->exec();
+    if (accepted != QDialog::Accepted) {
 		dlg->deleteLater();
 		return;
 	}
@@ -546,7 +579,7 @@ void ProjectItem::upload( ProcessOptionsList * pol )
 	ProcessOptions po;
 	dlg->initOptions( & po );
 	po.b_addToProject = false;
-	po.setInputFiles( QStringList( outputURL().path() ) );
+	po.setInputFiles( QStringList( outputURL().toLocalFile() ) );
 	po.setProcessPath( ProcessOptions::ProcessPath::Program_PIC );
 	
 	pol->append( po );
@@ -555,32 +588,32 @@ void ProjectItem::upload( ProcessOptionsList * pol )
 }
 
 
-QDomElement ProjectItem::toDomElement( QDomDocument & doc, const KUrl & baseURL ) const
+QDomElement ProjectItem::toDomElement( QDomDocument & doc, const QUrl & baseDirUrl ) const
 {
 	QDomElement node = doc.createElement("item");
 	
 	node.setAttribute( "type", typeToString() );
 	node.setAttribute( "name", m_name );
-	node.setAttribute( "url", KUrl::relativeUrl( baseURL, m_url.url() ) );
+	node.setAttribute( "url", ::relativeUrl(baseDirUrl, m_url) );
 	
-	node.appendChild( LinkerOptions::toDomElement( doc, baseURL ) );
-	node.appendChild( ProcessingOptions::toDomElement( doc, baseURL ) );
+	node.appendChild( LinkerOptions::toDomElement( doc, baseDirUrl ) );
+	node.appendChild( ProcessingOptions::toDomElement( doc, baseDirUrl ) );
 	
 	
 	ProjectItemList::const_iterator end = m_children.end();
 	for ( ProjectItemList::const_iterator it = m_children.begin(); it != end; ++it )
 	{
 		if (*it)
-			node.appendChild( (*it)->toDomElement( doc, baseURL ) );
+			node.appendChild( (*it)->toDomElement( doc, baseDirUrl ) );
 	}
 	
 	return node;
 }
 
 
-KUrl::List ProjectItem::childOutputURLs( unsigned types, unsigned outputTypes ) const
+QList<QUrl> ProjectItem::childOutputURLs( unsigned types, unsigned outputTypes ) const
 {
-	KUrl::List urls;
+	QList<QUrl> urls;
 	
 	ProjectItemList::const_iterator end = m_children.end();
 	for ( ProjectItemList::const_iterator it = m_children.begin(); it != end; ++it )
@@ -589,7 +622,7 @@ KUrl::List ProjectItem::childOutputURLs( unsigned types, unsigned outputTypes )
 			continue;
 		
 		if ( ((*it)->type() & types) && ((*it)->outputType() & outputTypes) )
-			urls += (*it)->outputURL().prettyUrl();
+			urls += (*it)->outputURL();
 		
 		urls += (*it)->childOutputURLs(types);
 	}
@@ -598,7 +631,7 @@ KUrl::List ProjectItem::childOutputURLs( unsigned types, unsigned outputTypes )
 }
 
 
-ProjectItem * ProjectItem::findItem( const KUrl & url )
+ProjectItem * ProjectItem::findItem( const QUrl & url )
 {
 	if ( this->url() == url )
 		return this;
@@ -614,7 +647,7 @@ ProjectItem * ProjectItem::findItem( const KUrl & url )
 			return found;
 	}
 	
-	return 0l;
+	return nullptr;
 }
 
 
@@ -624,7 +657,7 @@ bool ProjectItem::closeOpenFiles()
 	if ( doc && !doc->fileClose() )
 		return false;
 	
-	m_children.removeAll( (ProjectItem*)0l );
+	m_children.removeAll( (ProjectItem*)nullptr );
 	ProjectItemList::iterator end = m_children.end();
 	for ( ProjectItemList::iterator it = m_children.begin(); it != end; ++it )
 	{
@@ -638,10 +671,9 @@ bool ProjectItem::closeOpenFiles()
 
 void ProjectItem::addFiles()
 {
-	KUrl::List urls = KTechlab::self()->getFileURLs();
-	const KUrl::List::iterator end = urls.end();
-	for ( KUrl::List::iterator it = urls.begin(); it != end; ++ it)
-		addFile(*it);
+	const QList<QUrl> urls = KTechlab::self()->getFileURLs();
+	for (const QUrl &url : urls)
+		addFile(url);
 }
 
 
@@ -665,12 +697,12 @@ void ProjectItem::addCurrentFile()
 }
 
 
-void ProjectItem::addFile( const KUrl & url )
+void ProjectItem::addFile( const QUrl & url )
 {
 	if ( url.isEmpty() )
 		return;
 	
-	m_children.removeAll( (ProjectItem*)0l );
+	m_children.removeAll( (ProjectItem*)nullptr );
 	ProjectItemList::iterator end = m_children.end();
 	for ( ProjectItemList::iterator it = m_children.begin(); it != end; ++it )
 	{
@@ -722,11 +754,11 @@ ProjectItem::Type ProjectItem::stringToType( const QString & type )
 }
 
 
-void ProjectItem::domElementToItem( const QDomElement & element, const KUrl & baseURL )
+void ProjectItem::domElementToItem( const QDomElement & element, const QUrl & baseDirUrl )
 {
 	Type type = stringToType( element.attribute( "type", QString::null ) );
 	QString name = element.attribute( "name", QString::null );
-	KUrl url( baseURL, element.attribute( "url", QString::null ) );
+	QUrl url = baseDirUrl.resolved(QUrl(element.attribute("url", QString())));
 	
 	ProjectItem * createdItem = new ProjectItem( this, type, m_pProjectManager );
 	createdItem->setObjectName( name );
@@ -743,16 +775,16 @@ void ProjectItem::domElementToItem( const QDomElement & element, const KUrl & ba
 			const QString tagName = childElement.tagName();
 			
 			if ( tagName == "linker" )
-				createdItem->domElementToLinkerOptions( childElement, baseURL );
+				createdItem->domElementToLinkerOptions( childElement, baseDirUrl );
 			
 			else if ( tagName == "processing" )
-				createdItem->domElementToProcessingOptions( childElement, baseURL );
+				createdItem->domElementToProcessingOptions( childElement, baseDirUrl );
 			
 			else if ( tagName == "item" )
-				createdItem->domElementToItem( childElement, baseURL );
+				createdItem->domElementToItem( childElement, baseDirUrl );
 			
 			else
-				kError() << k_funcinfo << "Unrecognised element tag name: "<<tagName<<endl;
+				qCritical() << Q_FUNC_INFO << "Unrecognised element tag name: "<<tagName<<endl;
 		}
 		
 		node = node.nextSibling();
@@ -764,7 +796,7 @@ void ProjectItem::domElementToItem( const QDomElement & element, const KUrl & ba
 
 //BEGIN class ProjectInfo
 ProjectInfo::ProjectInfo( ProjectManager * projectManager )
-	: ProjectItem( 0l, ProjectItem::ProjectType, projectManager )
+	: ProjectItem( nullptr, ProjectItem::ProjectType, projectManager )
 {
 	m_microID = QString::null;
 }
@@ -775,39 +807,45 @@ ProjectInfo::~ ProjectInfo()
 }
 
 
-bool ProjectInfo::open( const KUrl & url )
+bool ProjectInfo::open( const QUrl & url )
 {
-	QString target;
-	if ( !KIO::NetAccess::download( url, target, 0l ) )
+	QScopedPointer<QFile> file;
+	if (!url.isLocalFile())
 	{
-		// If the file could not be downloaded, for example does not
-		// exist on disk, NetAccess will tell us what error to use
-		KMessageBox::error( 0l, KIO::NetAccess::lastErrorString() );
-		
-		return false;
+		QScopedPointer<QTemporaryFile> downloadedFile(new QTemporaryFile());
+		downloadedFile->open();
+		KIO::FileCopyJob* job = KIO::file_copy(url, QUrl::fromLocalFile(downloadedFile->fileName()));
+		KJobWidgets::setWindow(job, nullptr);
+		if (!job->exec())
+                {
+			KMessageBox::error( nullptr, job->errorString() );
+			return false;
+		}
+		file.reset(downloadedFile.take());
 	}
-	
-	QFile file(target);
-	if ( !file.open( QIODevice::ReadOnly ) )
+	else
 	{
-		KMessageBox::sorry( 0l, i18n("Could not open %1 for reading", target) );
-		return false;
+		QScopedPointer<QFile> localFile(new QFile(url.toLocalFile()));
+		if ( !localFile->open( QIODevice::ReadOnly ) )
+		{
+			KMessageBox::sorry( nullptr, i18n("Could not open %1 for reading", localFile->fileName()) );
+			return false;
+		}
+		file.reset(localFile.take());
 	}
 	
 	m_url = url;
 	
 	QString xml;
-	QTextStream textStream( &file );
+	QTextStream textStream( file.data() );
 	while ( !textStream.atEnd() ) //was: eof()
 		xml += textStream.readLine() + '\n';
 	
-	file.close();
-	
 	QDomDocument doc( "KTechlab" );
 	QString errorMessage;
 	if ( !doc.setContent( xml, &errorMessage ) )
 	{
-		KMessageBox::sorry( 0l, i18n("Could not parse XML:\n%1", errorMessage) );
+		KMessageBox::sorry( nullptr, i18n("Could not parse XML:\n%1", errorMessage) );
 		return false;
 	}
 	
@@ -831,7 +869,7 @@ bool ProjectInfo::open( const KUrl & url )
 				domElementToItem( element, m_url );
 			
 			else
-				kWarning() << k_funcinfo << "Unrecognised element tag name: "<<tagName<<endl;
+				qWarning() << Q_FUNC_INFO << "Unrecognised element tag name: "<<tagName<<endl;
 		}
 		
 		node = node.nextSibling();
@@ -844,10 +882,10 @@ bool ProjectInfo::open( const KUrl & url )
 
 bool ProjectInfo::save()
 {
-	QFile file( m_url.path() );
+	QFile file( m_url.toLocalFile() );
 	if ( file.open(QIODevice::WriteOnly) == false )
 	{
-		KMessageBox::sorry( NULL, i18n("Project could not be saved to \"%1\"", m_url.path()), i18n("Saving Project") );
+		KMessageBox::sorry( nullptr, i18n("Project could not be saved to \"%1\"", file.fileName()), i18n("Saving Project") );
 		return false;
 	}
 	
@@ -856,10 +894,11 @@ bool ProjectInfo::save()
 	QDomElement root = doc.createElement("project");
 	doc.appendChild(root);
 	
-	m_children.removeAll( (ProjectItem*)0l );
+	m_children.removeAll( (ProjectItem*)nullptr );
+	const QUrl baseDirUrl = m_url.adjusted(QUrl::RemoveFilename);
 	ProjectItemList::const_iterator end = m_children.end();
 	for ( ProjectItemList::const_iterator it = m_children.begin(); it != end; ++it )
-		root.appendChild( (*it)->toDomElement( doc, m_url ) );
+		root.appendChild( (*it)->toDomElement( doc, baseDirUrl ) );
 	
 	QTextStream stream(&file);
 	stream << doc.toString();
@@ -868,7 +907,7 @@ bool ProjectInfo::save()
     {
         QAction *recentfilesaction = KTechlab::self()->actionByName("project_open_recent");
         if (recentfilesaction) {
-            (static_cast<RecentFilesAction*>(recentfilesaction))->addURL(m_url);
+            (static_cast<RecentFilesAction*>(recentfilesaction))->addUrl(m_url);
         } else {
             qWarning() << "there is no project_open_recent action in KTechLab!";
         }
@@ -893,7 +932,7 @@ bool ProjectInfo::saveAndClose()
 
 
 //BEGIN class ProjectManager
-ProjectManager * ProjectManager::m_pSelf = 0l;
+ProjectManager * ProjectManager::m_pSelf = nullptr;
 
 ProjectManager * ProjectManager::self( KateMDI::ToolView * parent )
 {
@@ -908,7 +947,7 @@ ProjectManager * ProjectManager::self( KateMDI::ToolView * parent )
 
 ProjectManager::ProjectManager( KateMDI::ToolView * parent )
 	: ItemSelector( parent, "Project Manager" ),
-	m_pCurrentProject(0l)
+	m_pCurrentProject(nullptr)
 {
 	setWhatsThis( i18n("Displays the list of files in the project.\nTo open or close a project, use the \"Project\" menu. Right click on a file to remove it from the project") );
 	
@@ -930,17 +969,16 @@ void ProjectManager::slotNewProject()
 		return;
 	
 	NewProjectDlg *newProjectDlg = new NewProjectDlg(this);
-	newProjectDlg->exec();
+	const int accepted = newProjectDlg->exec();
 
-	if ( newProjectDlg->accepted() )
-	{
+	if (accepted == QDialog::Accepted) {
 		m_pCurrentProject = new ProjectInfo( this );
 		m_pCurrentProject->setObjectName( newProjectDlg->projectName() );
-		m_pCurrentProject->setURL( newProjectDlg->location() + m_pCurrentProject->name().toLower() + ".ktechlab" );
+		m_pCurrentProject->setURL(QUrl::fromLocalFile(newProjectDlg->location() + m_pCurrentProject->name().toLower() + ".ktechlab"));
 		
         QDir dir;
         if ( !dir.mkdir( m_pCurrentProject->directory() ) )
-			kDebug() << "Error in creating directory " << m_pCurrentProject->directory() << endl;
+			qDebug() << "Error in creating directory " << m_pCurrentProject->directory() << endl;
 		
 		m_pCurrentProject->save();
 		updateActions();
@@ -962,7 +1000,7 @@ void ProjectManager::slotOpenProject()
 	QString filter;
 	filter = QString("*.ktechlab|%1 (*.ktechlab)\n*|%2").arg( i18n("KTechlab Project") ).arg( i18n("All Files") );
 	
-    KUrl url = KFileDialog::getOpenUrl( KUrl(), filter, this, i18n("Open Location"));
+    QUrl url = QFileDialog::getOpenFileUrl(this, i18n("Open Location"), QUrl(), filter);
 	
     if ( url.isEmpty() )
 		return;
@@ -971,7 +1009,7 @@ void ProjectManager::slotOpenProject()
 }
 
 
-void ProjectManager::slotOpenProject( const KUrl & url )
+void ProjectManager::slotOpenProject( const QUrl & url )
 {
 	if ( m_pCurrentProject && m_pCurrentProject->url() == url )
 		return;
@@ -984,13 +1022,13 @@ void ProjectManager::slotOpenProject( const KUrl & url )
 	if ( !m_pCurrentProject->open(url) )
 	{
 		m_pCurrentProject->deleteLater();
-		m_pCurrentProject = 0l;
+		m_pCurrentProject = nullptr;
 		return;
 	}
 	{
         RecentFilesAction * rfa = static_cast<RecentFilesAction*>(KTechlab::self()->actionByName("project_open_recent"));
         if (rfa) {
-            rfa->addURL( m_pCurrentProject->url() );
+            rfa->addUrl( m_pCurrentProject->url() );
         } else {
             qWarning() << "there is no project_open_recent action in application";
         }
@@ -1013,7 +1051,7 @@ bool ProjectManager::slotCloseProject()
 		return false;
 	
 	m_pCurrentProject->deleteLater();
-	m_pCurrentProject = 0l;
+	m_pCurrentProject = nullptr;
 	updateActions();
 	emit projectClosed();
 	return true;
@@ -1026,10 +1064,9 @@ void ProjectManager::slotCreateSubproject()
 		return;
 	
 	CreateSubprojectDlg * dlg = new CreateSubprojectDlg(this);
-	dlg->exec();
+	const int accepted = dlg->exec();
 	
-	if ( dlg->accepted() )
-	{
+	if (accepted == QDialog::Accepted) {
 		ProjectItem::Type type = ProjectItem::ProgramType;
 		switch ( dlg->type() )
 		{
@@ -1043,7 +1080,7 @@ void ProjectManager::slotCreateSubproject()
 		}
 		
 		ProjectItem * subproject = new ProjectItem( currentProject(), type, this );
-		subproject->setURL( dlg->targetFile() );
+		subproject->setURL( QUrl::fromLocalFile(dlg->targetFile()) );
 		
 		currentProject()->addChild(subproject);
 		currentProject()->save();
@@ -1216,7 +1253,7 @@ void ProjectManager::slotContextMenuRequested( const QPoint& pos )
 	
     } else
 	{
-		ProcessOptions::ProcessPath::MediaType mediaType = ProcessOptions::guessMediaType( ilvItem->projectItem()->url().url() );
+		ProcessOptions::ProcessPath::MediaType mediaType = ProcessOptions::guessMediaType( ilvItem->projectItem()->url().toLocalFile() );
 		
 		switch ( ilvItem->projectItem()->type() )
 		{
@@ -1266,5 +1303,3 @@ void ProjectManager::slotContextMenuRequested( const QPoint& pos )
     }
 }
 //END class ProjectManager
-
-#include "projectmanager.moc"
