@@ -10,14 +10,12 @@
 
 #include "recentfilesaction.h"
 
-#include <kconfig.h>
-#include <kmenu.h>
-#include <kstandarddirs.h>
-#include <kurl.h>
-#include <kconfig.h>
-#include <kconfiggroup.h>
-#include <kglobal.h>
-#include <ksharedconfig.h>
+#include <KConfigGroup>
+#include <KSharedConfig>
+
+#include <QMenu>
+#include <QDir>
+#include <QUrl>
 
 RecentFilesAction::RecentFilesAction( const QString & configGroupName, const QString& text, const QObject* receiver, const char* slot, QObject* parent, const char* name )
 	: KSelectAction( text /*, 0*/ /*pix*/, parent /*, name */ )
@@ -26,17 +24,17 @@ RecentFilesAction::RecentFilesAction( const QString & configGroupName, const QSt
 
 	m_configGroupName = configGroupName;
 	m_maxItems = 10;
-	
-	m_popup = new KMenu;
+
+	m_popup = new QMenu;
 	connect(m_popup, SIGNAL(aboutToShow()), this, SLOT(menuAboutToShow()));
 	connect(m_popup, SIGNAL(triggered(QAction*)), this, SLOT(menuItemActivated(QAction*)));
 	connect( this, SIGNAL(triggered(const QString&)),
 			 this, SLOT( itemSelected( const QString& ) ) );
 
 	setMenuAccelsEnabled( false );
-	
+
 	if ( receiver )
-		connect( this, SIGNAL(urlSelected(const KUrl &)), receiver, slot );
+		connect( this, SIGNAL(urlSelected(QUrl)), receiver, slot );
 }
 
 
@@ -45,17 +43,13 @@ RecentFilesAction::~RecentFilesAction()
 	delete m_popup;
 }
 
-void RecentFilesAction::addURL( const KUrl& url )
+void RecentFilesAction::addUrl( const QUrl& url )
 {
-	if ( url.isLocalFile() && !KGlobal::dirs()->relativeLocation("tmp", url.path()).startsWith("/"))
+	if ( url.isLocalFile() && url.toLocalFile().startsWith(QDir::tempPath()))
 		return;
-	
-	QString file;
-	if ( url.isLocalFile() && url.ref().isNull() && url.query().isNull() )
-		file = url.path();
-	else
-		file = url.prettyUrl();
-	
+
+	const QString file = url.toDisplayString(QUrl::PreferLocalFile);
+
 	QStringList lst = items();
 
     // remove file if already in list
@@ -71,15 +65,15 @@ void RecentFilesAction::addURL( const KUrl& url )
     // add file to list
 	lst.prepend( file );
 	setItems( lst );
-	
+
 	saveEntries();
 }
 
 
 void RecentFilesAction::loadEntries()
 {
-	KConfig * config = KGlobal::config().data();
-	
+	KSharedConfigPtr config = KSharedConfig::openConfig();
+
 	QString     key;
 	QString     value;
 	//QString     oldGroup;
@@ -93,7 +87,7 @@ void RecentFilesAction::loadEntries()
 	for( unsigned int i = 1 ; i <= m_maxItems ; i++ )
 	{
 		key = QString( "File%1" ).arg( i );
-		value = grCfg.readEntry( key, "");
+		value = grCfg.readPathEntry( key, QString());
 
 		if (!value.isNull())
 			lst.append( value );
@@ -107,8 +101,8 @@ void RecentFilesAction::loadEntries()
 
 void RecentFilesAction::saveEntries()
 {
-	KConfig * config = KGlobal::config().data();
-	
+	KSharedConfigPtr config = KSharedConfig::openConfig();
+
 	QString     key;
 	QString     value;
 	//QString     oldGroup;
@@ -128,24 +122,24 @@ void RecentFilesAction::saveEntries()
 	}
 
 	//grCfg.setGroup( oldGroup );
-	
+
 	config->sync();
 }
 
 void RecentFilesAction::itemSelected( const QString& text )
 {
-	emit urlSelected( KUrl( text ) );
+	emit urlSelected( QUrl::fromUserInput(text) );
 }
 
 void RecentFilesAction::menuItemActivated( QAction *action )
 {
 	//emit urlSelected( KUrl(m_popup->text(id)) ); // 2018.11.21
-    emit urlSelected( KUrl(action->text()) );
+    emit urlSelected( QUrl::fromUserInput(action->text()) );
 }
 
 void RecentFilesAction::menuAboutToShow()
 {
-	KMenu *menu = m_popup;
+	QMenu *menu = m_popup;
 	menu->clear();
 	QStringList list = items();
 	QStringList::iterator end = list.end();
@@ -158,7 +152,7 @@ void RecentFilesAction::menuAboutToShow()
 void RecentFilesAction::slotClicked()
 {
 	//KAction::slotActivated(); // TODO CORRECT?
-    KAction::trigger();
+    QAction::trigger();
 }
 
 void RecentFilesAction::slotActivated(const QString& text)
@@ -180,6 +174,3 @@ void RecentFilesAction::slotActivated()
 	emit triggered( currentItem() );
 	//emit activated( currentText() ); // TODO how should this work?
 }
-
-
-#include "recentfilesaction.moc"
