@@ -12,11 +12,11 @@
 #define RECENTFILESACTION_H
 
 //#include <kactionclasses.h>
-#include <kselectaction.h>
+#include <KSelectAction>
 
 //class K3PopupMenu;
-class KUrl;
-class KMenu;
+class QUrl;
+class QMenu;
 
 /**
 Taken mainly from kdelibs/kdeui/kactionclasses.[cpp/h], author Michael Koch.
@@ -28,7 +28,7 @@ class RecentFilesAction : public KSelectAction
 	public:
 		RecentFilesAction( const QString & configGroupName, const QString & text, const QObject * receiver, const char* slot, QObject* parent, const char * name );
 		
-		~RecentFilesAction();
+		~RecentFilesAction() override;
 		
 		/**
 		 *  Loads the recent files entries from a given KConfig object.
@@ -51,7 +51,7 @@ class RecentFilesAction : public KSelectAction
 		 *
 		 *  @param url The URL of the file
 		 */
-		void addURL( const KUrl& url );
+		void addUrl( const QUrl& url );
 		
 	signals:
 		/**
@@ -59,7 +59,7 @@ class RecentFilesAction : public KSelectAction
 		 *
 		 *  @param url The URL thats the user selected.
 		 */
-		void urlSelected( const KUrl& url );
+		void urlSelected( const QUrl& url );
 		
 	protected slots:
 		void itemSelected( const QString& string );
@@ -72,7 +72,7 @@ class RecentFilesAction : public KSelectAction
 
 	protected:
 		unsigned m_maxItems;
-		KMenu * m_popup;
+		QMenu * m_popup;
 		QString m_configGroupName;
 };
 
