@@ -15,12 +15,12 @@
 #include "document.h"
 #include "gpsimprocessor.h"
 
-#include <qpointer.h>
+#include <QPointer>
 // #include <q3ptrlist.h>
 
 //#include <kate/document.h>
-#include <ktexteditor/document.h>
-#include <ktexteditor/markinterface.h>
+#include <KTextEditor/Document>
+#include <KTextEditor/MarkInterface>
 
 class GpsimDebugger;
 class SourceLine;
@@ -40,7 +40,7 @@ class TextDocument : public Document
 {
 Q_OBJECT
 public:
-	~TextDocument();
+	~TextDocument() override;
 
 	enum CodeType
 	{
@@ -50,7 +50,7 @@ public:
 		ct_hex,
 		ct_microbe
 	};
-	
+
 	enum MarkType {
 		Bookmark           = KTextEditor::MarkInterface::markType01,
 		Breakpoint         = KTextEditor::MarkInterface::markType02,
@@ -59,15 +59,16 @@ public:
 		DisabledBreakpoint = KTextEditor::MarkInterface::markType05,
 		ExecutionPoint     = KTextEditor::MarkInterface::markType06
 	};
-	
-	virtual View *createView( ViewContainer *viewContainer, uint viewAreaId, const char *name = 0l );
+
+	View *createView( ViewContainer *viewContainer, uint viewAreaId, const char *name = nullptr ) override;
+
 
 	/**
 	 * Attempts to construct a new TextDocument object and returns a pointer to
 	 * it if successful, or 0 if it failed.
 	 * @returns pointer to constructed object, or 0 if there was a problem
 	 */
-	static TextDocument *constructTextDocument( const QString& caption, const char *name = 0L );
+	static TextDocument *constructTextDocument( const QString& caption, const char *name = nullptr );
 	/**
 	 * @returns the guessed code type that this file is
 	 */
@@ -84,7 +85,7 @@ public:
 	 * @return List of bookmarks
 	 */
 	IntList bookmarkList() const;
-	
+
 	/**
 	 * Set the given lines as all breakpoints
 	 */
@@ -97,7 +98,7 @@ public:
 	 * @return List of breakpoints
 	 */
 	IntList breakpointList() const;
-	
+
 #ifndef NO_GPSIM
 	/**
 	 * Attach ourselves to the given debugger.
@@ -119,8 +120,9 @@ public:
 	virtual void clearBreakpoints();
 #endif
 	
-	virtual bool openURL(const KUrl& url);
-	void fileSave(const KUrl& url);
+	bool openURL(const QUrl& url) override;
+
+	void fileSave(const QUrl& url);
 	/**
 	 * Set the document to the given text, making the document unmodified, and
 	 * reseting the undo/redo history/
@@ -136,25 +138,26 @@ public:
 	 */
 	void guessScheme( bool allowDisable = true );
     
-	virtual void fileSave() { fileSave(url()); }
-	virtual void fileSaveAs();
-	virtual void print();
-	virtual void setModified( bool modified );
-	
-	KTextEditor::View* createKateView( QWidget *parent, const char *name = 0l );
-	
-	virtual void undo();
-	virtual void redo();
-	virtual void cut();
-	virtual void copy();
-	virtual void paste();
-	
-	virtual bool isModified() const { return m_doc->isModified(); }
-	virtual bool isUndoAvailable() const ; // { return (m_doc->undoCount() != 0); }
-	virtual bool isRedoAvailable() const ; // { return (m_doc->redoCount() != 0); }
+	void fileSave() override { fileSave(url()); }
+	void fileSaveAs() override;
+	void print() override;
+	void setModified( bool modified ) override;
+
+	KTextEditor::View* createKateView( QWidget *parent, const char *name = nullptr );
+
+	void undo() override;
+	void redo() override;
+	void cut() override;
+	void copy() override;
+	void paste() override;
+
+	bool isModified() const override { return m_doc->isModified(); }
+	bool isUndoAvailable() const override ; // { return (m_doc->undoCount() != 0); }
+	bool isRedoAvailable() const override ; // { return (m_doc->redoCount() != 0); }
 
 	void clearBookmarks();
-	virtual bool fileClose();
+	bool fileClose() override;
+
 
 	static const QPixmap* inactiveBreakpointPixmap();
 	static const QPixmap* activeBreakpointPixmap();
@@ -173,24 +176,24 @@ public:
 		HexOutput,
 		PICOutput
 	};
-	
+
 	KTextEditor::Document * kateDocument() const { return m_doc; }
-	
+
 public slots:
 	/**
 	 * @param target as ConvertToTarget
 	 */
 	void slotConvertTo( QAction *action );
-	void convertToAssembly();
-	void convertToHex();
-	void convertToPIC();
+	void convertToAssembly() override;
+	void convertToHex() override;
+	void convertToPIC() override;
 	void formatAssembly();
-	void debugRun();
-	void debugInterrupt();
-	void debugStep();
+	void debugRun() override;
+	void debugInterrupt() override;
+	void debugStep() override;
 	void debugStepOver();
 	void debugStepOut();
-	void debugStop();
+	void debugStop() override;
 	void slotInitLanguage( CodeType type );
 	/**
 	 * Called when change line / toggle marks
@@ -219,14 +222,14 @@ protected:
 	 * marks that we know about
 	 */
 	void syncBreakpoints();
-	
+
 	int m_lastDebugLineAt; // Last line with a debug point reached mark
 	bool m_bLoadDebuggerAsHLL;
 #endif
 
 	KTextEditor::Document *m_doc;
 	QPointer<TextDocument> m_pLastTextOutputTarget;
-	
+
 private slots:
 	void setLastTextOutputTarget( TextDocument * target );
 	void slotSyncModifiedStates();
@@ -237,12 +240,11 @@ private slots:
 // 	void slotSelectionmChanged(); // 2016.09.08 - moved to TextView
 
 private:
-	TextDocument( const QString& caption, const char *name = 0L );
+	TextDocument( const QString& caption, const char *name = nullptr );
 	bool m_constructorSuccessful;
 	CodeType m_guessedCodeType;
-	//Q3PtrList<KAction> m_bookmarkActions;
     QList<QAction*> m_bookmarkActions;
-	
+
 #ifndef NO_GPSIM
 	bool b_lockSyncBreakpoints; // Used to avoid calling syncMarks() when we are currently doing so
 	bool m_bOwnDebugger;
