@@ -15,15 +15,16 @@
 #include "viewiface.h"
 #include "viewcontainer.h"
 
-#include <kdebug.h>
-#include <kiconloader.h>
-#include <klocalizedstring.h>
-#include <ksqueezedtextlabel.h>
-#include <kxmlguifactory.h>
-#include <kactioncollection.h>
-
-#include <qapplication.h>
+#include <KIconLoader>
+#include <KLocalizedString>
+#include <KSqueezedTextLabel>
+#include <KXMLGUIFactory>
+#include <KActionCollection>
 
+#include <QDebug>
+#include <QApplication>
+#include <QVBoxLayout>
+#include <QPaintEvent>
 
 #include <cassert>
 
@@ -34,12 +35,12 @@ View::View( Document *document, ViewContainer *viewContainer, uint viewAreaId, c
 	  KXMLGUIClient()
 {
     setObjectName(name ? name : ("view_" + QString::number(viewAreaId)).toLatin1().data());
-	m_pFocusWidget = 0l;
+	m_pFocusWidget = nullptr;
 	m_dcopID = 0;
 	m_viewAreaId = viewAreaId;
 	m_pDocument = document;
 	p_viewContainer = viewContainer;
-	m_pViewIface = 0l;
+	m_pViewIface = nullptr;
 	
 	setFocusPolicy( Qt::ClickFocus );
 	
@@ -47,7 +48,7 @@ View::View( Document *document, ViewContainer *viewContainer, uint viewAreaId, c
 		viewArea->setView(this);
 	
 	else
-		kDebug() << k_funcinfo << " viewArea = " << viewArea <<endl;
+		qDebug() << Q_FUNC_INFO << " viewArea = " << viewArea <<endl;
 	
 	m_layout = new QVBoxLayout(this);
 	
@@ -81,7 +82,7 @@ QAction* View::actionByName( const QString& name ) const
 {
 	QAction * action = actionCollection()->action(name);
 	if ( !action )
-		kError() << k_funcinfo << "No such action: " << name << endl;
+		qCritical() << Q_FUNC_INFO << "No such action: " << name << endl;
 	return action;
 }
 
@@ -115,7 +116,7 @@ void View::setFocusWidget( QWidget * focusWidget )
 
 bool View::eventFilter( QObject * watched, QEvent * e )
 {
-// 	kDebug() << k_funcinfo << e->type() << endl;
+// 	qDebug() << Q_FUNC_INFO << e->type() << endl;
 	
 	if ( watched != m_pFocusWidget )
 		return false;
@@ -139,42 +140,42 @@ bool View::eventFilter( QObject * watched, QEvent * e )
 				ItemInterface::self()->updateItemActions();
 			}
 	
-// 			kDebug() << k_funcinfo << "Focused In\n";
+// 			qDebug() << Q_FUNC_INFO << "Focused In\n";
 			emit focused(this);
 			break;
 		}
 		
 		case QEvent::FocusOut:
 		{
-// 			kDebug() << k_funcinfo << "Focused Out.\n";
+// 			qDebug() << Q_FUNC_INFO << "Focused Out.\n";
             QFocusEvent *fe = static_cast<QFocusEvent*>(e);
 			
 			if ( QWidget * fw = qApp->focusWidget() )
 			{
 				QString fwClassName( fw->metaObject()->className() );
-// 				kDebug() << "New focus widget is \""<<fw->name()<<"\" of type " << fwClassName << endl;
+// 				qDebug() << "New focus widget is \""<<fw->name()<<"\" of type " << fwClassName << endl;
 				
 				if ( (fwClassName != "KateViewInternal") &&
 								  (fwClassName != "QViewportWidget") )
 				{
-// 					kDebug() << "Returning as a non-view widget has focus.\n";
+// 					qDebug() << "Returning as a non-view widget has focus.\n";
 					break;
 				}
 			}
 			else
 			{
-// 				kDebug() << "No widget currently has focus.\n";
+// 				qDebug() << "No widget currently has focus.\n";
 			}
 			
 			if ( fe->reason() == Qt::PopupFocusReason )
 			{
-// 				kDebug() << k_funcinfo << "Ignoring focus-out event as was a popup.\n";
+// 				qDebug() << Q_FUNC_INFO << "Ignoring focus-out event as was a popup.\n";
 				break;
 			}
 			
 			if ( fe->reason() == Qt::ActiveWindowFocusReason )
 			{
-// 				kDebug() << k_funcinfo << "Ignoring focus-out event as main window lost focus.\n";
+// 				qDebug() << Q_FUNC_INFO << "Ignoring focus-out event as main window lost focus.\n";
 				break;
 			}
 			
@@ -213,7 +214,7 @@ void View::setDCOPID( unsigned id )
 
 //BEGIN class ViewStatusBar
 ViewStatusBar::ViewStatusBar( View *view )
-	: KStatusBar(view)
+	: QStatusBar(view)
 {
 	p_view = view;
 	
@@ -221,12 +222,16 @@ ViewStatusBar::ViewStatusBar( View *view )
 	addWidget( m_modifiedLabel, 0 /*, false */ );
 	m_fileNameLabel = new KSqueezedTextLabel(this);
 	addWidget( m_fileNameLabel, 1 /*, false */ );
+    m_statusLabel = new QLabel(this);
+    m_statusLabel->setAlignment(Qt::AlignHCenter | Qt::AlignVCenter);
+    addPermanentWidget(m_statusLabel, 0);
 	
 	m_modifiedPixmap = KIconLoader::global()->loadIcon( "document-save", KIconLoader::Small );
 	m_unmodifiedPixmap = KIconLoader::global()->loadIcon( "null", KIconLoader::Small );
 	
 	connect( view->document(), SIGNAL(modifiedStateChanged()), this, SLOT(slotModifiedStateChanged()) );
-	connect( view->document(), SIGNAL(fileNameChanged(const KUrl& )), this, SLOT(slotFileNameChanged(const KUrl& )) );
+	connect( view->document(), &Document::fileNameChanged,
+	         this, &ViewStatusBar::slotFileNameChanged);
 	
 	connect( view, SIGNAL(focused(View* )), this, SLOT(slotViewFocused(View* )) );
 	connect( view, SIGNAL(unfocused()), this, SLOT(slotViewUnfocused()) );
@@ -237,6 +242,11 @@ ViewStatusBar::ViewStatusBar( View *view )
 	slotViewUnfocused();
 }
 
+void ViewStatusBar::setStatusText(const QString &statusText)
+{
+    m_statusLabel->setText(statusText);
+}
+
 
 void ViewStatusBar::slotModifiedStateChanged()
 {
@@ -244,9 +254,9 @@ void ViewStatusBar::slotModifiedStateChanged()
 }
 
 
-void ViewStatusBar::slotFileNameChanged( const KUrl &url )
+void ViewStatusBar::slotFileNameChanged( const QUrl &url )
 {
-	m_fileNameLabel->setText( url.isEmpty() ? i18n("Untitled") : url.fileName(KUrl::IgnoreTrailingSlash) );
+	m_fileNameLabel->setText( url.isEmpty() ? i18n("Untitled") : url.adjusted(QUrl::StripTrailingSlash).fileName() );
 }
 
 
@@ -288,5 +298,3 @@ void KVSSBSep::paintEvent( QPaintEvent *e )
     p.drawLine( e->rect().left(), 1, e->rect().right(), 1 );
 }
 //END  class KVSSBSep
-
-#include "view.moc"
