@@ -14,14 +14,13 @@
 #include "view.h"
 #include "viewcontainer.h"
 
-#include <kconfig.h>
-#include <kdebug.h>
-#include <kglobalsettings.h>
-#include <klocalizedstring.h>
-#include <kpushbutton.h>
-#include <ktabwidget.h>
-#include <kconfiggroup.h>
+#include <KLocalizedString>
+#include <KConfigGroup>
 
+#include <QDebug>
+#include <QHBoxLayout>
+#include <QTabWidget>
+#include <QPushButton>
 //#include <qobjectlist.h>
 
 
@@ -44,7 +43,7 @@ ViewContainer::ViewContainer( const QString & caption, QWidget * parent )
 	if ( !parent )
 	{
 		KTechlab::self()->tabWidget()->addTab( this, caption );
-		KTabWidget * tabWidget = KTechlab::self()->tabWidget();
+		QTabWidget * tabWidget = KTechlab::self()->tabWidget();
 		tabWidget->setCurrentIndex( tabWidget->indexOf(this) );
 	}
 	
@@ -81,12 +80,12 @@ View *ViewContainer::view( uint id ) const
 {
 	ViewArea *va = viewArea(id);
 	if (!va)
-		return 0l;
+		return nullptr;
 	
 	// We do not want a recursive search as ViewAreas also hold other ViewAreas
 	//QObjectList l = va->queryList( "View", 0, false, false ); // 2018.12.02
     QList<View*> l = va->findChildren<View*>();
-	View *view = 0l;
+	View *view = nullptr;
 	if ( !l.isEmpty() )
 		view = dynamic_cast<View*>(l.first());
 	//delete l;
@@ -98,7 +97,7 @@ View *ViewContainer::view( uint id ) const
 ViewArea *ViewContainer::viewArea( uint id ) const
 {
 	if ( !m_viewAreaMap.contains(id) )
-		return 0l;
+		return nullptr;
 	
 	return m_viewAreaMap[id];
 }
@@ -157,7 +156,7 @@ int ViewContainer::createViewArea( int relativeViewArea, ViewArea::Position posi
 	ViewArea *relative = viewArea(relativeViewArea);
 	if (!relative)
 	{
-		kError() << k_funcinfo << "Could not find relative view area" << endl;
+		qCritical() << Q_FUNC_INFO << "Could not find relative view area" << endl;
 		return -1;
 	}
 	
@@ -309,17 +308,16 @@ ViewArea::ViewArea( QWidget *parent, ViewContainer *viewContainer, int id, bool
     setObjectName(name);
 	p_viewContainer = viewContainer;
 	m_id = id;
-	p_view = 0l;
-	p_viewArea1 = 0l;
-	p_viewArea2 = 0l;
+	p_view = nullptr;
+	p_viewArea1 = nullptr;
+	p_viewArea2 = nullptr;
 	
 	if (id >= 0)
 		p_viewContainer->setViewAreaId( this, uint(id) );
 	
 	p_viewContainer->setIdUsed(id);
-	setOpaqueResize( KGlobalSettings::opaqueResize() );
 	
-	m_pEmptyViewArea = 0l;
+	m_pEmptyViewArea = nullptr;
 	if ( showOpenButton )
 		m_pEmptyViewArea = new EmptyViewArea( this );
 }
@@ -336,13 +334,13 @@ ViewArea *ViewArea::createViewArea( Position position, uint id, bool showOpenBut
 {
 	if (p_viewArea1 || p_viewArea2)
 	{
-		kError() << k_funcinfo << "Attempting to create ViewArea when already containing ViewAreas!" << endl;
-		return 0l;
+		qCritical() << Q_FUNC_INFO << "Attempting to create ViewArea when already containing ViewAreas!" << endl;
+		return nullptr;
 	}
 	if (!p_view)
 	{
-		kError() << k_funcinfo << "We don't have a view yet, so creating a new ViewArea is redundant" << endl;
-		return 0l;
+		qCritical() << Q_FUNC_INFO << "We don't have a view yet, so creating a new ViewArea is redundant" << endl;
+		return nullptr;
 	}
 	
 	setOrientation( ( position == Right ) ? Qt::Horizontal : Qt::Vertical );
@@ -361,7 +359,7 @@ ViewArea *ViewArea::createViewArea( Position position, uint id, bool showOpenBut
     p_view->move(QPoint());
     p_view->show();
 	p_viewArea1->setView(p_view);
-	setView( 0l );
+	setView( nullptr );
 	
 	m_id = p_viewContainer->uniqueParentId();
 	
@@ -381,10 +379,10 @@ void ViewArea::viewAreaDestroyed( QObject *obj )
 	ViewArea *viewArea = static_cast<ViewArea*>(obj);
 	
 	if ( viewArea == p_viewArea1 )
-		p_viewArea1 = 0l;
+		p_viewArea1 = nullptr;
 	
 	if ( viewArea == p_viewArea2 )
-		p_viewArea2 = 0l;
+		p_viewArea2 = nullptr;
 	
 	if ( !p_viewArea1 && !p_viewArea2 )
 		deleteLater();
@@ -395,8 +393,8 @@ void ViewArea::setView( View *view )
 {
 	if ( !view )
 	{
-		p_view = 0l;
-		setFocusProxy( 0l );
+		p_view = nullptr;
+		setFocusProxy( nullptr );
 		return;
 	}
 	
@@ -404,13 +402,13 @@ void ViewArea::setView( View *view )
 	
 	if ( p_view )
 	{
-		kError() << k_funcinfo << "Attempting to set already contained view!" << endl;
+		qCritical() << Q_FUNC_INFO << "Attempting to set already contained view!" << endl;
 		return;
 	}
 	
 	p_view = view;
 	
-// 	kDebug() << k_funcinfo << "p_view->isFocusEnabled()="<<p_view->isFocusEnabled()<<" p_view->isHidden()="<<p_view->isHidden()<<endl;
+// 	qDebug() << Q_FUNC_INFO << "p_view->isFocusEnabled()="<<p_view->isFocusEnabled()<<" p_view->isHidden()="<<p_view->isHidden()<<endl;
 	
 	connect( view, SIGNAL(destroyed()), this, SLOT(viewDestroyed()) );
 	bool hadFocus = hasFocus();
@@ -471,7 +469,7 @@ void ViewArea::saveState( KConfigGroup* config )
 	}
 	else if ( p_view && !p_view->document()->url().isEmpty() )
 	{
-		config->writePathEntry( fileKey(m_id), p_view->document()->url().prettyUrl() );
+		config->writePathEntry( fileKey(m_id), p_view->document()->url().toDisplayString(QUrl::PreferLocalFile) );
 	}
 }
 
@@ -508,7 +506,7 @@ void ViewArea::restoreState( KConfigGroup* config, int id, const QString& groupN
 		IntList contains = config->readEntry( containsKey(m_id), IntList());
 		
 		if ( contains.isEmpty() || contains.size() > 2 )
-			kError() << k_funcinfo << "Contained list has wrong size of " << contains.size() << endl;
+			qCritical() << Q_FUNC_INFO << "Contained list has wrong size of " << contains.size() << endl;
 		
 		else
 		{
@@ -537,7 +535,8 @@ void ViewArea::restoreState( KConfigGroup* config, int id, const QString& groupN
 	//config->setGroup(groupName);
 	if ( config->hasKey( fileKey(m_id) ) )
 	{
-		bool openedOk = DocManager::self()->openURL( config->readPathEntry( fileKey(m_id), "" ), this );
+		const QUrl url = QUrl::fromUserInput(config->readPathEntry(fileKey(m_id), QString()));
+		bool openedOk = DocManager::self()->openURL( url, this );
 		if (!openedOk)
 			deleteLater();
 	}
@@ -576,13 +575,13 @@ EmptyViewArea::EmptyViewArea( ViewArea * parent )
 	layout->setColumnStretch( 0, 1 );
 	layout->setColumnStretch( 2, 1 );
 	
-	KGuiItem openItem( i18n("Open Document"), "document-open" );
-	KPushButton * newDocButton = new KPushButton( openItem, this );
+	QPushButton * newDocButton = new QPushButton(QIcon::fromTheme(QStringLiteral("document-open")),
+                                                 i18n("Open Document"), this );
 	layout->addWidget( newDocButton, 1, 1 );
 	connect( newDocButton, SIGNAL(clicked()), this, SLOT(openDocument()) );
 	
-	KGuiItem cancelItem( i18n("Cancel"), "dialog-cancel" );
-	KPushButton * cancelButton = new KPushButton( cancelItem, this );
+	QPushButton * cancelButton = new QPushButton(QIcon::fromTheme(QStringLiteral("dialog-cancel")),
+                                                 i18n("Cancel"), this );
 	layout->addWidget( cancelButton, 3, 1 );
 	connect( cancelButton, SIGNAL(clicked()), m_pViewArea, SLOT(deleteLater()) );
 }
@@ -598,5 +597,3 @@ void EmptyViewArea::openDocument()
 	KTechlab::self()->openFile( m_pViewArea );
 }
 //END class EmptyViewArea
-
-#include "viewcontainer.moc"
