@@ -11,10 +11,10 @@
 #define VIEWCONTAINER_H
 
 // #include <q3dragobject.h>
-#include <qmap.h>
-#include <qsplitter.h>
-#include <qlist.h>
-#include <qpointer.h>
+#include <QMap>
+#include <QSplitter>
+#include <QList>
+#include <QPointer>
 
 class KConfigGroup;
 class KTechlab;
@@ -39,7 +39,7 @@ class EmptyViewArea : public QWidget
 	Q_OBJECT
 	public:
 		EmptyViewArea( ViewArea * parent );
-		~EmptyViewArea();
+		~EmptyViewArea() override;
 		
 	protected slots:
 		void openDocument();
@@ -65,8 +65,8 @@ public:
 		Bottom
 	};
 	
-	ViewArea( QWidget *parent, ViewContainer *viewContainer, int id, bool showOpenButton, const char * name = 0 );
-	~ViewArea();
+	ViewArea( QWidget *parent, ViewContainer *viewContainer, int id, bool showOpenButton, const char * name = nullptr );
+	~ViewArea() override;
 	
 	ViewContainer *viewContainer() const { return p_viewContainer; }
 	int id() const { return m_id; }
@@ -128,8 +128,8 @@ public:
 	 * parenting a View, with an id of 0. parent is only used if ktechlab is
 	 * null; otherwise the parent widget is ktechlab's tabWidget()
 	 */
-	ViewContainer( const QString & caption, QWidget * parent = 0 );
-	~ViewContainer();
+	ViewContainer( const QString & caption, QWidget * parent = nullptr );
+	~ViewContainer() override;
 	
 	/**
 	 * Returns the view in the ViewArea with the given id
